
-- #########################################################
-- #########################################################
-- ConfigEnv.sql
-- #########################################################
-- #########################################################

SPOOL spool.txt
WHENEVER SQLERROR EXIT SQL.SQLCODE ROLLBACK
WHENEVER OSERROR EXIT FAILURE ROLLBACK

-- #########################################################
-- #########################################################
-- VersionCheck.sql
-- #########################################################
-- #########################################################

declare
  curMajor number;
  curMinor number;
  apos number;
  npos number;
  verOk number;
  curVer varchar2(20);
  tstVer varchar2(20);
  aver varchar2(80);
begin
  aver := '14.00.00'; /*    ! */
  verOk := 0;
  select max(Major) into curMajor from DatabaseVersion;
  select max(Minor) into curMinor from DatabaseVersion where Major = curMajor;
  curVer := curMajor;
  apos := LENGTH(curVer) - 1;
  curVer := SUBSTR(curVer, 1, (apos - 1)) || '.' || SUBSTR(curVer, apos, 2) || '.' || TO_CHAR(curMinor, 'FM00');

  apos := 1;
  npos := 0;
  while ((verOk = 0) and (npos < LENGTH(aver))) loop
    npos := INSTR(aver, ',', apos);
    if (npos = 0) then
      npos := LENGTH(aver) + 1;
    end if;
    tstVer := SUBSTR(aver, apos, npos - apos);
    apos := npos + 1;
    if (SUBSTR(curVer, 1, LENGTH(tstVer)) = tstVer) then
      verOk := 1;
    end if;
  end loop;
  
  if (verOk = 0 ) then
    raise_application_error(-20000, '  [' || curVer || ']    ['|| aver ||']');
  end if;
  
end;
/

-- #########################################################
-- #########################################################
-- Fix_FacialFinDetail_AcceptDate.sql
-- #########################################################
-- #########################################################


ALTER TRIGGER TR_FACIALFINDETAIL_BU_500 DISABLE
/

CREATE OR REPLACE PROCEDURE FacialFinDetailFixAcceptDate
AS
BEGIN
  FOR REC$1 IN (SELECT fcc.AcceptDate AS CapAcceptDate, fcc.ID AS CapID 
      FROM FacialFinCaption fcc
  where (fcc.AcceptDate is not null)
  )
  LOOP
    UPDATE facialfindetail SET
      AcceptDate = REC$1.CapAcceptDate
    WHERE
    (RecordIndex = REC$1.CapID) and (AcceptDate is null) and (Reject_cls is null);   
  END LOOP;
END;
/

COMMIT WORK 
/

CALL FacialFinDetailFixAcceptDate()
/

DROP PROCEDURE FacialFinDetailFixAcceptDate
/

ALTER TRIGGER TR_FACIALFINDETAIL_BU_500 ENABLE
/

COMMIT WORK 
/


-- #########################################################
-- #########################################################
-- ALTER_TR_FACIALFINDETAIL_BI_BU_120.sql
-- #########################################################
-- #########################################################

/*   TR_FACIALFINDETAIL_BI_120, TR_FACIALFINDETAIL_BU_120*/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BI_120
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  SourceFacialAcc_CLS1$ NUMBER(10);
  DestFacialAcc_CLS1$ NUMBER(10);
  CapBuhOperationCLS1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  CapReject_cls$ NUMBER(10);
  CapRejectCause$ VARCHAR2(1000);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  BEGIN
    /*  ,    */
    select
    ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate, ffc.Reject_cls, ffc.RejectCause,
    ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
    into new$BudgetRef, CapBuhOperationCLS1$, CapClsType1$, CapAcceptDate1$, CapReject_cls$, CapRejectCause$,
    new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause  from
    FacialFinCaption ffc
    where
    ffc.id = new$RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*      */
  if (new$BuhOperationCls is null) then
    new$BuhOperationCls := CapBuhOperationCLS1$;
  END IF;
  /*      */
  if (new$ClsType is null) then
    new$ClsType := CapClsType1$;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  /*      */
  if (new$AcceptDate is null) then
    new$AcceptDate := CapAcceptDate1$;
  END IF;

  /*       */
  if (new$Reject_cls is null) then
    new$Reject_cls := CapReject_cls$;
  END IF;

  /*       */
  if (new$RejectCause is null) then
    new$RejectCause := CapRejectCause$;
  END IF;
  /*      */
  if ((new$SourceFacialAcc_CLS is null)or
  (new$DestFacialAcc_CLS is null)) then
    BEGIN
      select
      SourceFacialAcc_CLS,
      DestFacialAcc_CLS
      into
      SourceFacialAcc_CLS1$,
      DestFacialAcc_CLS1$    from
      FacialFinCaption
      where
      (new$RecordIndex=id)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$SourceFacialAcc_CLS is null) then
      new$SourceFacialAcc_CLS := SourceFacialAcc_CLS1$ ;
    END IF;
    if (new$DestFacialAcc_CLS is null) then
      new$DestFacialAcc_CLS := DestFacialAcc_CLS1$ ;

    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 14.00.00.3
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  IF (new$progindex=76) THEN
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex IN (66, 67, 76)) AND (new$DestPromise IS NOT NULL) AND
        (new$SourcePromise = new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex IN (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

  /*       */
  IF ((new$SENDERRECORDID IS NULL) AND (new$SENDERID IS NULL)) THEN
    IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
      GETTARGETCLS(NULL, new$sourcetransfertcls, NULL, new$sourcemeanstype,
      new$sourcetargetcls,new$sourcetargetcls);
    END IF;
    GETTARGETCLS(NULL, new$desttransfertcls, NULL, new$destmeanstype,
    new$desttargetcls,new$desttargetcls);
    IF (new$ProgIndex = 76) THEN
      new$SourceTargetCls := new$DestTargetCls;

    END IF;
  END IF;
  /*      */
  GetDocumentKESR(NULL, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(NULL, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode2$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
  END IF;
  if (PromiseMode2$ = 1) then
    /* source:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* source:  BudgetPromise,   Promise,   Promise */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /* dest:  BudgetPromise,   Promise,   Promise */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$NOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS,
    new$SOURCETARGETCLS,
    new$DESTTARGETCLS,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CARDNUMBER,
    new$DATEBIRTH,
    new$PAYMENTCODETYPE,
    new$CODEPURPOSE,
    new$LINENUMBER,
    new$AMOUNTISPDOC,
    new$SOURCEREGPROJECTRESULT,
    new$DESTREGPROJECTRESULT,
    new$SOURCEINCOMETARGETFUNDS,
    new$DESTINCOMETARGETFUNDS,
    new$SOURCEPAYTARGETFUNDS,
    new$DESTPAYTARGETFUNDS,
    new$SOURCEANALYTICALPARTITION,
    new$DESTANALYTICALPARTITION);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/
commit work
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_120
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (PromiseMode2$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;

    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode2$ = 1) then
    /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;

    /* source:  BudgetPromise    Promise=NULL,   Promise */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* dest:  BudgetPromise    Promise=NULL,   Promise */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$            from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* Source:  BudgetPromise -   Promise */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;

    END IF;
    /* Source:  Promise -   BudgetPromise */
    if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
      new$SourceBudgetPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  BudgetPromise -   Promise */
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  Promise -   BudgetPromise */
    if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
      new$DestBudgetPromise := null;
      new$Promise := null;

    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$SourceExecDoc := ExecID1$;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$DestExecDoc := ExecID1$;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
        new$sourceexecinnernumber := null;
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
        new$destexecinnernumber := null;
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Fix_Department_User1410.sql
-- #########################################################
-- #########################################################

/*    DepartmentCLS -> DBUsers +     DBUsers */
ALTER TRIGGER TR_DEPARTMENTCLS_BU_500 DISABLE
/
/*    */
update DepartmentCLS set
  USER_REF = null
where 
  (USER_REF is not null) and (USER_REF not in (select ID from DBUsers))
/
ALTER TRIGGER TR_DEPARTMENTCLS_BU_500 ENABLE
/
-- CREATE TRIGGER tr_DbUsers_bd_1
CREATE OR REPLACE TRIGGER TR_DBUSERS_ID
  INSTEAD OF DELETE
  ON DBUSERS
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DBUSERS_BD)
-- - - - - - - - - - - - -

        --    SYSDBA
        if (:old.id = 0) then
                RaiseException('EX_CANTDELETETHIS');
        end if;

-- - - - - - - - - - - - -
-- BD_1 (TR_DBUSERS_BD_1)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  delete from User_Workplaces
  where Users_ref = :old.id;

  delete from ReportsPermissions
  where Userid = :old.id;

  delete from UsersInGroups
  where UserRef = :old.id;

  delete from UsersRights
  where UserRef = :old.id;

  delete from DualRights
  where (UserRef = :old.id) and (IsGroup = 0);

  delete from SysNotifyHit
  where UserRef = :old.id;
    
  /*    DepartmentCLS */
  update DepartmentCLS set
  USER_REF = null
  where USER_REF = :old.id;  

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_DBUSERS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_10 (TR_DBUSERS_AD_10)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*    RemoteClients  DBUsers */
  if (:old.RemoteClientRef is not null) then
    SELECT COUNT(dbu.ID ) INTO CNT$1
    from DBUsers dbu where (dbu.RemoteClientRef = :old.RemoteClientRef) AND (ROWNUM = 1);
    /*     DBUsers     RemoteClient,   ,     */
    if (not (CNT$1<> 0)) then
      delete from RemoteClient where ID = :old.RemoteClientRef;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AD_20 (TR_DBUSERS_AD_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*         DBUsers */
  delete from LayerData
  where LayerRef in(select ID from Layers where Alias in('..','..')) and STRFIELD00 = :old.UserName;
  delete from LayerData
  where LayerRef = (select ID from Layers where Alias = '..') and STRFIELD01 = :old.UserName;
  delete from LayerData
  where LayerRef = (select ID from Layers where Alias = '..') and STRFIELD02 = :old.UserName;

-- - - - - - - - - - - - -
-- AD_30 (tr_dbusers_ad_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  update DepartmentCls set
  User_Ref = null
  where
  User_Ref = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_DBUSERS_AD_500)
-- - - - - - - - - - - - -

/*      */
  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
       values(100,:old.ID, sysdate);

END;
/
  
  
COMMIT WORK 
/


-- #########################################################
-- #########################################################
-- Alter_tr_FacialFinCaption_bu_0.sql
-- #########################################################
-- #########################################################

/*  ,           , ..       ,   */
-- CREATE TRIGGER TR_FACIALFINCAPTION_BU
CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CODEPURPOSE FACIALFINCAPTION.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$DOCORDERREF FACIALFINCAPTION.DOCORDERREF%TYPE := :NEW.DOCORDERREF;
  new$DOCTYPE FACIALFINCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DESTTARGETCLS FACIALFINCAPTION.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  Dummy$ NUMBER(10);
  ParentAcceptDate$ NUMBER;
  ParentReject_CLS$ NUMBER(10);
  ParentRejectCause$ VARCHAR2(255);
  ParentTREASUARYDOCSTATECLS$ NUMBER(10);
  ParentDOCSTATEREF$ NUMBER(10);
  ParentSOURCEACCOUNT$ NUMBER(10);
  ParentDESTACCOUNT$ NUMBER(10);
  ParentREESTR_REF$ NUMBER(10);
  SourcePromiseAccepted$ NUMBER(10);
  DestPromiseAccepted$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  DetCount1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  if (new$credit is null)then 
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then 
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then 
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then 
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then 
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then 
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then 
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;
  END IF;
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;
          
    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;
              
      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;
                  
        else
          new$SourceType := -1;
          new$DestType := -1;
                  
        END IF;
      END IF;  
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber1$); 
    if (DocNumber1$ is null) then 
      new$DepartmentCls:= 0;
          
    else 
      new$DepartmentCls:= DocNumber1$;
      
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount1$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then 
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */

  else
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_FACIALFINCAPTION_BU_10)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$IntegratedDocRef is not null) then
    /*           ,       */
    /*    */
    if (((new$AcceptDate = :old.AcceptDate)or((new$AcceptDate is null)and(:old.AcceptDate is null)))
    and((new$Reject_CLS = :old.Reject_CLS)or((new$Reject_CLS is null)and(:old.Reject_CLS is null)))
    and((new$RejectCause = :old.RejectCause)or((new$RejectCause is null)and(:old.RejectCause is null)))
    and((new$TREASUARYDOCSTATECLS = :old.TREASUARYDOCSTATECLS)or((new$TREASUARYDOCSTATECLS is null)and(:old.TREASUARYDOCSTATECLS is null)))
    and((new$DOCSTATEREF = :old.DOCSTATEREF)or((new$DOCSTATEREF is null)and(:old.DOCSTATEREF is null)))
    and((new$REESTR_REF = :old.REESTR_REF)or((new$REESTR_REF is NULL)and(:old.REESTR_REF is NULL)))
    and(new$SOURCEACCOUNT = :old.SOURCEACCOUNT)
    and(new$DESTACCOUNT = :old.DESTACCOUNT)
    ) then
      new$AcceptDate := :old.AcceptDate;

    Else
      BEGIN
        select
        fc.AcceptDate, fc.Reject_CLS, fc.RejectCause, fc.TREASUARYDOCSTATECLS, fc.DOCSTATEREF,
        fc.REESTR_REF,fc.SOURCEACCOUNT, fc.DESTACCOUNT
        into
        ParentAcceptDate$, ParentReject_CLS$, ParentRejectCause$, ParentTREASUARYDOCSTATECLS$,
        ParentDOCSTATEREF$,ParentREESTR_REF$,ParentSOURCEACCOUNT$,ParentDESTACCOUNT$       from
        FacialFinCaption fc
        where
        (fc.id = new$IntegratedDocRef)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (((new$AcceptDate = ParentAcceptDate$)or((new$AcceptDate is null)and(ParentAcceptDate$ is null)))
      and((new$Reject_CLS = ParentReject_CLS$)or((new$Reject_CLS is null)and(ParentReject_CLS$ is null)))
      and((new$RejectCause = ParentRejectCause$)or((new$RejectCause is null)and(ParentRejectCause$ is null)))
      and((new$TREASUARYDOCSTATECLS = ParentTREASUARYDOCSTATECLS$)or((new$TREASUARYDOCSTATECLS is null)and(ParentTREASUARYDOCSTATECLS$ is null)))
      and((new$DOCSTATEREF = ParentDOCSTATEREF$)or((new$DOCSTATEREF is null)and(ParentDOCSTATEREF$ is null)))
      and((new$REESTR_REF = ParentREESTR_REF$)or((new$REESTR_REF is NULL)and(ParentREESTR_REF$ is NULL)))
      and(new$SOURCEACCOUNT = ParentSOURCEACCOUNT$)
      and(new$DESTACCOUNT = ParentDESTACCOUNT$)
      ) then
        new$AcceptDate := ParentAcceptDate$;

      Else
        RaiseException('EX_CANNOTUPDATECHILDDOC');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINCAPTION_BU_200)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  if (new$reject_cls is null and :old.reject_cls is not null) then
    /*   ,        */
    FOR REC$1 IN (      select SourcePromise AS SourcePromise, SourceBudgetPromise AS SourceBudgetPromise, DestPromise AS DestPromise, DestBudgetPromise
     AS DestBudgetPromise       from FacialFinDetail
    where RecordIndex = new$id
    )
    LOOP
      if ((REC$1.SourcePromise is not null) or (REC$1.SourceBudgetPromise is not null)) then
        BEGIN
          /*     */
          select Accepted         into SourcePromiseAccepted$ from PaymentSchedule
          where ANumber = REC$1.SourcePromise  and InnerPromiseNum = REC$1.SourceBudgetPromise

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;

      if ((REC$1.DestPromise is not null) or (REC$1.DestBudgetPromise is not null)) then
        BEGIN
          /*     */
          select Accepted         into DestPromiseAccepted$ from PaymentSchedule
          where ANumber = REC$1.DestPromise  and InnerPromiseNum = REC$1.DestBudgetPromise

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;

      /*        */
      if (((REC$1.SourceBudgetPromise is not null) or (REC$1.DestBudgetPromise is not null))
      and ((SourcePromiseAccepted$ <> 1) or (DestPromiseAccepted$ <> 1)))
      then
        RaiseException('Ex_BP_Rejected');
      END IF;
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;

  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);

  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    AUTOSANCTION = new$AUTOSANCTION,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    REJECTCAUSE = new$REJECTCAUSE,
    CODEPURPOSE = new$CODEPURPOSE,
    DOCORDERREF = new$DOCORDERREF,
    DOCTYPE = new$DOCTYPE,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_FACIALFINCAPTION_AU_10)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 72) then /*   */
    if (((new$AcceptDate = :old.AcceptDate)or((new$AcceptDate is null)and(:old.AcceptDate is null)))
    and((new$Reject_CLS = :old.Reject_CLS)or((new$Reject_CLS is null)and(:old.Reject_CLS is null)))
    and((new$RejectCause = :old.RejectCause)or((new$RejectCause is null)and(:old.RejectCause is null)))
    and((new$TREASUARYDOCSTATECLS = :old.TREASUARYDOCSTATECLS)or((new$TREASUARYDOCSTATECLS is null)and(:old.TREASUARYDOCSTATECLS is null)))
    and((new$DOCSTATEREF = :old.DOCSTATEREF)or((new$DOCSTATEREF is null)and(:old.DOCSTATEREF is null)))
    and((new$REESTR_REF = :old.REESTR_REF)or((new$REESTR_REF is NULL)and(:old.REESTR_REF is NULL)))
    and(new$SOURCEACCOUNT = :old.SOURCEACCOUNT)
    and(new$DESTACCOUNT = :old.DESTACCOUNT)
    ) then
      Dummy$ := 0;

    Else
      /*    ,      */
      update FacialFinCaption set
      AcceptDate = new$AcceptDate,
      Reject_CLS = new$Reject_CLS,
      RejectCause = new$RejectCause,
      TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
      DOCSTATEREF = new$DOCSTATEREF,
      REESTR_REF = new$REESTR_REF,
      SOURCEACCOUNT = new$SOURCEACCOUNT,
      DESTACCOUNT = new$DESTACCOUNT
      where
      IntegratedDocRef = new$id;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    ,  ,     ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    (RecordIndex = new$id) and (Reject_cls is null);
  END IF;

  if ((new$Reject_cls <> :old.Reject_cls)or((new$Reject_cls is not null)and(:old.Reject_cls is null))
  or((new$Reject_cls is null)and(:old.Reject_cls is not null))) then
    update facialfindetail set
    Reject_cls = new$Reject_cls,
    AcceptDate = null,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;

  if ((new$RejectCause <> :old.RejectCause)or((new$RejectCause is not null)and(:old.RejectCause is null))
  or((new$RejectCause is null)and(:old.RejectCause is not null))) then
    update facialfindetail set
    RejectCause = new$RejectCause,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
commit work
/


-- #########################################################
-- #########################################################
-- Alter_VATPercent.sql
-- #########################################################
-- #########################################################

/*      ESTIMATE.VATPercent  "0",   "NULL".  61023 */
-- ALTER TRIGGER TR_Estimate_BI
CREATE OR REPLACE TRIGGER TR_ESTIMATE_BI
  BEFORE INSERT
  ON ESTIMATE
  FOR EACH ROW
DECLARE
  TempFacialAcc_CLS1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ESTIMATE_BI)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if  (:new.FacialAcc_Cls is null) then
    BEGIN
      select FacialAcc_Cls    into TempFacialAcc_CLS1$ from Agreements
      where (ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    :new.FacialAcc_Cls := TempFacialAcc_CLS1$;
     
  END IF;
  if (:new.ProductCls is null) then 
    :new.ProductCls := 0;
  END IF;
  if (:new.Amount is null) then 
    :new.amount := 0;
  END IF;
  if (:new.Price is null) then 
    :new.Price := 0;
  END IF;
  if (:new.Cost is null) then 
    :new.Cost := 0;
  END IF;
  if (:new.VATSumma is null) then 
    :new.VATSumma := 0;
  END IF;
  if (:new.Summa is null) then 
    :new.Summa := 0;
  END IF;
  if (:new.FinSumma is null) then 
    :new.FinSumma := 0;
  END IF;
  if (:new.PriceVAT is null) then 
    :new.PriceVAT := 0;
  END IF;
  BEGIN

    /*  ,    */
    select agr.BudgetRef      into :new.BudgetRef from Agreements agr
    where agr.ID = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_10 (TR_ESTIMATE_BI_10)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (:new.senderId is null) then
    :new.senderIdKey := -1;
  else
    :new.senderIdKey := :new.senderId;
  end if;

  if (:new.SenderRecordID is null)then
    :new.SenderRecordIDKey := :new.ID;
  else
    :new.SenderRecordIDKey := :new.SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_20 (TR_ESTIMATE_BI_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if ((:new.COST < 0) or (:new.SUMMA < 0)) then
    RaiseException('EX_EXECDOCEST_NEGATIVECOST');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_ESTIMATE_BI_500)
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;

END;
/
-- ALTER TRIGGER TR_Estimate_BU
CREATE OR REPLACE TRIGGER TR_ESTIMATE_BU
  BEFORE UPDATE
  ON ESTIMATE
  FOR EACH ROW
DECLARE
  TempFacialAcc_CLS1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ESTIMATE_BU)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  if  (:new.FacialAcc_Cls is null) then
    BEGIN
      select FacialAcc_Cls    into TempFacialAcc_CLS1$ from Agreements
      where (ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    :new.FacialAcc_Cls := TempFacialAcc_CLS1$;
     
  END IF;
  if (:new.ProductCls is null) then 
    :new.ProductCls := 0;
  END IF;
  if (:new.Amount is null) then 
    :new.amount := 0;
  END IF;
  if (:new.Price is null) then 
    :new.Price := 0;
  END IF;
  if (:new.Cost is null) then 
    :new.Cost := 0;
  END IF;
  if (:new.VATSumma is null) then 
    :new.VATSumma := 0;
  END IF;
  if (:new.Summa is null) then 
    :new.Summa := 0;
  END IF;
  if (:new.FinSumma is null) then 
    :new.FinSumma := 0;
  END IF;
  if (:new.PriceVAT is null) then 
    :new.PriceVAT := 0;
  END IF;
  /*     */
  if (:new.BudgetRef <> :old.BudgetRef) then
    if ( not((:new.BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_ESTIMATE_BU_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if ((:new.COST < 0) or (:new.SUMMA < 0)) then
    RaiseException('EX_EXECDOCEST_NEGATIVECOST');
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_Estimate_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (:new.RecordIndex <> :old.RecordIndex) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ESTIMATE_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (:NEW.RVersion IS NULL) THEN
      :NEW.RVersion := 1;
   ELSE
      IF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         :NEW.RVersion := :OLD.RVersion;
      ELSE
         :NEW.RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_TR_PAYMENTSCHEDULE_BI_1.sql
-- #########################################################
-- #########################################################

/*   "        / "
      SummaYear1  PaymentSchedule  ,       ,     . 
      Summa        ... ,  ,       . 
     Summa  PaymentSchedule   (ProgIndex=317, 318) .
*/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_BI_1
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_II
  INSTEAD OF INSERT
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$PAYMENTCODETYPE PAYMENTSCHEDULE.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$REGPROJECTRESULT PAYMENTSCHEDULE.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
  new$PAYTARGETFUNDS PAYMENTSCHEDULE.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$ANALYTICALPARTITION PAYMENTSCHEDULE.ANALYTICALPARTITION%TYPE := :NEW.ANALYTICALPARTITION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PreviousInner$ NUMBER(10);
  AdjDocNum$ NUMBER(10);
  Tmp$ NUMBER(10);
  InnerNumber_parent$ NUMBER(10);
  InnerNumber_child$ NUMBER(10);
  M011$ NUMBER;
  M021$ NUMBER;
  M031$ NUMBER;
  M041$ NUMBER;
  M051$ NUMBER;
  M061$ NUMBER;
  M071$ NUMBER;
  M081$ NUMBER;
  M091$ NUMBER;
  M101$ NUMBER;
  M111$ NUMBER;
  M121$ NUMBER;
  Q11$ NUMBER;
  Q21$ NUMBER;
  Q31$ NUMBER;
  Q41$ NUMBER;
  S5$ NUMBER;
  S21$ NUMBER;
  S31$ NUMBER;
  S41$ NUMBER;
  SOther1$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_PAYMENTSCHEDULE_BI)
-- Version 14.00.00.4
-- - - - - - - - - - - - -

  /*   13.10.01*/
  IF (new$id IS NULL) THEN
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$Accepted IS NULL) THEN
    new$Accepted := 1;
  END IF;
  IF (new$PromiseType IS NULL) THEN
    new$PromiseType := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN
    new$KFSR := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN
    new$KVSR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN
    new$KCSR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN
    new$KVR := 0;
  END IF;
  IF (new$SubKESR IS NULL) THEN
    new$SubKESR := 0;
  END IF;
  IF (new$AssignmentKind IS NULL) THEN
    new$AssignmentKind := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN
    new$DirectionCls := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$Region IS NULL) THEN
    new$Region := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN
    new$MeansType := 0;
  END IF;
  IF (new$FinSource IS NULL) THEN
    new$FinSource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN
    new$FinType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN
    new$Fact := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL) THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  IF (new$Month01 IS NULL) THEN
    new$Month01 := 0;
  END IF;
  IF (new$Month02 IS NULL) THEN
    new$Month02 := 0;
  END IF;
  IF (new$Month03 IS NULL) THEN
    new$Month03 := 0;
  END IF;
  IF (new$Month04 IS NULL) THEN
    new$Month04 := 0;
  END IF;
  IF (new$Month05 IS NULL) THEN
    new$Month05 := 0;
  END IF;
  IF (new$Month06 IS NULL) THEN
    new$Month06 := 0;
  END IF;
  IF (new$Month07 IS NULL) THEN
    new$Month07 := 0;
  END IF;
  IF (new$Month08 IS NULL) THEN
    new$Month08 := 0;
  END IF;
  IF (new$Month09 IS NULL) THEN
    new$Month09 := 0;
  END IF;
  IF (new$Month10 IS NULL) THEN
    new$Month10 := 0;
  END IF;
  IF (new$Month11 IS NULL) THEN
    new$Month11 := 0;
  END IF;
  IF (new$Month12 IS NULL) THEN
    new$Month12 := 0;
  END IF;
  IF (new$Quarter1 IS NULL) THEN
    new$Quarter1 := 0;
  END IF;
  IF (new$Quarter2 IS NULL) THEN
    new$Quarter2 := 0;
  END IF;
  IF (new$Quarter3 IS NULL) THEN
    new$Quarter3 := 0;
  END IF;
  IF (new$Quarter4 IS NULL) THEN
    new$Quarter4 := 0;
  END IF;
  IF (new$Summa IS NULL) THEN
    new$Summa := 0;
  END IF;
  IF (new$Month01Delta IS NULL) THEN
    new$Month01Delta := 0;
  END IF;
  IF (new$Month02Delta IS NULL) THEN
    new$Month02Delta := 0;
  END IF;
  IF (new$Month03Delta IS NULL) THEN
    new$Month03Delta := 0;
  END IF;
  IF (new$Month04Delta IS NULL) THEN
    new$Month04Delta := 0;
  END IF;
  IF (new$Month05Delta IS NULL) THEN
    new$Month05Delta := 0;
  END IF;
  IF (new$Month06Delta IS NULL) THEN
    new$Month06Delta := 0;
  END IF;
  IF (new$Month07Delta IS NULL) THEN
    new$Month07Delta := 0;
  END IF;
  IF (new$Month08Delta IS NULL) THEN
    new$Month08Delta := 0;
  END IF;
  IF (new$Month09Delta IS NULL) THEN
    new$Month09Delta := 0;
  END IF;
  IF (new$Month10Delta IS NULL) THEN
    new$Month10Delta := 0;
  END IF;
  IF (new$Month11Delta IS NULL) THEN
    new$Month11Delta := 0;
  END IF;
  IF (new$Month12Delta IS NULL) THEN
    new$Month12Delta := 0;
  END IF;
  IF (new$Quarter1Delta IS NULL) THEN
    new$Quarter1Delta := 0;
  END IF;
  IF (new$Quarter2Delta IS NULL) THEN
    new$Quarter2Delta := 0;
  END IF;
  IF (new$Quarter3Delta IS NULL) THEN
    new$Quarter3Delta := 0;
  END IF;
  IF (new$Quarter4Delta IS NULL) THEN
    new$Quarter4Delta := 0;
  END IF;
  IF (new$SummaDelta IS NULL) THEN
    new$SummaDelta := 0;
  END IF;
  IF (new$SummaPreviousYear IS NULL) THEN
    new$SummaPreviousYear := 0;
  END IF;
  IF (new$SummaFinPreviousYear IS NULL) THEN
    new$SummaFinPreviousYear := 0;
  END IF;
  IF (new$SummaYear2 IS NULL) THEN
    new$SummaYear2 := 0;
  END IF;
  IF (new$SummaYear3 IS NULL) THEN
    new$SummaYear3 := 0;
  END IF;
  IF (new$SummaYear4 IS NULL) THEN
    new$SummaYear4 := 0;
  END IF;
  IF (new$SummaOtherYears IS NULL) THEN
    new$SummaOtherYears := 0;
  END IF;
  IF (new$SummaYear2Delta IS NULL) THEN
    new$SummaYear2Delta := 0;
  END IF;
  IF (new$SummaYear3Delta IS NULL) THEN
    new$SummaYear3Delta := 0;
  END IF;
  IF (new$SummaYear4Delta IS NULL) THEN
    new$SummaYear4Delta := 0;
  END IF;
  IF (new$SummaOtherYearsDelta IS NULL) THEN
    new$SummaOtherYearsDelta := 0;
  END IF;
  /*   ,        */
  IF (new$ProgIndex = 304 AND new$RecordIndex IS NOT NULL) THEN
    SELECT COUNT(*) INTO CNT$1
    FROM AgreementSteps s WHERE (s.Id = new$RecordIndex AND s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    IF (NOT (CNT$1<> 0)) THEN
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*       */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    IF (new$ProgIndex IN (304,314,317,318)) THEN
      BEGIN
        SELECT a.BudgetRef       INTO new$BudgetRef FROM Agreements a
        WHERE a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    ELSE
      IF (new$ProgIndex = 308) THEN
        BEGIN
          SELECT e.BudgetRef
          INTO new$BudgetRef       FROM ExecutionDocumentsCaption e
          WHERE e.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;
    END IF;
  END IF;

  /*    ,     ,      */
  IF (new$AdjustmentRef IS NULL) THEN
    select g_shared.nextval into new$InnerPromiseNum from dual;
    new$ParentNumber := NULL;

  ELSE
    /*      , ..     */
    IF (new$Accepted = 0) THEN
      BEGIN
        SELECT
        InnerPromiseNum, ANumber
        INTO PreviousInner$, AdjDocNum$       FROM Paymentschedule
        WHERE ID = new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    ELSE
      BEGIN
        /*          */
        SELECT
        InnerPromiseNum, ANumber
        INTO PreviousInner$, AdjDocNum$       FROM Paymentschedule
        WHERE ID = new$AdjustmentRef AND LastAccepted = 1 AND LastAdjustment = 1
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (PreviousInner$ IS NULL) THEN
        RaiseException('EX_NotFindInnerNumber');
      END IF;
    END IF;
    new$InnerPromiseNum := PreviousInner$;
    new$ParentNumber := AdjDocNum$;

  END IF;
  /*    ,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0))
  THEN
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  IF (new$ANumber IS NOT NULL) THEN
    SELECT COUNT(                    id
    ) INTO CNT$2
    FROM
    PaymentSchedule ps
    WHERE
    (                    (ps.ANumber = new$ANumber)
    AND
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    IF ((CNT$2<> 0)) THEN
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;

  /*    */
  IF ((new$SENDERRECORDID IS NULL) AND (new$SENDERID IS NULL)) THEN
    GETTARGETCLS(NULL, new$transfertcls, NULL, new$meanstype,
    new$targetcls,new$targetcls);
  END IF;
  /*   */
  GetDocumentKESR(NULL, new$SubKESR, new$KESR, new$BudgetRef,new$KESR);

-- - - - - - - - - - - - -
-- BI_1 (TR_PAYMENTSCHEDULE_BI_1)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  /*   1.0*/    
  new$Quarter1 := new$Month01 + new$Month02 + new$Month03;
  new$Quarter2 := new$Month04 + new$Month05 + new$Month06;
  new$Quarter3 := new$Month07 + new$Month08 + new$Month09;
  new$Quarter4 := new$Month10 + new$Month11 + new$Month12;
  if (new$ProgIndex not in (317,318)) then
    new$Summa := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_PAYMENTSCHEDULE_BI_10)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*   13.10.01*/

  /*    .*/
  if (new$InnerPromiseNum is null) then
    RaiseException('EX_BP_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from PaymentSchedule
  where (InnerPromiseNum = new$InnerPromiseNum)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;

  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;

  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;
  /*     */
  if (new$AdjustmentRef is not null) then
    /*       */
    select count(ID)
    into Tmp$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (AcceptDate is not null)
    ;
    /*     ,  */
    if (Tmp$ = 0) then
      RaiseException('EX_BP_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_BP_AdjustDuplicate');
    END IF;
    /*   - ,  ,       */
    if (new$ProgIndex in (304, 314)) then
      BEGIN
        /*     */
        select a.InnerNumber
        into InnerNumber_child$             from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN
        /*       */
        select a.InnerNumber
        into InnerNumber_parent$             from PaymentSchedule ps
        left join Agreements a on (a.Id = ps.AgreementRef)
        where (ps.Id = new$AdjustmentRef)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*      */
      if (InnerNumber_parent$ <> InnerNumber_child$) then
        RaiseException('EX_PROMISE_ADJ_INCORRECT');
      END IF;
    else
      if (new$ProgIndex = 308) then
        BEGIN
          /*     */
          select edc.InnerNumber
          into InnerNumber_child$             from ExecutionDocumentsCaption edc
          where edc.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        BEGIN
          /*       */
          select edc.InnerNumber
          into InnerNumber_parent$             from PaymentSchedule ps
          left join ExecutionDocumentsCaption edc on (edc.id=ps.ExecutionRef)
          where (ps.Id = new$AdjustmentRef)
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        /*      */
        if (InnerNumber_parent$ <> InnerNumber_child$) then
          RaiseException('EX_PROMISE_ADJ_INCORRECT');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_PAYMENTSCHEDULE_BI_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M011$, M021$, M031$, M041$, M051$, M061$, M071$, M081$, M091$, M101$, M111$, M121$,
      Q11$, Q21$, Q31$, Q41$, S5$, S21$, S31$, S41$, SOther1$         from
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    new$Month01Delta := new$Month01 - M011$;
    new$Month02Delta := new$Month02 - M021$;
    new$Month03Delta := new$Month03 - M031$;
    new$Month04Delta := new$Month04 - M041$;
    new$Month05Delta := new$Month05 - M051$;
    new$Month06Delta := new$Month06 - M061$;
    new$Month07Delta := new$Month07 - M071$;
    new$Month08Delta := new$Month08 - M081$;
    new$Month09Delta := new$Month09 - M091$;
    new$Month10Delta := new$Month10 - M101$;
    new$Month11Delta := new$Month11 - M111$;
    new$Month12Delta := new$Month12 - M121$;
    new$Quarter1Delta := new$Quarter1 - Q11$;
    new$Quarter2Delta := new$Quarter2 - Q21$;
    new$Quarter3Delta := new$Quarter3 - Q31$;
    new$Quarter4Delta := new$Quarter4 - Q41$;
    new$SummaDelta := new$Summa - S5$;
    new$SummaYear2Delta := new$SummaYear2 - S21$;
    new$SummaYear3Delta := new$SummaYear3 - S31$;
    new$SummaYear4Delta := new$SummaYear4 - S41$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther1$;

  else    /*        */
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;

  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_PAYMENTSCHEDULE_BI_200)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*      */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_PAYMENTSCHEDULE_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PAYMENTSCHEDULE (
    ID,
    ANUMBER,
    PARENTNUMBER,
    KFSR,
    KESR,
    KVSR,
    KCSR,
    KVR,
    MONTH01,
    MONTH02,
    MONTH03,
    MONTH04,
    MONTH05,
    MONTH06,
    MONTH07,
    MONTH08,
    MONTH09,
    MONTH10,
    MONTH11,
    MONTH12,
    SUMMA,
    REGION,
    SUBKESR,
    MEANSTYPE,
    FINSOURCE,
    FINTYPE,
    FACT,
    FACIALACC_CLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    ACCEPTDATE,
    LASTADJUSTMENT,
    ACCEPTED,
    LASTACCEPTED,
    PROMISETYPE,
    ADJUSTMENTREF,
    SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR,
    QUARTER1,
    QUARTER2,
    QUARTER3,
    QUARTER4,
    RECORDINDEX,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DIRECTIONCLS,
    RVERSION,
    BUHOPERATIONCLS,
    MONTH01DELTA,
    MONTH02DELTA,
    MONTH03DELTA,
    MONTH04DELTA,
    MONTH05DELTA,
    MONTH06DELTA,
    MONTH07DELTA,
    MONTH08DELTA,
    MONTH09DELTA,
    MONTH10DELTA,
    MONTH11DELTA,
    MONTH12DELTA,
    QUARTER1DELTA,
    QUARTER2DELTA,
    QUARTER3DELTA,
    QUARTER4DELTA,
    SUMMADELTA,
    NOTE,
    FINYEAR,
    SUMMAYEAR2,
    SUMMAYEAR3,
    SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA,
    ASSIGNMENTKIND,
    TRANSFERTCLS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXECUTIONREF,
    INNERPROMISENUM,
    ADJUSTMENTNUMBER,
    PROMISENUMBER,
    SUBSIDYCLS,
    AGREEMENTREF,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    PROGINDEX,
    INVESTOBJECT,
    SUMMAYEAR4,
    SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    OLDNUMBER,
    PAYMENTCODETYPE,
    REGPROJECTRESULT,
    PAYTARGETFUNDS,
    ANALYTICALPARTITION
  ) VALUES (
    new$ID,
    new$ANUMBER,
    new$PARENTNUMBER,
    new$KFSR,
    new$KESR,
    new$KVSR,
    new$KCSR,
    new$KVR,
    new$MONTH01,
    new$MONTH02,
    new$MONTH03,
    new$MONTH04,
    new$MONTH05,
    new$MONTH06,
    new$MONTH07,
    new$MONTH08,
    new$MONTH09,
    new$MONTH10,
    new$MONTH11,
    new$MONTH12,
    new$SUMMA,
    new$REGION,
    new$SUBKESR,
    new$MEANSTYPE,
    new$FINSOURCE,
    new$FINTYPE,
    new$FACT,
    new$FACIALACC_CLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$ACCEPTDATE,
    new$LASTADJUSTMENT,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$PROMISETYPE,
    new$ADJUSTMENTREF,
    new$SUMMAPREVIOUSYEAR,
    new$SUMMAFINPREVIOUSYEAR,
    new$QUARTER1,
    new$QUARTER2,
    new$QUARTER3,
    new$QUARTER4,
    new$RECORDINDEX,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DIRECTIONCLS,
    new$RVERSION,
    new$BUHOPERATIONCLS,
    new$MONTH01DELTA,
    new$MONTH02DELTA,
    new$MONTH03DELTA,
    new$MONTH04DELTA,
    new$MONTH05DELTA,
    new$MONTH06DELTA,
    new$MONTH07DELTA,
    new$MONTH08DELTA,
    new$MONTH09DELTA,
    new$MONTH10DELTA,
    new$MONTH11DELTA,
    new$MONTH12DELTA,
    new$QUARTER1DELTA,
    new$QUARTER2DELTA,
    new$QUARTER3DELTA,
    new$QUARTER4DELTA,
    new$SUMMADELTA,
    new$NOTE,
    new$FINYEAR,
    new$SUMMAYEAR2,
    new$SUMMAYEAR3,
    new$SUMMAYEAR2DELTA,
    new$SUMMAYEAR3DELTA,
    new$ASSIGNMENTKIND,
    new$TRANSFERTCLS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXECUTIONREF,
    new$INNERPROMISENUM,
    new$ADJUSTMENTNUMBER,
    new$PROMISENUMBER,
    new$SUBSIDYCLS,
    new$AGREEMENTREF,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$PROGINDEX,
    new$INVESTOBJECT,
    new$SUMMAYEAR4,
    new$SUMMAOTHERYEARS,
    new$SUMMAYEAR4DELTA,
    new$SUMMAOTHERYEARSDELTA,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS,
    new$OLDNUMBER,
    new$PAYMENTCODETYPE,
    new$REGPROJECTRESULT,
    new$PAYTARGETFUNDS,
    new$ANALYTICALPARTITION);

-- - - - - - - - - - - - -
-- AI_10 (TR_PAYMENTSCHEDULE_AI_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*      */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
    if (new$LastAccepted = 1) then
      update PaymentSchedule set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_PAYMENTSCHEDULE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 113) and (RecordID = new$ID);

END;
/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_BU_1
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_IU
  INSTEAD OF UPDATE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$PAYMENTCODETYPE PAYMENTSCHEDULE.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$REGPROJECTRESULT PAYMENTSCHEDULE.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
  new$PAYTARGETFUNDS PAYMENTSCHEDULE.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$ANALYTICALPARTITION PAYMENTSCHEDULE.ANALYTICALPARTITION%TYPE := :NEW.ANALYTICALPARTITION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  previousAccept$ NUMBER(10);
  previousAcceptDate$ NUMBER(10);
  M011$ NUMBER;
  M021$ NUMBER;
  M031$ NUMBER;
  M041$ NUMBER;
  M051$ NUMBER;
  M061$ NUMBER;
  M071$ NUMBER;
  M081$ NUMBER;
  M091$ NUMBER;
  M101$ NUMBER;
  M111$ NUMBER;
  M121$ NUMBER;
  Q11$ NUMBER;
  Q21$ NUMBER;
  Q31$ NUMBER;
  Q41$ NUMBER;
  S5$ NUMBER;
  S21$ NUMBER;
  S31$ NUMBER;
  S41$ NUMBER;
  SOther1$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PAYMENTSCHEDULE_BU)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*   2.4*/
  /*    -*/
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then
    new$KFSR := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then
    new$AssignmentKind := 0;
  END IF;

  if (new$DirectionCls is null) then
    new$DirectionCls := 0;
  END IF;

  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$Month01 is null) then
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then
    new$SummaDelta := 0;
  END IF;
  if (new$SummaPreviousYear is null) then
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then
    new$SummaFinPreviousYear := 0;
  END IF;

  if (new$SummaYear2 is null) then
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then
    new$SummaOtherYears := 0;
  END IF;

  if (new$SummaYear2Delta is null) then
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then
    new$SummaOtherYearsDelta := 0;
  END IF;

  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null and (:old.RecordIndex is null or :old.RecordIndex <> new$RecordIndex)) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  if ((:old.ANumber is null) and (new$ANumber is not Null)) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);
  /*   */
  GetDocumentKESR(:old.SubKESR, new$SubKESR, new$KESR, new$BudgetRef,new$KESR);

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYMENTSCHEDULE_BU_1)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  /*   1.0*/    
  new$Quarter1 := new$Month01 + new$Month02 + new$Month03;
  new$Quarter2 := new$Month04 + new$Month05 + new$Month06;
  new$Quarter3 := new$Month07 + new$Month08 + new$Month09;
  new$Quarter4 := new$Month10 + new$Month11 + new$Month12;
  if (new$ProgIndex not in (317,318)) then
    new$Summa := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_PAYMENTSCHEDULE_BU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /* ,      ,   */
  if ((new$ANumber <> :old.ANumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$InnerPromiseNum <> :old.InnerPromiseNum) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;

  /*   */
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    BEGIN
      /*             */
      select Accepted, AcceptDate
      into previousAccept$, previousAcceptDate$       from Paymentschedule
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept$ = 0 or previousAcceptDate$ is null)) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;

  END IF;
  /*   ,     LastAccepted*/
  if ((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;

    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;

    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;

  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;

    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;

  /*   ,     LastAdjustment*/
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_BP_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_PAYMENTSCHEDULE_BU_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M011$, M021$, M031$, M041$, M051$, M061$, M071$, M081$, M091$, M101$, M111$, M121$,
      Q11$, Q21$, Q31$, Q41$, S5$, S21$, S31$, S41$, SOther1$         from
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    new$Month01Delta := new$Month01 - M011$;
    new$Month02Delta := new$Month02 - M021$;
    new$Month03Delta := new$Month03 - M031$;
    new$Month04Delta := new$Month04 - M041$;
    new$Month05Delta := new$Month05 - M051$;
    new$Month06Delta := new$Month06 - M061$;
    new$Month07Delta := new$Month07 - M071$;
    new$Month08Delta := new$Month08 - M081$;
    new$Month09Delta := new$Month09 - M091$;
    new$Month10Delta := new$Month10 - M101$;
    new$Month11Delta := new$Month11 - M111$;
    new$Month12Delta := new$Month12 - M121$;
    new$Quarter1Delta := new$Quarter1 - Q11$;
    new$Quarter2Delta := new$Quarter2 - Q21$;
    new$Quarter3Delta := new$Quarter3 - Q31$;
    new$Quarter4Delta := new$Quarter4 - Q41$;
    new$SummaDelta := new$Summa - S5$;
    new$SummaYear2Delta := new$SummaYear2 - S21$;
    new$SummaYear3Delta := new$SummaYear3 - S31$;
    new$SummaYear4Delta := new$SummaYear4 - S41$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther1$;

  else /*        */
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_PAYMENTSCHEDULE_BU_200)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    */
  if (new$Accepted = 0 and new$AcceptDate is not null and :old.Accepted = 1) then
    /*   ,     
         *    ,      */
    FOR REC$1 IN (      select ffc.Reject_Cls  AS DocumentRejectCls from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum
    )
    LOOP
      if (REC$1.DocumentRejectCls is null) then
        RaiseException('Ex_BP_CannotReject');
      END IF;
    END LOOP;
    /* ,         */
    FOR REC$1 IN (      SELECT Count(ps_in.ID)  AS AdjCount FROM PaymentSchedule ps_in
    WHERE (ps_in.InnerPromiseNum = new$InnerPromiseNum)and(ps_in.AdjustmentNumber > new$AdjustmentNumber)
    and (ps_in.Accepted<>0)
    )
    LOOP
      if (REC$1.AdjCount > 0) then
        RaiseException('EX_BP_AdjustmentedCANNOTREJECT');
      END IF;
    END LOOP;
  END IF;
  /*   .       */
  if (new$Accepted = 1 and new$AcceptDate is null and :old.Accepted = 1 and :old.AcceptDate is not null) then
    SELECT COUNT(ffc.id ) INTO CNT$1
    from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where ((SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum)
    and ffc.acceptdate is not null and ffc.Reject_cls is null) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_BP_NOTACCEPTED');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_PaymentSchedule_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$AgreementRef <> :old.AgreementRef or new$ExecutionRef <> :old.ExecutionRef) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYMENTSCHEDULE_BU_700)
-- Create 14.10.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$RVersion is null) then
    new$RVersion := 1;
  elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
    new$RVersion := :Old.RVersion;
  else
    new$RVersion := :Old.RVersion + 1;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYMENTSCHEDULE SET
    ID = new$ID,
    ANUMBER = new$ANUMBER,
    PARENTNUMBER = new$PARENTNUMBER,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    MONTH01 = new$MONTH01,
    MONTH02 = new$MONTH02,
    MONTH03 = new$MONTH03,
    MONTH04 = new$MONTH04,
    MONTH05 = new$MONTH05,
    MONTH06 = new$MONTH06,
    MONTH07 = new$MONTH07,
    MONTH08 = new$MONTH08,
    MONTH09 = new$MONTH09,
    MONTH10 = new$MONTH10,
    MONTH11 = new$MONTH11,
    MONTH12 = new$MONTH12,
    SUMMA = new$SUMMA,
    REGION = new$REGION,
    SUBKESR = new$SUBKESR,
    MEANSTYPE = new$MEANSTYPE,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    FACT = new$FACT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    ACCEPTDATE = new$ACCEPTDATE,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    PROMISETYPE = new$PROMISETYPE,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    SUMMAPREVIOUSYEAR = new$SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR = new$SUMMAFINPREVIOUSYEAR,
    QUARTER1 = new$QUARTER1,
    QUARTER2 = new$QUARTER2,
    QUARTER3 = new$QUARTER3,
    QUARTER4 = new$QUARTER4,
    RECORDINDEX = new$RECORDINDEX,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DIRECTIONCLS = new$DIRECTIONCLS,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MONTH01DELTA = new$MONTH01DELTA,
    MONTH02DELTA = new$MONTH02DELTA,
    MONTH03DELTA = new$MONTH03DELTA,
    MONTH04DELTA = new$MONTH04DELTA,
    MONTH05DELTA = new$MONTH05DELTA,
    MONTH06DELTA = new$MONTH06DELTA,
    MONTH07DELTA = new$MONTH07DELTA,
    MONTH08DELTA = new$MONTH08DELTA,
    MONTH09DELTA = new$MONTH09DELTA,
    MONTH10DELTA = new$MONTH10DELTA,
    MONTH11DELTA = new$MONTH11DELTA,
    MONTH12DELTA = new$MONTH12DELTA,
    QUARTER1DELTA = new$QUARTER1DELTA,
    QUARTER2DELTA = new$QUARTER2DELTA,
    QUARTER3DELTA = new$QUARTER3DELTA,
    QUARTER4DELTA = new$QUARTER4DELTA,
    SUMMADELTA = new$SUMMADELTA,
    NOTE = new$NOTE,
    FINYEAR = new$FINYEAR,
    SUMMAYEAR2 = new$SUMMAYEAR2,
    SUMMAYEAR3 = new$SUMMAYEAR3,
    SUMMAYEAR2DELTA = new$SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA = new$SUMMAYEAR3DELTA,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXECUTIONREF = new$EXECUTIONREF,
    INNERPROMISENUM = new$INNERPROMISENUM,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    PROMISENUMBER = new$PROMISENUMBER,
    SUBSIDYCLS = new$SUBSIDYCLS,
    AGREEMENTREF = new$AGREEMENTREF,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    PROGINDEX = new$PROGINDEX,
    INVESTOBJECT = new$INVESTOBJECT,
    SUMMAYEAR4 = new$SUMMAYEAR4,
    SUMMAOTHERYEARS = new$SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA = new$SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA = new$SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    OLDNUMBER = new$OLDNUMBER,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    REGPROJECTRESULT = new$REGPROJECTRESULT,
    PAYTARGETFUNDS = new$PAYTARGETFUNDS,
    ANALYTICALPARTITION = new$ANALYTICALPARTITION
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_10 (TR_PAYMENTSCHEDULE_AU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*      */
  /*        */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*              */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and ((:old.LastAdjustment = 1) or (new$LastAdjustment = 1))) then
    update PaymentSchedule set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment    */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PAYMENTSCHEDULE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (113, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=113) and (RecordId=new$ID);
  end if;

END;
/
commit work
/


-- #########################################################
-- #########################################################
-- alter_FACIALFINDETAIL_NOTE_1024.sql
-- #########################################################
-- #########################################################

/*    ""  1024  */
ALTER TRIGGER TR_FACIALFINDETAIL_BU_500 DISABLE
/
ALTER TABLE TB_FACIALFINDETAIL ADD (
  TempNOTE VARCHAR2(1024)
)
/

CREATE OR REPLACE VIEW FACIALFINDETAIL (
  ID,
  SOURCEFACIALACC_CLS,
  SOURCEKVR,
  SOURCEKESR,
  DESTFACIALACC_CLS,
  DESTKVR,
  DESTKESR,
  BUDGETREF,
  CREDIT,
  PAYSYMBOLCLS,
  MEMORDERNUM,
  NOTE,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SOURCEKVSR,
  SOURCEKCSR,
  SOURCEKFSR,
  SOURCESUBKESR,
  SOURCEFACT,
  SOURCEMEANSTYPE,
  SOURCEFINSOURCE,
  SOURCEFINTYPE,
  DESTKVSR,
  DESTKCSR,
  DESTKFSR,
  DESTSUBKESR,
  DESTFACT,
  DESTMEANSTYPE,
  DESTFINSOURCE,
  DESTFINTYPE,
  REQUESTSINDEX,
  SENDERID,
  SENDERRECORDID,
  PROMISE,
  SOURCEDOCTYPE,
  DESTDOCTYPE,
  SOURCEPROMISE,
  DESTPROMISE,
  RECORDINDEX2,
  SOURCEBUDGETPROMISE,
  DESTBUDGETPROMISE,
  SUBPROGINDEX,
  STIMATEID,
  RVERSION,
  SOURCEDIRECTIONCLS,
  DESTDIRECTIONCLS,
  SOURCEDOCBASE,
  DESTDOCBASE,
  SOURCEEXECDOC,
  DESTEXECDOC,
  BUHOPERATIONCLS,
  SOURCEIFS,
  DESTIFS,
  CLSTYPE,
  UNIONNOTIFYREF,
  ACCEPTDATE,
  SOURCEKD,
  DESTKD,
  SOURCEREGIONCLS,
  DESTREGIONCLS,
  DESTFUNDSSOURCE,
  SOURCEFUNDSSOURCE,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SOURCETRANSFERTCLS,
  DESTTRANSFERTCLS,
  DESTCLSTYPE,
  SOURCEASSIGNMENTKIND,
  DESTASSIGNMENTKIND,
  SOURCEEXECINNERNUMBER,
  DESTEXECINNERNUMBER,
  SOURCESUBSIDYCLS,
  DESTSUBSIDYCLS,
  SOURCEFAORG_TYPE,
  DESTFAORG_TYPE,
  SOURCEBUDALLOCATIONCLS,
  SOURCEPAYPROMISECLS,
  DESTBUDALLOCATIONCLS,
  DESTPAYPROMISECLS,
  SOURCEINVESTOBJECT,
  DESTINVESTOBJECT,
  TRANSFERTORG_REF,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  STOREDPAYMENTCONTENT,
  SOURCECONTRACTCOSTSCLS,
  DESTCONTRACTCOSTSCLS,
  SOURCETARGETCLS,
  DESTTARGETCLS,
  REJECT_CLS,
  REJECTCAUSE,
  CARDNUMBER,
  DATEBIRTH,
  PAYMENTCODETYPE,
  CODEPURPOSE,
  LINENUMBER,
  AMOUNTISPDOC,
  SOURCEREGPROJECTRESULT,
  DESTREGPROJECTRESULT,
  SOURCEINCOMETARGETFUNDS,
  DESTINCOMETARGETFUNDS,
  SOURCEPAYTARGETFUNDS,
  DESTPAYTARGETFUNDS,
  SOURCEANALYTICALPARTITION,
  DESTANALYTICALPARTITION,
  TEMPNOTE)
AS
  SELECT
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    TEMPNOTE
  FROM TB_FACIALFINDETAIL
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_ID
  INSTEAD OF DELETE
  ON FACIALFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_FACIALFINDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update facialfincaption set
  DocChangeDate = SYSDATE,
  RVersion=-1
  where id=:old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINDETAIL
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINDETAIL_AD_500)
-- Last update 27.08.2004
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes
              (TableID, RecordId, DeleteDate, ProgIndex, Summa)
       VALUES (22, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$TEMPNOTE FACIALFINDETAIL.TEMPNOTE%TYPE := :NEW.TEMPNOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  SourceFacialAcc_CLS1$ NUMBER(10);
  DestFacialAcc_CLS1$ NUMBER(10);
  CapBuhOperationCLS1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  CapReject_cls$ NUMBER(10);
  CapRejectCause$ VARCHAR2(1000);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  BEGIN
    /*  ,    */
    select
    ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate, ffc.Reject_cls, ffc.RejectCause,
    ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
    into new$BudgetRef, CapBuhOperationCLS1$, CapClsType1$, CapAcceptDate1$, CapReject_cls$, CapRejectCause$,
    new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause  from
    FacialFinCaption ffc
    where
    ffc.id = new$RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*      */
  if (new$BuhOperationCls is null) then
    new$BuhOperationCls := CapBuhOperationCLS1$;
  END IF;
  /*      */
  if (new$ClsType is null) then
    new$ClsType := CapClsType1$;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  /*      */
  if (new$AcceptDate is null) then
    new$AcceptDate := CapAcceptDate1$;
  END IF;

  /*       */
  if (new$Reject_cls is null) then
    new$Reject_cls := CapReject_cls$;
  END IF;

  /*       */
  if (new$RejectCause is null) then
    new$RejectCause := CapRejectCause$;
  END IF;
  /*      */
  if ((new$SourceFacialAcc_CLS is null)or
  (new$DestFacialAcc_CLS is null)) then
    BEGIN
      select
      SourceFacialAcc_CLS,
      DestFacialAcc_CLS
      into
      SourceFacialAcc_CLS1$,
      DestFacialAcc_CLS1$    from
      FacialFinCaption
      where
      (new$RecordIndex=id)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$SourceFacialAcc_CLS is null) then
      new$SourceFacialAcc_CLS := SourceFacialAcc_CLS1$ ;
    END IF;
    if (new$DestFacialAcc_CLS is null) then
      new$DestFacialAcc_CLS := DestFacialAcc_CLS1$ ;

    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 14.00.00.3
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  IF (new$progindex=76) THEN
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex IN (66, 67, 76)) AND (new$DestPromise IS NOT NULL) AND
        (new$SourcePromise = new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex IN (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

  /*       */
  IF ((new$SENDERRECORDID IS NULL) AND (new$SENDERID IS NULL)) THEN
    IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
      GETTARGETCLS(NULL, new$sourcetransfertcls, NULL, new$sourcemeanstype,
      new$sourcetargetcls,new$sourcetargetcls);
    END IF;
    GETTARGETCLS(NULL, new$desttransfertcls, NULL, new$destmeanstype,
    new$desttargetcls,new$desttargetcls);
    IF (new$ProgIndex = 76) THEN
      new$SourceTargetCls := new$DestTargetCls;

    END IF;
  END IF;
  /*      */
  GetDocumentKESR(NULL, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(NULL, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode2$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
  END IF;
  if (PromiseMode2$ = 1) then
    /* source:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* source:  BudgetPromise,   Promise,   Promise */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /* dest:  BudgetPromise,   Promise,   Promise */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    TEMPNOTE
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$NOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS,
    new$SOURCETARGETCLS,
    new$DESTTARGETCLS,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CARDNUMBER,
    new$DATEBIRTH,
    new$PAYMENTCODETYPE,
    new$CODEPURPOSE,
    new$LINENUMBER,
    new$AMOUNTISPDOC,
    new$SOURCEREGPROJECTRESULT,
    new$DESTREGPROJECTRESULT,
    new$SOURCEINCOMETARGETFUNDS,
    new$DESTINCOMETARGETFUNDS,
    new$SOURCEPAYTARGETFUNDS,
    new$DESTPAYTARGETFUNDS,
    new$SOURCEANALYTICALPARTITION,
    new$DESTANALYTICALPARTITION,
    new$TEMPNOTE);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$TEMPNOTE FACIALFINDETAIL.TEMPNOTE%TYPE := :NEW.TEMPNOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (PromiseMode2$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;

    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode2$ = 1) then
    /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;

    /* source:  BudgetPromise    Promise=NULL,   Promise */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* dest:  BudgetPromise    Promise=NULL,   Promise */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$            from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* Source:  BudgetPromise -   Promise */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;

    END IF;
    /* Source:  Promise -   BudgetPromise */
    if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
      new$SourceBudgetPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  BudgetPromise -   Promise */
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  Promise -   BudgetPromise */
    if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
      new$DestBudgetPromise := null;
      new$Promise := null;

    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$SourceExecDoc := ExecID1$;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$DestExecDoc := ExecID1$;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
        new$sourceexecinnernumber := null;
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
        new$destexecinnernumber := null;
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION,
    TEMPNOTE = new$TEMPNOTE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/
update FACIALFINDETAIL set
  TempNOTE = NOTE
/
ALTER TABLE TB_FACIALFINDETAIL DROP (NOTE)
/

CREATE OR REPLACE VIEW FACIALFINDETAIL (
  ID,
  SOURCEFACIALACC_CLS,
  SOURCEKVR,
  SOURCEKESR,
  DESTFACIALACC_CLS,
  DESTKVR,
  DESTKESR,
  BUDGETREF,
  CREDIT,
  PAYSYMBOLCLS,
  MEMORDERNUM,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SOURCEKVSR,
  SOURCEKCSR,
  SOURCEKFSR,
  SOURCESUBKESR,
  SOURCEFACT,
  SOURCEMEANSTYPE,
  SOURCEFINSOURCE,
  SOURCEFINTYPE,
  DESTKVSR,
  DESTKCSR,
  DESTKFSR,
  DESTSUBKESR,
  DESTFACT,
  DESTMEANSTYPE,
  DESTFINSOURCE,
  DESTFINTYPE,
  REQUESTSINDEX,
  SENDERID,
  SENDERRECORDID,
  PROMISE,
  SOURCEDOCTYPE,
  DESTDOCTYPE,
  SOURCEPROMISE,
  DESTPROMISE,
  RECORDINDEX2,
  SOURCEBUDGETPROMISE,
  DESTBUDGETPROMISE,
  SUBPROGINDEX,
  STIMATEID,
  RVERSION,
  SOURCEDIRECTIONCLS,
  DESTDIRECTIONCLS,
  SOURCEDOCBASE,
  DESTDOCBASE,
  SOURCEEXECDOC,
  DESTEXECDOC,
  BUHOPERATIONCLS,
  SOURCEIFS,
  DESTIFS,
  CLSTYPE,
  UNIONNOTIFYREF,
  ACCEPTDATE,
  SOURCEKD,
  DESTKD,
  SOURCEREGIONCLS,
  DESTREGIONCLS,
  DESTFUNDSSOURCE,
  SOURCEFUNDSSOURCE,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SOURCETRANSFERTCLS,
  DESTTRANSFERTCLS,
  DESTCLSTYPE,
  SOURCEASSIGNMENTKIND,
  DESTASSIGNMENTKIND,
  SOURCEEXECINNERNUMBER,
  DESTEXECINNERNUMBER,
  SOURCESUBSIDYCLS,
  DESTSUBSIDYCLS,
  SOURCEFAORG_TYPE,
  DESTFAORG_TYPE,
  SOURCEBUDALLOCATIONCLS,
  SOURCEPAYPROMISECLS,
  DESTBUDALLOCATIONCLS,
  DESTPAYPROMISECLS,
  SOURCEINVESTOBJECT,
  DESTINVESTOBJECT,
  TRANSFERTORG_REF,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  STOREDPAYMENTCONTENT,
  SOURCECONTRACTCOSTSCLS,
  DESTCONTRACTCOSTSCLS,
  SOURCETARGETCLS,
  DESTTARGETCLS,
  REJECT_CLS,
  REJECTCAUSE,
  CARDNUMBER,
  DATEBIRTH,
  PAYMENTCODETYPE,
  CODEPURPOSE,
  LINENUMBER,
  AMOUNTISPDOC,
  SOURCEREGPROJECTRESULT,
  DESTREGPROJECTRESULT,
  SOURCEINCOMETARGETFUNDS,
  DESTINCOMETARGETFUNDS,
  SOURCEPAYTARGETFUNDS,
  DESTPAYTARGETFUNDS,
  SOURCEANALYTICALPARTITION,
  DESTANALYTICALPARTITION,
  TEMPNOTE)
AS
  SELECT
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    TEMPNOTE
  FROM TB_FACIALFINDETAIL
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_ID
  INSTEAD OF DELETE
  ON FACIALFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_FACIALFINDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update facialfincaption set
  DocChangeDate = SYSDATE,
  RVersion=-1
  where id=:old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINDETAIL
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINDETAIL_AD_500)
-- Last update 27.08.2004
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes
              (TableID, RecordId, DeleteDate, ProgIndex, Summa)
       VALUES (22, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$TEMPNOTE FACIALFINDETAIL.TEMPNOTE%TYPE := :NEW.TEMPNOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  SourceFacialAcc_CLS1$ NUMBER(10);
  DestFacialAcc_CLS1$ NUMBER(10);
  CapBuhOperationCLS1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  CapReject_cls$ NUMBER(10);
  CapRejectCause$ VARCHAR2(1000);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  BEGIN
    /*  ,    */
    select
    ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate, ffc.Reject_cls, ffc.RejectCause,
    ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
    into new$BudgetRef, CapBuhOperationCLS1$, CapClsType1$, CapAcceptDate1$, CapReject_cls$, CapRejectCause$,
    new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause  from
    FacialFinCaption ffc
    where
    ffc.id = new$RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*      */
  if (new$BuhOperationCls is null) then
    new$BuhOperationCls := CapBuhOperationCLS1$;
  END IF;
  /*      */
  if (new$ClsType is null) then
    new$ClsType := CapClsType1$;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  /*      */
  if (new$AcceptDate is null) then
    new$AcceptDate := CapAcceptDate1$;
  END IF;

  /*       */
  if (new$Reject_cls is null) then
    new$Reject_cls := CapReject_cls$;
  END IF;

  /*       */
  if (new$RejectCause is null) then
    new$RejectCause := CapRejectCause$;
  END IF;
  /*      */
  if ((new$SourceFacialAcc_CLS is null)or
  (new$DestFacialAcc_CLS is null)) then
    BEGIN
      select
      SourceFacialAcc_CLS,
      DestFacialAcc_CLS
      into
      SourceFacialAcc_CLS1$,
      DestFacialAcc_CLS1$    from
      FacialFinCaption
      where
      (new$RecordIndex=id)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$SourceFacialAcc_CLS is null) then
      new$SourceFacialAcc_CLS := SourceFacialAcc_CLS1$ ;
    END IF;
    if (new$DestFacialAcc_CLS is null) then
      new$DestFacialAcc_CLS := DestFacialAcc_CLS1$ ;

    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 14.00.00.3
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  IF (new$progindex=76) THEN
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex IN (66, 67, 76)) AND (new$DestPromise IS NOT NULL) AND
        (new$SourcePromise = new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex IN (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

  /*       */
  IF ((new$SENDERRECORDID IS NULL) AND (new$SENDERID IS NULL)) THEN
    IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
      GETTARGETCLS(NULL, new$sourcetransfertcls, NULL, new$sourcemeanstype,
      new$sourcetargetcls,new$sourcetargetcls);
    END IF;
    GETTARGETCLS(NULL, new$desttransfertcls, NULL, new$destmeanstype,
    new$desttargetcls,new$desttargetcls);
    IF (new$ProgIndex = 76) THEN
      new$SourceTargetCls := new$DestTargetCls;

    END IF;
  END IF;
  /*      */
  GetDocumentKESR(NULL, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(NULL, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode2$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
  END IF;
  if (PromiseMode2$ = 1) then
    /* source:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* source:  BudgetPromise,   Promise,   Promise */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /* dest:  BudgetPromise,   Promise,   Promise */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    TEMPNOTE
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS,
    new$SOURCETARGETCLS,
    new$DESTTARGETCLS,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CARDNUMBER,
    new$DATEBIRTH,
    new$PAYMENTCODETYPE,
    new$CODEPURPOSE,
    new$LINENUMBER,
    new$AMOUNTISPDOC,
    new$SOURCEREGPROJECTRESULT,
    new$DESTREGPROJECTRESULT,
    new$SOURCEINCOMETARGETFUNDS,
    new$DESTINCOMETARGETFUNDS,
    new$SOURCEPAYTARGETFUNDS,
    new$DESTPAYTARGETFUNDS,
    new$SOURCEANALYTICALPARTITION,
    new$DESTANALYTICALPARTITION,
    new$TEMPNOTE);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$TEMPNOTE FACIALFINDETAIL.TEMPNOTE%TYPE := :NEW.TEMPNOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (PromiseMode2$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;

    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode2$ = 1) then
    /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;

    /* source:  BudgetPromise    Promise=NULL,   Promise */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* dest:  BudgetPromise    Promise=NULL,   Promise */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$            from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* Source:  BudgetPromise -   Promise */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;

    END IF;
    /* Source:  Promise -   BudgetPromise */
    if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
      new$SourceBudgetPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  BudgetPromise -   Promise */
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  Promise -   BudgetPromise */
    if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
      new$DestBudgetPromise := null;
      new$Promise := null;

    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$SourceExecDoc := ExecID1$;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$DestExecDoc := ExecID1$;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
        new$sourceexecinnernumber := null;
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
        new$destexecinnernumber := null;
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION,
    TEMPNOTE = new$TEMPNOTE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/
ALTER TABLE TB_FACIALFINDETAIL ADD (
  NOTE VARCHAR2(1024)
)
/

CREATE OR REPLACE VIEW FACIALFINDETAIL (
  ID,
  SOURCEFACIALACC_CLS,
  SOURCEKVR,
  SOURCEKESR,
  DESTFACIALACC_CLS,
  DESTKVR,
  DESTKESR,
  BUDGETREF,
  CREDIT,
  PAYSYMBOLCLS,
  MEMORDERNUM,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SOURCEKVSR,
  SOURCEKCSR,
  SOURCEKFSR,
  SOURCESUBKESR,
  SOURCEFACT,
  SOURCEMEANSTYPE,
  SOURCEFINSOURCE,
  SOURCEFINTYPE,
  DESTKVSR,
  DESTKCSR,
  DESTKFSR,
  DESTSUBKESR,
  DESTFACT,
  DESTMEANSTYPE,
  DESTFINSOURCE,
  DESTFINTYPE,
  REQUESTSINDEX,
  SENDERID,
  SENDERRECORDID,
  PROMISE,
  SOURCEDOCTYPE,
  DESTDOCTYPE,
  SOURCEPROMISE,
  DESTPROMISE,
  RECORDINDEX2,
  SOURCEBUDGETPROMISE,
  DESTBUDGETPROMISE,
  SUBPROGINDEX,
  STIMATEID,
  RVERSION,
  SOURCEDIRECTIONCLS,
  DESTDIRECTIONCLS,
  SOURCEDOCBASE,
  DESTDOCBASE,
  SOURCEEXECDOC,
  DESTEXECDOC,
  BUHOPERATIONCLS,
  SOURCEIFS,
  DESTIFS,
  CLSTYPE,
  UNIONNOTIFYREF,
  ACCEPTDATE,
  SOURCEKD,
  DESTKD,
  SOURCEREGIONCLS,
  DESTREGIONCLS,
  DESTFUNDSSOURCE,
  SOURCEFUNDSSOURCE,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SOURCETRANSFERTCLS,
  DESTTRANSFERTCLS,
  DESTCLSTYPE,
  SOURCEASSIGNMENTKIND,
  DESTASSIGNMENTKIND,
  SOURCEEXECINNERNUMBER,
  DESTEXECINNERNUMBER,
  SOURCESUBSIDYCLS,
  DESTSUBSIDYCLS,
  SOURCEFAORG_TYPE,
  DESTFAORG_TYPE,
  SOURCEBUDALLOCATIONCLS,
  SOURCEPAYPROMISECLS,
  DESTBUDALLOCATIONCLS,
  DESTPAYPROMISECLS,
  SOURCEINVESTOBJECT,
  DESTINVESTOBJECT,
  TRANSFERTORG_REF,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  STOREDPAYMENTCONTENT,
  SOURCECONTRACTCOSTSCLS,
  DESTCONTRACTCOSTSCLS,
  SOURCETARGETCLS,
  DESTTARGETCLS,
  REJECT_CLS,
  REJECTCAUSE,
  CARDNUMBER,
  DATEBIRTH,
  PAYMENTCODETYPE,
  CODEPURPOSE,
  LINENUMBER,
  AMOUNTISPDOC,
  SOURCEREGPROJECTRESULT,
  DESTREGPROJECTRESULT,
  SOURCEINCOMETARGETFUNDS,
  DESTINCOMETARGETFUNDS,
  SOURCEPAYTARGETFUNDS,
  DESTPAYTARGETFUNDS,
  SOURCEANALYTICALPARTITION,
  DESTANALYTICALPARTITION,
  TEMPNOTE,
  NOTE)
AS
  SELECT
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    TEMPNOTE,
    NOTE
  FROM TB_FACIALFINDETAIL
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_ID
  INSTEAD OF DELETE
  ON FACIALFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_FACIALFINDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update facialfincaption set
  DocChangeDate = SYSDATE,
  RVersion=-1
  where id=:old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINDETAIL
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINDETAIL_AD_500)
-- Last update 27.08.2004
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes
              (TableID, RecordId, DeleteDate, ProgIndex, Summa)
       VALUES (22, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$TEMPNOTE FACIALFINDETAIL.TEMPNOTE%TYPE := :NEW.TEMPNOTE;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  SourceFacialAcc_CLS1$ NUMBER(10);
  DestFacialAcc_CLS1$ NUMBER(10);
  CapBuhOperationCLS1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  CapReject_cls$ NUMBER(10);
  CapRejectCause$ VARCHAR2(1000);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  BEGIN
    /*  ,    */
    select
    ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate, ffc.Reject_cls, ffc.RejectCause,
    ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
    into new$BudgetRef, CapBuhOperationCLS1$, CapClsType1$, CapAcceptDate1$, CapReject_cls$, CapRejectCause$,
    new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause  from
    FacialFinCaption ffc
    where
    ffc.id = new$RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*      */
  if (new$BuhOperationCls is null) then
    new$BuhOperationCls := CapBuhOperationCLS1$;
  END IF;
  /*      */
  if (new$ClsType is null) then
    new$ClsType := CapClsType1$;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  /*      */
  if (new$AcceptDate is null) then
    new$AcceptDate := CapAcceptDate1$;
  END IF;

  /*       */
  if (new$Reject_cls is null) then
    new$Reject_cls := CapReject_cls$;
  END IF;

  /*       */
  if (new$RejectCause is null) then
    new$RejectCause := CapRejectCause$;
  END IF;
  /*      */
  if ((new$SourceFacialAcc_CLS is null)or
  (new$DestFacialAcc_CLS is null)) then
    BEGIN
      select
      SourceFacialAcc_CLS,
      DestFacialAcc_CLS
      into
      SourceFacialAcc_CLS1$,
      DestFacialAcc_CLS1$    from
      FacialFinCaption
      where
      (new$RecordIndex=id)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$SourceFacialAcc_CLS is null) then
      new$SourceFacialAcc_CLS := SourceFacialAcc_CLS1$ ;
    END IF;
    if (new$DestFacialAcc_CLS is null) then
      new$DestFacialAcc_CLS := DestFacialAcc_CLS1$ ;

    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 14.00.00.3
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  IF (new$progindex=76) THEN
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex IN (66, 67, 76)) AND (new$DestPromise IS NOT NULL) AND
        (new$SourcePromise = new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex IN (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

  /*       */
  IF ((new$SENDERRECORDID IS NULL) AND (new$SENDERID IS NULL)) THEN
    IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
      GETTARGETCLS(NULL, new$sourcetransfertcls, NULL, new$sourcemeanstype,
      new$sourcetargetcls,new$sourcetargetcls);
    END IF;
    GETTARGETCLS(NULL, new$desttransfertcls, NULL, new$destmeanstype,
    new$desttargetcls,new$desttargetcls);
    IF (new$ProgIndex = 76) THEN
      new$SourceTargetCls := new$DestTargetCls;

    END IF;
  END IF;
  /*      */
  GetDocumentKESR(NULL, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(NULL, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode2$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
  END IF;
  if (PromiseMode2$ = 1) then
    /* source:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* source:  BudgetPromise,   Promise,   Promise */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /* dest:  BudgetPromise,   Promise,   Promise */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    TEMPNOTE,
    NOTE
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS,
    new$SOURCETARGETCLS,
    new$DESTTARGETCLS,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CARDNUMBER,
    new$DATEBIRTH,
    new$PAYMENTCODETYPE,
    new$CODEPURPOSE,
    new$LINENUMBER,
    new$AMOUNTISPDOC,
    new$SOURCEREGPROJECTRESULT,
    new$DESTREGPROJECTRESULT,
    new$SOURCEINCOMETARGETFUNDS,
    new$DESTINCOMETARGETFUNDS,
    new$SOURCEPAYTARGETFUNDS,
    new$DESTPAYTARGETFUNDS,
    new$SOURCEANALYTICALPARTITION,
    new$DESTANALYTICALPARTITION,
    new$TEMPNOTE,
    new$NOTE);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$TEMPNOTE FACIALFINDETAIL.TEMPNOTE%TYPE := :NEW.TEMPNOTE;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (PromiseMode2$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;

    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode2$ = 1) then
    /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;

    /* source:  BudgetPromise    Promise=NULL,   Promise */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* dest:  BudgetPromise    Promise=NULL,   Promise */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$            from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* Source:  BudgetPromise -   Promise */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;

    END IF;
    /* Source:  Promise -   BudgetPromise */
    if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
      new$SourceBudgetPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  BudgetPromise -   Promise */
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  Promise -   BudgetPromise */
    if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
      new$DestBudgetPromise := null;
      new$Promise := null;

    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$SourceExecDoc := ExecID1$;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$DestExecDoc := ExecID1$;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
        new$sourceexecinnernumber := null;
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
        new$destexecinnernumber := null;
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION,
    TEMPNOTE = new$TEMPNOTE,
    NOTE = new$NOTE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/
update FACIALFINDETAIL set
  NOTE = TempNOTE
/
ALTER TABLE TB_FACIALFINDETAIL DROP (TempNOTE)
/

CREATE OR REPLACE VIEW FACIALFINDETAIL (
  ID,
  SOURCEFACIALACC_CLS,
  SOURCEKVR,
  SOURCEKESR,
  DESTFACIALACC_CLS,
  DESTKVR,
  DESTKESR,
  BUDGETREF,
  CREDIT,
  PAYSYMBOLCLS,
  MEMORDERNUM,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SOURCEKVSR,
  SOURCEKCSR,
  SOURCEKFSR,
  SOURCESUBKESR,
  SOURCEFACT,
  SOURCEMEANSTYPE,
  SOURCEFINSOURCE,
  SOURCEFINTYPE,
  DESTKVSR,
  DESTKCSR,
  DESTKFSR,
  DESTSUBKESR,
  DESTFACT,
  DESTMEANSTYPE,
  DESTFINSOURCE,
  DESTFINTYPE,
  REQUESTSINDEX,
  SENDERID,
  SENDERRECORDID,
  PROMISE,
  SOURCEDOCTYPE,
  DESTDOCTYPE,
  SOURCEPROMISE,
  DESTPROMISE,
  RECORDINDEX2,
  SOURCEBUDGETPROMISE,
  DESTBUDGETPROMISE,
  SUBPROGINDEX,
  STIMATEID,
  RVERSION,
  SOURCEDIRECTIONCLS,
  DESTDIRECTIONCLS,
  SOURCEDOCBASE,
  DESTDOCBASE,
  SOURCEEXECDOC,
  DESTEXECDOC,
  BUHOPERATIONCLS,
  SOURCEIFS,
  DESTIFS,
  CLSTYPE,
  UNIONNOTIFYREF,
  ACCEPTDATE,
  SOURCEKD,
  DESTKD,
  SOURCEREGIONCLS,
  DESTREGIONCLS,
  DESTFUNDSSOURCE,
  SOURCEFUNDSSOURCE,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SOURCETRANSFERTCLS,
  DESTTRANSFERTCLS,
  DESTCLSTYPE,
  SOURCEASSIGNMENTKIND,
  DESTASSIGNMENTKIND,
  SOURCEEXECINNERNUMBER,
  DESTEXECINNERNUMBER,
  SOURCESUBSIDYCLS,
  DESTSUBSIDYCLS,
  SOURCEFAORG_TYPE,
  DESTFAORG_TYPE,
  SOURCEBUDALLOCATIONCLS,
  SOURCEPAYPROMISECLS,
  DESTBUDALLOCATIONCLS,
  DESTPAYPROMISECLS,
  SOURCEINVESTOBJECT,
  DESTINVESTOBJECT,
  TRANSFERTORG_REF,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  STOREDPAYMENTCONTENT,
  SOURCECONTRACTCOSTSCLS,
  DESTCONTRACTCOSTSCLS,
  SOURCETARGETCLS,
  DESTTARGETCLS,
  REJECT_CLS,
  REJECTCAUSE,
  CARDNUMBER,
  DATEBIRTH,
  PAYMENTCODETYPE,
  CODEPURPOSE,
  LINENUMBER,
  AMOUNTISPDOC,
  SOURCEREGPROJECTRESULT,
  DESTREGPROJECTRESULT,
  SOURCEINCOMETARGETFUNDS,
  DESTINCOMETARGETFUNDS,
  SOURCEPAYTARGETFUNDS,
  DESTPAYTARGETFUNDS,
  SOURCEANALYTICALPARTITION,
  DESTANALYTICALPARTITION,
  NOTE)
AS
  SELECT
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    NOTE
  FROM TB_FACIALFINDETAIL
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_ID
  INSTEAD OF DELETE
  ON FACIALFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_FACIALFINDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update facialfincaption set
  DocChangeDate = SYSDATE,
  RVersion=-1
  where id=:old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINDETAIL
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINDETAIL_AD_500)
-- Last update 27.08.2004
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes
              (TableID, RecordId, DeleteDate, ProgIndex, Summa)
       VALUES (22, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  SourceFacialAcc_CLS1$ NUMBER(10);
  DestFacialAcc_CLS1$ NUMBER(10);
  CapBuhOperationCLS1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  CapReject_cls$ NUMBER(10);
  CapRejectCause$ VARCHAR2(1000);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  BEGIN
    /*  ,    */
    select
    ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate, ffc.Reject_cls, ffc.RejectCause,
    ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
    into new$BudgetRef, CapBuhOperationCLS1$, CapClsType1$, CapAcceptDate1$, CapReject_cls$, CapRejectCause$,
    new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause  from
    FacialFinCaption ffc
    where
    ffc.id = new$RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*      */
  if (new$BuhOperationCls is null) then
    new$BuhOperationCls := CapBuhOperationCLS1$;
  END IF;
  /*      */
  if (new$ClsType is null) then
    new$ClsType := CapClsType1$;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  /*      */
  if (new$AcceptDate is null) then
    new$AcceptDate := CapAcceptDate1$;
  END IF;

  /*       */
  if (new$Reject_cls is null) then
    new$Reject_cls := CapReject_cls$;
  END IF;

  /*       */
  if (new$RejectCause is null) then
    new$RejectCause := CapRejectCause$;
  END IF;
  /*      */
  if ((new$SourceFacialAcc_CLS is null)or
  (new$DestFacialAcc_CLS is null)) then
    BEGIN
      select
      SourceFacialAcc_CLS,
      DestFacialAcc_CLS
      into
      SourceFacialAcc_CLS1$,
      DestFacialAcc_CLS1$    from
      FacialFinCaption
      where
      (new$RecordIndex=id)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$SourceFacialAcc_CLS is null) then
      new$SourceFacialAcc_CLS := SourceFacialAcc_CLS1$ ;
    END IF;
    if (new$DestFacialAcc_CLS is null) then
      new$DestFacialAcc_CLS := DestFacialAcc_CLS1$ ;

    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 14.00.00.3
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  IF (new$progindex=76) THEN
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex IN (66, 67, 76)) AND (new$DestPromise IS NOT NULL) AND
        (new$SourcePromise = new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex IN (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

  /*       */
  IF ((new$SENDERRECORDID IS NULL) AND (new$SENDERID IS NULL)) THEN
    IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
      GETTARGETCLS(NULL, new$sourcetransfertcls, NULL, new$sourcemeanstype,
      new$sourcetargetcls,new$sourcetargetcls);
    END IF;
    GETTARGETCLS(NULL, new$desttransfertcls, NULL, new$destmeanstype,
    new$desttargetcls,new$desttargetcls);
    IF (new$ProgIndex = 76) THEN
      new$SourceTargetCls := new$DestTargetCls;

    END IF;
  END IF;
  /*      */
  GetDocumentKESR(NULL, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(NULL, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode2$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
  END IF;
  if (PromiseMode2$ = 1) then
    /* source:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* source:  BudgetPromise,   Promise,   Promise */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /* dest:  BudgetPromise,   Promise,   Promise */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    NOTE
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS,
    new$SOURCETARGETCLS,
    new$DESTTARGETCLS,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CARDNUMBER,
    new$DATEBIRTH,
    new$PAYMENTCODETYPE,
    new$CODEPURPOSE,
    new$LINENUMBER,
    new$AMOUNTISPDOC,
    new$SOURCEREGPROJECTRESULT,
    new$DESTREGPROJECTRESULT,
    new$SOURCEINCOMETARGETFUNDS,
    new$DESTINCOMETARGETFUNDS,
    new$SOURCEPAYTARGETFUNDS,
    new$DESTPAYTARGETFUNDS,
    new$SOURCEANALYTICALPARTITION,
    new$DESTANALYTICALPARTITION,
    new$NOTE);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.10.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (PromiseMode2$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;

    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode2$ = 1) then
    /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;

    /* source:  BudgetPromise    Promise=NULL,   Promise */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* dest:  BudgetPromise    Promise=NULL,   Promise */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$            from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* Source:  BudgetPromise -   Promise */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;

    END IF;
    /* Source:  Promise -   BudgetPromise */
    if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
      new$SourceBudgetPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  BudgetPromise -   Promise */
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  Promise -   BudgetPromise */
    if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
      new$DestBudgetPromise := null;
      new$Promise := null;

    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$SourceExecDoc := ExecID1$;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$DestExecDoc := ExecID1$;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
        new$sourceexecinnernumber := null;
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
        new$destexecinnernumber := null;
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION,
    NOTE = new$NOTE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
ALTER TRIGGER TR_FACIALFINDETAIL_BU_500 ENABLE
/
commit work 
/

-- #########################################################
-- #########################################################
-- UpdDocFields_14.10.00_Ora.sql
-- #########################################################
-- #########################################################


--  : 141000 - 141000.     11.11.2021 18:10:12.
CREATE OR REPLACE PROCEDURE ImportDocType (
   ID_               NUMBER,
   PROGINDEX_        NUMBER,
   NAME_             VARCHAR2,
   USESTATE_         NUMBER,
   DBTABLE_          VARCHAR2,
   NEEDEDS_          NUMBER,
   LOCKMASK_         NUMBER,
   DEFAULTACTIONMACROSNAME_ VARCHAR2,
   DOCUMENTKIND_     NUMBER,
   SHORTNAME_         VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentTypes
    WHERE (ID = ID_);

  IF (IDExists$ = 0) THEN
     INSERT INTO DocumentTypes
                 (ID, PROGINDEX, NAME, USESTATE, DBTABLE, NEEDEDS, LOCKMASK, DEFAULTACTIONMACROSNAME, DOCUMENTKIND, SHORTNAME)
          VALUES (ID_, PROGINDEX_, NAME_, USESTATE_, DBTABLE_, NEEDEDS_, LOCKMASK_, DEFAULTACTIONMACROSNAME_, DOCUMENTKIND_, SHORTNAME_);
  else
      Update documenttypes set
        Name=Name_,
		    DBTABLE=DBTABLE_,
        LockMask=LockMask_,
        DEFAULTACTIONMACROSNAME=DEFAULTACTIONMACROSNAME_,
        DOCUMENTKIND=DOCUMENTKIND_,
        SHORTNAME=SHORTNAME_,
	      PROGINDEX=PROGINDEX_
      where (id=ID_)
        and (
          (Name<>Name_) or
          ((LockMask is null) and (LockMask_ is not null)) or
          ((LockMask is not null) and (LockMask_ is null)) or
          ((LockMask is not null) and (LockMask_ is not null) and (LockMask <> LockMask_)) or
          (DEFAULTACTIONMACROSNAME is null) or
          (DOCUMENTKIND<>DOCUMENTKIND_) or 
          (SHORTNAME is null) or 
          (SHORTNAME<>SHORTNAME_) or
          (PROGINDEX <> PROGINDEX_) or 
          ((DBTABLE is null) and (DBTABLE_ is not null)) or
          ((DBTABLE is not null) and (DBTABLE_ is null)) or
          ((DBTABLE is not null) and (DBTABLE_ is not null) and (DBTABLE <> DBTABLE_))
        );
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE UPDATEINTERFACES (
  CLS_   NUMBER,
  NOTE_  VARCHAR2,
  GUID_  VARCHAR2,
  PARAM_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT (ID)
   INTO IDEXISTS$
   FROM INTERFACES
  WHERE (GUID=GUID_);
  
  IF (IDExists$ = 0)  THEN
    INSERT INTO INTERFACES
      (CLS,NOTE,GUID,PARAM)
    VALUES
      (CLS_,NOTE_,GUID_,PARAM_);
  ELSE
    IF ((PARAM_ ='')OR(PARAM_ IS NULL)) THEN 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    ELSE 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND (PARAM=PARAM_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    END IF;
  END IF;
END;
/

--   
CALL ImportDocType(302, 63, '  \', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(303, 65, ' ()', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(304, 64, '  ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(325, 283, '   ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(325, '   ', '{594D6AF0-9A00-4380-B4FE-9C18C45B2B70}', '') ;

CALL ImportDocType(1825, 0, '    ', 0, 'PayDocExchange ', 0,-1,'',10200,'	') ;

CALL UpdateInterfaces(1825, '    ', '{698B68B7-A731-4FCF-A36D-19A77365DF41}', '') ;

CALL ImportDocType(2504, 314, ' ', 0, 'Agreements', 0,-65537,'',10100,'') ;

DROP PROCEDURE ImportDocType
/

DROP PROCEDURE UPDATEINTERFACES
/



CREATE OR REPLACE PROCEDURE SELECTIONS_IMPORT(
  ID_ NUMBER,
  KIND_ NUMBER,
  NAME_ VARCHAR2,
  NOTE_ VARCHAR2,
  READONLY_ NUMBER,
  USEINDOC_ NUMBER,
  TABLENAME_ VARCHAR2,
  ALIAS_ VARCHAR2,
  TABLECODE_ NUMBER,
  NEEDGROUPONDB_ NUMBER,
  NEEDDISTINCT_ NUMBER,
  MASTER_ NUMBER,
  DISCRIMVALUE_ VARCHAR2,
  AVAILABLEINDEREF_ NUMBER,
  CACHETYPE_ NUMBER,
  FULLORMODINSREFRTIME_ NUMBER,
  DELETEREFRTIME_ NUMBER,
  FINDTIMEREFRESH_ NUMBER,
  ANNOTATION_ VARCHAR2,
  DEREFNAME_ VARCHAR2,
  GroupID_ NUMBER,
  IsLogged_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONS SET
      KIND = KIND_,
      NAME = NAME_,
      NOTE = NOTE_,
      READONLY = READONLY_,
      USEINDOC = USEINDOC_,
      TABLENAME = TABLENAME_,
      ALIAS = ALIAS_,
      TABLECODE = TABLECODE_,    
      NEEDGROUPONDB = NEEDGROUPONDB_,
      NEEDDISTINCT = NEEDDISTINCT_,
      MASTER = MASTER_,
      DISCRIMVALUE = DISCRIMVALUE_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,         
      CACHETYPE = CACHETYPE_,   
      FULLORMODINSREFRTIME = FULLORMODINSREFRTIME_,   
      DELETEREFRTIME = DELETEREFRTIME_,   
      FINDTIMEREFRESH = FINDTIMEREFRESH_,   
      ANNOTATION = ANNOTATION_,   
      DEREFNAME = DEREFNAME_,     
      GroupID = GroupID_, 
      IsLogged = IsLogged_  
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONS
      (ID, KIND, NAME, NOTE, READONLY, USEINDOC, TABLENAME, ALIAS, TABLECODE, NEEDGROUPONDB, NEEDDISTINCT, MASTER, DISCRIMVALUE,
      AVAILABLEINDEREF, CACHETYPE, FULLORMODINSREFRTIME, DELETEREFRTIME, FINDTIMEREFRESH, ANNOTATION, DEREFNAME, GroupID, IsLogged)
    VALUES
      (ID_, KIND_, NAME_, NOTE_, READONLY_, USEINDOC_, TABLENAME_, ALIAS_, TABLECODE_, NEEDGROUPONDB_, NEEDDISTINCT_, MASTER_, DISCRIMVALUE_,
      AVAILABLEINDEREF_, CACHETYPE_, FULLORMODINSREFRTIME_, DELETEREFRTIME_, FINDTIMEREFRESH_, ANNOTATION_, DEREFNAME_, GroupID_, IsLogged_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  ALIAS_ VARCHAR2,
  JOINORDER_ NUMBER,
  JOINTYPE_ NUMBER,
  RELATIONTYPE_ NUMBER,
  JOINCONDITION_ VARCHAR2,
  DONTUSETABLELIMITS_ NUMBER,
  LIMITNAMESLIST_ VARCHAR2,
  QueryGroup_ NUMBER  
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONSDETAIL
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONSDETAIL SET
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      ALIAS = ALIAS_,
      JOINORDER = JOINORDER_,
      JOINTYPE = JOINTYPE_,
      RELATIONTYPE = RELATIONTYPE_,
      JOINCONDITION = JOINCONDITION_,
      DONTUSETABLELIMITS = DONTUSETABLELIMITS_,
      LIMITNAMESLIST = LIMITNAMESLIST_,
      QueryGroup = QueryGroup_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONSDETAIL
      (ID, SELECTIONREF, TABLEREF, ALIAS, JOINORDER, JOINTYPE, RELATIONTYPE, JOINCONDITION, DONTUSETABLELIMITS, LIMITNAMESLIST, QueryGroup)
    VALUES
      (ID_, SELECTIONREF_, TABLEREF_, ALIAS_, JOINORDER_, JOINTYPE_, RELATIONTYPE_, JOINCONDITION_, DONTUSETABLELIMITS_, LIMITNAMESLIST_, QueryGroup_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_IMPORT(
  ID_ NUMBER,
  FIELDKIND_ NUMBER,
  DESCRIPTIONLEVEL_ NUMBER,
  ANCESTORREF_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  FIELDNAME_ VARCHAR2,
  DATATYPE_ NUMBER,
  SUBDATATYPE_ NUMBER,
  FIELDSIZE_ NUMBER,
  DISPLAYLABEL_ VARCHAR2,
  NOTE_ VARCHAR2,
  DEFAULTWIDTH_ NUMBER,
  EDITMASK_ VARCHAR2,
  DISPLAYFORMAT_ VARCHAR2,
  EDITFORMAT_ VARCHAR2,
  CANTEDIT_ NUMBER,
  NOVISUALIZE_ NUMBER,
  ENUMSREF_ NUMBER,
  REQUIRED_ NUMBER,
  FOREIGNKEY_ NUMBER,
  ONDELACTION_ NUMBER,
  PRIMARYKEY_ NUMBER,
  ISRVERSION_ NUMBER,
  LIMITPARAMNAMES_ VARCHAR2,
  FOLLOWORDER_ NUMBER,
  SORTDIRECTION_ NUMBER,
  SORTORDER_ NUMBER,
  AGRFUNCTION_ NUMBER,
  FLAGFIELDNAME_ NUMBER,
  FLAGDISPLAYLABEL_ NUMBER,
  FLAGNOTE_ NUMBER,
  FLAGDEFAULTWIDTH_ NUMBER,
  FLAGCANTEDIT_ NUMBER,
  FLAGNOVISUALIZE_ NUMBER,
  FLAGREQUIRED_ NUMBER,
  FLAGLIMITPARAMNAMES_ NUMBER,
  FLAGAGRFUNCTION_ NUMBER,
  ISTIMESTAMPFIELD_ NUMBER,
  ISBUDGET_ NUMBER,
  AVAILABLEINDEREF_ NUMBER,
  ANNOTATION_ VARCHAR2,
  ALIAS_ VARCHAR2,
  DEREFNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM FIELDSINFO
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE FIELDSINFO SET
      FIELDKIND = FIELDKIND_,
      DESCRIPTIONLEVEL = DESCRIPTIONLEVEL_,
      ANCESTORREF = ANCESTORREF_,
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      FIELDNAME = FIELDNAME_,
      DATATYPE = DATATYPE_,
      SUBDATATYPE = SUBDATATYPE_,
      FIELDSIZE = FIELDSIZE_,
      DISPLAYLABEL = DISPLAYLABEL_,
      NOTE = NOTE_,
      DEFAULTWIDTH = DEFAULTWIDTH_,
      EDITMASK = EDITMASK_,
      DISPLAYFORMAT = DISPLAYFORMAT_,
      EDITFORMAT = EDITFORMAT_,
      CANTEDIT = CANTEDIT_,
      NOVISUALIZE = NOVISUALIZE_,
      ENUMSREF = ENUMSREF_,
      REQUIRED = REQUIRED_,
      FOREIGNKEY = FOREIGNKEY_,
      ONDELACTION = ONDELACTION_,
      PRIMARYKEY = PRIMARYKEY_,
      ISRVERSION = ISRVERSION_,
      LIMITPARAMNAMES = LIMITPARAMNAMES_,
      FOLLOWORDER = FOLLOWORDER_,
      SORTDIRECTION = SORTDIRECTION_,
      SORTORDER = SORTORDER_,
      AGRFUNCTION = AGRFUNCTION_,
      FLAGFIELDNAME = FLAGFIELDNAME_,
      FLAGDISPLAYLABEL = FLAGDISPLAYLABEL_,
      FLAGNOTE = FLAGNOTE_,
      FLAGDEFAULTWIDTH = FLAGDEFAULTWIDTH_,
      FLAGCANTEDIT = FLAGCANTEDIT_,
      FLAGNOVISUALIZE = FLAGNOVISUALIZE_,
      FLAGREQUIRED = FLAGREQUIRED_,
      FLAGLIMITPARAMNAMES = FLAGLIMITPARAMNAMES_,
      FLAGAGRFUNCTION = FLAGAGRFUNCTION_,
      ISTIMESTAMPFIELD = ISTIMESTAMPFIELD_,
      ISBUDGET = ISBUDGET_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,
      ANNOTATION = ANNOTATION_,
      ALIAS = ALIAS_,
      DEREFNAME = DEREFNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO FIELDSINFO
      (ID, FIELDKIND, DESCRIPTIONLEVEL, ANCESTORREF, SELECTIONREF, TABLEREF, FIELDNAME, DATATYPE, SUBDATATYPE,
       FIELDSIZE, DISPLAYLABEL, NOTE, DEFAULTWIDTH, EDITMASK, DISPLAYFORMAT, EDITFORMAT, CANTEDIT, NOVISUALIZE,
       ENUMSREF, REQUIRED, FOREIGNKEY, ONDELACTION, PRIMARYKEY, ISRVERSION, LIMITPARAMNAMES,
       FOLLOWORDER, SORTDIRECTION, SORTORDER, AGRFUNCTION, FLAGFIELDNAME, FLAGDISPLAYLABEL, FLAGNOTE,
       FLAGDEFAULTWIDTH, FLAGCANTEDIT, FLAGNOVISUALIZE, FLAGREQUIRED, FLAGLIMITPARAMNAMES, FLAGAGRFUNCTION,
       ISTIMESTAMPFIELD, ISBUDGET, AVAILABLEINDEREF, ANNOTATION, ALIAS, DEREFNAME)
    VALUES
      (ID_, FIELDKIND_, DESCRIPTIONLEVEL_, ANCESTORREF_, SELECTIONREF_, TABLEREF_, FIELDNAME_, DATATYPE_, SUBDATATYPE_,
       FIELDSIZE_, DISPLAYLABEL_, NOTE_, DEFAULTWIDTH_, EDITMASK_, DISPLAYFORMAT_, EDITFORMAT_, CANTEDIT_, NOVISUALIZE_,
       ENUMSREF_, REQUIRED_, FOREIGNKEY_, ONDELACTION_, PRIMARYKEY_, ISRVERSION_, LIMITPARAMNAMES_,
       FOLLOWORDER_, SORTDIRECTION_, SORTORDER_, AGRFUNCTION_, FLAGFIELDNAME_, FLAGDISPLAYLABEL_, FLAGNOTE_,
       FLAGDEFAULTWIDTH_, FLAGCANTEDIT_, FLAGNOVISUALIZE_, FLAGREQUIRED_, FLAGLIMITPARAMNAMES_, FLAGAGRFUNCTION_,
       ISTIMESTAMPFIELD_, ISBUDGET_, AVAILABLEINDEREF_, ANNOTATION_, ALIAS_, DEREFNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  EVENTCODE_ NUMBER,
  SCRIPTNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONEVENTS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONEVENTS SET
      SELECTIONREF = SELECTIONREF_,
      EVENTCODE = EVENTCODE_,
      SCRIPTNAME = SCRIPTNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONEVENTS
      (ID, SELECTIONREF, EVENTCODE, SCRIPTNAME)
    VALUES
      (ID_, SELECTIONREF_, EVENTCODE_, SCRIPTNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_DELETE(
  ID_ NUMBER
) IS
BEGIN
  UPDATE DOCUMENTFIELDS SET
    FIELDINFOREF = NULL
  WHERE FIELDINFOREF = ID_;
  DELETE FROM FIELDSINFO FI
  WHERE FI.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONSDETAIL SLD
  WHERE SLD.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONEVENTS SE
  WHERE SE.ID = ID_;
END;
/

-- 
-- INVESTOBJECT
CALL FIELDSINFO_IMPORT(38206, 0, 1, null, 38203, null, 'SUBCODE', 1, 0, 50, '   .', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

--  
DROP PROCEDURE SELECTIONS_IMPORT
/

DROP PROCEDURE SELECTIONSDETAIL_IMPORT
/

DROP PROCEDURE FIELDSINFO_IMPORT
/

DROP PROCEDURE SELECTIONEVENTS_IMPORT
/

DROP PROCEDURE FIELDSINFO_DELETE
/

DROP PROCEDURE SELECTIONSDETAIL_DELETE
/

DROP PROCEDURE SELECTIONS_DELETE
/

DROP PROCEDURE SELECTIONEVENTS_DELETE
/

CREATE OR REPLACE PROCEDURE ImportDocCLS (
   ID_                 NUMBER,
   DOCTYPE_            NUMBER,
   DOCTYPENOTE_        VARCHAR2,
   TABLENAME_          VARCHAR2,
   TABLENAMEURM_       VARCHAR2,
   PRIMARYKEYNAME_     VARCHAR2,
   PRIMARYKEYNAMEURM_  VARCHAR2,
   LINKFIELDNAME_      VARCHAR2,
   LINKFIELDNAMEURM_   VARCHAR2,
   CLSTYPE_            NUMBER,
   SELECTIONREFBUDGET_ NUMBER,
   SELECTIONREFURM_    NUMBER,
   PROGINDEX_          NUMBER
) IS IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
   INTO IDExists$
   FROM DOCUMENTCLS
   WHERE (ID = ID_);

   IF (IDExists$ = 0) THEN
   INSERT INTO DOCUMENTCLS
   (ID, DOCTYPE, DOCTYPENOTE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM, LINKFIELDNAME, LINKFIELDNAMEURM, CLSTYPE, 
     SELECTIONREFBUDGET, SELECTIONREFURM, PROGINDEX)
   VALUES (ID_, DOCTYPE_, DOCTYPENOTE_, TABLENAME_, TABLENAMEURM_, PRIMARYKEYNAME_, PRIMARYKEYNAMEURM_, LINKFIELDNAME_, LINKFIELDNAMEURM_, CLSTYPE_, 
     SELECTIONREFBUDGET_, SELECTIONREFURM_, PROGINDEX_);
   ELSE
   UPDATE DOCUMENTCLS 
   SET
     DOCTYPENOTE = DOCTYPENOTE_,
     TABLENAME = TABLENAME_,
     TABLENAMEURM = TABLENAMEURM_,
     PRIMARYKEYNAME = PRIMARYKEYNAME_,
     PRIMARYKEYNAMEURM = PRIMARYKEYNAMEURM_,
     LINKFIELDNAME = LINKFIELDNAME_,
     LINKFIELDNAMEURM = LINKFIELDNAMEURM_,
     CLSTYPE = CLSTYPE_,
     SELECTIONREFBUDGET = SELECTIONREFBUDGET_,
     SELECTIONREFURM = SELECTIONREFURM_,
     PROGINDEX = PROGINDEX_
   WHERE  
    (ID = ID_)
    AND NOT (
            (
                    ((DOCTYPENOTE IS NOT NULL AND DOCTYPENOTE_ IS NOT NULL) AND
                       (UPPER (DOCTYPENOTE) = UPPER (DOCTYPENOTE_))
                    )
                    OR (DOCTYPENOTE IS NULL AND DOCTYPENOTE_ IS NULL)
                )    
        AND (UPPER (TABLENAME) = UPPER (TABLENAME_))    
        AND (
                    ((TABLENAMEURM IS NOT NULL AND TABLENAMEURM_ IS NOT NULL) AND
                       (UPPER (TABLENAMEURM) = UPPER (TABLENAMEURM_))
                    )
                    OR (TABLENAMEURM IS NULL AND TABLENAMEURM_ IS NULL)
                )    
        AND (UPPER (PRIMARYKEYNAME) = UPPER (PRIMARYKEYNAME_))
        AND (
                    ((PRIMARYKEYNAMEURM IS NOT NULL AND PRIMARYKEYNAMEURM_ IS NOT NULL) AND
                       (UPPER (PRIMARYKEYNAMEURM) = UPPER (PRIMARYKEYNAMEURM_))
                    )
                    OR (PRIMARYKEYNAMEURM IS NULL AND PRIMARYKEYNAMEURM_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAME IS NOT NULL AND LINKFIELDNAME_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAME) = UPPER (LINKFIELDNAME_))
                    )
                    OR (LINKFIELDNAME IS NULL AND LINKFIELDNAME_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAMEURM IS NOT NULL AND LINKFIELDNAMEURM_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAMEURM) = UPPER (LINKFIELDNAMEURM_))
                    )
                    OR (LINKFIELDNAMEURM IS NULL AND LINKFIELDNAMEURM_ IS NULL)
                )    
        AND (
                    ((CLSTYPE IS NOT NULL AND CLSTYPE_ IS NOT NULL) AND
                       (UPPER (CLSTYPE) = UPPER (CLSTYPE_))
                    )
                    OR (CLSTYPE IS NULL AND CLSTYPE_ IS NULL)
                ) 
        AND (
                    ((PROGINDEX IS NOT NULL AND PROGINDEX_ IS NOT NULL) AND
                       (PROGINDEX = PROGINDEX_)
                    )
                    OR (PROGINDEX IS NULL AND PROGINDEX_ IS NULL)
                )   
            );
   
   END IF;
END;
/

--   
CALL ImportDocCLS(10100, 101, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10101, 101, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10102, 101, ' ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10103, 101, ' ', 'DEBT', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10104, 101, ' %  ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10105, 101, ' ', 'INCOMES32', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20100, 201, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(20101, 201, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(30100, 301, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30101, 301, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30200, 302, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30201, 302, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30300, 303, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30301, 303, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30400, 304, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30401, 304, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30500, 305, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30501, 305, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30600, 306, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30601, 306, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30700, 307, '', 'FACIALFINREESTR', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(31100, 311, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31101, 311, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31200, 312, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31201, 312, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31400, 314, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31401, 314, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31500, 315, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(31501, 315, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(992500, 9925, '', 'Cards', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992501, 9925, ' ', 'CARDSDETAIL_FACC', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(490300, 4903, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 527) ;

CALL ImportDocCLS(32200, 322, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32201, 322, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32300, 323, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32301, 323, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32400, 324, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(32401, 324, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(40100, 401, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 130) ;

CALL ImportDocCLS(40101, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 131) ;

CALL ImportDocCLS(40102, 401, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 137) ;

CALL ImportDocCLS(40103, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 132) ;

CALL ImportDocCLS(40104, 401, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 134) ;

CALL ImportDocCLS(40105, 401, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 138) ;

CALL ImportDocCLS(40106, 401, ' %', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 133) ;

CALL ImportDocCLS(40107, 401, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40108, 401, '. ', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40109, 401, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 340) ;

CALL ImportDocCLS(40110, 401, '.', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 341) ;

CALL ImportDocCLS(40111, 401, '', 'LOANCREDITCONTRACTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 342) ;

CALL ImportDocCLS(50100, 501, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 120) ;

CALL ImportDocCLS(50101, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 121) ;

CALL ImportDocCLS(50102, 501, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 127) ;

CALL ImportDocCLS(50103, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 122) ;

CALL ImportDocCLS(50104, 501, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 124) ;

CALL ImportDocCLS(50105, 501, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 128) ;

CALL ImportDocCLS(50106, 501, ' %', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 123) ;

CALL ImportDocCLS(50107, 501, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(50108, 501, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 321) ;

CALL ImportDocCLS(70100, 701, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70101, 701, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70200, 702, '', 'PAYDOC32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70201, 702, '', 'PAYDOC32', ' ', 'ID', ' ', 'PARENTINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70300, 703, '', 'FINDOCDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, 36) ;

CALL ImportDocCLS(80100, 801, '', 'LIMITNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80101, 801, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 57) ;

CALL ImportDocCLS(80200, 802, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80300, 803, '', 'REQUESTFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80301, 803, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80400, 804, '', 'LIMITFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90100, 901, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 145) ;

CALL ImportDocCLS(90101, 901, '', 'INCOMES32', ' ', 'ID', ' ', 'RecordIndex', ' ', 0, null, null, 0) ;

CALL ImportDocCLS(90300, 903, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90301, 903, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90500, 905, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 44) ;

CALL ImportDocCLS(90600, 906, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 41) ;

CALL ImportDocCLS(90601, 906, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 42) ;

CALL ImportDocCLS(120100, 1201, '', 'BUH_JOURNAL', ' ', 'ID', ' ', '', ' ', 0, null, null, 309) ;

CALL ImportDocCLS(150100, 1501, '', 'ORGOPERAT', ' ', 'ID', ' ', '', ' ', 0, null, null, 35) ;

CALL ImportDocCLS(160100, 1601, '', 'PROMISE_CAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(160101, 1601, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', 'TITLE_REF', ' ', 0, null, null, 345) ;

CALL ImportDocCLS(160200, 1602, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(170100, 1701, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 222) ;

CALL ImportDocCLS(170200, 1702, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 221) ;

CALL ImportDocCLS(170201, 1702, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(190100, 1901, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(190101, 1901, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(220100, 2201, '', 'BUDNOTIFY', 'BUDNOTIFY', 'ID', ' ', '', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(220101, 2201, '', 'BUDGETDATA', 'BUDGETDATA', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(280100, 2801, '', 'ACCSOPERTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(280101, 2801, '', 'PAYDOC32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 16) ;

CALL ImportDocCLS(280200, 2802, '', 'DFACCOUNTOPERATION', ' ', 'ID', ' ', '', ' ', 0, null, null, 50) ;

CALL ImportDocCLS(440100, 4401, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(440101, 4401, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(0, 0, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991304, 9913, ' ', 'STATICLINKS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(440300, 4403, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(440301, 4403, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(989500, 9895, ' ', 'OKTMO', 'OKTMO', 'id', 'id', '', '', 95, null, null, null) ;

CALL ImportDocCLS(990300, 9903, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990301, 9903, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990302, 9903, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990500, 9905, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90200, 902, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 38) ;

CALL ImportDocCLS(20701, 207, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(90700, 907, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181200, 1812, '', 'ED_CorrectionCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181000, 1810, '', 'ED_OUTPAYDOC', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20700, 207, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(181001, 1810, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992700, 9927, '', 'REMOTECLIENT', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550100, 5501, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(20801, 208, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(30701, 307, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', 'REESTR_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21100, 211, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 275) ;

CALL ImportDocCLS(490100, 4901, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 525) ;

CALL ImportDocCLS(992701, 9927, '  ', 'REMOTEREADRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(550101, 5501, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(490301, 4903, '', 'ARCHIVEOPLOG', ' ', 'ID', ' ', 'DATAPACKETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(390100, 3901, '', 'DELOIN', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21101, 211, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(992300, 9923, '', 'SIGNSCHEMECAPTION', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181201, 1812, '', 'ED_CorrectionDetail', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(550200, 5502, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(20800, 208, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(550201, 5502, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(90000, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992301, 9923, '', 'SIGNSCHEMEDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991600, 9916, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992200, 9922, '', 'ARCHIVEDOCTYPE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(90001, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(390101, 3901, '', 'DELOEXEC', ' ', 'ID', ' ', 'DOCID', ' ', 0, null, null, null) ;

CALL ImportDocCLS(180700, 1807, '', 'PayDocExchange', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(21102, 211, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(991700, 9917, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991200, 9912, '', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181600, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30800, 308, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250100, 2501, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 305) ;

CALL ImportDocCLS(21200, 212, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 276) ;

CALL ImportDocCLS(250101, 2501, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(30801, 308, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250200, 2502, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 304) ;

CALL ImportDocCLS(250201, 2502, ' ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(988900, 9889, ' ', 'SubsidyCls', ' ', 'id', ' ', '', '', 89, null, null, null) ;

CALL ImportDocCLS(250202, 2502, '  ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 304) ;

CALL ImportDocCLS(988700, 9887, ' ', 'VariantCls', ' ', 'ID', ' ', '', '', 87, null, null, null) ;

CALL ImportDocCLS(520100, 5201, '', 'WritExecutionCaption', 'WritExecutionCaption', 'id', 'id', '', '', 0, null, null, 555) ;

CALL ImportDocCLS(990800, 9908, '', 'DocumentTypes', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(250300, 2503, '', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21201, 212, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(250301, 2503, '', 'EXECUTIONDOCUMENTSDETAIL', 'EXECUTIONDOCUMENTSDETAIL', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(180500, 1805, '', 'BANKEXCH_MERDOC', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20201, 202, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20301, 203, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20401, 204, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20501, 205, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20601, 206, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190201, 1902, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190301, 1903, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(20000, 200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190601, 1906, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(20200, 202, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20300, 203, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20400, 204, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20500, 205, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20600, 206, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190200, 1902, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190300, 1903, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(180501, 1805, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(190600, 1906, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(988400, 9884, ' ', 'TransfertCLS', ' ', 'ID', ' ', '', '', 84, null, null, null) ;

CALL ImportDocCLS(988800, 9888, ' ', 'OKP', ' ', 'ID', ' ', '', '', 88, null, null, null) ;

CALL ImportDocCLS(989900, 9899, ' ', 'DBUsers', ' ', 'ID', ' ', '', '', 201, null, null, null) ;

CALL ImportDocCLS(990801, 9908, ' ', 'DOCUMENTFIELDS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(361000, 3610, '', 'UTYPEDFORMSCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 550) ;

CALL ImportDocCLS(987200, 9872, ' ', 'BalanceCls', ' ', 'ID', ' ', '', '', 72, null, null, null) ;

CALL ImportDocCLS(984600, 9846, ' ', 'BUHPAYMENTCLS', ' ', 'ID', ' ', '', '', 46, null, null, null) ;

CALL ImportDocCLS(981800, 9818, ' ', 'CURRENCYCLS', ' ', 'ID', ' ', '', '', 18, null, null, null) ;

CALL ImportDocCLS(988500, 9885, ' ', 'AssignmentKind', ' ', 'ID', ' ', '', '', 85, null, null, null) ;

CALL ImportDocCLS(983500, 9835, ' ', 'BUDGETTYPE', ' ', 'ID', ' ', '', '', 35, null, null, null) ;

CALL ImportDocCLS(985800, 9858, ' ', 'DEBTTYPE', ' ', 'ID', ' ', '', '', 58, null, null, null) ;

CALL ImportDocCLS(988600, 9886, ' ', 'AssignmentSource', ' ', 'ID', ' ', ' ', ' ', 86, null, null, null) ;

CALL ImportDocCLS(988300, 9883, ' ', 'Org_Type', ' ', 'ID', ' ', '', '', 83, null, null, null) ;

CALL ImportDocCLS(986400, 9864, ' ', 'PlanDocType', ' ', 'ID', ' ', '', '', 64, null, null, null) ;

CALL ImportDocCLS(985700, 9857, ' ', 'LOANTYPE', ' ', 'ID', ' ', '', '', 57, null, null, null) ;

CALL ImportDocCLS(984300, 9843, ' ', 'PAYTYPECLS', ' ', 'ID', ' ', '', '', 43, null, null, null) ;

CALL ImportDocCLS(982300, 9823, ' ', 'GOSNI', ' ', 'ID', ' ', '', '', 23, null, null, null) ;

CALL ImportDocCLS(982200, 9822, ' ', 'GroupInf_CLS', ' ', 'ID', ' ', '', '', 22, null, null, null) ;

CALL ImportDocCLS(982900, 9829, ' ', 'DocBase', ' ', 'ID', ' ', '', '', 29, null, null, null) ;

CALL ImportDocCLS(981100, 9811, ' ', 'DocTypes', ' ', 'ID', ' ', '', '', 11, null, null, null) ;

CALL ImportDocCLS(986000, 9860, ' ', 'MEASUREMENTCLS', ' ', 'ID', ' ', '', '', 60, null, null, null) ;

CALL ImportDocCLS(988000, 9880, ' ', 'FundsSource', ' ', 'ID', ' ', '', '', 80, null, null, null) ;

CALL ImportDocCLS(985200, 9852, ' ', 'InnerFinSource', ' ', 'ID', ' ', '', '', 52, null, null, null) ;

CALL ImportDocCLS(981300, 9813, ' ', 'NOTIFYTYPES', ' ', 'ID', ' ', '', '', 13, null, null, null) ;

CALL ImportDocCLS(984500, 9845, ' ', 'PAYSYMBOLCLS', ' ', 'ID', ' ', '', '', 45, null, null, null) ;

CALL ImportDocCLS(980400, 9804, ' ', 'KVR', ' ', 'ID', ' ', '', '', 4, null, null, null) ;

CALL ImportDocCLS(980300, 9803, ' ', 'KVSR', ' ', 'ID', ' ', '', '', 3, null, null, null) ;

CALL ImportDocCLS(980900, 9809, ' ', 'KD', ' ', 'ID', ' ', '', '', 9, null, null, null) ;

CALL ImportDocCLS(984700, 9847, ' ', 'TYPEOPERATIONCLS', ' ', 'ID', ' ', '', '', 47, null, null, null) ;

CALL ImportDocCLS(986800, 9868, ' ', 'KESR', ' ', 'ID', ' ', '', '', 68, null, null, null) ;

CALL ImportDocCLS(987900, 9879, ' ', 'TargetCls', ' ', 'ID', ' ', '', '', 79, null, null, null) ;

CALL ImportDocCLS(985100, 9851, ' ', 'Error', ' ', 'ID', ' ', '', '', 51, null, null, null) ;

CALL ImportDocCLS(982100, 9821, ' ', 'ACC_CLS', ' ', 'ID', ' ', '', '', 21, null, null, null) ;

CALL ImportDocCLS(981400, 9814, ' ', 'KSHK', ' ', 'ID', ' ', '', '', 14, null, null, null) ;

CALL ImportDocCLS(980200, 9802, ' ', 'kfsr', ' ', 'ID', ' ', '', '', 2, null, null, null) ;

CALL ImportDocCLS(980500, 9805, ' ', 'KCSR', ' ', 'ID', ' ', '', '', 5, null, null, null) ;

CALL ImportDocCLS(984100, 9841, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', '', '', 41, null, null, null) ;

CALL ImportDocCLS(981500, 9815, ' ', 'VALUECLS', ' ', 'ID', ' ', '', '', 15, null, null, null) ;

CALL ImportDocCLS(982800, 9828, ' ', 'FACT', ' ', 'ID', ' ', '', '', 28, null, null, null) ;

CALL ImportDocCLS(984800, 9848, ' ', 'PAYDESTINATIONCLS', ' ', 'ID', ' ', '', '', 48, null, null, null) ;

CALL ImportDocCLS(986900, 9869, ' ', 'DirectionCLS', ' ', 'ID', ' ', '', '', 69, null, null, null) ;

CALL ImportDocCLS(986200, 9862, ' ', 'OKATO', ' ', 'ID', ' ', '', '', 62, null, null, null) ;

CALL ImportDocCLS(988200, 9882, ' ', 'OKOPF', ' ', 'ID', ' ', '', '', 82, null, null, null) ;

CALL ImportDocCLS(988100, 9881, ' ', 'OKFS', ' ', 'ID', ' ', '', '', 81, null, null, null) ;

CALL ImportDocCLS(981600, 9816, ' ', 'MeansCLS', ' ', 'ID', ' ', '', '', 16, null, null, null) ;

CALL ImportDocCLS(985900, 9859, ' ', 'DepartmentCLS', ' ', 'ID', ' ', '', '', 59, null, null, null) ;

CALL ImportDocCLS(986500, 9865, ' ', 'BuhAccPlan', ' ', 'ID', ' ', '', '', 65, null, null, null) ;

CALL ImportDocCLS(986100, 9861, ' ', 'TenderObjects', ' ', 'ID', ' ', '', '', 61, null, null, null) ;

CALL ImportDocCLS(985000, 9850, ' ', 'RejectCLS', ' ', 'ID', ' ', '', '', 50, null, null, null) ;

CALL ImportDocCLS(987000, 9870, ' ', 'ProgramCode', ' ', 'ID', ' ', '', '', 70, null, null, null) ;

CALL ImportDocCLS(981200, 9812, ' ', 'RegionCLS', ' ', 'ID', ' ', '', '', 12, null, null, null) ;

CALL ImportDocCLS(982600, 9826, ' ', 'BUDGETACCOUNTS', ' ', 'ID', ' ', '', '', 26, null, null, null) ;

CALL ImportDocCLS(981700, 9817, ' ', 'REFCLS', ' ', 'ID', ' ', '', '', 17, null, null, null) ;

CALL ImportDocCLS(981000, 9810, ' ', 'SubKD', ' ', 'ID', ' ', '', '', 10, null, null, null) ;

CALL ImportDocCLS(980600, 9806, ' ', 'SUBKCSR', ' ', 'ID', ' ', '', '', 6, null, null, null) ;

CALL ImportDocCLS(980800, 9808, ' ', 'KESRSubCode', ' ', 'ID', ' ', '', '', 8, null, null, null) ;

CALL ImportDocCLS(986300, 9863, ' ', 'COLLATERALTYPE', ' ', 'ID', ' ', '', '', 63, null, null, null) ;

CALL ImportDocCLS(982000, 9820, ' ', 'ORG_CLS', ' ', 'ID', ' ', '', '', 20, null, null, null) ;

CALL ImportDocCLS(983400, 9834, ' ', 'ReportType', ' ', 'ID', ' ', '', '', 34, null, null, null) ;

CALL ImportDocCLS(985300, 9853, ' ', 'REESTRTYPE', ' ', 'ID', ' ', '', '', 53, null, null, null) ;

CALL ImportDocCLS(984900, 9849, ' ', 'MEANSTYPE', ' ', 'ID', ' ', '', '', 49, null, null, null) ;

CALL ImportDocCLS(982700, 9827, ' ', 'FinType', ' ', 'ID', ' ', '', '', 27, null, null, null) ;

CALL ImportDocCLS(984400, 9844, ' ', 'Org_AccDefaults', ' ', 'ID', ' ', '', '', 44, null, null, null) ;

CALL ImportDocCLS(960100, 9601, ' ', 'ORGANIZATIONS', ' ', 'ID', ' ', '', '', 1000, null, null, null) ;

CALL ImportDocCLS(960200, 9602, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', '', '', 1001, null, null, null) ;

CALL ImportDocCLS(960400, 9604, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', '', 1003, null, null, null) ;

CALL ImportDocCLS(960300, 9603, ' ', 'BANKS', ' ', 'ID', ' ', '', '', 1002, null, null, null) ;

CALL ImportDocCLS(987100, 9871, ' ', 'BuhOperationCls', ' ', 'Id', ' ', '', '', 71, null, null, null) ;

CALL ImportDocCLS(987800, 9878, ' ', 'budgets_s', ' ', 'id', ' ', '', '', 78, null, null, null) ;

CALL ImportDocCLS(991400, 9914, '', 'DATAPACKETTYPES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991401, 9914, '', 'DATAPACKETCONTENT', ' ', 'ID', ' ', 'DATAPACKETTYPE', '', 0, null, null, null) ;

CALL ImportDocCLS(991500, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991501, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', 'ID', '', 0, null, null, null) ;

CALL ImportDocCLS(20001, 200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(30000, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30001, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190000, 1900, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190001, 1900, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(220000, 2200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(220001, 2200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991300, 9913, '', 'INTERFACES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991301, 9913, '', 'Permissions', ' ', 'ID', ' ', 'INTERFACEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(991302, 9913, '', 'LinkType', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991303, 9913, ' ', ' ', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(490200, 4902, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 526) ;

CALL ImportDocCLS(250400, 2504, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', '', 0, null, null, 314) ;

CALL ImportDocCLS(300100, 3001, '', 'TenderCaption', ' ', 'ID', ' ', '', '', 0, null, null, 230) ;

CALL ImportDocCLS(250401, 2504, '  ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(250402, 2504, '   ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 304) ;

CALL ImportDocCLS(250403, 2504, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(300600, 3006, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 241) ;

CALL ImportDocCLS(250102, 2501, '  . ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(70202, 702, '', 'PAYDOCEXCHANGE', ' ', 'ID', ' ', 'PAYDOCREF', '', 0, null, null, null) ;

CALL ImportDocCLS(170101, 1701, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20900, 209, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 274) ;

CALL ImportDocCLS(300601, 3006, '  ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 241) ;

CALL ImportDocCLS(300602, 3006, '   ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300300, 3003, '', 'TenderResultCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(300101, 3001, ' ', 'TenderProduct', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 230) ;

CALL ImportDocCLS(300102, 3001, ' ', 'TenderLot', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300103, 3001, '   ', 'TENDERSOURCEORG', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300104, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300105, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300106, 3001, ' ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300107, 3001, '   ', 'TENDERSUPPLEMENTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300108, 3001, ',  ', 'TENDERSUPDOCUMENT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(370100, 3701, '', 'TenderObjects', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(520101, 5201, '', 'WritExecutionDetail', 'WritExecutionDetail', 'id', 'id', 'RecordIndex', '', 0, null, null, 556) ;

CALL ImportDocCLS(20901, 209, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(21000, 210, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 252) ;

CALL ImportDocCLS(21001, 210, ', ', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 252) ;

CALL ImportDocCLS(21002, 210, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 253) ;

CALL ImportDocCLS(991800, 9918, '', 'USERGENERATOR', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991801, 9918, '', 'USERGENERATORFIELDS', ' ', 'ID', ' ', 'GENREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992702, 9927, '   ', 'REMOTEINPUTRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(21202, 212, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(990802, 9908, ' ', 'STATE_DOCSTATES', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990803, 9908, '', 'STATE_JUMPS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990804, 9908, '', 'STATE_ACTIONS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992703, 9927, '   ', 'REMOTECLIENTACCOUNT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992000, 9920, '', 'BUHOPERATIONCLS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992001, 9920, '', 'BUHACCCORR', ' ', 'ID', ' ', 'BUHOPERATIONCLS', '', 0, null, null, null) ;

CALL ImportDocCLS(992100, 9921, '', 'BUDGETS_S', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992101, 9921, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992102, 9921, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(989000, 9890, ' ', 'BudAllocationCls', ' ', 'id', ' ', '', '', 90, null, null, null) ;

CALL ImportDocCLS(989100, 9891, ' ', 'PayPromiseCls', ' ', 'id', ' ', '', '', 91, null, null, null) ;

CALL ImportDocCLS(550300, 5503, '', 'ReplacementClsCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550301, 5503, '   ', 'ReplacementClsDetail', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(550302, 5503, ' ', 'ReplacementClsDetailInfo', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(250302, 2503, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'EXECUTIONREF', '', 0, null, null, 308) ;

CALL ImportDocCLS(181400, 1814, '', 'BANKEXCH_LS_KB', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(180900, 1809, '', 'BANKEXCH_SUBSTITUTION', 'BANKEXCH_SUBSTITUTION', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181500, 1815, '', 'BANKEXCH_KO_SALDO', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992900, 9929, '', 'BudStruct', 'BudStruct', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992201, 9922, '', 'ARCHIVEDOCPARAMS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(992400, 9924, '', 'SIGNS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(480101, 4801, '', 'GeneralDocsDetail', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992502, 9925, '', 'CARDSDETAIL_KESR', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(250203, 2502, ' ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 304) ;

CALL ImportDocCLS(250404, 2504, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', '', 0, null, null, 318) ;

CALL ImportDocCLS(520102, 5201, '2', 'WritExecutionNotify', 'WritExecutionNotify', 'id', 'id', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(989200, 9892, ' ', 'ArchiveDocType', ' ', 'id', ' ', '', '', 92, null, null, null) ;

CALL ImportDocCLS(480100, 4801, '', 'GeneralDocuments', ' ', 'ID', ' ', '', '', 0, null, null, 528) ;

CALL ImportDocCLS(992600, 9926, '', 'WritNotifyCls', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992601, 9926, '', 'WRITNOTIFYCLSDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992602, 9926, ' ', 'WritNotifyClsPart', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(31600, 316, '', 'ManagerBid', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20902, 209, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(992704, 9927, '  + /', 'DUALRIGHTS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992705, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992706, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(990400, 9904, '', 'CONTACTPERSONS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181601, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992707, 9927, '', 'SIGNCERTIFICATE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992708, 9927, '  ', 'SIGNDOCUMENTSGROUP', ' ', 'ID', ' ', 'CLIENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(510100, 5101, '', 'StoredAttributesCaption', 'StoredAttributesCaption', 'id', 'id', '', '', 0, null, null, null) ;

CALL ImportDocCLS(510101, 5101, '', 'StoredAttributesDetail', 'StoredAttributesDetail', 'id', 'id', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(250405, 2504, ' ', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', 'AGREEMENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(993000, 9930, '', 'AUTOSANCTIONDATA', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(301000, 3010, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 242) ;

CALL ImportDocCLS(970200, 9702, ' ', 'AnalyticalGroupIFS', 'AnalyticalGroupIFS', 'ID', 'ID', '', '', 102, null, null, null) ;

CALL ImportDocCLS(970100, 9701, ' ', 'AnalyticalGroupKD', 'AnalyticalGroupKD', 'ID', 'ID', '', '', 101, null, null, null) ;

CALL ImportDocCLS(181800, 1818, '', 'OOS_CONTRACT', 'OOS_CONTRACT', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(301100, 3011, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 243) ;

CALL ImportDocCLS(301101, 3011, ' ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 243) ;

CALL ImportDocCLS(300500, 3005, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 240) ;

CALL ImportDocCLS(181801, 1818, '', 'OOS_CONTRACT_FINANCES', 'OOS_CONTRACT_FINANCES', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(181802, 1818, '', 'OOS_CONTRACT_PRODUCTS', 'OOS_CONTRACT_PRODUCTS', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(181803, 1818, '', 'OOS_CONTRACTPROCEDURE', 'OOS_CONTRACTPROCEDURE', 'ID', 'ID', 'RegNum', 'RegNum', 0, null, null, null) ;

CALL ImportDocCLS(989700, 9897, ' ', 'ContractCostsCls', 'ContractCostsCls', 'id', 'id', '', '', 97, null, null, null) ;

CALL ImportDocCLS(960101, 9601, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(989800, 9898, ' ', 'PURCHASETYPE ', 'PURCHASETYPE ', 'id', 'id', '', '', 98, null, null, null) ;

CALL ImportDocCLS(21300, 213, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 277) ;

CALL ImportDocCLS(21301, 213, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 277) ;

CALL ImportDocCLS(21400, 214, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 278) ;

CALL ImportDocCLS(21401, 214, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 278) ;

CALL ImportDocCLS(993200, 9932, '', 'BudStrLink', 'BudStrLink', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(993201, 9932, '', 'BudStrLink', 'BudStrLink', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(21500, 215, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 279) ;

CALL ImportDocCLS(21501, 215, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 279) ;

CALL ImportDocCLS(250204, 2502, ' ', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', 'AGREEMENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(181900, 1819, '', 'OOS_CONTRACT', 'OOS_CONTRACT', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181901, 1819, '', 'OOS_CONTRACT_FINANCES', 'OOS_CONTRACT_FINANCES', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(182000, 1820, '', 'OOS_CONTRACT', 'OOS_CONTRACT', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(182001, 1820, '', 'OOS_CONTRACT_FINANCES', 'OOS_CONTRACT_FINANCES', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(181804, 1818, '', 'OOS_ATTACHMENTS', 'OOS_ATTACHMENTS', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(250406, 2504, '', 'Suppliers', 'Suppliers', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(540200, 5402, '', 'EPBSExportLogCaption', 'EPBSExportLogCaption', 'id', 'id', '', '', 0, null, null, null) ;

CALL ImportDocCLS(540201, 5402, '', 'EPBSExportLogDetail', 'EPBSExportLogDetail', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(970900, 9709, ' ', 'TargetCls', ' ', 'ID', ' ', '', '', 109, null, null, null) ;

CALL ImportDocCLS(985400, 9854, ' ', 'InvestObject', ' ', 'ID', ' ', '', '', 54, null, null, null) ;

CALL ImportDocCLS(182100, 1821, '', 'PayDocExchange', 'PayDocExchange', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(470100, 4701, '', 'SignCertificate', 'SignCertificate', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(971000, 9710, ' ', 'NATIONALPROJECT', 'NATIONALPROJECT', 'ID', 'ID', '', '', 110, null, null, null) ;

CALL ImportDocCLS(21600, 216, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 280) ;

CALL ImportDocCLS(21601, 216, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 280) ;

CALL ImportDocCLS(21700, 217, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 281) ;

CALL ImportDocCLS(21701, 217, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 281) ;

CALL ImportDocCLS(21702, 217, '2', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 281) ;

CALL ImportDocCLS(993300, 9933, '', 'ClsCorr', 'ClsCorr', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(993301, 9933, '', 'ClsCorrColumns', 'ClsCorrColumns', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(993400, 9934, '', 'ClsCorr', 'ClsCorr', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(993401, 9934, '', 'ClsCorrValues', 'ClsCorrValues', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(971100, 9711, ' ', 'RegProjectResult', 'RegProjectResult', 'ID', 'ID', '', '', 111, null, null, null) ;

CALL ImportDocCLS(21800, 218, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 282) ;

CALL ImportDocCLS(21801, 218, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 282) ;

CALL ImportDocCLS(32500, 325, '', 'FACIALFINCAPTION', 'FACIALFINCAPTION', 'ID', 'ID', '', '', 0, null, null, 283) ;

CALL ImportDocCLS(32501, 325, '', 'FACIALFINDETAIL', 'FACIALFINDETAIL', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, 283) ;

CALL ImportDocCLS(182400, 1824, '', 'PayDocExchange ', 'PayDocExchange ', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(182401, 1824, '', 'ED_OUT_FACIALACC', 'ED_OUT_FACIALACC', 'ID', 'ID', 'ELDOCREF', '', 0, null, null, null) ;

CALL ImportDocCLS(182500, 1825, '', 'PayDocExchange', 'PayDocExchange', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(971300, 9713, ' ', 'PayTargetFunds', 'PayTargetFunds', 'ID', 'ID', '', '', 113, null, null, null) ;

CALL ImportDocCLS(971200, 9712, ' ', 'IncomeTargetFunds', 'IncomeTargetFunds', 'ID', 'ID', '', '', 112, null, null, null) ;

CALL ImportDocCLS(971400, 9714, ' ', 'AnalyticalPartition', 'AnalyticalPartition', 'ID', 'ID', '', '', 114, null, null, null) ;

CALL ImportDocCLS(971600, 9716, ' ', 'PaymentCodeType', 'PaymentCodeType', 'ID', 'ID', '', '', 116, null, null, null) ;

DROP PROCEDURE ImportDocCLS
/

COMMIT WORK
/


CREATE OR REPLACE PROCEDURE ImportField (
   ID_                NUMBER,
   NAME_              VARCHAR2,
   ITFFIELDNAME_      VARCHAR2,
   NOTE_              VARCHAR2,
   TEMPLATEFIELD_     VARCHAR2,
   ISBUDGET_          NUMBER,
   DOCTYPEREF_        NUMBER,
   DETAILNUMBER_      NUMBER,
   ONLYREAD_          NUMBER,
   ReportFieldName_   VARCHAR2,
   KIND_	      NUMBER,
   FIELDINFOREF_      NUMBER,
   CONTAINERREF_      NUMBER, 
   ATTRFIELDKIND_     NUMBER,
   ATTRIBUTENAME_     VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentFields
    WHERE (ID = ID_);

   IF (IDExists$ <> 0) THEN
      UPDATE DocumentFields
         SET NAME = NAME_,
             ITFFIELDNAME = ITFFIELDNAME_,
             NOTE = NOTE_,
             TEMPLATEFIELD = TEMPLATEFIELD_,
             ISBUDGET = ISBUDGET_,
             DOCTYPEREF = DOCTYPEREF_,
             DETAILNUMBER = DETAILNUMBER_,
             ONLYREAD = ONLYREAD_,
             ReportFieldName = ReportFieldName_,
			       FIELDINFOREF = FIELDINFOREF_, 
             CONTAINERREF = CONTAINERREF_, 
             ATTRFIELDKIND = ATTRFIELDKIND_,
             ATTRIBUTENAME = ATTRIBUTENAME_
       WHERE (ID = ID_)
         AND NOT (
                      (
                          (
                           (NAME IS NOT NULL AND NAME_ IS NOT NULL) AND
                           (UPPER (NAME) = UPPER (NAME_))
                          )
                       OR (NAME IS NULL AND NAME_ IS NULL)
                      )

                  AND (
                          (
                           (ITFFIELDNAME_ IS NOT NULL AND ITFFIELDNAME IS NOT NULL) AND
                           (UPPER (ITFFIELDNAME_) = UPPER (ITFFIELDNAME))
                          )
                       OR (ITFFIELDNAME_ IS NULL AND ITFFIELDNAME IS NULL)
                      )
                      
                  AND (
                          (
                           (NOTE IS NOT NULL AND NOTE_ IS NOT NULL) AND
                           (UPPER (NOTE) = UPPER (NOTE_))
                          )
                       OR (NOTE IS NULL AND NOTE_ IS NULL)
                      )
                  AND (UPPER (TEMPLATEFIELD) = UPPER (TEMPLATEFIELD_))
                  AND (
                          (
                           (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                           (ISBUDGET = ISBUDGET_)
                          )
                       OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                      )
                  AND (
                          (
                           (FIELDINFOREF IS NOT NULL AND FIELDINFOREF_ IS NOT NULL) AND
                           (FIELDINFOREF = FIELDINFOREF_)
                          )
                       OR (FIELDINFOREF IS NULL AND FIELDINFOREF_ IS NULL)
                      )
                  AND (
                          (
                           (CONTAINERREF IS NOT NULL AND CONTAINERREF_ IS NOT NULL) AND
                           (CONTAINERREF = CONTAINERREF_)
                          )
                       OR (CONTAINERREF IS NULL AND CONTAINERREF_ IS NULL)
                      )   
                  AND (
                          (
                           (ATTRFIELDKIND IS NOT NULL AND ATTRFIELDKIND_ IS NOT NULL) AND
                           (ATTRFIELDKIND = ATTRFIELDKIND_)
                          )
                       OR (ATTRFIELDKIND IS NULL AND ATTRFIELDKIND_ IS NULL)
                      )
                  AND (
                          (
                           (ATTRIBUTENAME_ IS NOT NULL AND ATTRIBUTENAME IS NOT NULL) AND
                           (UPPER (ATTRIBUTENAME_) = UPPER (ATTRIBUTENAME))
                          )
                       OR (ATTRIBUTENAME_ IS NULL AND ATTRIBUTENAME IS NULL)
                      )
                  AND (DOCTYPEREF = DOCTYPEREF_)
                  AND (DETAILNUMBER = DETAILNUMBER_)
                  AND (ONLYREAD = ONLYREAD_)
                  AND (
                          (
                           (ReportFieldName IS NOT NULL AND ReportFieldName_ IS NOT NULL) AND
                           (UPPER (ReportFieldName) = UPPER (ReportFieldName_))
                          )
                       OR (ReportFieldName IS NULL AND ReportFieldName_ IS NULL)
                      )
                 );
   ELSE
      INSERT INTO DocumentFields
                  (ID, NAME, ITFFIELDNAME, NOTE, TEMPLATEFIELD,
                   ISBUDGET, DOCTYPEREF, DETAILNUMBER, ONLYREAD, ReportFieldName, FIELDINFOREF, CONTAINERREF, ATTRFIELDKIND, ATTRIBUTENAME
                  )
           VALUES (ID_, NAME_, ITFFIELDNAME_, NOTE_, TEMPLATEFIELD_,
                   ISBUDGET_, DOCTYPEREF_, DETAILNUMBER_, ONLYREAD_, ReportFieldName_, FIELDINFOREF_, CONTAINERREF_, ATTRFIELDKIND_, ATTRIBUTENAME_
                  );
   END IF;

   FOR tab_rec IN (
                   SELECT ID
                     FROM DocumentFields
                    WHERE (ID <> ID_)
                      AND (DOCTYPEREF = DOCTYPEREF_)
                      AND (
                              (
                               (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                               (ISBUDGET = ISBUDGET_)
                              )
                           OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                          )
                      AND (DETAILNUMBER = DETAILNUMBER_)
              AND ( /*      ,       ,       */
                            (
                             ((ITFFIELDNAME_ IS NULL)or(ITFFIELDNAME_=' '))
                 and not((TEMPLATEFIELD_ IS NULL)or(TEMPLATEFIELD_=' '))
                 and(TEMPLATEFIELD is NOT null) and (UPPER(TEMPLATEFIELD)=UPPER(TEMPLATEFIELD_))
                            )
                    or (
                        not ((ITFFIELDNAME_ IS NULL) or (ITFFIELDNAME_=' '))
                                and (ITFFIELDNAME IS NOT NULL) and (UPPER(ITFFIELDNAME)=UPPER(ITFFIELDNAME_)))
                            )
                       )
   LOOP
      UPDATE State_OpenFields
         SET DOCFIELDREF = ID_
       WHERE (DOCFIELDREF = tab_rec.ID);

      UPDATE DOCLOCKFIELDS
         SET FIELDREF = ID_
       WHERE (FIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET PARENTFIELDREF = ID_
      WHERE (PARENTFIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET CHILDFIELDREF = ID_
      WHERE (CHILDFIELDREF = tab_rec.ID);

      DELETE FROM DocumentFields
            WHERE (ID = tab_rec.ID);
   END LOOP;
END;
/

CREATE OR REPLACE PROCEDURE DeleteFields (ID$ NUMBER) IS
BEGIN
  DELETE FROM State_OpenFields
  WHERE (docfieldref = ID$);
  DELETE FROM DOCLOCKFIELDS
  WHERE (fieldref = ID$);

  DELETE FROM STATE_JUMPCONTROL
  WHERE STATICLINKREF IN(SELECT ID FROM staticlinks
                           WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$));
  DELETE FROM staticlinks
  WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$);
  
  DELETE FROM DOCUMENTTEMPLATEFIELDS
  WHERE (FIELDS=ID$);

  DELETE FROM STOREDATTRIBUTESDETAIL
  WHERE (ATTRIBUTEFIELD = ID$) or (CONTAINERFIELD = ID$);  

  DELETE FROM DocumentFields
  WHERE (id = ID$);
END;
/

CREATE OR REPLACE PROCEDURE INSERTCONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER,
  NOTE_          VARCHAR2,
  VARCHARVALUE_  VARCHAR2,
  DOUBLEVALUE_   NUMBER,
  INTVALUE_      INTEGER,
  EDITDOCCODE_   INTEGER
) IS
  IDEXISTS$ NUMBER;
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM IntConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO INTCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,INTVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE INTCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 8) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM VarcharConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO VARCHARCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,VARCHARVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE VARCHARCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 5) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM RealConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO REALCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,DOUBLEVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE REALCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;   
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DELETECONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER
) IS
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    UPDATE IntConst
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
  IF (CONSTTYPE_ = 8) THEN
    UPDATE VARCHARCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_); 
  END IF;
  IF (CONSTTYPE_ = 5) THEN
    UPDATE REALCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
END;
/

--       
ALTER TRIGGER TR_INTCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 DISABLE
/

--     
--    (), +(2)
CALL ImportField(20111214, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20111215, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 201, 1, 1, '', 0, null, 0, 0, '') ;

--  (), +(2)
CALL ImportField(20211159, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 202, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20211160, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 202, 1, 1, '', 0, null, 0, 0, '') ;

--   (), +(2)
CALL ImportField(20311167, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 203, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20311168, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 203, 1, 1, '', 0, null, 0, 0, '') ;

--  , , +(2)
CALL ImportField(20411159, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 204, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20411160, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 204, 1, 1, '', 0, null, 0, 0, '') ;

-- , +(2)
CALL ImportField(20511146, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 205, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20511147, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 205, 1, 1, '', 0, null, 0, 0, '') ;

--    (), +(2)
CALL ImportField(20611207, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 206, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20611208, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 206, 1, 1, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(20711230, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 207, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20711231, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 207, 1, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(20811231, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 208, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20811232, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 208, 1, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(20911168, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 209, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20911169, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 209, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20912170, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 209, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20912171, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 209, 2, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(21011090, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 210, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21011091, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 210, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21012092, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 210, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21012093, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 210, 2, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(21111089, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 211, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21111090, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 211, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21112091, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 211, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21112092, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 211, 2, 1, '', 0, null, 0, 0, '') ;

--   , , +(2)
CALL ImportField(21211075, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 212, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21211076, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 212, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21212079, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 212, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21212080, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 212, 2, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(21811134, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 218, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21811135, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 218, 1, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(30111226, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 301, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30111227, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 301, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30111228, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 301, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30111229, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 301, 1, 1, '', 0, null, 0, 0, '') ;

--   \, +(2)
CALL ImportField(30211238, '   ', 'SourceRegProjectResultCode', '   ', 'SourceRegProjectResultCode', 2, 302, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30211239, '   ', 'DestRegProjectResultCode', '   ', 'DestRegProjectResultCode', 2, 302, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30211240, '   ()', 'SourceRegProjectResult', '   ()', 'SourceRegProjectResult', 2, 302, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(30211241, '   ()', 'DestRegProjectResult', '   ()', 'DestRegProjectResult', 2, 302, 1, 1, '', 0, null, 0, 0, '') ;

--  (), +(2)
CALL ImportField(30311125, '   ', 'DestRegProjectResultCode', '   ', 'DestRegProjectResultCode', 2, 303, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30311126, '   ()', 'DestRegProjectResult', '   ()', 'DestRegProjectResult', 2, 303, 1, 1, ',', 0, null, 0, 0, '') ;

--   , (0)
CALL ImportField(30401041, '  .', 'SourceBudgetPromiseAgrReestrNum', '  .', 'SourceBudgetPromiseAgrReestrNum', 0, 304, 1, 1, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(30411181, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 304, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30411182, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 304, 1, 1, ',', 0, null, 0, 0, '') ;

--   \, +(2)
CALL ImportField(30511194, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 305, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30511195, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 305, 1, 1, ',', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(30611212, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 306, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30611213, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 306, 1, 1, ',', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(30811269, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 308, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30811270, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 308, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(30811271, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 308, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30811272, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 308, 1, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(31111124, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 311, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(31111125, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 311, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(31111126, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 311, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(31111127, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 311, 1, 1, '', 0, null, 0, 0, '') ;

--     , +(2)
CALL ImportField(31211188, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 312, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(31211189, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 312, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(31211190, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 312, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(31211191, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 312, 1, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(31411183, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 314, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(31411184, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 314, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(31411185, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 314, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(31411186, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 314, 1, 1, '', 0, null, 0, 0, '') ;

--      , +(2)
CALL ImportField(31511111, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 315, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(31511112, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 315, 1, 1, ',', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(32211107, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 322, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(32211108, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 322, 1, 1, ',', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(32311225, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 323, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(32311226, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 323, 1, 1, ',', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(32411270, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 324, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(32411271, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 324, 1, 1, ',', 0, null, 0, 0, '') ;

--    , (0)
CALL ImportField(32500028, '. ()', 'DESTFACIALACC_CLS', '. ()', 'DESTFACIALACCCLS', 0, 325, 0, 0, ',DestFacialACCCLS', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(32510027, '. ()', 'DESTFACIALACC_CLS', '. ()', 'DESTFACIALACCCLS', 1, 325, 0, 0, ',DestFacialACCCLS', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(32510147, ' ', 'CRYPTOSTATUS', ' ', 'CRYPTOSTATUS', 2, 325, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(32511138, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 325, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(32511139, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResultKey', 2, 325, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(32511140, '   ', 'ACCEPTDATE', '   ', 'ACCEPTDATE_DET', 2, 325, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(32511148, ' ', 'SourceRegionCLS', ' ', 'SourceRegionCls', 2, 325, 1, 1, ',', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(250212096, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 2502, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250212097, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 2502, 2, 1, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(250312088, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 2503, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250312089, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 2503, 2, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(250412053, '', 'InvestObject', '', 'InvestObject', 2, 2504, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250412054, '', 'InvestObjectCode', '', 'InvestObjectCode', 2, 2504, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250412168, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 2504, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250412169, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 2504, 2, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(300111154, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 3001, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300111155, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 3001, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300111156, '   ', 'PayTargetFundsCode', '   ', 'PayTargetFunds', 2, 3001, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300111157, '   ()', 'PayTargetFunds', '   ', ' ', 2, 3001, 1, 1, '', 0, null, 0, 0, '') ;

--     223-, +(2)
CALL ImportField(300611094, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 3006, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300611095, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 3006, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300611096, '   ', 'PayTargetFundsCode', '   ', 'PayTargetFunds', 2, 3006, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300611097, '   ()', 'PayTargetFunds', '   ', ' ', 2, 3006, 1, 1, '', 0, null, 0, 0, '') ;

--  - , +(2)
CALL ImportField(301111034, '', 'DirectionClsCode', '', 'DirectionCls', 2, 3011, 1, 0, '', 0, 36861, 0, 0, '') ;

CALL ImportField(301111037, ' . ', 'FinTypeCode', '', 'FinType', 2, 3011, 1, 0, ',', 0, 36853, 0, 0, '') ;

CALL ImportField(301111039, ' ', 'SubsidyClsCode', '', 'SubsidyClsCode', 2, 3011, 1, 0, '', 0, 26641, 0, 0, '') ;

CALL ImportField(301111041, ' .  ()', 'FinType', '', 'FinTypeKey', 2, 3011, 1, 1, ',', 0, 21114, 0, 0, '') ;

CALL ImportField(301111042, ' ()', 'DirectionCls', '', 'DirectionClsKey', 2, 3011, 1, 1, '', 0, 21104, 0, 0, '') ;

CALL ImportField(301111049, '', 'ContractCostsCls', '', 'ContractCostsCls', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111050, '', 'ContractCostsClsCode', '', 'ContractCostsClsCode', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111064, '  ()', 'BudAllocationCls', '', 'BudAllocationCls', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301111084, '   ', 'PayTargetFundsCode', '   ', 'PayTargetFundsCode', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111085, '   ()', 'PayTargetFunds', '   ', 'PayTargetFunds', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301111086, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111087, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(440111081, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 4401, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(440111082, '   ()', 'RegProjectResult', '   ()', 'RegProjectResult', 2, 4401, 1, 1, '', 0, null, 0, 0, '') ;

--  ,, +(2)
CALL ImportField(440311073, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 4403, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(440311074, '   ()', 'RegProjectResult', '   ()', 'RegProjectResult', 2, 4403, 1, 1, '', 0, null, 0, 0, '') ;

--  / , +(2)
CALL ImportField(520111089, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 5201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(520111090, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 5201, 1, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(550111194, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 5501, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550111195, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 5501, 1, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(550211208, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 5502, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550211209, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 5502, 1, 1, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(550311085, '  ', 'RegProjectResultCode', '  ', 'RegProjectResult', 1, 5503, 1, 0, '', 0, null, 0, 0, '') ;

-- , +(2)
CALL ImportField(985410010, '   .', 'SubCode', '', ' ', 2, 9854, 0, 0, '', 0, 38206, 0, 0, '') ;

--       
ALTER TRIGGER TR_INTCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 ENABLE
/

DROP PROCEDURE ImportField
/

/*      */
ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 DISABLE
/

Update TB_DocumentFields df
set documentcls=doctyperef*100+detailnumber
where (detailnumber<100)and(documentcls is null)
 and(exists(select dc.id from documentcls dc where id=df.doctyperef*100+df.detailnumber))
/

ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 ENABLE
/

DROP PROCEDURE DeleteFields
/

DROP PROCEDURE InsertConst
/

DROP PROCEDURE DELETECONST
/




CREATE OR REPLACE PROCEDURE DOCLOCK_IMPORT(
  NAME_              VARCHAR2,
  LOCKMASK_          NUMBER,
  DOCREF_            NUMBER,
  DETAILNUM_         NUMBER,
  RUNPOS_            NUMBER,
  LOCKACTION_        NUMBER,
  USERIGHTS_        NUMBER,
  FORMULA_           VARCHAR2,
  FORDELETE_         NUMBER,
  ISSYSTEM_          NUMBER,
  NOTE_              VARCHAR2,
  FORINSERT_         NUMBER,
  VALIDATEMESSAGE_ VARCHAR2,
  VALIDATELEVEL_   NUMBER,
  VALIDATEFILTER_  VARCHAR2,
  ISBUDGET_ NUMBER,
  DEFAULTVALUE_ VARCHAR2)
IS
  DOCLOCKID$ Number(10);
BEGIN
   BEGIN
     SELECT ID
     INTO DOCLOCKID$
     FROM DOCLOCK
     WHERE (DOCREF = DOCREF_) AND(DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DOCLOCKID$ := NULL;  
   END;
   
   IF (DOCLOCKID$ is not null) THEN
     IF (ISSYSTEM_ = 3) THEN
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_,
         USERIGHTS = USERIGHTS_,
         DEFAULTVALUE = DEFAULTVALUE_
       WHERE ID = DOCLOCKID$;  
     ELSE
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_,
         DEFAULTVALUE = DEFAULTVALUE_
       WHERE ID = DOCLOCKID$;    
     END IF;  
   ELSE
     INSERT INTO DOCLOCK
       (ISBUDGET,NAME,LOCKMASK,DOCREF,DETAILNUM,RUNPOS,LOCKACTION,USERIGHTS,FORMULA,FORDELETE,ISSYSTEM,NOTE,FORINSERT,VALIDATEMESSAGE,VALIDATELEVEL,VALIDATEFILTER,DEFAULTVALUE)
     VALUES
       (ISBUDGET_,NAME_,LOCKMASK_,DOCREF_,DETAILNUM_,RUNPOS_,LOCKACTION_,USERIGHTS_,FORMULA_,FORDELETE_,ISSYSTEM_,NOTE_,FORINSERT_,VALIDATEMESSAGE_,VALIDATELEVEL_,VALIDATEFILTER_,DEFAULTVALUE_);
   END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_INSERTFIELD(
  NAME_      VARCHAR2,
  DOCREF_    NUMBER,
  DETAILNUM_ NUMBER,
  FIELDREF_  NUMBER,
  ISBUDGET_ NUMBER)
IS
  NID$ NUMBER(10);
  cnt$ number(10);
BEGIN
  BEGIN
    SELECT ID
    INTO NID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      NID$ := NULL;  
  END;

  IF (NID$ is not null) THEN
    CNT$ := 0;
    SELECT count(ID)
    into cnt$
    FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    
    IF (cnt$ = 0) THEN
      INSERT INTO DOCLOCKFIELDS
        (DOCLOCKREF,FIELDREF,ISSYSTEM)
      VALUES
        (NID$,FIELDREF_,1);
    ELSE
      UPDATE DOCLOCKFIELDS SET
        ISSYSTEM = 1
      WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    END IF;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCK_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCK
    WHERE ID = DOCLOCKID$;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, CANCHANGEFIELDS_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION  
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;  

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = DOCLOCKID$) AND ((ISSYSTEM = 1) OR ((ISSYSTEM = 0) AND (CANCHANGEFIELDS_ = 0) ));
  END IF;
END;
/

-- 
CALL DOCLOCK_DELETE('  ""',1824, -1, 1) ;

CALL DOCLOCK_DELETE('  ""',1824, -1, 1) ;

CALL DOCLOCK_DELETE('  ""',1824, 0, 1) ;

CALL DOCLOCK_IMPORT('     ',0,200,1,0,11,0,'([20011012] = 2)   ( in (213, 214, 215))',0,3,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[20011017] = 0)  ([970910023] = .[20011026]) 

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[20011026], 4)))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 200, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',200,1,20011043,1) ;

CALL DOCLOCK_IMPORT('     ',0,200,1,0,11,0,'[20001012] = 2',0,3,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[20011017] = 0)  ([970910023] = .[20011026]) 

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[20011026], 4)))',0,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 200, 1, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',200,1,20001043,0) ;

CALL DOCLOCK_IMPORT('   ',0,203,0,0,11,0,'',0,1,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1,'') ;

CALL DOCLOCKFIELDS_DELETE('   ', 203, 0, 0, 1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',203,0,20310039,1) ;

CALL DOCLOCK_IMPORT('   ',0,203,0,0,11,0,'',0,1,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',0,'') ;

CALL DOCLOCKFIELDS_DELETE('   ', 203, 0, 0, 0) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',203,0,20300124,0) ;

CALL DOCLOCK_IMPORT('   ',0,203,1,0,11,0,'',0,1,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1,'') ;

CALL DOCLOCKFIELDS_DELETE('   ', 203, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('   ',203,1,20311038,1) ;

CALL DOCLOCK_IMPORT('   ',0,203,1,0,11,0,'',0,1,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',0,'') ;

CALL DOCLOCKFIELDS_DELETE('   ', 203, 1, 0, 0) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('   ',203,1,20301139,0) ;

CALL DOCLOCK_IMPORT('  ""',32768,1824,0,0,7,4,'',0,1,'         ',0,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('  ""', 1824, 0, 0, 1) ;

DROP PROCEDURE DOCLOCK_IMPORT      
/

DROP PROCEDURE DocLockFields_InsertField
/

DROP PROCEDURE DOCLOCK_DELETE
/

DROP PROCEDURE DOCLOCKFIELDS_DELETE
/

CREATE OR REPLACE PROCEDURE LINKTYPE_DELETE(
  NAME_         VARCHAR2,
  TEMPLATECLS_  NUMBER,
  PARENTDOCCLS_ NUMBER,
  CHILDDOCCLS_  NUMBER) IS
BEGIN
  FOR tab_rec in (SELECT id FROM LINKTYPE LT
  WHERE (((NAME_ <> '') or (NAME_ is not null)) and (LT.NAME = NAME_)) or 
    (((NAME_ = '') or (NAME_ is null)) and (LT.TEMPLATECLS = TEMPLATECLS_ AND LT.PARENTDOCCLS = PARENTDOCCLS_ AND LT.CHILDDOCCLS = CHILDDOCCLS_)))    
  LOOP
    UPDATE STATE_JUMPCONTROL SET
      REFERENCEREF = NULL
    WHERE REFERENCEREF = tab_rec.id;
    DELETE FROM REPLACEMENTCLSDETAIL WHERE LINKID IN (SELECT ID FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id);
    DELETE FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id;
    DELETE FROM LINKTYPE LT
      WHERE LT.ID = tab_rec.id;
  END LOOP;     
END;
/

CREATE OR REPLACE PROCEDURE LINKTYPE_IMPORT(
   ID_                    NUMBER,
   NAME_                  VARCHAR2,
   TEMPLATECLS_           NUMBER,
   PARENTDOCCLS_          NUMBER,
   CHILDDOCCLS_           NUMBER,
   LINKCOMMENT_           VARCHAR2,
   BLOCKPARENT_           NUMBER,
   BLOCKCHILD_            NUMBER,
   CANDELBLOCKPARENT_     NUMBER,
   CANDELBLOCKCHILD_      NUMBER,
   PARENTPICTURETYPE_     NUMBER,
   PARENTPICTURENAME_     VARCHAR2,
   CHILDPICTURETYPE_      NUMBER,
   CHILDPICTURENAME_      VARCHAR2,
   PICTURECOLLECTIONNAME_ VARCHAR2,
   URMUSE_                NUMBER,
   DELMACROSNAME_         VARCHAR2,
   NEEDDELCHILD_          NUMBER,
   LINKKIND_              NUMBER
) IS
   CNT$ NUMBER(10);
BEGIN
   /*          ,     */
   /*  ,   , ,  ,     */
   IF (
   ((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0))or(Name_ is not null))   
   THEN
     FOR tab_rec in(SELECT id FROM LINKTYPE LT WHERE 
		 (id<>ID_)	
         and(((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0)and(LT.TEMPLATECLS = TEMPLATECLS_)
         and (LT.PARENTDOCCLS = PARENTDOCCLS_) and (LT.CHILDDOCCLS = CHILDDOCCLS_))
         or((Name_ is not null)and(lt.Name=Name_))))
     LOOP
        /*             */    
        DELETE FROM LINKRECORDS WHERE LINKTYPEREF = -10;  
        DELETE FROM TB_LINKTYPE WHERE ID = -10;
        DELETE FROM DOCUMENTCLS WHERE ID = -10;
        DELETE FROM DOCUMENTTYPES WHERE ID = -10;
        INSERT INTO DOCUMENTTYPES(ID, PROGINDEX) VALUES(-10, -10);
        INSERT INTO DOCUMENTCLS(ID, DOCTYPE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM)
           VALUES(-10, -10, ' ', ' ', ' ', ' ');
        INSERT INTO LINKTYPE(ID, PARENTDOCCLS, CHILDDOCCLS, NAME) VALUES(-10, -10, -10, ' ');
        UPDATE STATE_JUMPCONTROL SET
           REFERENCEREF = -10
        WHERE
           REFERENCEREF = tab_rec.id;
        UPDATE LINKRECORDS SET
           LINKTYPEREF = -10
        WHERE
           LINKTYPEREF = tab_rec.id;
        DELETE FROM TB_LINKTYPE WHERE ID = tab_rec.Id;
     END LOOP;
   end if;
   /*      */ 
   SELECT count(*) into CNT$
      FROM LINKTYPE LT WHERE LT.ID = ID_;
   IF (CNT$ = 0)    
   THEN
      INSERT INTO LINKTYPE
       (ID,NAME,TEMPLATECLS,PARENTDOCCLS, CHILDDOCCLS, LINKCOMMENT, BLOCKPARENT,BLOCKCHILD,CANDELBLOCKPARENT,
        CANDELBLOCKCHILD, PARENTPICTURETYPE,PARENTPICTURENAME,CHILDPICTURETYPE,CHILDPICTURENAME,
        PICTURECOLLECTIONNAME,URMUSE,DELMACROSNAME,NEEDDELCHILD,LINKKIND)
      VALUES
       (ID_,NAME_,TEMPLATECLS_, PARENTDOCCLS_, CHILDDOCCLS_, LINKCOMMENT_, BLOCKPARENT_,BLOCKCHILD_,CANDELBLOCKPARENT_,
        CANDELBLOCKCHILD_, PARENTPICTURETYPE_,PARENTPICTURENAME_,CHILDPICTURETYPE_,CHILDPICTURENAME_,
        PICTURECOLLECTIONNAME_,URMUSE_,DELMACROSNAME_,NEEDDELCHILD_,LINKKIND_);
   ELSE
      UPDATE LINKTYPE SET
         NAME = NAME_,
         TEMPLATECLS = TEMPLATECLS_,
         PARENTDOCCLS = PARENTDOCCLS_,
         CHILDDOCCLS = CHILDDOCCLS_,
         LINKCOMMENT = LINKCOMMENT_,
         BLOCKPARENT = BLOCKPARENT_,
         BLOCKCHILD = BLOCKCHILD_,
         CANDELBLOCKPARENT = CANDELBLOCKPARENT_,
         CANDELBLOCKCHILD = CANDELBLOCKCHILD_,
         PARENTPICTURETYPE = PARENTPICTURETYPE_,
         PARENTPICTURENAME = PARENTPICTURENAME_,
         CHILDPICTURETYPE = CHILDPICTURETYPE_,
         CHILDPICTURENAME = CHILDPICTURENAME_,
         PICTURECOLLECTIONNAME = PICTURECOLLECTIONNAME_,
         URMUSE = URMUSE_,
         DELMACROSNAME = DELMACROSNAME_,
         NEEDDELCHILD = NEEDDELCHILD_,
         LINKKIND = LINKKIND_
      WHERE ID = ID_;
   END IF;      
   
   /*      ,      */
   UPDATE STATE_JUMPCONTROL SET
     REFERENCEREF = ID_
   WHERE
     REFERENCEREF = -10;
   UPDATE LINKRECORDS SET
      LINKTYPEREF = ID_
   WHERE
      LINKTYPEREF = -10;
   /*   */  
   DELETE FROM TB_LINKTYPE WHERE ID = -10;
   DELETE FROM DOCUMENTCLS WHERE ID = -10;
   DELETE FROM DOCUMENTTYPES WHERE ID = -10;
END;
/

--  
DROP PROCEDURE LINKTYPE_DELETE
/

DROP PROCEDURE LINKTYPE_IMPORT
/

CREATE OR REPLACE PROCEDURE STATICLINK_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATICLINKS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE STATICLINK_IMPORT(
  ID_             NUMBER,
  NAME_           VARCHAR2,
  PARENTFIELDREF_ NUMBER,
  CHILDFIELDREF_  NUMBER,
  LINKKIND_      NUMBER,
  ParentDelAction_ NUMBER
) IS
  FINDID$ NUMBER;
  FINDNEWID$ NUMBER;
  IDExists$ NUMBER;
BEGIN
  /*     ID,    CHILDFIELDREF,PARENTFIELDREF. 
   ,     ,    ID.       ID  , 
   (  )     id ,      */
  BEGIN
    SELECT
      SL.ID
    INTO FINDID$
    FROM 
      STATICLINKS SL
    WHERE (SL.CHILDFIELDREF = CHILDFIELDREF_) AND (SL.PARENTFIELDREF = PARENTFIELDREF_) AND (SL.ID <> ID_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      FINDID$ := NULL;
  END;
  
  IF (FINDID$ IS NOT NULL) THEN
  /*   ID         */

    SELECT COUNT (ID)
      INTO IDExists$
      FROM STATE_JUMPCONTROL
    WHERE (STATICLINKREF = FINDID$);

    IF (IDExists$ > 0) THEN

      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM 
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
 
      IF (FINDNEWID$ IS NULL) THEN
        INSERT INTO STATICLINKS
         (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
        VALUES
          (ID_,NAME_,CHILDFIELDREF_,PARENTFIELDREF_,1,ParentDelAction_);
      END IF;        
      UPDATE STATE_JUMPCONTROL
        SET STATICLINKREF = ID_
      WHERE (STATICLINKREF = FINDID$);

      DELETE FROM STATICLINKS  
      WHERE ID=FINDID$;
    ELSE   
      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
      IF (FINDNEWID$ IS NULL) THEN
        UPDATE STATICLINKS
        SET ID=ID_
        WHERE ID=FINDID$;
      ELSE
        DELETE FROM STATICLINKS
        WHERE ID=FINDID$;
      END IF;
    END IF;
      
  END IF; /*  id  */
  
  /*       ( ), 
   ,            CHILDFIELDREF.
   ,        1( )*/
  IF (LINKKIND_=0) THEN
    UPDATE STATICLINKS
    SET LINKKIND=1  
    WHERE (CHILDFIELDREF = CHILDFIELDREF_) AND (ID <> ID_) AND (LINKKIND=0);
  END IF;    
  
  /*        id.  ,   .  ,   */
  BEGIN
    SELECT SL.ID
      INTO FINDID$
      FROM
        STATICLINKS SL
      WHERE
        (SL.ID = ID_);
  EXCEPTION
      WHEN NO_DATA_FOUND THEN
        FINDID$ := NULL;
  END;
  IF (FINDID$ IS NOT NULL) THEN
    UPDATE STATICLINKS SET
      NAME           = NAME_,
      PARENTFIELDREF = PARENTFIELDREF_,
      CHILDFIELDREF  = CHILDFIELDREF_,
      LINKKIND       = LINKKIND_,
      ParentDelAction = ParentDelAction_
      WHERE ID = ID_;
  ELSE
    INSERT INTO STATICLINKS
     (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
    VALUES
      (ID_,NAME_,PARENTFIELDREF_,CHILDFIELDREF_,LINKKIND_,ParentDelAction_);
  END IF;      

END;
/

--  
CALL STATICLINK_IMPORT(970203200,'_.1.REGPROJECTRESULT()->.ID',971110002,20111215,0,0) ;

CALL STATICLINK_IMPORT(970203300,'_.1.REGPROJECTRESULT()->.ID',971110002,20211160,0,0) ;

CALL STATICLINK_IMPORT(970203400,'_.1.REGPROJECTRESULT()->.ID',971110002,20311168,0,0) ;

CALL STATICLINK_IMPORT(970203500,'_.1.REGPROJECTRESULT()->.ID',971110002,20411160,0,0) ;

CALL STATICLINK_IMPORT(970203600,'.1.REGPROJECTRESULT()->.ID',971110002,20511147,0,0) ;

CALL STATICLINK_IMPORT(970203700,'__.1.REGPROJECTRESULT()->.ID',971110002,20611208,0,0) ;

CALL STATICLINK_IMPORT(970203800,'_.1.REGPROJECTRESULT()->.ID',971110002,20711231,0,0) ;

CALL STATICLINK_IMPORT(970203900,'__.1.REGPROJECTRESULT()->.ID',971110002,20811232,0,0) ;

CALL STATICLINK_IMPORT(970204000,'_.1.REGPROJECTRESULT()->.ID',971110002,20911169,0,0) ;

CALL STATICLINK_IMPORT(970204100,'.1.REGPROJECTRESULT()->.ID',971110002,21011091,0,0) ;

CALL STATICLINK_IMPORT(970204200,'_.1.REGPROJECTRESULT()->.ID',971110002,21111090,0,0) ;

CALL STATICLINK_IMPORT(970204300,'_.1.REGPROJECTRESULT()->.ID',971110002,21211076,0,0) ;

CALL STATICLINK_IMPORT(970302300,'.1.SOURCEREGPROJECTRESULT()->.ID',971110002,30111227,0,0) ;

CALL STATICLINK_IMPORT(970302400,'.1.DESTREGPROJECTRESULT()->.ID',971110002,30111229,0,0) ;

CALL STATICLINK_IMPORT(970302900,'.1.DESTPAYTARGETFUNDS()->.ID',971110002,30511193,0,0) ;

CALL STATICLINK_IMPORT(970304000,'.1.SOURCEPAYTARGETFUNDS()->.ID',971110002,32211106,0,0) ;

CALL STATICLINK_IMPORT(970303500,'_.1.SOURCEPAYTARGETFUNDS(,)->.ID',971110002,31211185,0,0) ;

CALL STATICLINK_IMPORT(970303600,'_.1.DESTPAYTARGETFUNDS()->.ID',971110002,31211187,0,0) ;

CALL STATICLINK_IMPORT(970303700,'_.1.SOURCEPAYTARGETFUNDS(,)->.ID',971110002,31411180,0,0) ;

CALL STATICLINK_IMPORT(970303800,'_.1.DESTPAYTARGETFUNDS()->.ID',971110002,31411182,0,0) ;

CALL STATICLINK_IMPORT(970303900,'_.1.DESTPAYTARGETFUNDS()->.ID',971110002,31511110,0,0) ;

CALL STATICLINK_IMPORT(970302600,'.1.DESTREGPROJECTRESULTCODE()->.ID',971110002,30211239,0,0) ;

CALL STATICLINK_IMPORT(970302500,'.1.SOURCEREGPROJECTRESULT()->.ID',971110002,30211240,0,0) ;

CALL STATICLINK_IMPORT(970302700,'.1.DESTREGPROJECTRESULT()->.ID',971110002,30311126,0,0) ;

CALL STATICLINK_IMPORT(970302800,'.1.SOURCEREGPROJECTRESULT()->.ID',971110002,30411182,0,0) ;

CALL STATICLINK_IMPORT(970303000,'.1.DESTREGPROJECTRESULT()->.ID',971110002,30611213,0,0) ;

CALL STATICLINK_IMPORT(970303200,'.1.SOURCEREGPROJECTRESULT()->.ID',971110002,30811270,0,0) ;

CALL STATICLINK_IMPORT(970303100,'.1.DESTREGPROJECTRESULT()->.ID',971110002,30811272,0,0) ;

CALL STATICLINK_IMPORT(970303400,'_.1.SOURCEREGPROJECTRESULT()->.ID',971110002,31111125,0,0) ;

CALL STATICLINK_IMPORT(970303300,'_.1.DESTREGPROJECTRESULT()->.ID',971110002,31111127,0,0) ;

CALL STATICLINK_IMPORT(970304100,'.1.DESTREGPROJECTRESULT()->.ID',971110002,32311226,0,0) ;

CALL STATICLINK_IMPORT(970304200,'.1.DESTREGPROJECTRESULT()->.ID',971110002,32411271,0,0) ;

CALL STATICLINK_IMPORT(975500500,'_.1.REGPROJECTRESULT()->.ID',971110002,550111195,0,0) ;

CALL STATICLINK_IMPORT(975500600,'_.1.REGPROJECTRESULT()->.ID',971110002,550211209,0,0) ;

CALL STATICLINK_IMPORT(972500500,'.2.REGPROJECTRESULT()->.ID',971110002,250212097,0,0) ;

CALL STATICLINK_IMPORT(972500600,'.2.REGPROJECTRESULT()->.ID',971110002,250312089,0,0) ;

CALL STATICLINK_IMPORT(972500700,'.2.REGPROJECTRESULT()->.ID',971110002,250412169,0,0) ;

CALL STATICLINK_IMPORT(974400300,'.1.REGPROJECTRESULT()->.ID',971110002,440111082,0,0) ;

CALL STATICLINK_IMPORT(974400400,'.1.REGPROJECTRESULT()->.ID',971110002,440311074,0,0) ;

DROP PROCEDURE STATICLINK_DELETE
/

DROP PROCEDURE STATICLINK_IMPORT
/

CREATE OR REPLACE PROCEDURE FILTERS_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATE_JUMPCONTROL
  WHERE STATE_JUMPCONTROL.FILTERCODE = ID_;
  UPDATE STATE_ACTIONJUMPS SAJ
  SET SAJ.FILTERCODE = NULL, SAJ.OPTIONS = NULL
  WHERE SAJ.FILTERCODE = ID_;
  DELETE FROM State_Filter SF
  WHERE SF.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORT(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValue_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValue,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValue_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValue = FilterValue_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORTURM(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValueURM_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValueURM,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValueURM_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValueURM = FilterValueURM_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

-- 
DROP PROCEDURE FILTERS_DELETE
/

DROP PROCEDURE FILTERS_IMPORT
/

DROP PROCEDURE FILTERS_IMPORTURM
/

CREATE OR REPLACE PROCEDURE STATUSICONS_IMPORT(
  ID_ NUMBER,
  NOTE_ VARCHAR2,
  DOCREF_ NUMBER,
  DETAILNUM_ NUMBER,
  ICONNAME_ VARCHAR2,
  ISSYSTEM_ NUMBER,
  ICONPOS_ NUMBER,
  RUNPOS_ NUMBER,
  RESERVEPOS_ NUMBER,
  ICONHINT_ VARCHAR2,
  ICONKIND_ NUMBER,
  LOCKMASK_ NUMBER,
  FORMULA_ VARCHAR2,
  ISBUDGET_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM STATUSICONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE STATUSICONS SET
      NOTE = NOTE_,
      DOCREF = DOCREF_,
      DETAILNUM = DETAILNUM_,
      ICONNAME = ICONNAME_,
      ISSYSTEM = ISSYSTEM_,
      ICONPOS = ICONPOS_,
      RUNPOS = RUNPOS_,
      RESERVEPOS = RESERVEPOS_,
      ICONHINT = ICONHINT_,
      ICONKIND = ICONKIND_,
      LOCKMASK = LOCKMASK_,
      ISBUDGET = ISBUDGET_,
      FORMULA = FORMULA_
    WHERE ID = ID_;
  ELSE
    INSERT INTO STATUSICONS
      (ISBUDGET, ID, NOTE, DOCREF, DETAILNUM, ICONNAME, ISSYSTEM, ICONPOS, RUNPOS, RESERVEPOS, ICONHINT, ICONKIND, LOCKMASK, FORMULA)
    VALUES
      (ISBUDGET_, ID_, NOTE_, DOCREF_, DETAILNUM_, ICONNAME_, ISSYSTEM_, ICONPOS_, RUNPOS_, RESERVEPOS_, ICONHINT_, ICONKIND_, LOCKMASK_, FORMULA_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE STATUSICONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM STATUSICONS SI
  WHERE SI.ID = ID_;
END;
/

--  
DROP PROCEDURE STATUSICONS_IMPORT
/

DROP PROCEDURE STATUSICONS_DELETE
/


CREATE OR REPLACE PROCEDURE ENUMS_IMPORT(NAME_ VARCHAR2,FACIALACCCLS_ NUMBER) IS
  IDEXISTS$ NUMBER;
BEGIN
  SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMS WHERE NAME = NAME_;
  IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMS E1
      WHERE (E1.NAME = NAME_) AND (E1.ID > (SELECT MIN(E2.ID) FROM ENUMS E2 WHERE E2.NAME = NAME_));
  END IF;
  IF (IDEXISTS$ > 0) THEN
    UPDATE ENUMS SET
      FACIALACCCLS = FACIALACCCLS_,
      ISSYSTEM = 1
    WHERE NAME = NAME_;
  ELSE
    INSERT INTO ENUMS
      (NAME,FACIALACCCLS,ISSYSTEM)    
    VALUES
      (NAME_,FACIALACCCLS_,1);
  END IF;    
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_IMPORT(ENUMNAME_ VARCHAR2,NAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
  IDEXISTS$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      IDENUM$ := NULL;
  END;  
  IF (IDENUM$ IS NOT NULL) THEN
    SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMVALUES WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMVALUES EV1
      WHERE (EV1.ENUMREF = IDENUM$) AND (EV1.VAL = VAL_) AND
        (EV1.ID > (SELECT MIN(EV2.ID) FROM ENUMVALUES EV2 WHERE EV2.ENUMREF = IDENUM$ AND EV2.VAL = VAL_));
    END IF;
    IF (IDEXISTS$ > 0) THEN
      UPDATE ENUMVALUES SET
        NAME = NAME_
      WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    ELSE
      INSERT INTO ENUMVALUES
        (VAL,NAME,ENUMREF)  
      VALUES
        (VAL_,NAME_,IDENUM$);
    END IF;    
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE ENUMS_DELETE(NAME_ VARCHAR2) IS
BEGIN
  DELETE FROM ENUMS WHERE NAME = NAME_;
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_DELETE(ENUMNAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       IDENUM$ := NULL;  
  END;
  IF (IDENUM$ IS NOT NULL) THEN
    DELETE FROM ENUMVALUES WHERE (VAL = VAL_) AND (ENUMREF = IDENUM$);
  END IF;  
END;
/

-- 
CALL ENUMVALUES_DELETE('',9) ;

CALL ENUMVALUES_DELETE('',10) ;

CALL ENUMVALUES_DELETE('',11) ;

CALL ENUMVALUES_DELETE('',12) ;

CALL ENUMVALUES_DELETE('',18) ;

CALL ENUMVALUES_DELETE('',21) ;

CALL ENUMVALUES_DELETE('',22) ;

CALL ENUMVALUES_DELETE('',25) ;

CALL ENUMVALUES_DELETE('',26) ;

CALL ENUMVALUES_DELETE('',2) ;

CALL ENUMVALUES_DELETE('',3) ;

CALL ENUMVALUES_DELETE('',7) ;

CALL ENUMVALUES_DELETE('',8) ;

CALL ENUMVALUES_DELETE('',9) ;

CALL ENUMVALUES_DELETE('',16) ;

CALL ENUMVALUES_DELETE('',28) ;

CALL ENUMVALUES_DELETE('',9) ;

CALL ENUMVALUES_DELETE('',10) ;

CALL ENUMVALUES_IMPORT('',' ',1) ;

CALL ENUMVALUES_IMPORT('','',2) ;

CALL ENUMVALUES_IMPORT('','  ',3) ;

CALL ENUMVALUES_IMPORT('',' ',4) ;

CALL ENUMVALUES_IMPORT('','  ',5) ;

CALL ENUMVALUES_IMPORT('','    ',6) ;

CALL ENUMVALUES_IMPORT('','',7) ;

CALL ENUMVALUES_IMPORT('','13= ( ,     ,   ) - , , ,   , ,   ,   () ',13) ;

CALL ENUMVALUES_IMPORT('','30= ,         (  ,   )',30) ;

CALL ENUMVALUES_IMPORT('','=    ,  () ,    ',1) ;

CALL ENUMVALUES_IMPORT('','=  () ,    -               ,     ',20) ;

CALL ENUMVALUES_IMPORT('','     ',8) ;

CALL ENUMS_IMPORT('',null) ;

CALL ENUMVALUES_IMPORT('',' ',0) ;

CALL ENUMVALUES_IMPORT('',' ',1) ;

CALL ENUMVALUES_IMPORT('',' ',2) ;

CALL ENUMVALUES_IMPORT('','   ',3) ;

CALL ENUMVALUES_IMPORT('','   ',4) ;

CALL ENUMVALUES_IMPORT('','   ',5) ;

CALL ENUMVALUES_IMPORT('',' ',6) ;

CALL ENUMVALUES_IMPORT('',' ',7) ;

CALL ENUMVALUES_IMPORT('','',8) ;

CALL ENUMVALUES_IMPORT('','  ',9) ;

CALL ENUMVALUES_IMPORT('','',10) ;

DROP PROCEDURE ENUMS_IMPORT
/

DROP PROCEDURE ENUMVALUES_IMPORT
/

DROP PROCEDURE ENUMS_DELETE
/

DROP PROCEDURE ENUMVALUES_DELETE
/

--      
INSERT INTO DFUCHANGELOG (VersionID, BEGINUPDATECODE, ENDUPDATECODE, LASTUPDATEDFU, ISBUDGET, INCLUDEDEL, INCLUDEBLOCKS, INCLUDEDOCS, SCRIPTCREATOR, SCRIPTCREATEDATE, NOTE) VALUES (3684, 141000, 141000, TO_DATE('11.11.2021 18:10:12', 'DD.MM.YYYY HH24:MI:SS'), 2, 1, ',    ,  , ,  , ,  , , ', '00.00, 01.01, 02.00, 02.01, 02.02, 02.03, 02.04, 02.05, 02.06, 02.07, 02.08, 02.09, 02.10, 02.11, 02.12, 02.13, 02.14, 02.15, 02.16, 02.17, 02.18, 03.00, 03.01, 03.02, 03.03, 03.04, 03.05, 03.06, 03.07, 03.08, 03.11, 03.12, 03.14, 03.15, 03.16, 03.22, 03.23, 03.24, 03.25, 04.01, 05.01, 07.01, 07.02, 07.03, 08.01, 08.02, 08.03, 08.04, 09.00, 09.01, 09.02, 09.03, 09.05, 09.06, 09.07, 12.01, 15.01, 16.01, 16.02, 17.01, 17.02, 18.05, 18.07, 18.09, 18.10, 18.12, 18.13, 18.14, 18.15, 18.16, 18.18, 18.19, 18.20, 18.21, 18.24, 18.25, 19.00, 19.01, 19.02, 19.03, 19.06, 22.00, 22.01, 25.01, 25.02, 25.03, 25.04, 28.01, 28.02, 30.01, 30.02, 30.03, 30.04, 30.05, 30.06, 30.10, 30.11, 36.10, 37.01, 39.01, 44.01, 44.03, 47.01, 48.01, 49.01, 49.02, 49.03, 51.01, 52.01, 53.01, 53.02, 53.03, 53.04, 53.05, 53.06, 54.01, 54.02, 55.01, 55.02, 55.03, 56.01, 96.01, 96.02, 96.03, 96.04, 97.01, 97.02, 97.09, 97.10, 97.11, 97.12, 97.13, 97.14, 97.16, 98.02, 98.03, 98.04, 98.05, 98.06, 98.08, 98.09, 98.10, 98.11, 98.12, 98.13, 98.14, 98.15, 98.16, 98.17, 98.18, 98.20, 98.21, 98.22, 98.23, 98.26, 98.27, 98.28, 98.29, 98.34, 98.35, 98.41, 98.42, 98.43, 98.44, 98.45, 98.46, 98.47, 98.48, 98.49, 98.50, 98.51, 98.52, 98.53, 98.54, 98.57, 98.58, 98.59, 98.60, 98.61, 98.62, 98.63, 98.64, 98.65, 98.67, 98.68, 98.69, 98.70, 98.71, 98.72, 98.78, 98.79, 98.80, 98.81, 98.82, 98.83, 98.84, 98.85, 98.86, 98.87, 98.88, 98.89, 98.90, 98.91, 98.92, 98.94, 98.95, 98.97, 98.98, 98.99, 99.03, 99.04, 99.05, 99.08, 99.12, 99.13, 99.14, 99.15, 99.16, 99.17, 99.18, 99.19, 99.20, 99.21, 99.22, 99.23, 99.24, 99.25, 99.26, 99.27, 99.28, 99.29, 99.30, 99.31, 99.32, 99.33, 99.34', 'MALINOVKIN/malinovkin', TO_DATE('11.11.2021 18:18:13', 'DD.MM.YYYY HH24:MI:SS'), '') ;

COMMIT WORK
/




-- #########################################################
-- #########################################################
-- DBVersion.sql
-- #########################################################
-- #########################################################

INSERT INTO DataBaseVersion(VERSION, Major, Minor, AComment)
  VALUES ('14.10.00', 1410, 00, ' 14.10.00')
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Index_Fix.sql
-- #########################################################
-- #########################################################

--      INDX
DECLARE
  CURSOR C$ IS
    select INDEX_NAME from DBA_INDEXES
    where OWNER = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      and TABLESPACE_NAME <> 'INDX'
      and INDEX_TYPE LIKE '%NORMAL%';
  CNT$ NUMBER(10);    
BEGIN
  BEGIN
    select count(*) into CNT$ from V$TABLESPACE
    where name = 'INDX';
  EXCEPTION
    WHEN OTHERS THEN
      CNT$ := 1;
  END;
  IF CNT$ = 1 THEN
    FOR R$ IN C$ LOOP
      EXECUTE IMMEDIATE 'ALTER INDEX ' || R$.INDEX_NAME || ' REBUILD TABLESPACE INDX';
    END LOOP;
  END IF;
END;
/

-- #########################################################
-- #########################################################
-- compile_scr.sql
-- #########################################################
-- #########################################################

--      , 
--  -  
--  DBMS_UTILITY.COMPILE_SCHEMA(user, TRUE);

DECLARE
  CURSOR C$ IS
    SELECT 'ALTER ' || object_type || ' ' || owner || '.' || object_name || ' COMPILE' AS str,
      object_type, object_name
    FROM SYS.ALL_OBJECTS
    WHERE owner = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      AND object_type IN ('VIEW', 'PROCEDURE', 'TRIGGER')
      AND status = 'INVALID'
      AND object_name not like 'BIN$%'
    ORDER BY DECODE(object_type, 'VIEW', 1, 'PROCEDURE', 2, 'TRIGGER', 3), object_name;
  S VARCHAR2(100);
BEGIN
  FOR R$ IN C$ LOOP
    BEGIN
      S := R$.object_type || ' ' || R$.object_name;
      EXECUTE IMMEDIATE R$.str;
    EXCEPTION
      WHEN OTHERS THEN 
        --DBMS_OUTPUT.PUT_LINE(S);
        RAISE_APPLICATION_ERROR(-20000, '    ' || S);
    END;
  END LOOP;
END;
/

-- #########################################################
-- #########################################################
-- dbms_stats_scr.sql
-- #########################################################
-- #########################################################

ALTER SESSION SET NLS_NUMERIC_CHARACTERS='.,'
/

BEGIN
  DBMS_STATS.GATHER_SCHEMA_STATS(
    SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA'),
    DBMS_STATS.AUTO_SAMPLE_SIZE,
    false,
    'FOR ALL COLUMNS SIZE AUTO',
    cascade=>TRUE
  );
END;
/

exit
