
-- #########################################################
-- #########################################################
-- ConfigEnv.sql
-- #########################################################
-- #########################################################

SPOOL spool.txt
WHENEVER SQLERROR EXIT SQL.SQLCODE ROLLBACK
WHENEVER OSERROR EXIT FAILURE ROLLBACK

-- #########################################################
-- #########################################################
-- VersionCheck.sql
-- #########################################################
-- #########################################################

declare
  curMajor number;
  curMinor number;
  apos number;
  npos number;
  verOk number;
  curVer varchar2(20);
  tstVer varchar2(20);
  aver varchar2(80);
begin
  aver := '14.00.00,14.10.00'; /*    ! */
  verOk := 0;
  select max(Major) into curMajor from DatabaseVersion;
  select max(Minor) into curMinor from DatabaseVersion where Major = curMajor;
  curVer := curMajor;
  apos := LENGTH(curVer) - 1;
  curVer := SUBSTR(curVer, 1, (apos - 1)) || '.' || SUBSTR(curVer, apos, 2) || '.' || TO_CHAR(curMinor, 'FM00');

  apos := 1;
  npos := 0;
  while ((verOk = 0) and (npos < LENGTH(aver))) loop
    npos := INSTR(aver, ',', apos);
    if (npos = 0) then
      npos := LENGTH(aver) + 1;
    end if;
    tstVer := SUBSTR(aver, apos, npos - apos);
    apos := npos + 1;
    if (SUBSTR(curVer, 1, LENGTH(tstVer)) = tstVer) then
      verOk := 1;
    end if;
  end loop;
  
  if (verOk = 0 ) then
    raise_application_error(-20000, '  [' || curVer || ']    ['|| aver ||']');
  end if;
  
end;
/

-- #########################################################
-- #########################################################
-- Fix_FacialFinDetail_AcceptDate.sql
-- #########################################################
-- #########################################################


ALTER TRIGGER TR_FACIALFINDETAIL_BU_500 DISABLE
/

CREATE OR REPLACE PROCEDURE FacialFinDetailFixAcceptDate
AS
BEGIN
  FOR REC$1 IN (SELECT fcc.AcceptDate AS CapAcceptDate, fcc.ID AS CapID 
      FROM FacialFinCaption fcc
  where (fcc.AcceptDate is not null)
  )
  LOOP
    UPDATE facialfindetail SET
      AcceptDate = REC$1.CapAcceptDate
    WHERE
    (RecordIndex = REC$1.CapID) and (AcceptDate is null) and (Reject_cls is null);   
  END LOOP;
END;
/

COMMIT WORK 
/

CALL FacialFinDetailFixAcceptDate()
/

DROP PROCEDURE FacialFinDetailFixAcceptDate
/

ALTER TRIGGER TR_FACIALFINDETAIL_BU_500 ENABLE
/

COMMIT WORK 
/


-- #########################################################
-- #########################################################
-- ALTER_TR_FACIALFINDETAIL_BI_BU_120.sql
-- #########################################################
-- #########################################################

/*   TR_FACIALFINDETAIL_BI_120, TR_FACIALFINDETAIL_BU_120*/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BI_120
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  SourceFacialAcc_CLS1$ NUMBER(10);
  DestFacialAcc_CLS1$ NUMBER(10);
  CapBuhOperationCLS1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  CapReject_cls$ NUMBER(10);
  CapRejectCause$ VARCHAR2(1000);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  BEGIN
    /*  ,    */
    select
    ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate, ffc.Reject_cls, ffc.RejectCause,
    ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
    into new$BudgetRef, CapBuhOperationCLS1$, CapClsType1$, CapAcceptDate1$, CapReject_cls$, CapRejectCause$,
    new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause  from
    FacialFinCaption ffc
    where
    ffc.id = new$RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*      */
  if (new$BuhOperationCls is null) then
    new$BuhOperationCls := CapBuhOperationCLS1$;
  END IF;
  /*      */
  if (new$ClsType is null) then
    new$ClsType := CapClsType1$;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  /*      */
  if (new$AcceptDate is null) then
    new$AcceptDate := CapAcceptDate1$;
  END IF;

  /*       */
  if (new$Reject_cls is null) then
    new$Reject_cls := CapReject_cls$;
  END IF;

  /*       */
  if (new$RejectCause is null) then
    new$RejectCause := CapRejectCause$;
  END IF;
  /*      */
  if ((new$SourceFacialAcc_CLS is null)or
  (new$DestFacialAcc_CLS is null)) then
    BEGIN
      select
      SourceFacialAcc_CLS,
      DestFacialAcc_CLS
      into
      SourceFacialAcc_CLS1$,
      DestFacialAcc_CLS1$    from
      FacialFinCaption
      where
      (new$RecordIndex=id)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$SourceFacialAcc_CLS is null) then
      new$SourceFacialAcc_CLS := SourceFacialAcc_CLS1$ ;
    END IF;
    if (new$DestFacialAcc_CLS is null) then
      new$DestFacialAcc_CLS := DestFacialAcc_CLS1$ ;

    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 14.00.00.3
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  IF (new$progindex=76) THEN
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex IN (66, 67, 76)) AND (new$DestPromise IS NOT NULL) AND
        (new$SourcePromise = new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex IN (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

  /*       */
  IF ((new$SENDERRECORDID IS NULL) AND (new$SENDERID IS NULL)) THEN
    IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
      GETTARGETCLS(NULL, new$sourcetransfertcls, NULL, new$sourcemeanstype,
      new$sourcetargetcls,new$sourcetargetcls);
    END IF;
    GETTARGETCLS(NULL, new$desttransfertcls, NULL, new$destmeanstype,
    new$desttargetcls,new$desttargetcls);
    IF (new$ProgIndex = 76) THEN
      new$SourceTargetCls := new$DestTargetCls;

    END IF;
  END IF;
  /*      */
  GetDocumentKESR(NULL, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(NULL, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode2$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
  END IF;
  if (PromiseMode2$ = 1) then
    /* source:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* source:  BudgetPromise,   Promise,   Promise */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /* dest:  BudgetPromise,   Promise,   Promise */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$NOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS,
    new$SOURCETARGETCLS,
    new$DESTTARGETCLS,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CARDNUMBER,
    new$DATEBIRTH,
    new$PAYMENTCODETYPE,
    new$CODEPURPOSE,
    new$LINENUMBER,
    new$AMOUNTISPDOC,
    new$SOURCEREGPROJECTRESULT,
    new$DESTREGPROJECTRESULT,
    new$SOURCEINCOMETARGETFUNDS,
    new$DESTINCOMETARGETFUNDS,
    new$SOURCEPAYTARGETFUNDS,
    new$DESTPAYTARGETFUNDS,
    new$SOURCEANALYTICALPARTITION,
    new$DESTANALYTICALPARTITION);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/
commit work
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_120
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (PromiseMode2$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;

    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode2$ = 1) then
    /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;

    /* source:  BudgetPromise    Promise=NULL,   Promise */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* dest:  BudgetPromise    Promise=NULL,   Promise */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$            from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* Source:  BudgetPromise -   Promise */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;

    END IF;
    /* Source:  Promise -   BudgetPromise */
    if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
      new$SourceBudgetPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  BudgetPromise -   Promise */
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  Promise -   BudgetPromise */
    if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
      new$DestBudgetPromise := null;
      new$Promise := null;

    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$SourceExecDoc := ExecID1$;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$DestExecDoc := ExecID1$;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
        new$sourceexecinnernumber := null;
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
        new$destexecinnernumber := null;
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Fix_Department_User1410.sql
-- #########################################################
-- #########################################################

/*    DepartmentCLS -> DBUsers +     DBUsers */
ALTER TRIGGER TR_DEPARTMENTCLS_BU_500 DISABLE
/
/*    */
update DepartmentCLS set
  USER_REF = null
where 
  (USER_REF is not null) and (USER_REF not in (select ID from DBUsers))
/
ALTER TRIGGER TR_DEPARTMENTCLS_BU_500 ENABLE
/
-- CREATE TRIGGER tr_DbUsers_bd_1
CREATE OR REPLACE TRIGGER TR_DBUSERS_ID
  INSTEAD OF DELETE
  ON DBUSERS
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DBUSERS_BD)
-- - - - - - - - - - - - -

        --    SYSDBA
        if (:old.id = 0) then
                RaiseException('EX_CANTDELETETHIS');
        end if;

-- - - - - - - - - - - - -
-- BD_1 (TR_DBUSERS_BD_1)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  delete from User_Workplaces
  where Users_ref = :old.id;

  delete from ReportsPermissions
  where Userid = :old.id;

  delete from UsersInGroups
  where UserRef = :old.id;

  delete from UsersRights
  where UserRef = :old.id;

  delete from DualRights
  where (UserRef = :old.id) and (IsGroup = 0);

  delete from SysNotifyHit
  where UserRef = :old.id;
    
  /*    DepartmentCLS */
  update DepartmentCLS set
  USER_REF = null
  where USER_REF = :old.id;  

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_DBUSERS
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_10 (TR_DBUSERS_AD_10)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /*    RemoteClients  DBUsers */
  if (:old.RemoteClientRef is not null) then
    SELECT COUNT(dbu.ID ) INTO CNT$1
    from DBUsers dbu where (dbu.RemoteClientRef = :old.RemoteClientRef) AND (ROWNUM = 1);
    /*     DBUsers     RemoteClient,   ,     */
    if (not (CNT$1<> 0)) then
      delete from RemoteClient where ID = :old.RemoteClientRef;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AD_20 (TR_DBUSERS_AD_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  /*         DBUsers */
  delete from LayerData
  where LayerRef in(select ID from Layers where Alias in('..','..')) and STRFIELD00 = :old.UserName;
  delete from LayerData
  where LayerRef = (select ID from Layers where Alias = '..') and STRFIELD01 = :old.UserName;
  delete from LayerData
  where LayerRef = (select ID from Layers where Alias = '..') and STRFIELD02 = :old.UserName;

-- - - - - - - - - - - - -
-- AD_30 (tr_dbusers_ad_30)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  update DepartmentCls set
  User_Ref = null
  where
  User_Ref = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_DBUSERS_AD_500)
-- - - - - - - - - - - - -

/*      */
  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
       values(100,:old.ID, sysdate);

END;
/
  
  
COMMIT WORK 
/


-- #########################################################
-- #########################################################
-- Alter_tr_FacialFinCaption_bu_0.sql
-- #########################################################
-- #########################################################

/*  ,           , ..       ,   */
-- CREATE TRIGGER TR_FACIALFINCAPTION_BU
CREATE OR REPLACE TRIGGER TR_FACIALFINCAPTION_IU
  INSTEAD OF UPDATE
  ON FACIALFINCAPTION
  FOR EACH ROW
DECLARE
  new$ID FACIALFINCAPTION.ID%TYPE := :NEW.ID;
  new$DOCNUMBER FACIALFINCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SOURCEDOCNUM FACIALFINCAPTION.SOURCEDOCNUM%TYPE := :NEW.SOURCEDOCNUM;
  new$PAYDATE FACIALFINCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$ACCEPTDATE FACIALFINCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$DOCUMENTDATE FACIALFINCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$REESTRDATE FACIALFINCAPTION.REESTRDATE%TYPE := :NEW.REESTRDATE;
  new$CREDIT FACIALFINCAPTION.CREDIT%TYPE := :NEW.CREDIT;
  new$SOURCEACCOUNT FACIALFINCAPTION.SOURCEACCOUNT%TYPE := :NEW.SOURCEACCOUNT;
  new$SOURCEFACIALACC_CLS FACIALFINCAPTION.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$DESTACCOUNT FACIALFINCAPTION.DESTACCOUNT%TYPE := :NEW.DESTACCOUNT;
  new$DESTFACIALACC_CLS FACIALFINCAPTION.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$PROGINDEX FACIALFINCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$ARHIVEDOC FACIALFINCAPTION.ARHIVEDOC%TYPE := :NEW.ARHIVEDOC;
  new$PAYSYMBOLCLS FACIALFINCAPTION.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$PAYTYPECLS FACIALFINCAPTION.PAYTYPECLS%TYPE := :NEW.PAYTYPECLS;
  new$NOTE FACIALFINCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$PERIOD FACIALFINCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$PAYPRIORITY FACIALFINCAPTION.PAYPRIORITY%TYPE := :NEW.PAYPRIORITY;
  new$TYPEOPERATIONCLS FACIALFINCAPTION.TYPEOPERATIONCLS%TYPE := :NEW.TYPEOPERATIONCLS;
  new$BUHPAYMENTCLS FACIALFINCAPTION.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$CREATERUSER FACIALFINCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF FACIALFINCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECORDINDEX FACIALFINCAPTION.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$SENDERID FACIALFINCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REESTR_REF FACIALFINCAPTION.REESTR_REF%TYPE := :NEW.REESTR_REF;
  new$REJECT_CLS FACIALFINCAPTION.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$CLIENTBANKNUMBER FACIALFINCAPTION.CLIENTBANKNUMBER%TYPE := :NEW.CLIENTBANKNUMBER;
  new$CRYPTOSTATUS FACIALFINCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$TRUSTNUMBER FACIALFINCAPTION.TRUSTNUMBER%TYPE := :NEW.TRUSTNUMBER;
  new$LINKEDDOCUMENT FACIALFINCAPTION.LINKEDDOCUMENT%TYPE := :NEW.LINKEDDOCUMENT;
  new$BNKRECORDID FACIALFINCAPTION.BNKRECORDID%TYPE := :NEW.BNKRECORDID;
  new$SUBPROGINDEX FACIALFINCAPTION.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$DOCUMENTSTATE FACIALFINCAPTION.DOCUMENTSTATE%TYPE := :NEW.DOCUMENTSTATE;
  new$USERSVISA FACIALFINCAPTION.USERSVISA%TYPE := :NEW.USERSVISA;
  new$TREASUARYDOCSTATECLS FACIALFINCAPTION.TREASUARYDOCSTATECLS%TYPE := :NEW.TREASUARYDOCSTATECLS;
  new$DEPARTMENTCLS FACIALFINCAPTION.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$NDS FACIALFINCAPTION.NDS%TYPE := :NEW.NDS;
  new$TAXNOTE FACIALFINCAPTION.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$MANAGERBID FACIALFINCAPTION.MANAGERBID%TYPE := :NEW.MANAGERBID;
  new$BIDNUMBER FACIALFINCAPTION.BIDNUMBER%TYPE := :NEW.BIDNUMBER;
  new$GROUPID FACIALFINCAPTION.GROUPID%TYPE := :NEW.GROUPID;
  new$GROUPSUMMA FACIALFINCAPTION.GROUPSUMMA%TYPE := :NEW.GROUPSUMMA;
  new$DOCSTATEREF FACIALFINCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$LASTEXTRCHANGE FACIALFINCAPTION.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$STIMATEID FACIALFINCAPTION.STIMATEID%TYPE := :NEW.STIMATEID;
  new$INTEGRATEDDOCREF FACIALFINCAPTION.INTEGRATEDDOCREF%TYPE := :NEW.INTEGRATEDDOCREF;
  new$REQUESTNUMBER FACIALFINCAPTION.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$REQUESTDATE FACIALFINCAPTION.REQUESTDATE%TYPE := :NEW.REQUESTDATE;
  new$RVERSION FACIALFINCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$FEDERALFUNDSREF FACIALFINCAPTION.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$ELDOCREF FACIALFINCAPTION.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$BUHOPERATIONCLS FACIALFINCAPTION.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CLSTYPE FACIALFINCAPTION.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$OPERATIONDIRECTION FACIALFINCAPTION.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE FACIALFINCAPTION.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE FACIALFINCAPTION.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$CARDNUMBER FACIALFINCAPTION.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$ISBLOCKED FACIALFINCAPTION.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINCAPTION.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINCAPTION.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINCAPTION.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$CASHIERPERSONALINFO FACIALFINCAPTION.CASHIERPERSONALINFO%TYPE := :NEW.CASHIERPERSONALINFO;
  new$BIDDATE FACIALFINCAPTION.BIDDATE%TYPE := :NEW.BIDDATE;
  new$CARDREF FACIALFINCAPTION.CARDREF%TYPE := :NEW.CARDREF;
  new$SOURCESTOREDPAYMENTPROPS FACIALFINCAPTION.SOURCESTOREDPAYMENTPROPS%TYPE := :NEW.SOURCESTOREDPAYMENTPROPS;
  new$DESTSTOREDPAYMENTPROPS FACIALFINCAPTION.DESTSTOREDPAYMENTPROPS%TYPE := :NEW.DESTSTOREDPAYMENTPROPS;
  new$STOREDPAYMENTNOTE FACIALFINCAPTION.STOREDPAYMENTNOTE%TYPE := :NEW.STOREDPAYMENTNOTE;
  new$DOCCHANGEDATE FACIALFINCAPTION.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$UINCODE FACIALFINCAPTION.UINCODE%TYPE := :NEW.UINCODE;
  new$DOCOSN FACIALFINCAPTION.DOCOSN%TYPE := :NEW.DOCOSN;
  new$SIGNERS FACIALFINCAPTION.SIGNERS%TYPE := :NEW.SIGNERS;
  new$DESTCLSTYPE FACIALFINCAPTION.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SENDERIDKEY FACIALFINCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$AUTOSANCTION FACIALFINCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$STOREDPAYMENTCONTENT FACIALFINCAPTION.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$REJECTCAUSE FACIALFINCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CODEPURPOSE FACIALFINCAPTION.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$DOCORDERREF FACIALFINCAPTION.DOCORDERREF%TYPE := :NEW.DOCORDERREF;
  new$DOCTYPE FACIALFINCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DESTTARGETCLS FACIALFINCAPTION.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
--
  SourceFacialAcc_CLS$ NUMBER(10);
  DestFacialAcc_CLS$ NUMBER(10);
  CNT$1 NUMBER(10);
  reestrAccepted1$ NUMBER(10);
  IsReject1$ NUMBER(10);
  Dummy$ NUMBER(10);
  ParentAcceptDate$ NUMBER;
  ParentReject_CLS$ NUMBER(10);
  ParentRejectCause$ VARCHAR2(255);
  ParentTREASUARYDOCSTATECLS$ NUMBER(10);
  ParentDOCSTATEREF$ NUMBER(10);
  ParentSOURCEACCOUNT$ NUMBER(10);
  ParentDESTACCOUNT$ NUMBER(10);
  ParentREESTR_REF$ NUMBER(10);
  SourcePromiseAccepted$ NUMBER(10);
  DestPromiseAccepted$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  DetCount1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINCAPTION_BU)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  if (new$credit is null)then 
    new$credit:= 0;
  END IF;
  if (new$ArhiveDoc is null) then 
    new$ArhiveDoc:= 0;
  END IF;
  if (new$PayTypeCls is null) then 
    new$PayTypeCls:= 0;
  END IF;
  if (new$BuhPaymentCls is null) then 
    new$BuhPaymentCls:= 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$ClsType is null) then 
    new$ClsType := 0;
  END IF;
  if (new$DestClsType is null) then 
    new$DestClsType := new$ClsType;
  END IF;
  if (new$SourceFacialAcc_CLS is null) then 
    new$SourceFacialAcc_CLS:= 0;
  END IF;
  if (new$DestFacialAcc_CLS is null) then 
    new$DestFacialAcc_CLS:= 0;
  END IF;
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;
  END IF;
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$OperationDirection <> :old.OperationDirection) then
    if (new$OperationDirection = 0) then
      new$SourceType := 1;
      new$DestType := 1;
          
    else
      if (new$OperationDirection = 1) then
        new$SourceType := 1;
        new$DestType := -1;
              
      else
        if (new$OperationDirection = 2) then
          new$SourceType := -1;
          new$DestType := 1;
                  
        else
          new$SourceType := -1;
          new$DestType := -1;
                  
        END IF;
      END IF;  
    END IF;
  END IF;
  if (new$DepartmentCls is null) then
    GetIntConst(30, 20,DocNumber1$); 
    if (DocNumber1$ is null) then 
      new$DepartmentCls:= 0;
          
    else 
      new$DepartmentCls:= DocNumber1$;
      
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount1$ from FacialFinDetail where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then 
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_1 (TR_FACIALFINCAPTION_BU_1)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --   -     
   IF (new$GroupID IS NULL) THEN new$GroupID := new$ID; END IF;
   IF (new$GroupSumma IS NULL) THEN new$GroupSumma := 0; END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_FACIALFINCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (not (    ((new$progindex = 63) or (new$progindex = 64) or (new$progindex = 68) or (new$progindex = 70))
  and (   (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001))
  or (new$sourcefacialacc_cls <> :old.sourcefacialacc_cls)
  or (
  ((new$sourceaccount is null) and (:old.sourceaccount is not null)) or
  ((new$sourceaccount is not null) and (:old.sourceaccount is null)) or
  ((new$sourceaccount <> :old.sourceaccount ) and (:old.sourceaccount is not null) and (new$sourceaccount is not null))
  )
  or (
  ((new$destaccount is null) and (:old.destaccount is not null)) or
  ((new$destaccount is not null) and (:old.destaccount is null)) or
  ((new$destaccount <> :old.destaccount ) and (:old.destaccount is not null) and (new$destaccount is not null))
  )
  or (    (:old.reestr_ref is null)
  and (new$reestr_ref is not null)
  )
  or (    (:old.reestr_ref is not null)
  and (new$reestr_ref is null)
  )
  or (:old.reestr_ref <> new$reestr_ref)
  )
  )
  )
  then /*      NULL */
    reestrAccepted1$ := 0;  /*   IB 4.2 */

  else
    BEGIN
      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=new$REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
    BEGIN

      select accepted     into reestrAccepted1$ from
      FacialFinReestr
      where
      id=:old.REESTR_REF
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (reestrAccepted1$ = 1) then
      RaiseException('ex_AcceptedReestrUpdate');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_6 (TR_FACIALFINCAPTION_BU_6)
-- Version 11.30.00.1
-- - - - - - - - - - - - -

  if (:old.ProgIndex in(63,68,70)) then /*    */
    SELECT COUNT(id ) INTO CNT$1
    from paydocexchange where ((paydocref=:old.id)and(status<>0)and(TypeInf BETWEEN 0 and 10)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      if(/* (new.DOCNUMBER<>old.DOCNUMBER) or ((new.DOCNUMBER is NULL)and(not old.DOCNUMBER is NULL)) or ((old.DOCNUMBER is NULL)and(not new.DOCNUMBER is NULL)) or*/
      (new$SOURCEDOCNUM<>:old.SOURCEDOCNUM) or ((new$SOURCEDOCNUM is NULL)and(not :old.SOURCEDOCNUM is NULL)) or ((:old.SOURCEDOCNUM is NULL)and(not new$SOURCEDOCNUM is NULL)) or
      (new$PAYDATE<>:old.PAYDATE) or ((new$PAYDATE is NULL)and(not :old.PAYDATE is NULL)) or ((:old.PAYDATE is NULL)and(not new$PAYDATE is NULL))or
      /* (new.DOCUMENTDATE<>old.DOCUMENTDATE) or ((new.DOCUMENTDATE is NULL)and(not old.DOCUMENTDATE is NULL)) or ((old.DOCUMENTDATE is NULL)and(not new.DOCUMENTDATE is NULL))or*/
      (new$REESTRDATE<>:old.REESTRDATE) or ((new$REESTRDATE is NULL)and(not :old.REESTRDATE is NULL)) or ((:old.REESTRDATE is NULL)and(not new$REESTRDATE is NULL))or
      (((new$credit - :old.credit)>0.001)or((new$credit - :old.credit)<-0.001)) or
      (new$SOURCEACCOUNT<>:old.SOURCEACCOUNT) or
      (new$DESTACCOUNT<>:old.DESTACCOUNT) or
      (new$PAYTYPECLS<>:old.PAYTYPECLS) or
      (new$NOTE<>:old.NOTE) or  ((new$NOTE is NULL)and(not :old.NOTE is NULL)) or ((:old.NOTE is NULL)and(not new$NOTE is NULL))or
      (new$PAYPRIORITY<>:old.PAYPRIORITY) or ((new$PAYPRIORITY is NULL)and(not :old.PAYPRIORITY is NULL)) or ((:old.PAYPRIORITY is NULL)and(not new$PAYPRIORITY is NULL))or
      (new$REESTR_REF<>:old.REESTR_REF) or ((new$REESTR_REF is NULL)and(not :old.REESTR_REF is NULL)) or ((:old.REESTR_REF is NULL)and(not new$REESTR_REF is NULL))or
      (new$NDS<>:old.NDS) or ((new$NDS is NULL)and(not :old.NDS is NULL)) or ((:old.NDS is NULL)and(not new$NDS is NULL))or
      (new$TAXNOTE<>:old.TAXNOTE) or ((new$TAXNOTE is NULL)and(not :old.TAXNOTE is NULL)) or ((:old.TAXNOTE is NULL)and(not new$TAXNOTE is NULL)) )then
        RaiseException('ex_CannotChangeSended');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_FACIALFINCAPTION_BU_10)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$IntegratedDocRef is not null) then
    /*           ,       */
    /*    */
    if (((new$AcceptDate = :old.AcceptDate)or((new$AcceptDate is null)and(:old.AcceptDate is null)))
    and((new$Reject_CLS = :old.Reject_CLS)or((new$Reject_CLS is null)and(:old.Reject_CLS is null)))
    and((new$RejectCause = :old.RejectCause)or((new$RejectCause is null)and(:old.RejectCause is null)))
    and((new$TREASUARYDOCSTATECLS = :old.TREASUARYDOCSTATECLS)or((new$TREASUARYDOCSTATECLS is null)and(:old.TREASUARYDOCSTATECLS is null)))
    and((new$DOCSTATEREF = :old.DOCSTATEREF)or((new$DOCSTATEREF is null)and(:old.DOCSTATEREF is null)))
    and((new$REESTR_REF = :old.REESTR_REF)or((new$REESTR_REF is NULL)and(:old.REESTR_REF is NULL)))
    and(new$SOURCEACCOUNT = :old.SOURCEACCOUNT)
    and(new$DESTACCOUNT = :old.DESTACCOUNT)
    ) then
      new$AcceptDate := :old.AcceptDate;

    Else
      BEGIN
        select
        fc.AcceptDate, fc.Reject_CLS, fc.RejectCause, fc.TREASUARYDOCSTATECLS, fc.DOCSTATEREF,
        fc.REESTR_REF,fc.SOURCEACCOUNT, fc.DESTACCOUNT
        into
        ParentAcceptDate$, ParentReject_CLS$, ParentRejectCause$, ParentTREASUARYDOCSTATECLS$,
        ParentDOCSTATEREF$,ParentREESTR_REF$,ParentSOURCEACCOUNT$,ParentDESTACCOUNT$       from
        FacialFinCaption fc
        where
        (fc.id = new$IntegratedDocRef)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (((new$AcceptDate = ParentAcceptDate$)or((new$AcceptDate is null)and(ParentAcceptDate$ is null)))
      and((new$Reject_CLS = ParentReject_CLS$)or((new$Reject_CLS is null)and(ParentReject_CLS$ is null)))
      and((new$RejectCause = ParentRejectCause$)or((new$RejectCause is null)and(ParentRejectCause$ is null)))
      and((new$TREASUARYDOCSTATECLS = ParentTREASUARYDOCSTATECLS$)or((new$TREASUARYDOCSTATECLS is null)and(ParentTREASUARYDOCSTATECLS$ is null)))
      and((new$DOCSTATEREF = ParentDOCSTATEREF$)or((new$DOCSTATEREF is null)and(ParentDOCSTATEREF$ is null)))
      and((new$REESTR_REF = ParentREESTR_REF$)or((new$REESTR_REF is NULL)and(ParentREESTR_REF$ is NULL)))
      and(new$SOURCEACCOUNT = ParentSOURCEACCOUNT$)
      and(new$DESTACCOUNT = ParentDESTACCOUNT$)
      ) then
        new$AcceptDate := ParentAcceptDate$;

      Else
        RaiseException('EX_CANNOTUPDATECHILDDOC');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_32 (TR_FACIALFINCAPTION_BU_32)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$Reestr_ref IS NULL)    /*    select ,  */
                              THEN
      new$SourceDocNum := '';
      new$ReestrDate := NULL;
   ELSIF (    (new$Reestr_ref = :OLD.Reestr_ref)
          AND (new$SourceDocNum = :OLD.SourceDocNum)
          AND (new$ReestrDate = :OLD.ReestrDate)
         ) THEN
/*          */
      NULL;
   ELSE
      BEGIN
         SELECT ffr.ReestrNumber, ffr.ReestrDate
           INTO new$SourceDocNum, new$ReestrDate
           FROM FacialFinReestr ffr
          WHERE ffr.ID = new$Reestr_ref;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            new$SourceDocNum := NULL;
            new$ReestrDate := NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BU_60 (T_FACIALFINCAPTION_BU_60)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF ((new$progindex = 60) AND (new$Credit <> :OLD.Credit)) THEN
      UPDATE FacialFinDetail
         SET Credit = new$Credit
       WHERE (RecordIndex = new$ID);
   END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_FACIALFINCAPTION_BU_70)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   --         
   IF (new$SubProgIndex = 416) THEN
      UPDATE Guarantee
         SET AcceptDate = new$AcceptDate
       WHERE SubRecordIndex = new$ID;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (T_FACIALFINCAPTION_BU_100)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*   ,    */
   IF (    (   (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS)
            OR (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS)
           )
       AND ((new$SubProgIndex <> 1) OR (new$SubProgIndex IS NULL))
      ) THEN
      FOR R$ IN (SELECT ID, SourceFacialAcc_CLS, DestFacialAcc_CLS
                   FROM FacialFinDetail
                  WHERE RecordIndex = new$ID) LOOP
         IF (NOT (new$SourceFacialAcc_CLS = 0)) THEN
            SourceFacialAcc_CLS$ := new$SourceFacialAcc_CLS;
         ELSE
            SourceFacialAcc_CLS$ := R$.SourceFacialAcc_CLS;
         END IF;

         IF (NOT (new$DestFacialAcc_CLS = 0)) THEN
            DestFacialAcc_CLS$ := new$DestFacialAcc_CLS;
         ELSE
            DestFacialAcc_CLS$ := R$.DestFacialAcc_CLS;
         END IF;

         IF (:OLD.SourceFacialAcc_CLS <> new$SourceFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET SourceFacialAcc_CLS = SourceFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;

         IF (:OLD.DestFacialAcc_CLS <> new$DestFacialAcc_CLS) THEN
            UPDATE FacialFinDetail
               SET DestFacialAcc_CLS = DestFacialAcc_CLS$,
                   RVersion = -1
             WHERE (ID = R$.ID);
         END IF;
      END LOOP;
   END IF;

   /*    / , 
           .*/
  IF (((NEW$IsBlocked <> :OLD.IsBlocked) OR
      ((NEW$IsBlocked IS NULL) AND (:OLD.IsBlocked IS NOT NULL)) OR
      ((NEW$IsBlocked IS NOT NULL) AND (:OLD.IsBlocked IS NULL))
     ) OR
     ((NEW$BlockedCause <> :OLD.BlockedCause) OR
      ((NEW$BlockedCause IS NULL) AND (:OLD.BlockedCause IS NOT NULL)) OR
      ((NEW$BlockedCause IS NOT NULL) AND (:OLD.BlockedCause IS NULL))
     ) OR
     ((NEW$UnBlockedDate <> :OLD.UnBlockedDate) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedDate IS NOT NULL)) OR
      ((NEW$UnBlockedDate IS NOT NULL) AND (:OLD.UnBlockedDate IS NULL))
     ) OR
     ((NEW$UnBlockedCause <> :OLD.UnBlockedCause) OR
      ((NEW$UnBlockedDate IS NULL) AND (:OLD.UnBlockedCause IS NOT NULL)) OR
      ((NEW$UnBlockedCause IS NOT NULL) AND (:OLD.UnBlockedCause IS NULL))
     )) THEN
     UPDATE FacialFinDetail ffd
     SET ffd.IsBlocked = NEW$IsBlocked, ffd.BlockedCause = NEW$BlockedCause,
         ffd.UnBlockedDate = NEW$UnBlockedDate, ffd.UnBlockedCause = NEW$UnBlockedCause
     WHERE ffd.recordindex = NEW$ID;
  end if;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINCAPTION_BU_200)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  if (new$reject_cls is null and :old.reject_cls is not null) then
    /*   ,        */
    FOR REC$1 IN (      select SourcePromise AS SourcePromise, SourceBudgetPromise AS SourceBudgetPromise, DestPromise AS DestPromise, DestBudgetPromise
     AS DestBudgetPromise       from FacialFinDetail
    where RecordIndex = new$id
    )
    LOOP
      if ((REC$1.SourcePromise is not null) or (REC$1.SourceBudgetPromise is not null)) then
        BEGIN
          /*     */
          select Accepted         into SourcePromiseAccepted$ from PaymentSchedule
          where ANumber = REC$1.SourcePromise  and InnerPromiseNum = REC$1.SourceBudgetPromise

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;

      if ((REC$1.DestPromise is not null) or (REC$1.DestBudgetPromise is not null)) then
        BEGIN
          /*     */
          select Accepted         into DestPromiseAccepted$ from PaymentSchedule
          where ANumber = REC$1.DestPromise  and InnerPromiseNum = REC$1.DestBudgetPromise

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;

      /*        */
      if (((REC$1.SourceBudgetPromise is not null) or (REC$1.DestBudgetPromise is not null))
      and ((SourcePromiseAccepted$ <> 1) or (DestPromiseAccepted$ <> 1)))
      then
        RaiseException('Ex_BP_Rejected');
      END IF;
    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINCAPTION_BU_210)
-- Create 27.08.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   /*      */
   IF (new$DOCSTATEREF <> :OLD.DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (T_FACIALFINCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;

  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID = new$ID;
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from FacialFinDetail d where d.RecordIndex = new$id);

  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINCAPTION_BU_700)
-- Create 17.09.2004
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINCAPTION SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    SOURCEDOCNUM = new$SOURCEDOCNUM,
    PAYDATE = new$PAYDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    REESTRDATE = new$REESTRDATE,
    CREDIT = new$CREDIT,
    SOURCEACCOUNT = new$SOURCEACCOUNT,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    DESTACCOUNT = new$DESTACCOUNT,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    PROGINDEX = new$PROGINDEX,
    ARHIVEDOC = new$ARHIVEDOC,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    PAYTYPECLS = new$PAYTYPECLS,
    NOTE = new$NOTE,
    PERIOD = new$PERIOD,
    PAYPRIORITY = new$PAYPRIORITY,
    TYPEOPERATIONCLS = new$TYPEOPERATIONCLS,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    RECORDINDEX = new$RECORDINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REESTR_REF = new$REESTR_REF,
    REJECT_CLS = new$REJECT_CLS,
    CLIENTBANKNUMBER = new$CLIENTBANKNUMBER,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    TRUSTNUMBER = new$TRUSTNUMBER,
    LINKEDDOCUMENT = new$LINKEDDOCUMENT,
    BNKRECORDID = new$BNKRECORDID,
    SUBPROGINDEX = new$SUBPROGINDEX,
    DOCUMENTSTATE = new$DOCUMENTSTATE,
    USERSVISA = new$USERSVISA,
    TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    NDS = new$NDS,
    TAXNOTE = new$TAXNOTE,
    MANAGERBID = new$MANAGERBID,
    BIDNUMBER = new$BIDNUMBER,
    GROUPID = new$GROUPID,
    GROUPSUMMA = new$GROUPSUMMA,
    DOCSTATEREF = new$DOCSTATEREF,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    STIMATEID = new$STIMATEID,
    INTEGRATEDDOCREF = new$INTEGRATEDDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    REQUESTDATE = new$REQUESTDATE,
    RVERSION = new$RVERSION,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    ELDOCREF = new$ELDOCREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CLSTYPE = new$CLSTYPE,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    CARDNUMBER = new$CARDNUMBER,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    CASHIERPERSONALINFO = new$CASHIERPERSONALINFO,
    BIDDATE = new$BIDDATE,
    CARDREF = new$CARDREF,
    SOURCESTOREDPAYMENTPROPS = new$SOURCESTOREDPAYMENTPROPS,
    DESTSTOREDPAYMENTPROPS = new$DESTSTOREDPAYMENTPROPS,
    STOREDPAYMENTNOTE = new$STOREDPAYMENTNOTE,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    UINCODE = new$UINCODE,
    DOCOSN = new$DOCOSN,
    SIGNERS = new$SIGNERS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    AUTOSANCTION = new$AUTOSANCTION,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    REJECTCAUSE = new$REJECTCAUSE,
    CODEPURPOSE = new$CODEPURPOSE,
    DOCORDERREF = new$DOCORDERREF,
    DOCTYPE = new$DOCTYPE,
    DESTTARGETCLS = new$DESTTARGETCLS
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_FACIALFINCAPTION_AU_10)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 72) then /*   */
    if (((new$AcceptDate = :old.AcceptDate)or((new$AcceptDate is null)and(:old.AcceptDate is null)))
    and((new$Reject_CLS = :old.Reject_CLS)or((new$Reject_CLS is null)and(:old.Reject_CLS is null)))
    and((new$RejectCause = :old.RejectCause)or((new$RejectCause is null)and(:old.RejectCause is null)))
    and((new$TREASUARYDOCSTATECLS = :old.TREASUARYDOCSTATECLS)or((new$TREASUARYDOCSTATECLS is null)and(:old.TREASUARYDOCSTATECLS is null)))
    and((new$DOCSTATEREF = :old.DOCSTATEREF)or((new$DOCSTATEREF is null)and(:old.DOCSTATEREF is null)))
    and((new$REESTR_REF = :old.REESTR_REF)or((new$REESTR_REF is NULL)and(:old.REESTR_REF is NULL)))
    and(new$SOURCEACCOUNT = :old.SOURCEACCOUNT)
    and(new$DESTACCOUNT = :old.DESTACCOUNT)
    ) then
      Dummy$ := 0;

    Else
      /*    ,      */
      update FacialFinCaption set
      AcceptDate = new$AcceptDate,
      Reject_CLS = new$Reject_CLS,
      RejectCause = new$RejectCause,
      TREASUARYDOCSTATECLS = new$TREASUARYDOCSTATECLS,
      DOCSTATEREF = new$DOCSTATEREF,
      REESTR_REF = new$REESTR_REF,
      SOURCEACCOUNT = new$SOURCEACCOUNT,
      DESTACCOUNT = new$DESTACCOUNT
      where
      IntegratedDocRef = new$id;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_FACIALFINCAPTION_AU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    ,  ,     ,      */
  if ((new$AcceptDate <> :old.AcceptDate)or((new$AcceptDate is not null)and(:old.AcceptDate is null))
  or((new$AcceptDate is null)and(:old.AcceptDate is not null))) then
    update facialfindetail set
    AcceptDate = new$AcceptDate,
    RVersion = -1
    where
    (RecordIndex = new$id) and (Reject_cls is null);
  END IF;

  if ((new$Reject_cls <> :old.Reject_cls)or((new$Reject_cls is not null)and(:old.Reject_cls is null))
  or((new$Reject_cls is null)and(:old.Reject_cls is not null))) then
    update facialfindetail set
    Reject_cls = new$Reject_cls,
    AcceptDate = null,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;

  if ((new$RejectCause <> :old.RejectCause)or((new$RejectCause is not null)and(:old.RejectCause is null))
  or((new$RejectCause is null)and(:old.RejectCause is not null))) then
    update facialfindetail set
    RejectCause = new$RejectCause,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if (new$BuhOperationCLS <> :old.BuhOperationCLS)  then
    update facialfindetail set
    BuhOperationCLS = new$BuhOperationCLS,
    RVersion = -1
    where
    RecordIndex = new$id;
  END IF;
  if ((new$ClsType <> :old.ClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$ClsType = 0) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceIFS = 0,
      DestIFS = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 1) then
      update facialfindetail set
      SourceKD = 0,
      DestKD = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);
    END IF;
    if (new$ClsType = 2) then
      update facialfindetail set
      SourceIFS = 0,
      DestIFS = 0,
      SourceKVSR = 0,
      SourceKFSR = 0,
      SourceKCSR = 0,
      SourceKVR = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      ClsType = new$ClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(ClsType=:old.ClsType);

    END IF;
  END IF;
  if ((new$DestClsType <> :old.DestClsType)
  and
  ((new$RVersion<>:old.RVersion)
  or
  ((:old.RVersion is null)and(new$RVersion is not null)))) then
    if (new$DestClsType = 0) then
      update facialfindetail set
      DestKD = 0,
      DestIFS = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 1) then
      update facialfindetail set
      DestKD = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);
    END IF;
    if (new$DestClsType = 2) then
      update facialfindetail set
      DestIFS = 0,
      DestKVSR = 0,
      DestKFSR = 0,
      DestKCSR = 0,
      DestKVR = 0,
      DestClsType = new$DestClsType,
      RVersion = -1
      where
      (RecordIndex = new$id)and(DestClsType=:old.DestClsType);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   IF (:NEW.ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (23, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
        WHERE (TableID = 23) AND (RecordId = :NEW.ID);
   END IF;

END;
/
commit work
/


-- #########################################################
-- #########################################################
-- Alter_VATPercent.sql
-- #########################################################
-- #########################################################

/*      ESTIMATE.VATPercent  "0",   "NULL".  61023 */
-- ALTER TRIGGER TR_Estimate_BI
CREATE OR REPLACE TRIGGER TR_ESTIMATE_BI
  BEFORE INSERT
  ON ESTIMATE
  FOR EACH ROW
DECLARE
  TempFacialAcc_CLS1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ESTIMATE_BI)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if  (:new.FacialAcc_Cls is null) then
    BEGIN
      select FacialAcc_Cls    into TempFacialAcc_CLS1$ from Agreements
      where (ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    :new.FacialAcc_Cls := TempFacialAcc_CLS1$;
     
  END IF;
  if (:new.ProductCls is null) then 
    :new.ProductCls := 0;
  END IF;
  if (:new.Amount is null) then 
    :new.amount := 0;
  END IF;
  if (:new.Price is null) then 
    :new.Price := 0;
  END IF;
  if (:new.Cost is null) then 
    :new.Cost := 0;
  END IF;
  if (:new.VATSumma is null) then 
    :new.VATSumma := 0;
  END IF;
  if (:new.Summa is null) then 
    :new.Summa := 0;
  END IF;
  if (:new.FinSumma is null) then 
    :new.FinSumma := 0;
  END IF;
  if (:new.PriceVAT is null) then 
    :new.PriceVAT := 0;
  END IF;
  BEGIN

    /*  ,    */
    select agr.BudgetRef      into :new.BudgetRef from Agreements agr
    where agr.ID = :new.RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BI_10 (TR_ESTIMATE_BI_10)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (:new.senderId is null) then
    :new.senderIdKey := -1;
  else
    :new.senderIdKey := :new.senderId;
  end if;

  if (:new.SenderRecordID is null)then
    :new.SenderRecordIDKey := :new.ID;
  else
    :new.SenderRecordIDKey := :new.SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_20 (TR_ESTIMATE_BI_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if ((:new.COST < 0) or (:new.SUMMA < 0)) then
    RaiseException('EX_EXECDOCEST_NEGATIVECOST');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_ESTIMATE_BI_500)
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;

END;
/
-- ALTER TRIGGER TR_Estimate_BU
CREATE OR REPLACE TRIGGER TR_ESTIMATE_BU
  BEFORE UPDATE
  ON ESTIMATE
  FOR EACH ROW
DECLARE
  TempFacialAcc_CLS1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ESTIMATE_BU)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  if  (:new.FacialAcc_Cls is null) then
    BEGIN
      select FacialAcc_Cls    into TempFacialAcc_CLS1$ from Agreements
      where (ID = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    :new.FacialAcc_Cls := TempFacialAcc_CLS1$;
     
  END IF;
  if (:new.ProductCls is null) then 
    :new.ProductCls := 0;
  END IF;
  if (:new.Amount is null) then 
    :new.amount := 0;
  END IF;
  if (:new.Price is null) then 
    :new.Price := 0;
  END IF;
  if (:new.Cost is null) then 
    :new.Cost := 0;
  END IF;
  if (:new.VATSumma is null) then 
    :new.VATSumma := 0;
  END IF;
  if (:new.Summa is null) then 
    :new.Summa := 0;
  END IF;
  if (:new.FinSumma is null) then 
    :new.FinSumma := 0;
  END IF;
  if (:new.PriceVAT is null) then 
    :new.PriceVAT := 0;
  END IF;
  /*     */
  if (:new.BudgetRef <> :old.BudgetRef) then
    if ( not((:new.BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_ESTIMATE_BU_20)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if ((:new.COST < 0) or (:new.SUMMA < 0)) then
    RaiseException('EX_EXECDOCEST_NEGATIVECOST');
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_Estimate_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (:new.RecordIndex <> :old.RecordIndex) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_ESTIMATE_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (:NEW.RVersion IS NULL) THEN
      :NEW.RVersion := 1;
   ELSE
      IF ((:NEW.RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         :NEW.RVersion := :OLD.RVersion;
      ELSE
         :NEW.RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_TR_PAYMENTSCHEDULE_BI_1.sql
-- #########################################################
-- #########################################################

/*   "        / "
      SummaYear1  PaymentSchedule  ,       ,     . 
      Summa        ... ,  ,       . 
     Summa  PaymentSchedule   (ProgIndex=317, 318) .
*/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_BI_1
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_II
  INSTEAD OF INSERT
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$PAYMENTCODETYPE PAYMENTSCHEDULE.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$REGPROJECTRESULT PAYMENTSCHEDULE.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
  new$PAYTARGETFUNDS PAYMENTSCHEDULE.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$ANALYTICALPARTITION PAYMENTSCHEDULE.ANALYTICALPARTITION%TYPE := :NEW.ANALYTICALPARTITION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PreviousInner$ NUMBER(10);
  AdjDocNum$ NUMBER(10);
  Tmp$ NUMBER(10);
  InnerNumber_parent$ NUMBER(10);
  InnerNumber_child$ NUMBER(10);
  M011$ NUMBER;
  M021$ NUMBER;
  M031$ NUMBER;
  M041$ NUMBER;
  M051$ NUMBER;
  M061$ NUMBER;
  M071$ NUMBER;
  M081$ NUMBER;
  M091$ NUMBER;
  M101$ NUMBER;
  M111$ NUMBER;
  M121$ NUMBER;
  Q11$ NUMBER;
  Q21$ NUMBER;
  Q31$ NUMBER;
  Q41$ NUMBER;
  S5$ NUMBER;
  S21$ NUMBER;
  S31$ NUMBER;
  S41$ NUMBER;
  SOther1$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_PAYMENTSCHEDULE_BI)
-- Version 14.00.00.4
-- - - - - - - - - - - - -

  /*   13.10.01*/
  IF (new$id IS NULL) THEN
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$Accepted IS NULL) THEN
    new$Accepted := 1;
  END IF;
  IF (new$PromiseType IS NULL) THEN
    new$PromiseType := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN
    new$KFSR := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN
    new$KVSR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN
    new$KCSR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN
    new$KVR := 0;
  END IF;
  IF (new$SubKESR IS NULL) THEN
    new$SubKESR := 0;
  END IF;
  IF (new$AssignmentKind IS NULL) THEN
    new$AssignmentKind := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN
    new$DirectionCls := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$Region IS NULL) THEN
    new$Region := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN
    new$MeansType := 0;
  END IF;
  IF (new$FinSource IS NULL) THEN
    new$FinSource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN
    new$FinType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN
    new$Fact := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL) THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  IF (new$Month01 IS NULL) THEN
    new$Month01 := 0;
  END IF;
  IF (new$Month02 IS NULL) THEN
    new$Month02 := 0;
  END IF;
  IF (new$Month03 IS NULL) THEN
    new$Month03 := 0;
  END IF;
  IF (new$Month04 IS NULL) THEN
    new$Month04 := 0;
  END IF;
  IF (new$Month05 IS NULL) THEN
    new$Month05 := 0;
  END IF;
  IF (new$Month06 IS NULL) THEN
    new$Month06 := 0;
  END IF;
  IF (new$Month07 IS NULL) THEN
    new$Month07 := 0;
  END IF;
  IF (new$Month08 IS NULL) THEN
    new$Month08 := 0;
  END IF;
  IF (new$Month09 IS NULL) THEN
    new$Month09 := 0;
  END IF;
  IF (new$Month10 IS NULL) THEN
    new$Month10 := 0;
  END IF;
  IF (new$Month11 IS NULL) THEN
    new$Month11 := 0;
  END IF;
  IF (new$Month12 IS NULL) THEN
    new$Month12 := 0;
  END IF;
  IF (new$Quarter1 IS NULL) THEN
    new$Quarter1 := 0;
  END IF;
  IF (new$Quarter2 IS NULL) THEN
    new$Quarter2 := 0;
  END IF;
  IF (new$Quarter3 IS NULL) THEN
    new$Quarter3 := 0;
  END IF;
  IF (new$Quarter4 IS NULL) THEN
    new$Quarter4 := 0;
  END IF;
  IF (new$Summa IS NULL) THEN
    new$Summa := 0;
  END IF;
  IF (new$Month01Delta IS NULL) THEN
    new$Month01Delta := 0;
  END IF;
  IF (new$Month02Delta IS NULL) THEN
    new$Month02Delta := 0;
  END IF;
  IF (new$Month03Delta IS NULL) THEN
    new$Month03Delta := 0;
  END IF;
  IF (new$Month04Delta IS NULL) THEN
    new$Month04Delta := 0;
  END IF;
  IF (new$Month05Delta IS NULL) THEN
    new$Month05Delta := 0;
  END IF;
  IF (new$Month06Delta IS NULL) THEN
    new$Month06Delta := 0;
  END IF;
  IF (new$Month07Delta IS NULL) THEN
    new$Month07Delta := 0;
  END IF;
  IF (new$Month08Delta IS NULL) THEN
    new$Month08Delta := 0;
  END IF;
  IF (new$Month09Delta IS NULL) THEN
    new$Month09Delta := 0;
  END IF;
  IF (new$Month10Delta IS NULL) THEN
    new$Month10Delta := 0;
  END IF;
  IF (new$Month11Delta IS NULL) THEN
    new$Month11Delta := 0;
  END IF;
  IF (new$Month12Delta IS NULL) THEN
    new$Month12Delta := 0;
  END IF;
  IF (new$Quarter1Delta IS NULL) THEN
    new$Quarter1Delta := 0;
  END IF;
  IF (new$Quarter2Delta IS NULL) THEN
    new$Quarter2Delta := 0;
  END IF;
  IF (new$Quarter3Delta IS NULL) THEN
    new$Quarter3Delta := 0;
  END IF;
  IF (new$Quarter4Delta IS NULL) THEN
    new$Quarter4Delta := 0;
  END IF;
  IF (new$SummaDelta IS NULL) THEN
    new$SummaDelta := 0;
  END IF;
  IF (new$SummaPreviousYear IS NULL) THEN
    new$SummaPreviousYear := 0;
  END IF;
  IF (new$SummaFinPreviousYear IS NULL) THEN
    new$SummaFinPreviousYear := 0;
  END IF;
  IF (new$SummaYear2 IS NULL) THEN
    new$SummaYear2 := 0;
  END IF;
  IF (new$SummaYear3 IS NULL) THEN
    new$SummaYear3 := 0;
  END IF;
  IF (new$SummaYear4 IS NULL) THEN
    new$SummaYear4 := 0;
  END IF;
  IF (new$SummaOtherYears IS NULL) THEN
    new$SummaOtherYears := 0;
  END IF;
  IF (new$SummaYear2Delta IS NULL) THEN
    new$SummaYear2Delta := 0;
  END IF;
  IF (new$SummaYear3Delta IS NULL) THEN
    new$SummaYear3Delta := 0;
  END IF;
  IF (new$SummaYear4Delta IS NULL) THEN
    new$SummaYear4Delta := 0;
  END IF;
  IF (new$SummaOtherYearsDelta IS NULL) THEN
    new$SummaOtherYearsDelta := 0;
  END IF;
  /*   ,        */
  IF (new$ProgIndex = 304 AND new$RecordIndex IS NOT NULL) THEN
    SELECT COUNT(*) INTO CNT$1
    FROM AgreementSteps s WHERE (s.Id = new$RecordIndex AND s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    IF (NOT (CNT$1<> 0)) THEN
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*       */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    IF (new$ProgIndex IN (304,314,317,318)) THEN
      BEGIN
        SELECT a.BudgetRef       INTO new$BudgetRef FROM Agreements a
        WHERE a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    ELSE
      IF (new$ProgIndex = 308) THEN
        BEGIN
          SELECT e.BudgetRef
          INTO new$BudgetRef       FROM ExecutionDocumentsCaption e
          WHERE e.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
      END IF;
    END IF;
  END IF;

  /*    ,     ,      */
  IF (new$AdjustmentRef IS NULL) THEN
    select g_shared.nextval into new$InnerPromiseNum from dual;
    new$ParentNumber := NULL;

  ELSE
    /*      , ..     */
    IF (new$Accepted = 0) THEN
      BEGIN
        SELECT
        InnerPromiseNum, ANumber
        INTO PreviousInner$, AdjDocNum$       FROM Paymentschedule
        WHERE ID = new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    ELSE
      BEGIN
        /*          */
        SELECT
        InnerPromiseNum, ANumber
        INTO PreviousInner$, AdjDocNum$       FROM Paymentschedule
        WHERE ID = new$AdjustmentRef AND LastAccepted = 1 AND LastAdjustment = 1
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (PreviousInner$ IS NULL) THEN
        RaiseException('EX_NotFindInnerNumber');
      END IF;
    END IF;
    new$InnerPromiseNum := PreviousInner$;
    new$ParentNumber := AdjDocNum$;

  END IF;
  /*    ,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0))
  THEN
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  IF (new$ANumber IS NOT NULL) THEN
    SELECT COUNT(                    id
    ) INTO CNT$2
    FROM
    PaymentSchedule ps
    WHERE
    (                    (ps.ANumber = new$ANumber)
    AND
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    IF ((CNT$2<> 0)) THEN
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;

  /*    */
  IF ((new$SENDERRECORDID IS NULL) AND (new$SENDERID IS NULL)) THEN
    GETTARGETCLS(NULL, new$transfertcls, NULL, new$meanstype,
    new$targetcls,new$targetcls);
  END IF;
  /*   */
  GetDocumentKESR(NULL, new$SubKESR, new$KESR, new$BudgetRef,new$KESR);

-- - - - - - - - - - - - -
-- BI_1 (TR_PAYMENTSCHEDULE_BI_1)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*   1.0*/    
  new$Quarter1 := new$Month01 + new$Month02 + new$Month03;
  new$Quarter2 := new$Month04 + new$Month05 + new$Month06;
  new$Quarter3 := new$Month07 + new$Month08 + new$Month09;
  new$Quarter4 := new$Month10 + new$Month11 + new$Month12;
  if (new$ProgIndex not in (317,318)) then
    new$Summa := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_PAYMENTSCHEDULE_BI_10)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*   13.10.01*/

  /*    .*/
  if (new$InnerPromiseNum is null) then
    RaiseException('EX_BP_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$         from PaymentSchedule
  where (InnerPromiseNum = new$InnerPromiseNum)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;

  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;

  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;
  /*     */
  if (new$AdjustmentRef is not null) then
    /*       */
    select count(ID)
    into Tmp$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (AcceptDate is not null)
    ;
    /*     ,  */
    if (Tmp$ = 0) then
      RaiseException('EX_BP_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$             from PaymentSchedule
    where (InnerPromiseNum = new$InnerPromiseNum) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_BP_AdjustDuplicate');
    END IF;
    /*   - ,  ,       */
    if (new$ProgIndex in (304, 314)) then
      BEGIN
        /*     */
        select a.InnerNumber
        into InnerNumber_child$             from Agreements a
        where a.ID = new$AgreementRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN
        /*       */
        select a.InnerNumber
        into InnerNumber_parent$             from PaymentSchedule ps
        left join Agreements a on (a.Id = ps.AgreementRef)
        where (ps.Id = new$AdjustmentRef)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*      */
      if (InnerNumber_parent$ <> InnerNumber_child$) then
        RaiseException('EX_PROMISE_ADJ_INCORRECT');
      END IF;
    else
      if (new$ProgIndex = 308) then
        BEGIN
          /*     */
          select edc.InnerNumber
          into InnerNumber_child$             from ExecutionDocumentsCaption edc
          where edc.ID = new$ExecutionRef
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        BEGIN
          /*       */
          select edc.InnerNumber
          into InnerNumber_parent$             from PaymentSchedule ps
          left join ExecutionDocumentsCaption edc on (edc.id=ps.ExecutionRef)
          where (ps.Id = new$AdjustmentRef)
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        /*      */
        if (InnerNumber_parent$ <> InnerNumber_child$) then
          RaiseException('EX_PROMISE_ADJ_INCORRECT');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_PAYMENTSCHEDULE_BI_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M011$, M021$, M031$, M041$, M051$, M061$, M071$, M081$, M091$, M101$, M111$, M121$,
      Q11$, Q21$, Q31$, Q41$, S5$, S21$, S31$, S41$, SOther1$         from
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    new$Month01Delta := new$Month01 - M011$;
    new$Month02Delta := new$Month02 - M021$;
    new$Month03Delta := new$Month03 - M031$;
    new$Month04Delta := new$Month04 - M041$;
    new$Month05Delta := new$Month05 - M051$;
    new$Month06Delta := new$Month06 - M061$;
    new$Month07Delta := new$Month07 - M071$;
    new$Month08Delta := new$Month08 - M081$;
    new$Month09Delta := new$Month09 - M091$;
    new$Month10Delta := new$Month10 - M101$;
    new$Month11Delta := new$Month11 - M111$;
    new$Month12Delta := new$Month12 - M121$;
    new$Quarter1Delta := new$Quarter1 - Q11$;
    new$Quarter2Delta := new$Quarter2 - Q21$;
    new$Quarter3Delta := new$Quarter3 - Q31$;
    new$Quarter4Delta := new$Quarter4 - Q41$;
    new$SummaDelta := new$Summa - S5$;
    new$SummaYear2Delta := new$SummaYear2 - S21$;
    new$SummaYear3Delta := new$SummaYear3 - S31$;
    new$SummaYear4Delta := new$SummaYear4 - S41$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther1$;

  else    /*        */
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;

  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_PAYMENTSCHEDULE_BI_200)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*      */
  if (new$senderId is null) then
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;

-- - - - - - - - - - - - -
-- BI_500 (TR_PAYMENTSCHEDULE_BI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_PAYMENTSCHEDULE (
    ID,
    ANUMBER,
    PARENTNUMBER,
    KFSR,
    KESR,
    KVSR,
    KCSR,
    KVR,
    MONTH01,
    MONTH02,
    MONTH03,
    MONTH04,
    MONTH05,
    MONTH06,
    MONTH07,
    MONTH08,
    MONTH09,
    MONTH10,
    MONTH11,
    MONTH12,
    SUMMA,
    REGION,
    SUBKESR,
    MEANSTYPE,
    FINSOURCE,
    FINTYPE,
    FACT,
    FACIALACC_CLS,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    ACCEPTDATE,
    LASTADJUSTMENT,
    ACCEPTED,
    LASTACCEPTED,
    PROMISETYPE,
    ADJUSTMENTREF,
    SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR,
    QUARTER1,
    QUARTER2,
    QUARTER3,
    QUARTER4,
    RECORDINDEX,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    DIRECTIONCLS,
    RVERSION,
    BUHOPERATIONCLS,
    MONTH01DELTA,
    MONTH02DELTA,
    MONTH03DELTA,
    MONTH04DELTA,
    MONTH05DELTA,
    MONTH06DELTA,
    MONTH07DELTA,
    MONTH08DELTA,
    MONTH09DELTA,
    MONTH10DELTA,
    MONTH11DELTA,
    MONTH12DELTA,
    QUARTER1DELTA,
    QUARTER2DELTA,
    QUARTER3DELTA,
    QUARTER4DELTA,
    SUMMADELTA,
    NOTE,
    FINYEAR,
    SUMMAYEAR2,
    SUMMAYEAR3,
    SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA,
    ASSIGNMENTKIND,
    TRANSFERTCLS,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    EXECUTIONREF,
    INNERPROMISENUM,
    ADJUSTMENTNUMBER,
    PROMISENUMBER,
    SUBSIDYCLS,
    AGREEMENTREF,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    PROGINDEX,
    INVESTOBJECT,
    SUMMAYEAR4,
    SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    OLDNUMBER,
    PAYMENTCODETYPE,
    REGPROJECTRESULT,
    PAYTARGETFUNDS,
    ANALYTICALPARTITION
  ) VALUES (
    new$ID,
    new$ANUMBER,
    new$PARENTNUMBER,
    new$KFSR,
    new$KESR,
    new$KVSR,
    new$KCSR,
    new$KVR,
    new$MONTH01,
    new$MONTH02,
    new$MONTH03,
    new$MONTH04,
    new$MONTH05,
    new$MONTH06,
    new$MONTH07,
    new$MONTH08,
    new$MONTH09,
    new$MONTH10,
    new$MONTH11,
    new$MONTH12,
    new$SUMMA,
    new$REGION,
    new$SUBKESR,
    new$MEANSTYPE,
    new$FINSOURCE,
    new$FINTYPE,
    new$FACT,
    new$FACIALACC_CLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$ACCEPTDATE,
    new$LASTADJUSTMENT,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$PROMISETYPE,
    new$ADJUSTMENTREF,
    new$SUMMAPREVIOUSYEAR,
    new$SUMMAFINPREVIOUSYEAR,
    new$QUARTER1,
    new$QUARTER2,
    new$QUARTER3,
    new$QUARTER4,
    new$RECORDINDEX,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DIRECTIONCLS,
    new$RVERSION,
    new$BUHOPERATIONCLS,
    new$MONTH01DELTA,
    new$MONTH02DELTA,
    new$MONTH03DELTA,
    new$MONTH04DELTA,
    new$MONTH05DELTA,
    new$MONTH06DELTA,
    new$MONTH07DELTA,
    new$MONTH08DELTA,
    new$MONTH09DELTA,
    new$MONTH10DELTA,
    new$MONTH11DELTA,
    new$MONTH12DELTA,
    new$QUARTER1DELTA,
    new$QUARTER2DELTA,
    new$QUARTER3DELTA,
    new$QUARTER4DELTA,
    new$SUMMADELTA,
    new$NOTE,
    new$FINYEAR,
    new$SUMMAYEAR2,
    new$SUMMAYEAR3,
    new$SUMMAYEAR2DELTA,
    new$SUMMAYEAR3DELTA,
    new$ASSIGNMENTKIND,
    new$TRANSFERTCLS,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$EXECUTIONREF,
    new$INNERPROMISENUM,
    new$ADJUSTMENTNUMBER,
    new$PROMISENUMBER,
    new$SUBSIDYCLS,
    new$AGREEMENTREF,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$PROGINDEX,
    new$INVESTOBJECT,
    new$SUMMAYEAR4,
    new$SUMMAOTHERYEARS,
    new$SUMMAYEAR4DELTA,
    new$SUMMAOTHERYEARSDELTA,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS,
    new$OLDNUMBER,
    new$PAYMENTCODETYPE,
    new$REGPROJECTRESULT,
    new$PAYTARGETFUNDS,
    new$ANALYTICALPARTITION);

-- - - - - - - - - - - - -
-- AI_10 (TR_PAYMENTSCHEDULE_AI_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*      */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
    if (new$LastAccepted = 1) then
      update PaymentSchedule set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_PAYMENTSCHEDULE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 113) and (RecordID = new$ID);

END;
/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_BU_1
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_IU
  INSTEAD OF UPDATE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$PAYMENTCODETYPE PAYMENTSCHEDULE.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$REGPROJECTRESULT PAYMENTSCHEDULE.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
  new$PAYTARGETFUNDS PAYMENTSCHEDULE.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$ANALYTICALPARTITION PAYMENTSCHEDULE.ANALYTICALPARTITION%TYPE := :NEW.ANALYTICALPARTITION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  previousAccept$ NUMBER(10);
  previousAcceptDate$ NUMBER(10);
  M011$ NUMBER;
  M021$ NUMBER;
  M031$ NUMBER;
  M041$ NUMBER;
  M051$ NUMBER;
  M061$ NUMBER;
  M071$ NUMBER;
  M081$ NUMBER;
  M091$ NUMBER;
  M101$ NUMBER;
  M111$ NUMBER;
  M121$ NUMBER;
  Q11$ NUMBER;
  Q21$ NUMBER;
  Q31$ NUMBER;
  Q41$ NUMBER;
  S5$ NUMBER;
  S21$ NUMBER;
  S31$ NUMBER;
  S41$ NUMBER;
  SOther1$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PAYMENTSCHEDULE_BU)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*   2.4*/
  /*    -*/
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then
    new$KFSR := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then
    new$AssignmentKind := 0;
  END IF;

  if (new$DirectionCls is null) then
    new$DirectionCls := 0;
  END IF;

  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$Month01 is null) then
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then
    new$SummaDelta := 0;
  END IF;
  if (new$SummaPreviousYear is null) then
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then
    new$SummaFinPreviousYear := 0;
  END IF;

  if (new$SummaYear2 is null) then
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then
    new$SummaOtherYears := 0;
  END IF;

  if (new$SummaYear2Delta is null) then
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then
    new$SummaOtherYearsDelta := 0;
  END IF;

  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null and (:old.RecordIndex is null or :old.RecordIndex <> new$RecordIndex)) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  if ((:old.ANumber is null) and (new$ANumber is not Null)) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);
  /*   */
  GetDocumentKESR(:old.SubKESR, new$SubKESR, new$KESR, new$BudgetRef,new$KESR);

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYMENTSCHEDULE_BU_1)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*   1.0*/    
  new$Quarter1 := new$Month01 + new$Month02 + new$Month03;
  new$Quarter2 := new$Month04 + new$Month05 + new$Month06;
  new$Quarter3 := new$Month07 + new$Month08 + new$Month09;
  new$Quarter4 := new$Month10 + new$Month11 + new$Month12;
  if (new$ProgIndex not in (317,318)) then
    new$Summa := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_PAYMENTSCHEDULE_BU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /* ,      ,   */
  if ((new$ANumber <> :old.ANumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$InnerPromiseNum <> :old.InnerPromiseNum) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;

  /*   */
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    BEGIN
      /*             */
      select Accepted, AcceptDate
      into previousAccept$, previousAcceptDate$       from Paymentschedule
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept$ = 0 or previousAcceptDate$ is null)) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;

  END IF;
  /*   ,     LastAccepted*/
  if ((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;

    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;

    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;

  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;

    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;

  /*   ,     LastAdjustment*/
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_BP_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_PAYMENTSCHEDULE_BU_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M011$, M021$, M031$, M041$, M051$, M061$, M071$, M081$, M091$, M101$, M111$, M121$,
      Q11$, Q21$, Q31$, Q41$, S5$, S21$, S31$, S41$, SOther1$         from
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    new$Month01Delta := new$Month01 - M011$;
    new$Month02Delta := new$Month02 - M021$;
    new$Month03Delta := new$Month03 - M031$;
    new$Month04Delta := new$Month04 - M041$;
    new$Month05Delta := new$Month05 - M051$;
    new$Month06Delta := new$Month06 - M061$;
    new$Month07Delta := new$Month07 - M071$;
    new$Month08Delta := new$Month08 - M081$;
    new$Month09Delta := new$Month09 - M091$;
    new$Month10Delta := new$Month10 - M101$;
    new$Month11Delta := new$Month11 - M111$;
    new$Month12Delta := new$Month12 - M121$;
    new$Quarter1Delta := new$Quarter1 - Q11$;
    new$Quarter2Delta := new$Quarter2 - Q21$;
    new$Quarter3Delta := new$Quarter3 - Q31$;
    new$Quarter4Delta := new$Quarter4 - Q41$;
    new$SummaDelta := new$Summa - S5$;
    new$SummaYear2Delta := new$SummaYear2 - S21$;
    new$SummaYear3Delta := new$SummaYear3 - S31$;
    new$SummaYear4Delta := new$SummaYear4 - S41$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther1$;

  else /*        */
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_PAYMENTSCHEDULE_BU_200)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    */
  if (new$Accepted = 0 and new$AcceptDate is not null and :old.Accepted = 1) then
    /*   ,     
         *    ,      */
    FOR REC$1 IN (      select ffc.Reject_Cls  AS DocumentRejectCls from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum
    )
    LOOP
      if (REC$1.DocumentRejectCls is null) then
        RaiseException('Ex_BP_CannotReject');
      END IF;
    END LOOP;
    /* ,         */
    FOR REC$1 IN (      SELECT Count(ps_in.ID)  AS AdjCount FROM PaymentSchedule ps_in
    WHERE (ps_in.InnerPromiseNum = new$InnerPromiseNum)and(ps_in.AdjustmentNumber > new$AdjustmentNumber)
    and (ps_in.Accepted<>0)
    )
    LOOP
      if (REC$1.AdjCount > 0) then
        RaiseException('EX_BP_AdjustmentedCANNOTREJECT');
      END IF;
    END LOOP;
  END IF;
  /*   .       */
  if (new$Accepted = 1 and new$AcceptDate is null and :old.Accepted = 1 and :old.AcceptDate is not null) then
    SELECT COUNT(ffc.id ) INTO CNT$1
    from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where ((SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum)
    and ffc.acceptdate is not null and ffc.Reject_cls is null) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_BP_NOTACCEPTED');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_PaymentSchedule_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$AgreementRef <> :old.AgreementRef or new$ExecutionRef <> :old.ExecutionRef) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYMENTSCHEDULE_BU_700)
-- Create 14.10.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$RVersion is null) then
    new$RVersion := 1;
  elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
    new$RVersion := :Old.RVersion;
  else
    new$RVersion := :Old.RVersion + 1;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYMENTSCHEDULE SET
    ID = new$ID,
    ANUMBER = new$ANUMBER,
    PARENTNUMBER = new$PARENTNUMBER,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    MONTH01 = new$MONTH01,
    MONTH02 = new$MONTH02,
    MONTH03 = new$MONTH03,
    MONTH04 = new$MONTH04,
    MONTH05 = new$MONTH05,
    MONTH06 = new$MONTH06,
    MONTH07 = new$MONTH07,
    MONTH08 = new$MONTH08,
    MONTH09 = new$MONTH09,
    MONTH10 = new$MONTH10,
    MONTH11 = new$MONTH11,
    MONTH12 = new$MONTH12,
    SUMMA = new$SUMMA,
    REGION = new$REGION,
    SUBKESR = new$SUBKESR,
    MEANSTYPE = new$MEANSTYPE,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    FACT = new$FACT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    ACCEPTDATE = new$ACCEPTDATE,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    PROMISETYPE = new$PROMISETYPE,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    SUMMAPREVIOUSYEAR = new$SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR = new$SUMMAFINPREVIOUSYEAR,
    QUARTER1 = new$QUARTER1,
    QUARTER2 = new$QUARTER2,
    QUARTER3 = new$QUARTER3,
    QUARTER4 = new$QUARTER4,
    RECORDINDEX = new$RECORDINDEX,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DIRECTIONCLS = new$DIRECTIONCLS,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MONTH01DELTA = new$MONTH01DELTA,
    MONTH02DELTA = new$MONTH02DELTA,
    MONTH03DELTA = new$MONTH03DELTA,
    MONTH04DELTA = new$MONTH04DELTA,
    MONTH05DELTA = new$MONTH05DELTA,
    MONTH06DELTA = new$MONTH06DELTA,
    MONTH07DELTA = new$MONTH07DELTA,
    MONTH08DELTA = new$MONTH08DELTA,
    MONTH09DELTA = new$MONTH09DELTA,
    MONTH10DELTA = new$MONTH10DELTA,
    MONTH11DELTA = new$MONTH11DELTA,
    MONTH12DELTA = new$MONTH12DELTA,
    QUARTER1DELTA = new$QUARTER1DELTA,
    QUARTER2DELTA = new$QUARTER2DELTA,
    QUARTER3DELTA = new$QUARTER3DELTA,
    QUARTER4DELTA = new$QUARTER4DELTA,
    SUMMADELTA = new$SUMMADELTA,
    NOTE = new$NOTE,
    FINYEAR = new$FINYEAR,
    SUMMAYEAR2 = new$SUMMAYEAR2,
    SUMMAYEAR3 = new$SUMMAYEAR3,
    SUMMAYEAR2DELTA = new$SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA = new$SUMMAYEAR3DELTA,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXECUTIONREF = new$EXECUTIONREF,
    INNERPROMISENUM = new$INNERPROMISENUM,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    PROMISENUMBER = new$PROMISENUMBER,
    SUBSIDYCLS = new$SUBSIDYCLS,
    AGREEMENTREF = new$AGREEMENTREF,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    PROGINDEX = new$PROGINDEX,
    INVESTOBJECT = new$INVESTOBJECT,
    SUMMAYEAR4 = new$SUMMAYEAR4,
    SUMMAOTHERYEARS = new$SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA = new$SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA = new$SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    OLDNUMBER = new$OLDNUMBER,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    REGPROJECTRESULT = new$REGPROJECTRESULT,
    PAYTARGETFUNDS = new$PAYTARGETFUNDS,
    ANALYTICALPARTITION = new$ANALYTICALPARTITION
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_10 (TR_PAYMENTSCHEDULE_AU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*      */
  /*        */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*              */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and ((:old.LastAdjustment = 1) or (new$LastAdjustment = 1))) then
    update PaymentSchedule set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment    */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PAYMENTSCHEDULE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (113, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=113) and (RecordId=new$ID);
  end if;

END;
/
commit work
/


-- #########################################################
-- #########################################################
-- alter_FACIALFINDETAIL_NOTE_1024.sql
-- #########################################################
-- #########################################################

/*    ""  1024  */
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_200
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode2$);
--   /*     */
--   if (PromiseMode2$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
-- 
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode2$ = 1) then
--     /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
-- 
--     /* source:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$SourcePromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* dest:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$            from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$DestPromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* Source:  BudgetPromise -   Promise */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Source:  Promise -   BudgetPromise */
--     if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
--       new$SourceBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  BudgetPromise -   Promise */
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  Promise -   BudgetPromise */
--     if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
--       new$DestBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$SourceExecDoc := ExecID1$;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$DestExecDoc := ExecID1$;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
        new$sourceexecinnernumber := null;
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
        new$destexecinnernumber := null;
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_210
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode2$);
--   /*     */
--   if (PromiseMode2$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
-- 
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode2$ = 1) then
--     /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
-- 
--     /* source:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$SourcePromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* dest:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$            from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$DestPromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* Source:  BudgetPromise -   Promise */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Source:  Promise -   BudgetPromise */
--     if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
--       new$SourceBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  BudgetPromise -   Promise */
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  Promise -   BudgetPromise */
--     if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
--       new$DestBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode$);
--   if (PromiseMode$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex1$ = 308) then
--         new$SourceExecDoc := ExecID1$;
--         new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--       else
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType1$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */
--           new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--         END IF;
--       END IF;/*       ,   ,  */
--     else
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber1$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex1$ = 308) then
--         new$DestExecDoc := ExecID1$;
--         new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--       else
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType1$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */
--           new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--         END IF;
--       END IF;/*       ,   ,  */
--     else
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber1$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted1$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');
--       END IF;/*         */
--     else
--       if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
--         new$sourceexecinnernumber := null;
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted1$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');
--       END IF;/*         */
--     else
--       if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
--         new$destexecinnernumber := null;
--       END IF;
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
ALTER TRIGGER TR_FACIALFINDETAIL_BU_500 DISABLE
/
ALTER TABLE TB_FACIALFINDETAIL ADD (
  TempNOTE VARCHAR2(1024)
)
/

CREATE OR REPLACE VIEW FACIALFINDETAIL (
  ID,
  SOURCEFACIALACC_CLS,
  SOURCEKVR,
  SOURCEKESR,
  DESTFACIALACC_CLS,
  DESTKVR,
  DESTKESR,
  BUDGETREF,
  CREDIT,
  PAYSYMBOLCLS,
  MEMORDERNUM,
  NOTE,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SOURCEKVSR,
  SOURCEKCSR,
  SOURCEKFSR,
  SOURCESUBKESR,
  SOURCEFACT,
  SOURCEMEANSTYPE,
  SOURCEFINSOURCE,
  SOURCEFINTYPE,
  DESTKVSR,
  DESTKCSR,
  DESTKFSR,
  DESTSUBKESR,
  DESTFACT,
  DESTMEANSTYPE,
  DESTFINSOURCE,
  DESTFINTYPE,
  REQUESTSINDEX,
  SENDERID,
  SENDERRECORDID,
  PROMISE,
  SOURCEDOCTYPE,
  DESTDOCTYPE,
  SOURCEPROMISE,
  DESTPROMISE,
  RECORDINDEX2,
  SOURCEBUDGETPROMISE,
  DESTBUDGETPROMISE,
  SUBPROGINDEX,
  STIMATEID,
  RVERSION,
  SOURCEDIRECTIONCLS,
  DESTDIRECTIONCLS,
  SOURCEDOCBASE,
  DESTDOCBASE,
  SOURCEEXECDOC,
  DESTEXECDOC,
  BUHOPERATIONCLS,
  SOURCEIFS,
  DESTIFS,
  CLSTYPE,
  UNIONNOTIFYREF,
  ACCEPTDATE,
  SOURCEKD,
  DESTKD,
  SOURCEREGIONCLS,
  DESTREGIONCLS,
  DESTFUNDSSOURCE,
  SOURCEFUNDSSOURCE,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SOURCETRANSFERTCLS,
  DESTTRANSFERTCLS,
  DESTCLSTYPE,
  SOURCEASSIGNMENTKIND,
  DESTASSIGNMENTKIND,
  SOURCEEXECINNERNUMBER,
  DESTEXECINNERNUMBER,
  SOURCESUBSIDYCLS,
  DESTSUBSIDYCLS,
  SOURCEFAORG_TYPE,
  DESTFAORG_TYPE,
  SOURCEBUDALLOCATIONCLS,
  SOURCEPAYPROMISECLS,
  DESTBUDALLOCATIONCLS,
  DESTPAYPROMISECLS,
  SOURCEINVESTOBJECT,
  DESTINVESTOBJECT,
  TRANSFERTORG_REF,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  STOREDPAYMENTCONTENT,
  SOURCECONTRACTCOSTSCLS,
  DESTCONTRACTCOSTSCLS,
  SOURCETARGETCLS,
  DESTTARGETCLS,
  REJECT_CLS,
  REJECTCAUSE,
  CARDNUMBER,
  DATEBIRTH,
  PAYMENTCODETYPE,
  CODEPURPOSE,
  LINENUMBER,
  AMOUNTISPDOC,
  SOURCEREGPROJECTRESULT,
  DESTREGPROJECTRESULT,
  SOURCEINCOMETARGETFUNDS,
  DESTINCOMETARGETFUNDS,
  SOURCEPAYTARGETFUNDS,
  DESTPAYTARGETFUNDS,
  SOURCEANALYTICALPARTITION,
  DESTANALYTICALPARTITION,
  TEMPNOTE)
AS
  SELECT
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    TEMPNOTE
  FROM TB_FACIALFINDETAIL
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_ID
  INSTEAD OF DELETE
  ON FACIALFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_FACIALFINDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update facialfincaption set
  DocChangeDate = SYSDATE,
  RVersion=-1
  where id=:old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINDETAIL
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINDETAIL_AD_500)
-- Last update 27.08.2004
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes
              (TableID, RecordId, DeleteDate, ProgIndex, Summa)
       VALUES (22, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$TEMPNOTE FACIALFINDETAIL.TEMPNOTE%TYPE := :NEW.TEMPNOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  SourceFacialAcc_CLS1$ NUMBER(10);
  DestFacialAcc_CLS1$ NUMBER(10);
  CapBuhOperationCLS1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  CapReject_cls$ NUMBER(10);
  CapRejectCause$ VARCHAR2(1000);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  BEGIN
    /*  ,    */
    select
    ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate, ffc.Reject_cls, ffc.RejectCause,
    ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
    into new$BudgetRef, CapBuhOperationCLS1$, CapClsType1$, CapAcceptDate1$, CapReject_cls$, CapRejectCause$,
    new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause  from
    FacialFinCaption ffc
    where
    ffc.id = new$RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*      */
  if (new$BuhOperationCls is null) then
    new$BuhOperationCls := CapBuhOperationCLS1$;
  END IF;
  /*      */
  if (new$ClsType is null) then
    new$ClsType := CapClsType1$;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  /*      */
  if (new$AcceptDate is null) then
    new$AcceptDate := CapAcceptDate1$;
  END IF;

  /*       */
  if (new$Reject_cls is null) then
    new$Reject_cls := CapReject_cls$;
  END IF;

  /*       */
  if (new$RejectCause is null) then
    new$RejectCause := CapRejectCause$;
  END IF;
  /*      */
  if ((new$SourceFacialAcc_CLS is null)or
  (new$DestFacialAcc_CLS is null)) then
    BEGIN
      select
      SourceFacialAcc_CLS,
      DestFacialAcc_CLS
      into
      SourceFacialAcc_CLS1$,
      DestFacialAcc_CLS1$    from
      FacialFinCaption
      where
      (new$RecordIndex=id)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$SourceFacialAcc_CLS is null) then
      new$SourceFacialAcc_CLS := SourceFacialAcc_CLS1$ ;
    END IF;
    if (new$DestFacialAcc_CLS is null) then
      new$DestFacialAcc_CLS := DestFacialAcc_CLS1$ ;

    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 14.00.00.3
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  IF (new$progindex=76) THEN
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex IN (66, 67, 76)) AND (new$DestPromise IS NOT NULL) AND
        (new$SourcePromise = new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex IN (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

  /*       */
  IF ((new$SENDERRECORDID IS NULL) AND (new$SENDERID IS NULL)) THEN
    IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
      GETTARGETCLS(NULL, new$sourcetransfertcls, NULL, new$sourcemeanstype,
      new$sourcetargetcls,new$sourcetargetcls);
    END IF;
    GETTARGETCLS(NULL, new$desttransfertcls, NULL, new$destmeanstype,
    new$desttargetcls,new$desttargetcls);
    IF (new$ProgIndex = 76) THEN
      new$SourceTargetCls := new$DestTargetCls;

    END IF;
  END IF;
  /*      */
  GetDocumentKESR(NULL, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(NULL, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode2$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
  END IF;
  if (PromiseMode2$ = 1) then
    /* source:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* source:  BudgetPromise,   Promise,   Promise */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /* dest:  BudgetPromise,   Promise,   Promise */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    NOTE,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    TEMPNOTE
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$NOTE,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS,
    new$SOURCETARGETCLS,
    new$DESTTARGETCLS,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CARDNUMBER,
    new$DATEBIRTH,
    new$PAYMENTCODETYPE,
    new$CODEPURPOSE,
    new$LINENUMBER,
    new$AMOUNTISPDOC,
    new$SOURCEREGPROJECTRESULT,
    new$DESTREGPROJECTRESULT,
    new$SOURCEINCOMETARGETFUNDS,
    new$DESTINCOMETARGETFUNDS,
    new$SOURCEPAYTARGETFUNDS,
    new$DESTPAYTARGETFUNDS,
    new$SOURCEANALYTICALPARTITION,
    new$DESTANALYTICALPARTITION,
    new$TEMPNOTE);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$TEMPNOTE FACIALFINDETAIL.TEMPNOTE%TYPE := :NEW.TEMPNOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode2$);
--   /*     */
--   if (PromiseMode2$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
-- 
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode2$ = 1) then
--     /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
-- 
--     /* source:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$SourcePromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* dest:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$            from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$DestPromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* Source:  BudgetPromise -   Promise */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Source:  Promise -   BudgetPromise */
--     if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
--       new$SourceBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  BudgetPromise -   Promise */
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  Promise -   BudgetPromise */
--     if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
--       new$DestBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode$);
--   if (PromiseMode$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex1$ = 308) then
--         new$SourceExecDoc := ExecID1$;
--         new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--       else
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType1$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */
--           new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--         END IF;
--       END IF;/*       ,   ,  */
--     else
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber1$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex1$ = 308) then
--         new$DestExecDoc := ExecID1$;
--         new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--       else
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType1$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */
--           new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--         END IF;
--       END IF;/*       ,   ,  */
--     else
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber1$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted1$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');
--       END IF;/*         */
--     else
--       if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
--         new$sourceexecinnernumber := null;
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted1$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');
--       END IF;/*         */
--     else
--       if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
--         new$destexecinnernumber := null;
--       END IF;
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    NOTE = new$NOTE,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION,
    TEMPNOTE = new$TEMPNOTE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/
update FACIALFINDETAIL set
  TempNOTE = NOTE
/
ALTER TABLE TB_FACIALFINDETAIL DROP (NOTE)
/

CREATE OR REPLACE VIEW FACIALFINDETAIL (
  ID,
  SOURCEFACIALACC_CLS,
  SOURCEKVR,
  SOURCEKESR,
  DESTFACIALACC_CLS,
  DESTKVR,
  DESTKESR,
  BUDGETREF,
  CREDIT,
  PAYSYMBOLCLS,
  MEMORDERNUM,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SOURCEKVSR,
  SOURCEKCSR,
  SOURCEKFSR,
  SOURCESUBKESR,
  SOURCEFACT,
  SOURCEMEANSTYPE,
  SOURCEFINSOURCE,
  SOURCEFINTYPE,
  DESTKVSR,
  DESTKCSR,
  DESTKFSR,
  DESTSUBKESR,
  DESTFACT,
  DESTMEANSTYPE,
  DESTFINSOURCE,
  DESTFINTYPE,
  REQUESTSINDEX,
  SENDERID,
  SENDERRECORDID,
  PROMISE,
  SOURCEDOCTYPE,
  DESTDOCTYPE,
  SOURCEPROMISE,
  DESTPROMISE,
  RECORDINDEX2,
  SOURCEBUDGETPROMISE,
  DESTBUDGETPROMISE,
  SUBPROGINDEX,
  STIMATEID,
  RVERSION,
  SOURCEDIRECTIONCLS,
  DESTDIRECTIONCLS,
  SOURCEDOCBASE,
  DESTDOCBASE,
  SOURCEEXECDOC,
  DESTEXECDOC,
  BUHOPERATIONCLS,
  SOURCEIFS,
  DESTIFS,
  CLSTYPE,
  UNIONNOTIFYREF,
  ACCEPTDATE,
  SOURCEKD,
  DESTKD,
  SOURCEREGIONCLS,
  DESTREGIONCLS,
  DESTFUNDSSOURCE,
  SOURCEFUNDSSOURCE,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SOURCETRANSFERTCLS,
  DESTTRANSFERTCLS,
  DESTCLSTYPE,
  SOURCEASSIGNMENTKIND,
  DESTASSIGNMENTKIND,
  SOURCEEXECINNERNUMBER,
  DESTEXECINNERNUMBER,
  SOURCESUBSIDYCLS,
  DESTSUBSIDYCLS,
  SOURCEFAORG_TYPE,
  DESTFAORG_TYPE,
  SOURCEBUDALLOCATIONCLS,
  SOURCEPAYPROMISECLS,
  DESTBUDALLOCATIONCLS,
  DESTPAYPROMISECLS,
  SOURCEINVESTOBJECT,
  DESTINVESTOBJECT,
  TRANSFERTORG_REF,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  STOREDPAYMENTCONTENT,
  SOURCECONTRACTCOSTSCLS,
  DESTCONTRACTCOSTSCLS,
  SOURCETARGETCLS,
  DESTTARGETCLS,
  REJECT_CLS,
  REJECTCAUSE,
  CARDNUMBER,
  DATEBIRTH,
  PAYMENTCODETYPE,
  CODEPURPOSE,
  LINENUMBER,
  AMOUNTISPDOC,
  SOURCEREGPROJECTRESULT,
  DESTREGPROJECTRESULT,
  SOURCEINCOMETARGETFUNDS,
  DESTINCOMETARGETFUNDS,
  SOURCEPAYTARGETFUNDS,
  DESTPAYTARGETFUNDS,
  SOURCEANALYTICALPARTITION,
  DESTANALYTICALPARTITION,
  TEMPNOTE)
AS
  SELECT
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    TEMPNOTE
  FROM TB_FACIALFINDETAIL
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_ID
  INSTEAD OF DELETE
  ON FACIALFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_FACIALFINDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update facialfincaption set
  DocChangeDate = SYSDATE,
  RVersion=-1
  where id=:old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINDETAIL
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINDETAIL_AD_500)
-- Last update 27.08.2004
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes
              (TableID, RecordId, DeleteDate, ProgIndex, Summa)
       VALUES (22, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$TEMPNOTE FACIALFINDETAIL.TEMPNOTE%TYPE := :NEW.TEMPNOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  SourceFacialAcc_CLS1$ NUMBER(10);
  DestFacialAcc_CLS1$ NUMBER(10);
  CapBuhOperationCLS1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  CapReject_cls$ NUMBER(10);
  CapRejectCause$ VARCHAR2(1000);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  BEGIN
    /*  ,    */
    select
    ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate, ffc.Reject_cls, ffc.RejectCause,
    ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
    into new$BudgetRef, CapBuhOperationCLS1$, CapClsType1$, CapAcceptDate1$, CapReject_cls$, CapRejectCause$,
    new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause  from
    FacialFinCaption ffc
    where
    ffc.id = new$RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*      */
  if (new$BuhOperationCls is null) then
    new$BuhOperationCls := CapBuhOperationCLS1$;
  END IF;
  /*      */
  if (new$ClsType is null) then
    new$ClsType := CapClsType1$;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  /*      */
  if (new$AcceptDate is null) then
    new$AcceptDate := CapAcceptDate1$;
  END IF;

  /*       */
  if (new$Reject_cls is null) then
    new$Reject_cls := CapReject_cls$;
  END IF;

  /*       */
  if (new$RejectCause is null) then
    new$RejectCause := CapRejectCause$;
  END IF;
  /*      */
  if ((new$SourceFacialAcc_CLS is null)or
  (new$DestFacialAcc_CLS is null)) then
    BEGIN
      select
      SourceFacialAcc_CLS,
      DestFacialAcc_CLS
      into
      SourceFacialAcc_CLS1$,
      DestFacialAcc_CLS1$    from
      FacialFinCaption
      where
      (new$RecordIndex=id)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$SourceFacialAcc_CLS is null) then
      new$SourceFacialAcc_CLS := SourceFacialAcc_CLS1$ ;
    END IF;
    if (new$DestFacialAcc_CLS is null) then
      new$DestFacialAcc_CLS := DestFacialAcc_CLS1$ ;

    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 14.00.00.3
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  IF (new$progindex=76) THEN
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex IN (66, 67, 76)) AND (new$DestPromise IS NOT NULL) AND
        (new$SourcePromise = new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex IN (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

  /*       */
  IF ((new$SENDERRECORDID IS NULL) AND (new$SENDERID IS NULL)) THEN
    IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
      GETTARGETCLS(NULL, new$sourcetransfertcls, NULL, new$sourcemeanstype,
      new$sourcetargetcls,new$sourcetargetcls);
    END IF;
    GETTARGETCLS(NULL, new$desttransfertcls, NULL, new$destmeanstype,
    new$desttargetcls,new$desttargetcls);
    IF (new$ProgIndex = 76) THEN
      new$SourceTargetCls := new$DestTargetCls;

    END IF;
  END IF;
  /*      */
  GetDocumentKESR(NULL, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(NULL, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode2$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
  END IF;
  if (PromiseMode2$ = 1) then
    /* source:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* source:  BudgetPromise,   Promise,   Promise */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /* dest:  BudgetPromise,   Promise,   Promise */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    TEMPNOTE
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS,
    new$SOURCETARGETCLS,
    new$DESTTARGETCLS,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CARDNUMBER,
    new$DATEBIRTH,
    new$PAYMENTCODETYPE,
    new$CODEPURPOSE,
    new$LINENUMBER,
    new$AMOUNTISPDOC,
    new$SOURCEREGPROJECTRESULT,
    new$DESTREGPROJECTRESULT,
    new$SOURCEINCOMETARGETFUNDS,
    new$DESTINCOMETARGETFUNDS,
    new$SOURCEPAYTARGETFUNDS,
    new$DESTPAYTARGETFUNDS,
    new$SOURCEANALYTICALPARTITION,
    new$DESTANALYTICALPARTITION,
    new$TEMPNOTE);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$TEMPNOTE FACIALFINDETAIL.TEMPNOTE%TYPE := :NEW.TEMPNOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode2$);
--   /*     */
--   if (PromiseMode2$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
-- 
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode2$ = 1) then
--     /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
-- 
--     /* source:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$SourcePromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* dest:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$            from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$DestPromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* Source:  BudgetPromise -   Promise */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Source:  Promise -   BudgetPromise */
--     if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
--       new$SourceBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  BudgetPromise -   Promise */
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  Promise -   BudgetPromise */
--     if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
--       new$DestBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode$);
--   if (PromiseMode$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex1$ = 308) then
--         new$SourceExecDoc := ExecID1$;
--         new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--       else
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType1$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */
--           new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--         END IF;
--       END IF;/*       ,   ,  */
--     else
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber1$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex1$ = 308) then
--         new$DestExecDoc := ExecID1$;
--         new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--       else
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType1$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */
--           new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--         END IF;
--       END IF;/*       ,   ,  */
--     else
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber1$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted1$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');
--       END IF;/*         */
--     else
--       if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
--         new$sourceexecinnernumber := null;
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted1$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');
--       END IF;/*         */
--     else
--       if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
--         new$destexecinnernumber := null;
--       END IF;
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION,
    TEMPNOTE = new$TEMPNOTE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/
ALTER TABLE TB_FACIALFINDETAIL ADD (
  NOTE VARCHAR2(1024)
)
/

CREATE OR REPLACE VIEW FACIALFINDETAIL (
  ID,
  SOURCEFACIALACC_CLS,
  SOURCEKVR,
  SOURCEKESR,
  DESTFACIALACC_CLS,
  DESTKVR,
  DESTKESR,
  BUDGETREF,
  CREDIT,
  PAYSYMBOLCLS,
  MEMORDERNUM,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SOURCEKVSR,
  SOURCEKCSR,
  SOURCEKFSR,
  SOURCESUBKESR,
  SOURCEFACT,
  SOURCEMEANSTYPE,
  SOURCEFINSOURCE,
  SOURCEFINTYPE,
  DESTKVSR,
  DESTKCSR,
  DESTKFSR,
  DESTSUBKESR,
  DESTFACT,
  DESTMEANSTYPE,
  DESTFINSOURCE,
  DESTFINTYPE,
  REQUESTSINDEX,
  SENDERID,
  SENDERRECORDID,
  PROMISE,
  SOURCEDOCTYPE,
  DESTDOCTYPE,
  SOURCEPROMISE,
  DESTPROMISE,
  RECORDINDEX2,
  SOURCEBUDGETPROMISE,
  DESTBUDGETPROMISE,
  SUBPROGINDEX,
  STIMATEID,
  RVERSION,
  SOURCEDIRECTIONCLS,
  DESTDIRECTIONCLS,
  SOURCEDOCBASE,
  DESTDOCBASE,
  SOURCEEXECDOC,
  DESTEXECDOC,
  BUHOPERATIONCLS,
  SOURCEIFS,
  DESTIFS,
  CLSTYPE,
  UNIONNOTIFYREF,
  ACCEPTDATE,
  SOURCEKD,
  DESTKD,
  SOURCEREGIONCLS,
  DESTREGIONCLS,
  DESTFUNDSSOURCE,
  SOURCEFUNDSSOURCE,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SOURCETRANSFERTCLS,
  DESTTRANSFERTCLS,
  DESTCLSTYPE,
  SOURCEASSIGNMENTKIND,
  DESTASSIGNMENTKIND,
  SOURCEEXECINNERNUMBER,
  DESTEXECINNERNUMBER,
  SOURCESUBSIDYCLS,
  DESTSUBSIDYCLS,
  SOURCEFAORG_TYPE,
  DESTFAORG_TYPE,
  SOURCEBUDALLOCATIONCLS,
  SOURCEPAYPROMISECLS,
  DESTBUDALLOCATIONCLS,
  DESTPAYPROMISECLS,
  SOURCEINVESTOBJECT,
  DESTINVESTOBJECT,
  TRANSFERTORG_REF,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  STOREDPAYMENTCONTENT,
  SOURCECONTRACTCOSTSCLS,
  DESTCONTRACTCOSTSCLS,
  SOURCETARGETCLS,
  DESTTARGETCLS,
  REJECT_CLS,
  REJECTCAUSE,
  CARDNUMBER,
  DATEBIRTH,
  PAYMENTCODETYPE,
  CODEPURPOSE,
  LINENUMBER,
  AMOUNTISPDOC,
  SOURCEREGPROJECTRESULT,
  DESTREGPROJECTRESULT,
  SOURCEINCOMETARGETFUNDS,
  DESTINCOMETARGETFUNDS,
  SOURCEPAYTARGETFUNDS,
  DESTPAYTARGETFUNDS,
  SOURCEANALYTICALPARTITION,
  DESTANALYTICALPARTITION,
  TEMPNOTE,
  NOTE)
AS
  SELECT
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    TEMPNOTE,
    NOTE
  FROM TB_FACIALFINDETAIL
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_ID
  INSTEAD OF DELETE
  ON FACIALFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_FACIALFINDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update facialfincaption set
  DocChangeDate = SYSDATE,
  RVersion=-1
  where id=:old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINDETAIL
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINDETAIL_AD_500)
-- Last update 27.08.2004
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes
              (TableID, RecordId, DeleteDate, ProgIndex, Summa)
       VALUES (22, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$TEMPNOTE FACIALFINDETAIL.TEMPNOTE%TYPE := :NEW.TEMPNOTE;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  SourceFacialAcc_CLS1$ NUMBER(10);
  DestFacialAcc_CLS1$ NUMBER(10);
  CapBuhOperationCLS1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  CapReject_cls$ NUMBER(10);
  CapRejectCause$ VARCHAR2(1000);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  BEGIN
    /*  ,    */
    select
    ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate, ffc.Reject_cls, ffc.RejectCause,
    ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
    into new$BudgetRef, CapBuhOperationCLS1$, CapClsType1$, CapAcceptDate1$, CapReject_cls$, CapRejectCause$,
    new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause  from
    FacialFinCaption ffc
    where
    ffc.id = new$RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*      */
  if (new$BuhOperationCls is null) then
    new$BuhOperationCls := CapBuhOperationCLS1$;
  END IF;
  /*      */
  if (new$ClsType is null) then
    new$ClsType := CapClsType1$;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  /*      */
  if (new$AcceptDate is null) then
    new$AcceptDate := CapAcceptDate1$;
  END IF;

  /*       */
  if (new$Reject_cls is null) then
    new$Reject_cls := CapReject_cls$;
  END IF;

  /*       */
  if (new$RejectCause is null) then
    new$RejectCause := CapRejectCause$;
  END IF;
  /*      */
  if ((new$SourceFacialAcc_CLS is null)or
  (new$DestFacialAcc_CLS is null)) then
    BEGIN
      select
      SourceFacialAcc_CLS,
      DestFacialAcc_CLS
      into
      SourceFacialAcc_CLS1$,
      DestFacialAcc_CLS1$    from
      FacialFinCaption
      where
      (new$RecordIndex=id)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$SourceFacialAcc_CLS is null) then
      new$SourceFacialAcc_CLS := SourceFacialAcc_CLS1$ ;
    END IF;
    if (new$DestFacialAcc_CLS is null) then
      new$DestFacialAcc_CLS := DestFacialAcc_CLS1$ ;

    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 14.00.00.3
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  IF (new$progindex=76) THEN
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex IN (66, 67, 76)) AND (new$DestPromise IS NOT NULL) AND
        (new$SourcePromise = new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex IN (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

  /*       */
  IF ((new$SENDERRECORDID IS NULL) AND (new$SENDERID IS NULL)) THEN
    IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
      GETTARGETCLS(NULL, new$sourcetransfertcls, NULL, new$sourcemeanstype,
      new$sourcetargetcls,new$sourcetargetcls);
    END IF;
    GETTARGETCLS(NULL, new$desttransfertcls, NULL, new$destmeanstype,
    new$desttargetcls,new$desttargetcls);
    IF (new$ProgIndex = 76) THEN
      new$SourceTargetCls := new$DestTargetCls;

    END IF;
  END IF;
  /*      */
  GetDocumentKESR(NULL, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(NULL, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode2$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
  END IF;
  if (PromiseMode2$ = 1) then
    /* source:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* source:  BudgetPromise,   Promise,   Promise */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /* dest:  BudgetPromise,   Promise,   Promise */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    TEMPNOTE,
    NOTE
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS,
    new$SOURCETARGETCLS,
    new$DESTTARGETCLS,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CARDNUMBER,
    new$DATEBIRTH,
    new$PAYMENTCODETYPE,
    new$CODEPURPOSE,
    new$LINENUMBER,
    new$AMOUNTISPDOC,
    new$SOURCEREGPROJECTRESULT,
    new$DESTREGPROJECTRESULT,
    new$SOURCEINCOMETARGETFUNDS,
    new$DESTINCOMETARGETFUNDS,
    new$SOURCEPAYTARGETFUNDS,
    new$DESTPAYTARGETFUNDS,
    new$SOURCEANALYTICALPARTITION,
    new$DESTANALYTICALPARTITION,
    new$TEMPNOTE,
    new$NOTE);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$TEMPNOTE FACIALFINDETAIL.TEMPNOTE%TYPE := :NEW.TEMPNOTE;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode2$);
--   /*     */
--   if (PromiseMode2$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
-- 
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode2$ = 1) then
--     /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
-- 
--     /* source:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$SourcePromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* dest:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$            from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$DestPromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* Source:  BudgetPromise -   Promise */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Source:  Promise -   BudgetPromise */
--     if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
--       new$SourceBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  BudgetPromise -   Promise */
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  Promise -   BudgetPromise */
--     if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
--       new$DestBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode$);
--   if (PromiseMode$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex1$ = 308) then
--         new$SourceExecDoc := ExecID1$;
--         new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--       else
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType1$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */
--           new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--         END IF;
--       END IF;/*       ,   ,  */
--     else
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber1$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex1$ = 308) then
--         new$DestExecDoc := ExecID1$;
--         new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--       else
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType1$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */
--           new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--         END IF;
--       END IF;/*       ,   ,  */
--     else
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber1$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted1$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');
--       END IF;/*         */
--     else
--       if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
--         new$sourceexecinnernumber := null;
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted1$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');
--       END IF;/*         */
--     else
--       if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
--         new$destexecinnernumber := null;
--       END IF;
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION,
    TEMPNOTE = new$TEMPNOTE,
    NOTE = new$NOTE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/
update FACIALFINDETAIL set
  NOTE = TempNOTE
/
ALTER TABLE TB_FACIALFINDETAIL DROP (TempNOTE)
/

CREATE OR REPLACE VIEW FACIALFINDETAIL (
  ID,
  SOURCEFACIALACC_CLS,
  SOURCEKVR,
  SOURCEKESR,
  DESTFACIALACC_CLS,
  DESTKVR,
  DESTKESR,
  BUDGETREF,
  CREDIT,
  PAYSYMBOLCLS,
  MEMORDERNUM,
  PROGINDEX,
  RECORDINDEX,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  SOURCEKVSR,
  SOURCEKCSR,
  SOURCEKFSR,
  SOURCESUBKESR,
  SOURCEFACT,
  SOURCEMEANSTYPE,
  SOURCEFINSOURCE,
  SOURCEFINTYPE,
  DESTKVSR,
  DESTKCSR,
  DESTKFSR,
  DESTSUBKESR,
  DESTFACT,
  DESTMEANSTYPE,
  DESTFINSOURCE,
  DESTFINTYPE,
  REQUESTSINDEX,
  SENDERID,
  SENDERRECORDID,
  PROMISE,
  SOURCEDOCTYPE,
  DESTDOCTYPE,
  SOURCEPROMISE,
  DESTPROMISE,
  RECORDINDEX2,
  SOURCEBUDGETPROMISE,
  DESTBUDGETPROMISE,
  SUBPROGINDEX,
  STIMATEID,
  RVERSION,
  SOURCEDIRECTIONCLS,
  DESTDIRECTIONCLS,
  SOURCEDOCBASE,
  DESTDOCBASE,
  SOURCEEXECDOC,
  DESTEXECDOC,
  BUHOPERATIONCLS,
  SOURCEIFS,
  DESTIFS,
  CLSTYPE,
  UNIONNOTIFYREF,
  ACCEPTDATE,
  SOURCEKD,
  DESTKD,
  SOURCEREGIONCLS,
  DESTREGIONCLS,
  DESTFUNDSSOURCE,
  SOURCEFUNDSSOURCE,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SOURCETRANSFERTCLS,
  DESTTRANSFERTCLS,
  DESTCLSTYPE,
  SOURCEASSIGNMENTKIND,
  DESTASSIGNMENTKIND,
  SOURCEEXECINNERNUMBER,
  DESTEXECINNERNUMBER,
  SOURCESUBSIDYCLS,
  DESTSUBSIDYCLS,
  SOURCEFAORG_TYPE,
  DESTFAORG_TYPE,
  SOURCEBUDALLOCATIONCLS,
  SOURCEPAYPROMISECLS,
  DESTBUDALLOCATIONCLS,
  DESTPAYPROMISECLS,
  SOURCEINVESTOBJECT,
  DESTINVESTOBJECT,
  TRANSFERTORG_REF,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  STOREDPAYMENTCONTENT,
  SOURCECONTRACTCOSTSCLS,
  DESTCONTRACTCOSTSCLS,
  SOURCETARGETCLS,
  DESTTARGETCLS,
  REJECT_CLS,
  REJECTCAUSE,
  CARDNUMBER,
  DATEBIRTH,
  PAYMENTCODETYPE,
  CODEPURPOSE,
  LINENUMBER,
  AMOUNTISPDOC,
  SOURCEREGPROJECTRESULT,
  DESTREGPROJECTRESULT,
  SOURCEINCOMETARGETFUNDS,
  DESTINCOMETARGETFUNDS,
  SOURCEPAYTARGETFUNDS,
  DESTPAYTARGETFUNDS,
  SOURCEANALYTICALPARTITION,
  DESTANALYTICALPARTITION,
  NOTE)
AS
  SELECT
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    NOTE
  FROM TB_FACIALFINDETAIL
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_ID
  INSTEAD OF DELETE
  ON FACIALFINDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_FACIALFINDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update facialfincaption set
  DocChangeDate = SYSDATE,
  RVersion=-1
  where id=:old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALFINDETAIL
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALFINDETAIL_AD_500)
-- Last update 27.08.2004
-- - - - - - - - - - - - -

  INSERT INTO DelRecIndexes
              (TableID, RecordId, DeleteDate, ProgIndex, Summa)
       VALUES (22, :OLD.ID, SYSDATE, :OLD.ProgIndex, :OLD.Credit);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_II
  INSTEAD OF INSERT
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted$ NUMBER(10);
  BPInnerNum$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted$ NUMBER(10);
  SourceFacialAcc_CLS1$ NUMBER(10);
  DestFacialAcc_CLS1$ NUMBER(10);
  CapBuhOperationCLS1$ NUMBER(10);
  CapClsType1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  CapReject_cls$ NUMBER(10);
  CapRejectCause$ VARCHAR2(1000);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALFINDETAIL_BI_0)
-- Last update 15.12.2002
-- - - - - - - - - - - - -

   IF (new$ID IS NULL) THEN
      SELECT g_Shared.NEXTVAL INTO new$ID FROM DUAL;
   END IF;

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

-- - - - - - - - - - - - -
-- BI_10 (tr_FacialFinDetail_bi_10)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$SenderID is null) then
    new$SenderIDKey := -1;

  else
    new$SenderIDKey := new$SenderID;
  END IF;

  if (new$SenderRecordID is null) then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALFINDETAIL_BI_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  BEGIN
    /*  ,    */
    select
    ffc.BudgetRef, ffc.BuhOperationCls, ffc.ClsType, ffc.AcceptDate, ffc.Reject_cls, ffc.RejectCause,
    ffc.IsBlocked, ffc.BlockedCause, ffc.UnBlockedDate, ffc.UnBlockedCause
    into new$BudgetRef, CapBuhOperationCLS1$, CapClsType1$, CapAcceptDate1$, CapReject_cls$, CapRejectCause$,
    new$IsBlocked, new$BlockedCause, new$UnBlockedDate, new$UnBlockedCause  from
    FacialFinCaption ffc
    where
    ffc.id = new$RecordIndex
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*      */
  if (new$BuhOperationCls is null) then
    new$BuhOperationCls := CapBuhOperationCLS1$;
  END IF;
  /*      */
  if (new$ClsType is null) then
    new$ClsType := CapClsType1$;
  END IF;
  if (new$DestClsType is null) then
    new$DestClsType := new$ClsType;
  END IF;
  /*      */
  if (new$AcceptDate is null) then
    new$AcceptDate := CapAcceptDate1$;
  END IF;

  /*       */
  if (new$Reject_cls is null) then
    new$Reject_cls := CapReject_cls$;
  END IF;

  /*       */
  if (new$RejectCause is null) then
    new$RejectCause := CapRejectCause$;
  END IF;
  /*      */
  if ((new$SourceFacialAcc_CLS is null)or
  (new$DestFacialAcc_CLS is null)) then
    BEGIN
      select
      SourceFacialAcc_CLS,
      DestFacialAcc_CLS
      into
      SourceFacialAcc_CLS1$,
      DestFacialAcc_CLS1$    from
      FacialFinCaption
      where
      (new$RecordIndex=id)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$SourceFacialAcc_CLS is null) then
      new$SourceFacialAcc_CLS := SourceFacialAcc_CLS1$ ;
    END IF;
    if (new$DestFacialAcc_CLS is null) then
      new$DestFacialAcc_CLS := DestFacialAcc_CLS1$ ;

    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_FACIALFINDETAIL_BI_110)
-- Version 14.00.00.3
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL OR (new$Sourcefintype=0)) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL OR (new$Destfintype=0)) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 1000;
  END IF;
  IF (new$SourceIFS IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 1000;
  END IF;
  IF (new$DestIFS IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  IF (new$progindex=76) THEN
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*   Promise null,    */
  IF ((new$Promise IS NULL) AND
  ((new$SourcePromise IS NOT NULL) OR
  (new$DestPromise IS NOT NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex IN (66, 67, 76)) AND (new$DestPromise IS NOT NULL) AND
        (new$SourcePromise = new$DestPromise)) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*    ,  ,       */
  ELSE
    IF ((new$Promise IS NOT NULL) AND
    (new$SourcePromise IS NULL) AND
    (new$DestPromise IS NULL)) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex IN (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*     \   */
    SELECT org.Org_Type  INTO new$SourceFAOrg_Type FROM Organizations org
    INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$SourceFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  BEGIN

    SELECT org.Org_Type  INTO new$DestFAOrg_Type FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$DestFacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

  /*       */
  IF ((new$SENDERRECORDID IS NULL) AND (new$SENDERID IS NULL)) THEN
    IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
      GETTARGETCLS(NULL, new$sourcetransfertcls, NULL, new$sourcemeanstype,
      new$sourcetargetcls,new$sourcetargetcls);
    END IF;
    GETTARGETCLS(NULL, new$desttransfertcls, NULL, new$destmeanstype,
    new$desttargetcls,new$desttargetcls);
    IF (new$ProgIndex = 76) THEN
      new$SourceTargetCls := new$DestTargetCls;

    END IF;
  END IF;
  /*      */
  GetDocumentKESR(NULL, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(NULL, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BI_120 (TR_FACIALFINDETAIL_BI_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if ((new$DestClsType is NULL) and
  (
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71))) or (new$ProgIndex = 60)
  )) then
    new$DestClsType := 1; /*       ClsType */
      
  else
    if ((new$DestClsType is NULL) and
    ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
    ) then
      new$DestClsType := 2; /*        ClsType */
          
    else
      if (new$DestClsType is null) then
        new$DestClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALFINDETAIL_BI_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (((new$SourcePromise is not null) or (new$DestPromise is not null)) and (PromiseMode2$ <> 1)) then
    if (new$SourcePromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    if (new$DestPromise is not null) then
      /*         */
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$         from
      promise_detail pr
      where
      (pr.registrnumber = new$DESTPROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
  END IF;
  if (PromiseMode2$ = 1) then
    /* source:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$SourcePromise is not null) and (new$SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise,   BudgetPromise,   BudgetPromise */
    if ((new$DestPromise is not null) and (new$DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$DestBudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* source:  BudgetPromise,   Promise,   Promise */
    if ((new$SourceBudgetPromise is not null) and (new$SourcePromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /* dest:  BudgetPromise,   Promise,   Promise */
    if ((new$DestBudgetPromise is not null) and (new$DestPromise is null)) then
      BEGIN
        select ANumber
        into BPInnerNum$           from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum$;
      new$Promise := BPInnerNum$;

    END IF;
    /*     */
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$1
      from PaymentSchedule where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber ) INTO CNT$2
      from PaymentSchedule where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_FACIALFINDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$SourceExecDoc := ExecID$;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$SourceExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$DestExecDoc := ExecID$;
        new$DestExecInnerNumber := ExecInnerNumber$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$DestExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALFINDETAIL_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update facialfincaption set
  DocChangeDate = new$UpdateDate,
  RVersion=-1
  where id=new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALFINDETAIL (
    ID,
    SOURCEFACIALACC_CLS,
    SOURCEKVR,
    SOURCEKESR,
    DESTFACIALACC_CLS,
    DESTKVR,
    DESTKESR,
    BUDGETREF,
    CREDIT,
    PAYSYMBOLCLS,
    MEMORDERNUM,
    PROGINDEX,
    RECORDINDEX,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    SOURCEKVSR,
    SOURCEKCSR,
    SOURCEKFSR,
    SOURCESUBKESR,
    SOURCEFACT,
    SOURCEMEANSTYPE,
    SOURCEFINSOURCE,
    SOURCEFINTYPE,
    DESTKVSR,
    DESTKCSR,
    DESTKFSR,
    DESTSUBKESR,
    DESTFACT,
    DESTMEANSTYPE,
    DESTFINSOURCE,
    DESTFINTYPE,
    REQUESTSINDEX,
    SENDERID,
    SENDERRECORDID,
    PROMISE,
    SOURCEDOCTYPE,
    DESTDOCTYPE,
    SOURCEPROMISE,
    DESTPROMISE,
    RECORDINDEX2,
    SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE,
    SUBPROGINDEX,
    STIMATEID,
    RVERSION,
    SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS,
    SOURCEDOCBASE,
    DESTDOCBASE,
    SOURCEEXECDOC,
    DESTEXECDOC,
    BUHOPERATIONCLS,
    SOURCEIFS,
    DESTIFS,
    CLSTYPE,
    UNIONNOTIFYREF,
    ACCEPTDATE,
    SOURCEKD,
    DESTKD,
    SOURCEREGIONCLS,
    DESTREGIONCLS,
    DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS,
    DESTCLSTYPE,
    SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE,
    DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT,
    DESTINVESTOBJECT,
    TRANSFERTORG_REF,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS,
    DESTTARGETCLS,
    REJECT_CLS,
    REJECTCAUSE,
    CARDNUMBER,
    DATEBIRTH,
    PAYMENTCODETYPE,
    CODEPURPOSE,
    LINENUMBER,
    AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION,
    NOTE
  ) VALUES (
    new$ID,
    new$SOURCEFACIALACC_CLS,
    new$SOURCEKVR,
    new$SOURCEKESR,
    new$DESTFACIALACC_CLS,
    new$DESTKVR,
    new$DESTKESR,
    new$BUDGETREF,
    new$CREDIT,
    new$PAYSYMBOLCLS,
    new$MEMORDERNUM,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$SOURCEKVSR,
    new$SOURCEKCSR,
    new$SOURCEKFSR,
    new$SOURCESUBKESR,
    new$SOURCEFACT,
    new$SOURCEMEANSTYPE,
    new$SOURCEFINSOURCE,
    new$SOURCEFINTYPE,
    new$DESTKVSR,
    new$DESTKCSR,
    new$DESTKFSR,
    new$DESTSUBKESR,
    new$DESTFACT,
    new$DESTMEANSTYPE,
    new$DESTFINSOURCE,
    new$DESTFINTYPE,
    new$REQUESTSINDEX,
    new$SENDERID,
    new$SENDERRECORDID,
    new$PROMISE,
    new$SOURCEDOCTYPE,
    new$DESTDOCTYPE,
    new$SOURCEPROMISE,
    new$DESTPROMISE,
    new$RECORDINDEX2,
    new$SOURCEBUDGETPROMISE,
    new$DESTBUDGETPROMISE,
    new$SUBPROGINDEX,
    new$STIMATEID,
    new$RVERSION,
    new$SOURCEDIRECTIONCLS,
    new$DESTDIRECTIONCLS,
    new$SOURCEDOCBASE,
    new$DESTDOCBASE,
    new$SOURCEEXECDOC,
    new$DESTEXECDOC,
    new$BUHOPERATIONCLS,
    new$SOURCEIFS,
    new$DESTIFS,
    new$CLSTYPE,
    new$UNIONNOTIFYREF,
    new$ACCEPTDATE,
    new$SOURCEKD,
    new$DESTKD,
    new$SOURCEREGIONCLS,
    new$DESTREGIONCLS,
    new$DESTFUNDSSOURCE,
    new$SOURCEFUNDSSOURCE,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SOURCETRANSFERTCLS,
    new$DESTTRANSFERTCLS,
    new$DESTCLSTYPE,
    new$SOURCEASSIGNMENTKIND,
    new$DESTASSIGNMENTKIND,
    new$SOURCEEXECINNERNUMBER,
    new$DESTEXECINNERNUMBER,
    new$SOURCESUBSIDYCLS,
    new$DESTSUBSIDYCLS,
    new$SOURCEFAORG_TYPE,
    new$DESTFAORG_TYPE,
    new$SOURCEBUDALLOCATIONCLS,
    new$SOURCEPAYPROMISECLS,
    new$DESTBUDALLOCATIONCLS,
    new$DESTPAYPROMISECLS,
    new$SOURCEINVESTOBJECT,
    new$DESTINVESTOBJECT,
    new$TRANSFERTORG_REF,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$STOREDPAYMENTCONTENT,
    new$SOURCECONTRACTCOSTSCLS,
    new$DESTCONTRACTCOSTSCLS,
    new$SOURCETARGETCLS,
    new$DESTTARGETCLS,
    new$REJECT_CLS,
    new$REJECTCAUSE,
    new$CARDNUMBER,
    new$DATEBIRTH,
    new$PAYMENTCODETYPE,
    new$CODEPURPOSE,
    new$LINENUMBER,
    new$AMOUNTISPDOC,
    new$SOURCEREGPROJECTRESULT,
    new$DESTREGPROJECTRESULT,
    new$SOURCEINCOMETARGETFUNDS,
    new$DESTINCOMETARGETFUNDS,
    new$SOURCEPAYTARGETFUNDS,
    new$DESTPAYTARGETFUNDS,
    new$SOURCEANALYTICALPARTITION,
    new$DESTANALYTICALPARTITION,
    new$NOTE);

-- - - - - - - - - - - - -
-- AI_100 (TR_FACIALFINDETAIL_AI_100)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  update FacialFinCaption set
  ClsType = new$ClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(ClsType <> new$ClsType);
  update FacialFinCaption set
  DestClsType = new$DestClsType,
  RVersion = -1
  where
  (id = new$RecordIndex)and(DestClsType <> new$DestClsType);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALFINDETAIL_AI_500)
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID =22 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode2$);
--   /*     */
--   if (PromiseMode2$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
-- 
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode2$ = 1) then
--     /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
-- 
--     /* source:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$SourcePromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* dest:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$            from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$DestPromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* Source:  BudgetPromise -   Promise */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Source:  Promise -   BudgetPromise */
--     if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
--       new$SourceBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  BudgetPromise -   Promise */
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  Promise -   BudgetPromise */
--     if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
--       new$DestBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*    ?*/
--   GetIntConst(30, 15,PromiseMode$);
--   if (PromiseMode$ = 1) then
--     /*        */
--     if (new$SourcePromise is not null and (
--     (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
--     (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex1$ = 308) then
--         new$SourceExecDoc := ExecID1$;
--         new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--       else
--         if (new$SourceExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
--             where
--             Id = new$SourceExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType1$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */
--           new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--         END IF;
--       END IF;/*       ,   ,  */
--     else
--       if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber1$       from ExecutionDocumentsCaption
--           where
--           Id = new$SourceExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$SourceExecInnerNumber := ExecInnerNumber1$;
-- 
--       END IF;
--     END IF;
--     /*     Dest */
-- 
--     /*        */
--     if (new$DestPromise is not null and (
--     (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
--     (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
--     )) then
--       BEGIN
--         /* ,       ,    */
--         select
--         ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
--         into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
--         left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
--         left join Agreements a on a.Id = ps.AgreementRef
--         where
--         ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*    ,      */
--       if (ProgIndex1$ = 308) then
--         new$DestExecDoc := ExecID1$;
--         new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--       else
--         if (new$DestExecDoc is not null) then
--           BEGIN
--             /*      ,         */
--             /*        */
--             select
--             RegistrationType, AgreementInnerNumber, InnerNumber
--             into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
--             where
--             Id = new$DestExecDoc
--             ;
--           EXCEPTION
--             WHEN NO_DATA_FOUND THEN NULL;
--           END;
--           /*    ,    */
--           if (ExecRegType1$ = 4) then
--             RaiseException('EX_IncorrectBindingExec_BO');
--           END IF;
--           /*        ,     */
--           if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
--             RaiseException('EX_DiffAgree_InBOExec');
--           END IF;
--           /*    ,      */
--           new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--         END IF;
--       END IF;/*       ,   ,  */
--     else
--       if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
--         BEGIN
--           /*      */
--           select
--           InnerNumber
--           into ExecInnerNumber1$       from ExecutionDocumentsCaption
--           where
--           Id = new$DestExecDoc
--           ;
--         EXCEPTION
--           WHEN NO_DATA_FOUND THEN NULL;
--         END;
--         new$DestExecInnerNumber := ExecInnerNumber1$;
-- 
--       END IF;
--     END IF;
--     if (new$SourceExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Source */
--         select Accepted
--         into EDAccepted1$       from ExecutionDocumentsCaption
--         where id = new$SourceExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');
--       END IF;/*         */
--     else
--       if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
--         new$sourceexecinnernumber := null;
--       END IF;
--     END IF;
--     if (new$DestExecDoc is not null) then
--       BEGIN
--         /*     */
--         select Reject_Cls
--         into CaptionRejectCls$       from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*     Dest */
--         select Accepted
--         into EDAccepted1$       from ExecutionDocumentsCaption
--         where ID = new$DestExecDoc
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
--         RaiseException('Ex_ExecDoc_Rejected');
--       END IF;/*         */
--     else
--       if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
--         new$destexecinnernumber := null;
--       END IF;
--     END IF;/*   " "*/
--   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION,
    NOTE = new$NOTE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
ALTER TRIGGER TR_FACIALFINDETAIL_BU_500 ENABLE
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_210
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -
  NULL;
--   /*       */
--   GetIntConst(30, 15,PromiseMode2$);
--   /*     */
--   if (PromiseMode2$ <> 1) then
--     /*          */
--     if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$SOURCEPROMISE)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /*          */
--     if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
--       select
--       count(pr.REGISTRNUMBER)
--       into
--       Promise_Count1$          from
--       promise_detail pr
--       where
--       (pr.registrnumber = new$DestPromise)
--       ;
--       /*    ,  */
--       if (Promise_Count1$ = 0) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
-- 
--     END IF;/* end  PromiseMode <> 1*/
--   END IF;
--   /*     */
--   if (PromiseMode2$ = 1) then
--     /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
--     (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$SourceBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
--     /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
--     if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
--     (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
--       select max(InnerPromiseNum)
--       into BPInnerNum1$           from PaymentSchedule
--       where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
--       ;
--       if (BPInnerNum1$ <> 0) then
--         new$DestBudgetPromise := BPInnerNum1$;
-- 
--       else
--         RaiseException('EX_BP_NotExist');
--       END IF;
--     END IF;
-- 
--     /* source:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
--     (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$           from PaymentSchedule
--         where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$SourcePromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* dest:  BudgetPromise    Promise=NULL,   Promise */
--     if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
--     (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
--       BEGIN
--         select ANumber
--         into BPInnerNum1$            from PaymentSchedule
--         where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       if (BPInnerNum1$ is NULL) then
--         RaiseException('EX_BP_NotExist');
--       END IF;
--       new$DestPromise := BPInnerNum1$;
--       new$Promise := BPInnerNum1$;
-- 
--     END IF;
--     /* Source:  BudgetPromise -   Promise */
--     if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
--       new$SourcePromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Source:  Promise -   BudgetPromise */
--     if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
--       new$SourceBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  BudgetPromise -   Promise */
--     if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
--       new$DestPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     /* Dest:  Promise -   BudgetPromise */
--     if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
--       new$DestBudgetPromise := null;
--       new$Promise := null;
-- 
--     END IF;
--     if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$1
--       from PaymentSchedule
--       where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$1<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Source */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--     if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
--       SELECT COUNT(ANumber
--       ) INTO CNT$2
--       from PaymentSchedule
--       where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
--       if (not (CNT$2<> 0)) then
--         RaiseException('Ex_BP_NotExist');
--       END IF;
--       BEGIN
-- 
--         /*        */
--         select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
--         where ID = new$RecordIndex
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       BEGIN
-- 
--         /*      Dest */
--         select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
--         where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
--         ;
--       EXCEPTION
--         WHEN NO_DATA_FOUND THEN NULL;
--       END;
--       /*        */
--       if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
--         RaiseException('Ex_BP_Rejected');
--       END IF;
--       /*         */
--       if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
--         RaiseException('Ex_BP_NotAccepted');
--       END IF;
--     END IF;
--   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$SourceExecDoc := ExecID1$;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$DestExecDoc := ExecID1$;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
        new$sourceexecinnernumber := null;
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
        new$destexecinnernumber := null;
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION,
    NOTE = new$NOTE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER TR_FACIALFINDETAIL_BU_200
CREATE OR REPLACE TRIGGER TR_FACIALFINDETAIL_IU
  INSTEAD OF UPDATE
  ON FACIALFINDETAIL
  FOR EACH ROW
DECLARE
  new$ID FACIALFINDETAIL.ID%TYPE := :NEW.ID;
  new$SOURCEFACIALACC_CLS FACIALFINDETAIL.SOURCEFACIALACC_CLS%TYPE := :NEW.SOURCEFACIALACC_CLS;
  new$SOURCEKVR FACIALFINDETAIL.SOURCEKVR%TYPE := :NEW.SOURCEKVR;
  new$SOURCEKESR FACIALFINDETAIL.SOURCEKESR%TYPE := :NEW.SOURCEKESR;
  new$DESTFACIALACC_CLS FACIALFINDETAIL.DESTFACIALACC_CLS%TYPE := :NEW.DESTFACIALACC_CLS;
  new$DESTKVR FACIALFINDETAIL.DESTKVR%TYPE := :NEW.DESTKVR;
  new$DESTKESR FACIALFINDETAIL.DESTKESR%TYPE := :NEW.DESTKESR;
  new$BUDGETREF FACIALFINDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREDIT FACIALFINDETAIL.CREDIT%TYPE := :NEW.CREDIT;
  new$PAYSYMBOLCLS FACIALFINDETAIL.PAYSYMBOLCLS%TYPE := :NEW.PAYSYMBOLCLS;
  new$MEMORDERNUM FACIALFINDETAIL.MEMORDERNUM%TYPE := :NEW.MEMORDERNUM;
  new$PROGINDEX FACIALFINDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX FACIALFINDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CREATERUSER FACIALFINDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE FACIALFINDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALFINDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER FACIALFINDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$SOURCEKVSR FACIALFINDETAIL.SOURCEKVSR%TYPE := :NEW.SOURCEKVSR;
  new$SOURCEKCSR FACIALFINDETAIL.SOURCEKCSR%TYPE := :NEW.SOURCEKCSR;
  new$SOURCEKFSR FACIALFINDETAIL.SOURCEKFSR%TYPE := :NEW.SOURCEKFSR;
  new$SOURCESUBKESR FACIALFINDETAIL.SOURCESUBKESR%TYPE := :NEW.SOURCESUBKESR;
  new$SOURCEFACT FACIALFINDETAIL.SOURCEFACT%TYPE := :NEW.SOURCEFACT;
  new$SOURCEMEANSTYPE FACIALFINDETAIL.SOURCEMEANSTYPE%TYPE := :NEW.SOURCEMEANSTYPE;
  new$SOURCEFINSOURCE FACIALFINDETAIL.SOURCEFINSOURCE%TYPE := :NEW.SOURCEFINSOURCE;
  new$SOURCEFINTYPE FACIALFINDETAIL.SOURCEFINTYPE%TYPE := :NEW.SOURCEFINTYPE;
  new$DESTKVSR FACIALFINDETAIL.DESTKVSR%TYPE := :NEW.DESTKVSR;
  new$DESTKCSR FACIALFINDETAIL.DESTKCSR%TYPE := :NEW.DESTKCSR;
  new$DESTKFSR FACIALFINDETAIL.DESTKFSR%TYPE := :NEW.DESTKFSR;
  new$DESTSUBKESR FACIALFINDETAIL.DESTSUBKESR%TYPE := :NEW.DESTSUBKESR;
  new$DESTFACT FACIALFINDETAIL.DESTFACT%TYPE := :NEW.DESTFACT;
  new$DESTMEANSTYPE FACIALFINDETAIL.DESTMEANSTYPE%TYPE := :NEW.DESTMEANSTYPE;
  new$DESTFINSOURCE FACIALFINDETAIL.DESTFINSOURCE%TYPE := :NEW.DESTFINSOURCE;
  new$DESTFINTYPE FACIALFINDETAIL.DESTFINTYPE%TYPE := :NEW.DESTFINTYPE;
  new$REQUESTSINDEX FACIALFINDETAIL.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$SENDERID FACIALFINDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID FACIALFINDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$PROMISE FACIALFINDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$SOURCEDOCTYPE FACIALFINDETAIL.SOURCEDOCTYPE%TYPE := :NEW.SOURCEDOCTYPE;
  new$DESTDOCTYPE FACIALFINDETAIL.DESTDOCTYPE%TYPE := :NEW.DESTDOCTYPE;
  new$SOURCEPROMISE FACIALFINDETAIL.SOURCEPROMISE%TYPE := :NEW.SOURCEPROMISE;
  new$DESTPROMISE FACIALFINDETAIL.DESTPROMISE%TYPE := :NEW.DESTPROMISE;
  new$RECORDINDEX2 FACIALFINDETAIL.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$SOURCEBUDGETPROMISE FACIALFINDETAIL.SOURCEBUDGETPROMISE%TYPE := :NEW.SOURCEBUDGETPROMISE;
  new$DESTBUDGETPROMISE FACIALFINDETAIL.DESTBUDGETPROMISE%TYPE := :NEW.DESTBUDGETPROMISE;
  new$SUBPROGINDEX FACIALFINDETAIL.SUBPROGINDEX%TYPE := :NEW.SUBPROGINDEX;
  new$STIMATEID FACIALFINDETAIL.STIMATEID%TYPE := :NEW.STIMATEID;
  new$RVERSION FACIALFINDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$SOURCEDIRECTIONCLS FACIALFINDETAIL.SOURCEDIRECTIONCLS%TYPE := :NEW.SOURCEDIRECTIONCLS;
  new$DESTDIRECTIONCLS FACIALFINDETAIL.DESTDIRECTIONCLS%TYPE := :NEW.DESTDIRECTIONCLS;
  new$SOURCEDOCBASE FACIALFINDETAIL.SOURCEDOCBASE%TYPE := :NEW.SOURCEDOCBASE;
  new$DESTDOCBASE FACIALFINDETAIL.DESTDOCBASE%TYPE := :NEW.DESTDOCBASE;
  new$SOURCEEXECDOC FACIALFINDETAIL.SOURCEEXECDOC%TYPE := :NEW.SOURCEEXECDOC;
  new$DESTEXECDOC FACIALFINDETAIL.DESTEXECDOC%TYPE := :NEW.DESTEXECDOC;
  new$BUHOPERATIONCLS FACIALFINDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$SOURCEIFS FACIALFINDETAIL.SOURCEIFS%TYPE := :NEW.SOURCEIFS;
  new$DESTIFS FACIALFINDETAIL.DESTIFS%TYPE := :NEW.DESTIFS;
  new$CLSTYPE FACIALFINDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$UNIONNOTIFYREF FACIALFINDETAIL.UNIONNOTIFYREF%TYPE := :NEW.UNIONNOTIFYREF;
  new$ACCEPTDATE FACIALFINDETAIL.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SOURCEKD FACIALFINDETAIL.SOURCEKD%TYPE := :NEW.SOURCEKD;
  new$DESTKD FACIALFINDETAIL.DESTKD%TYPE := :NEW.DESTKD;
  new$SOURCEREGIONCLS FACIALFINDETAIL.SOURCEREGIONCLS%TYPE := :NEW.SOURCEREGIONCLS;
  new$DESTREGIONCLS FACIALFINDETAIL.DESTREGIONCLS%TYPE := :NEW.DESTREGIONCLS;
  new$DESTFUNDSSOURCE FACIALFINDETAIL.DESTFUNDSSOURCE%TYPE := :NEW.DESTFUNDSSOURCE;
  new$SOURCEFUNDSSOURCE FACIALFINDETAIL.SOURCEFUNDSSOURCE%TYPE := :NEW.SOURCEFUNDSSOURCE;
  new$ISBLOCKED FACIALFINDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE FACIALFINDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE FACIALFINDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE FACIALFINDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SOURCETRANSFERTCLS FACIALFINDETAIL.SOURCETRANSFERTCLS%TYPE := :NEW.SOURCETRANSFERTCLS;
  new$DESTTRANSFERTCLS FACIALFINDETAIL.DESTTRANSFERTCLS%TYPE := :NEW.DESTTRANSFERTCLS;
  new$DESTCLSTYPE FACIALFINDETAIL.DESTCLSTYPE%TYPE := :NEW.DESTCLSTYPE;
  new$SOURCEASSIGNMENTKIND FACIALFINDETAIL.SOURCEASSIGNMENTKIND%TYPE := :NEW.SOURCEASSIGNMENTKIND;
  new$DESTASSIGNMENTKIND FACIALFINDETAIL.DESTASSIGNMENTKIND%TYPE := :NEW.DESTASSIGNMENTKIND;
  new$SOURCEEXECINNERNUMBER FACIALFINDETAIL.SOURCEEXECINNERNUMBER%TYPE := :NEW.SOURCEEXECINNERNUMBER;
  new$DESTEXECINNERNUMBER FACIALFINDETAIL.DESTEXECINNERNUMBER%TYPE := :NEW.DESTEXECINNERNUMBER;
  new$SOURCESUBSIDYCLS FACIALFINDETAIL.SOURCESUBSIDYCLS%TYPE := :NEW.SOURCESUBSIDYCLS;
  new$DESTSUBSIDYCLS FACIALFINDETAIL.DESTSUBSIDYCLS%TYPE := :NEW.DESTSUBSIDYCLS;
  new$SOURCEFAORG_TYPE FACIALFINDETAIL.SOURCEFAORG_TYPE%TYPE := :NEW.SOURCEFAORG_TYPE;
  new$DESTFAORG_TYPE FACIALFINDETAIL.DESTFAORG_TYPE%TYPE := :NEW.DESTFAORG_TYPE;
  new$SOURCEBUDALLOCATIONCLS FACIALFINDETAIL.SOURCEBUDALLOCATIONCLS%TYPE := :NEW.SOURCEBUDALLOCATIONCLS;
  new$SOURCEPAYPROMISECLS FACIALFINDETAIL.SOURCEPAYPROMISECLS%TYPE := :NEW.SOURCEPAYPROMISECLS;
  new$DESTBUDALLOCATIONCLS FACIALFINDETAIL.DESTBUDALLOCATIONCLS%TYPE := :NEW.DESTBUDALLOCATIONCLS;
  new$DESTPAYPROMISECLS FACIALFINDETAIL.DESTPAYPROMISECLS%TYPE := :NEW.DESTPAYPROMISECLS;
  new$SOURCEINVESTOBJECT FACIALFINDETAIL.SOURCEINVESTOBJECT%TYPE := :NEW.SOURCEINVESTOBJECT;
  new$DESTINVESTOBJECT FACIALFINDETAIL.DESTINVESTOBJECT%TYPE := :NEW.DESTINVESTOBJECT;
  new$TRANSFERTORG_REF FACIALFINDETAIL.TRANSFERTORG_REF%TYPE := :NEW.TRANSFERTORG_REF;
  new$SENDERIDKEY FACIALFINDETAIL.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY FACIALFINDETAIL.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$STOREDPAYMENTCONTENT FACIALFINDETAIL.STOREDPAYMENTCONTENT%TYPE := :NEW.STOREDPAYMENTCONTENT;
  new$SOURCECONTRACTCOSTSCLS FACIALFINDETAIL.SOURCECONTRACTCOSTSCLS%TYPE := :NEW.SOURCECONTRACTCOSTSCLS;
  new$DESTCONTRACTCOSTSCLS FACIALFINDETAIL.DESTCONTRACTCOSTSCLS%TYPE := :NEW.DESTCONTRACTCOSTSCLS;
  new$SOURCETARGETCLS FACIALFINDETAIL.SOURCETARGETCLS%TYPE := :NEW.SOURCETARGETCLS;
  new$DESTTARGETCLS FACIALFINDETAIL.DESTTARGETCLS%TYPE := :NEW.DESTTARGETCLS;
  new$REJECT_CLS FACIALFINDETAIL.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$REJECTCAUSE FACIALFINDETAIL.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CARDNUMBER FACIALFINDETAIL.CARDNUMBER%TYPE := :NEW.CARDNUMBER;
  new$DATEBIRTH FACIALFINDETAIL.DATEBIRTH%TYPE := :NEW.DATEBIRTH;
  new$PAYMENTCODETYPE FACIALFINDETAIL.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$CODEPURPOSE FACIALFINDETAIL.CODEPURPOSE%TYPE := :NEW.CODEPURPOSE;
  new$LINENUMBER FACIALFINDETAIL.LINENUMBER%TYPE := :NEW.LINENUMBER;
  new$AMOUNTISPDOC FACIALFINDETAIL.AMOUNTISPDOC%TYPE := :NEW.AMOUNTISPDOC;
  new$SOURCEREGPROJECTRESULT FACIALFINDETAIL.SOURCEREGPROJECTRESULT%TYPE := :NEW.SOURCEREGPROJECTRESULT;
  new$DESTREGPROJECTRESULT FACIALFINDETAIL.DESTREGPROJECTRESULT%TYPE := :NEW.DESTREGPROJECTRESULT;
  new$SOURCEINCOMETARGETFUNDS FACIALFINDETAIL.SOURCEINCOMETARGETFUNDS%TYPE := :NEW.SOURCEINCOMETARGETFUNDS;
  new$DESTINCOMETARGETFUNDS FACIALFINDETAIL.DESTINCOMETARGETFUNDS%TYPE := :NEW.DESTINCOMETARGETFUNDS;
  new$SOURCEPAYTARGETFUNDS FACIALFINDETAIL.SOURCEPAYTARGETFUNDS%TYPE := :NEW.SOURCEPAYTARGETFUNDS;
  new$DESTPAYTARGETFUNDS FACIALFINDETAIL.DESTPAYTARGETFUNDS%TYPE := :NEW.DESTPAYTARGETFUNDS;
  new$SOURCEANALYTICALPARTITION FACIALFINDETAIL.SOURCEANALYTICALPARTITION%TYPE := :NEW.SOURCEANALYTICALPARTITION;
  new$DESTANALYTICALPARTITION FACIALFINDETAIL.DESTANALYTICALPARTITION%TYPE := :NEW.DESTANALYTICALPARTITION;
  new$NOTE FACIALFINDETAIL.NOTE%TYPE := :NEW.NOTE;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  BPInnerNum1$ NUMBER(10);
  PromiseMode2$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  CaptionAcceptDate1$ NUMBER;
  CaptionRejectCls2$ NUMBER(10);
  PromiseAcceptDate1$ NUMBER;
  PromiseAccepted1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex1$ NUMBER(10);
  ExecID1$ NUMBER(10);
  ExecInnerNumber1$ NUMBER(10);
  ExecRegType1$ NUMBER(10);
  ExecAgrInnerNum1$ NUMBER(10);
  AgrInnerNumber1$ NUMBER(10);
  CaptionRejectCls$ NUMBER(10);
  EDAccepted1$ NUMBER(10);
  CapAcceptDate1$ NUMBER(10);
  i_fintype$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALFINDETAIL_BU_0)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

   IF (new$Credit IS NULL) THEN new$Credit := 0; END IF;

   /*     */
   IF     (new$BudgetRef <> :OLD.BudgetRef)
      AND (NOT ((new$BudgetRef IS NULL) AND (:OLD.BudgetRef IS NULL))) THEN
      raiseException ('Ex_CantModufyBudget');
   END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_FACIALFINDETAIL_BU_110)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*     ,      */
  i_fintype$ := -1 ;
  IF (new$SourceFintype IS NULL) THEN
    BEGIN
      SELECT constvalue INTO i_fintype$   FROM intconst
      WHERE (progindex=30) AND (constindex=10) ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    new$SourceFintype := i_fintype$  ;

  END IF;
  IF (new$DestFintype IS NULL) THEN
    IF (i_fintype$ = -1) THEN
      BEGIN
        SELECT constvalue INTO i_fintype$   FROM intconst
        WHERE (progindex=30) AND (constindex=10) ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
    new$DestFintype := i_fintype$  ;

  END IF;
  IF (new$SourceFacialAcc_CLS IS NULL) THEN
    new$SourceFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$SourceKVR IS NULL) THEN
    new$SourceKVR := 0;
  END IF;
  IF (new$SourceKVSR IS NULL) THEN
    new$SourceKVSR := 0;
  END IF;
  IF (new$SourceKFSR IS NULL) THEN
    new$SourceKFSR := 0;
  END IF;
  IF (new$SourceKCSR IS NULL) THEN
    new$SourceKCSR := 0;
  END IF;
  IF (new$SourceSubKESR IS NULL) THEN
    new$SourceSubKESR := 0;
  END IF;
  IF (new$SourceDirectionCls IS NULL) THEN
    new$SourceDirectionCls := 0;
  END IF;
  IF (new$SourceFact IS NULL) THEN
    new$SourceFact := 0;
  END IF;
  IF (new$SourceMeansType IS NULL) THEN
    new$SourceMeansType := 0;
  END IF;
  IF (new$SourceFinSource IS NULL) THEN
    new$SourceFinSource := 0;
  END IF;
  IF (new$SourceFinType IS NULL) THEN
    new$SourceFinType := 0;
  END IF;
  IF (new$SourceDocType IS NULL) THEN
    new$SourceDocType := 0;
  END IF;
  IF (new$Sourceifs IS NULL) THEN
    new$Sourceifs := 0;
  END IF;
  IF (new$SourceKD IS NULL) THEN
    new$SourceKD := 0;
  END IF;
  IF (new$SourceFundsSource IS NULL) THEN
    new$SourceFundsSource := 0;
  END IF;
  IF (new$SourceAssignmentKind IS NULL) THEN
    new$SourceAssignmentKind := 0;
  END IF;
  IF (new$SourceRegionCLS IS NULL) THEN
    new$SourceRegionCLS := 0;
  END IF;
  IF (new$DestFacialAcc_CLS IS NULL) THEN
    new$DestFacialAcc_CLS := 0;
  END IF;
  /*   */
  IF (new$DestKVR IS NULL) THEN
    new$DestKVR := 0;
  END IF;
  IF (new$DestKVSR IS NULL) THEN
    new$DestKVSR := 0;
  END IF;
  IF (new$DestKFSR IS NULL) THEN
    new$DestKFSR := 0;
  END IF;
  IF (new$DestKCSR IS NULL) THEN
    new$DestKCSR := 0;
  END IF;
  IF (new$DestSubKESR IS NULL) THEN
    new$DestSubKESR := 0;
  END IF;
  IF (new$DestDirectionCls IS NULL) THEN
    new$DestDirectionCls := 0;
  END IF;
  IF (new$DestFact IS NULL) THEN
    new$DestFact := 0;
  END IF;
  IF (new$DestMeansType IS NULL) THEN
    new$DestMeansType := 0;
  END IF;
  IF (new$DestFinSource IS NULL) THEN
    new$DestFinSource := 0;
  END IF;
  IF (new$DestFinType IS NULL) THEN
    new$DestFinType := 0;
  END IF;
  IF (new$DestDocType IS NULL) THEN
    new$DestDocType := 0;
  END IF;
  IF (new$Destifs IS NULL) THEN
    new$Destifs := 0;
  END IF;
  IF (new$DestKD IS NULL) THEN
    new$DestKD := 0;
  END IF;
  IF (new$DestFundsSource IS NULL) THEN
    new$DestFundsSource := 0;
  END IF;
  IF (new$DestAssignmentKind IS NULL) THEN
    new$DestAssignmentKind := 0;
  END IF;
  IF (new$DestRegionCLS IS NULL) THEN
    new$DestRegionCLS := 0;
  END IF;
  /*   :       */
  if (new$progindex=76) then
    new$SourceKVR := new$DestKVR;
    new$SourceKESR := new$DestKESR;
    new$SourceKVSR := new$DestKVSR;
    new$SourceKFSR := new$DestKFSR;
    new$SourceKCSR := new$DestKCSR;
    new$SourceSubKESR := new$DestSubKESR;
    new$SourceDirectionCls := new$DestDirectionCls;
    new$SourceFact := new$DestFact;
    new$SourceMeansType := new$DestMeansType;
    new$SourceFinSource := new$DestFinSource;
    new$SourceFinType := new$DestFinType;
    new$SourceDocType := new$DestDocType;
    new$SourceIFS := new$DestIFS;
    new$SourceKD := new$DestKD;
    new$SourceRegionCls := new$DestRegionCls;
    new$SourceDocBase := new$DestDocBase;
    new$SourceAssignmentKind := new$DestAssignmentKind;
    new$SourceSubsidyCls := new$DestSubsidyCls;
    new$SourceTransfertCLS := new$DestTransfertCLS;
    new$SourceBudAllocationCls := new$DestBudAllocationCls;
    new$SourcePayPromiseCls := new$DestPayPromiseCls;

  END IF;
  /*      */
  IF (new$progindex = 283) THEN
    /*          */
    IF ((new$ACCEPTDATE IS NOT NULL) AND (:old.REJECT_CLS IS NULL) AND (new$REJECT_CLS IS NOT NULL)) THEN
      new$ACCEPTDATE := null;
    END IF;
    /*              */
    IF ((:old.REJECT_CLS IS NOT NULL) AND (new$REJECT_CLS IS NULL)) THEN
      BEGIN
        select AcceptDate
        into new$ACCEPTDATE      from facialfincaption
        where (id = new$RecordIndex)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;
  END IF;

  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  /*    */
  IF ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NOT NULL)
  AND (new$SourcePromise <> :old.SourcePromise)
  OR ((new$SourcePromise IS NULL) AND (:old.SourcePromise IS NOT NULL))
  OR ((new$SourcePromise IS NOT NULL) AND (:old.SourcePromise IS NULL))
  OR (new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NOT NULL)
  AND (new$DestPromise <> :old.DestPromise)
  OR ((new$DestPromise IS NULL) AND (:old.DestPromise IS NOT NULL))
  OR ((new$DestPromise IS NOT NULL) AND (:old.DestPromise IS NULL))) THEN
    IF (new$progindex IN (63, 64, 73)) THEN
      new$Promise := new$SourcePromise;

    ELSE
      IF (new$progindex IN (61, 62, 65, 75)) THEN
        new$Promise := new$DestPromise;

      ELSE
        IF ((new$progindex in (66, 67, 76))AND((new$SourcePromise=new$DestPromise)OR
        ((new$SourcePromise IS NULL)AND(new$DestPromise IS NULL)))) THEN
          new$Promise := new$DestPromise;
        END IF;
      END IF;
    END IF;/*     */
  ELSE
    IF ((new$Promise IS NOT NULL) AND (:old.Promise IS NOT NULL)
    AND (new$Promise <> :old.Promise)
    OR ((new$Promise IS NULL) AND (:old.Promise IS NOT NULL))
    OR ((new$Promise IS NOT NULL) AND (:old.Promise IS NULL))) THEN
      IF (new$progindex IN (63, 64, 73)) THEN
        new$SourcePromise := new$Promise;

      ELSE
        IF (new$progindex IN (61, 62, 65, 75)) THEN
          new$DestPromise := new$Promise;

        ELSE
          IF (new$progindex in (66, 67, 76)) THEN
            new$SourcePromise := new$Promise;
            new$DestPromise := new$Promise;

          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \   */
  IF ( (new$SourceFacialACC_Cls <> :old.SourceFacialAcc_Cls) OR (new$SourceFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$SourceFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$SourceFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  IF ( (new$DestFacialACC_Cls <> :old.DestFacialAcc_Cls) OR (new$DestFAOrg_Type is null) OR
  ((new$AcceptDate is not null) AND ((:old.AcceptDate is null) OR (new$AcceptDate <> :old.AcceptDate))) ) THEN
    BEGIN
      SELECT org.Org_Type    INTO new$DestFAOrg_Type FROM Organizations org
      INNER JOIN FacialACC_Cls fac ON (org.ID = fac.Org_Ref)
      WHERE (fac.ID = new$DestFacialAcc_Cls)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  /*       */
  IF (new$ProgIndex <> 76) THEN /*  03.24   .    */
    GETTARGETCLS(:old.Sourcetransfertcls, new$Sourcetransfertcls, :old.Sourcemeanstype, new$Sourcemeanstype,
    new$Sourcetargetcls,new$Sourcetargetcls);
  END IF;
  GETTARGETCLS(:old.Desttransfertcls, new$Desttransfertcls, :old.Destmeanstype, new$Destmeanstype,
  new$Desttargetcls,new$Desttargetcls);
  IF (new$ProgIndex = 76) THEN
    new$SourceTargetCls := new$DestTargetCls;
  END IF;
  /*      */
  GetDocumentKESR(:old.SourceSubKESR, new$SourceSubKESR, new$SourceKESR, new$BudgetRef,new$SourceKESR);
  GetDocumentKESR(:old.DestSubKESR, new$DestSubKESR, new$DestKESR, new$BudgetRef,new$DestKESR);

-- - - - - - - - - - - - -
-- BU_120 (TR_FACIALFINDETAIL_BU_120)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*       60 :  '   .'; source
            61 :  '      '; dest
            62 :  '   ';dest
            63 :  '    '; source
            64 :  '   '; source
            65 :  ' , ';dest
            66 :  '  ,  - '; source dest
            67 :  '   ';source
            68 :  '  \ ';dest
            69 :  '   \ '; dest
            70 :  '  \ ';source
            71 :  '   \ '; dest
          283 :  '   '; source */

  /* ClsType*/
  if ((new$ClsType is NULL) and
  (
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283))) or
  (new$ProgIndex = 60)
  )) then
    new$ClsType := 1; /*       ClsType */
      
  else
    if ((new$ClsType is NULL) and (new$SourceKD <> 0) and
    (new$ProgIndex in (63,64,66,67,68,70,283))) then
      new$ClsType := 2; /*        ClsType */
          
    else
      if (new$ClsType is null) then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND
  (((new$SourceIFS <> 0) or (new$SourceKD <> 0)) and
  (new$ProgIndex in (63,64,66,67,68,70,283)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 1) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceKD <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$SourceKVSR <> 0) OR (new$SourceKFSR <> 0) OR
  (new$SourceKCSR <> 0) OR (new$SourceKVR <> 0) OR
  ((new$SourceIFS <> 0) and (new$ProgIndex in (63,64,66,67,68,70,283)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  /* DestClsType*/
  if (((new$ProgIndex <> 67)and(new$ClsType <> :old.ClsType))or(new$DestClsType is null)) then
    new$DestClsType := new$ClsType;
  END IF;
  IF ((new$DestClsType = 0) AND
  (((new$DestIFS <> 0) or (new$DestKD <> 0)) and
  (new$ProgIndex in (61,62,65,69,71)))
  ) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 1) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestKD <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$DestClsType = 2) AND (
  (new$DestKVSR <> 0) OR (new$DestKFSR <> 0) OR
  (new$DestKCSR <> 0) OR (new$DestKVR <> 0) OR
  ((new$DestIFS <> 0) and (new$ProgIndex in (61,62,65,69,71)))
  )) THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALFINDETAIL_BU_200)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode2$);
  /*     */
  if (PromiseMode2$ <> 1) then
    /*          */
    if ((new$SourcePromise is not null) and (:old.SourcePromise <> new$SourcePromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$SOURCEPROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /*          */
    if ((new$DestPromise is not null) and (:old.DestPromise <> new$DestPromise )) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$          from
      promise_detail pr
      where
      (pr.registrnumber = new$DestPromise)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;

    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /*     */
  if (PromiseMode2$ = 1) then
    /* source:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$SourcePromise is not null)and((:old.SourcePromise is null)or(:old.SourcePromise <> new$SourcePromise )) and
    (new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$SourcePromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$SourceBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /* dest:  Promise    BudgetPromise=NULL,   BudgetPromise */
    if ((new$DestPromise is not null)and((:old.DestPromise is null)or(new$DestPromise <> :old.DestPromise)) and
    (new$DestBudgetPromise is null) and (:old.DestBudgetPromise is null)) then
      select max(InnerPromiseNum)
      into BPInnerNum1$           from PaymentSchedule
      where (ANumber = new$DestPromise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        new$DestBudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;

    /* source:  BudgetPromise    Promise=NULL,   Promise */
    if (new$SourcePromise is null and ((new$SourceBudgetPromise is not null and :old.SourceBudgetPromise is null) or
    (new$SourceBudgetPromise <> :old.SourceBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$           from PaymentSchedule
        where (InnerPromiseNum = new$SourceBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$SourcePromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* dest:  BudgetPromise    Promise=NULL,   Promise */
    if (new$DestPromise is null and ((new$DestBudgetPromise is not null and :old.DestBudgetPromise is null) or
    (new$DestBudgetPromise <> :old.DestBudgetPromise))) then
      BEGIN
        select ANumber
        into BPInnerNum1$            from PaymentSchedule
        where (InnerPromiseNum = new$DestBudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (BPInnerNum1$ is NULL) then
        RaiseException('EX_BP_NotExist');
      END IF;
      new$DestPromise := BPInnerNum1$;
      new$Promise := BPInnerNum1$;

    END IF;
    /* Source:  BudgetPromise -   Promise */
    if ((new$SourceBudgetPromise is null) and (:old.SourceBudgetPromise is not null)) then
      new$SourcePromise := null;
      new$Promise := null;

    END IF;
    /* Source:  Promise -   BudgetPromise */
    if ((new$SourcePromise is null) and (:old.SourcePromise is not null)) then
      new$SourceBudgetPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  BudgetPromise -   Promise */
    if ((new$DestBudgetPromise is null) and (:old.DestBudgetPromise is not null)) then
      new$DestPromise := null;
      new$Promise := null;

    END IF;
    /* Dest:  Promise -   BudgetPromise */
    if ((new$DestPromise is null) and (:old.DestPromise is not null)) then
      new$DestBudgetPromise := null;
      new$Promise := null;

    END IF;
    if (new$SourceBudgetPromise is not null and new$SourcePromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$1
      from PaymentSchedule
      where (ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$1<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Source */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$SourcePromise and InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
    if (new$DestBudgetPromise is not null and new$DestPromise is not null) then
      SELECT COUNT(ANumber
      ) INTO CNT$2
      from PaymentSchedule
      where (ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise) AND (ROWNUM = 1);
      if (not (CNT$2<> 0)) then
        RaiseException('Ex_BP_NotExist');
      END IF;
      BEGIN

        /*        */
        select AcceptDate, Reject_Cls         into CaptionAcceptDate1$, CaptionRejectCls2$ from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*      Dest */
        select AcceptDate, Accepted         into PromiseAcceptDate1$, PromiseAccepted1$ from PaymentSchedule
        where ANumber = new$DestPromise and InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls2$ is null and PromiseAccepted1$ <> 1) then
        RaiseException('Ex_BP_Rejected');
      END IF;
      /*         */
      if (CaptionAcceptDate1$ is not null and (PromiseAcceptDate1$ is null or PromiseAccepted1$ <> 1)) then
        RaiseException('Ex_BP_NotAccepted');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_FACIALFINDETAIL_BU_210)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (new$SourcePromise is not null and (
    (:old.SourcePromise is null or :old.SourcePromise <> new$SourcePromise) or
    (:old.SourceExecDoc is null or new$SourceExecDoc is null or :old.SourceExecDoc <> new$SourceExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$SourcePromise and ps.InnerPromiseNum = new$SourceBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$SourceExecDoc := ExecID1$;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$SourceExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$SourceExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$SourceExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$SourceExecDoc is null or :old.SourceExecDoc is null or new$SourceExecDoc <> :old.SourceExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$SourceExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$SourceExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    /*     Dest */

    /*        */
    if (new$DestPromise is not null and (
    (:old.DestPromise is null or :old.DestPromise <> new$DestPromise) or
    (:old.DestExecDoc is null or new$DestExecDoc is null or :old.DestExecDoc <> new$DestExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex1$, ExecID1$, ExecInnerNumber1$, AgrInnerNumber1$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$DestPromise and ps.InnerPromiseNum = new$DestBudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex1$ = 308) then
        new$DestExecDoc := ExecID1$;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      else
        if (new$DestExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType1$, ExecAgrInnerNum1$, ExecInnerNumber1$         from ExecutionDocumentsCaption
            where
            Id = new$DestExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType1$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum1$ <> AgrInnerNumber1$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$DestExecInnerNumber := ExecInnerNumber1$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$DestExecDoc is null or :old.DestExecDoc is null or new$DestExecDoc <> :old.DestExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber1$       from ExecutionDocumentsCaption
          where
          Id = new$DestExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$DestExecInnerNumber := ExecInnerNumber1$;

      END IF;
    END IF;
    if (new$SourceExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Source */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where id = new$SourceExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$sourceexecinnernumber is not null or :old.sourceexecinnernumber is not null) then
        new$sourceexecinnernumber := null;
      END IF;
    END IF;
    if (new$DestExecDoc is not null) then
      BEGIN
        /*     */
        select Reject_Cls
        into CaptionRejectCls$       from FacialFinCaption
        where ID = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      BEGIN

        /*     Dest */
        select Accepted
        into EDAccepted1$       from ExecutionDocumentsCaption
        where ID = new$DestExecDoc
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*        */
      if (CaptionRejectCls$ is null and EDAccepted1$ <> 1) then
        RaiseException('Ex_ExecDoc_Rejected');
      END IF;/*         */
    else
      if (new$destexecinnernumber is not null or :old.destexecinnernumber is not null) then
        new$destexecinnernumber := null;
      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_FACIALFINDETAIL_BU_300)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*          (  ) */
  if ((:old.AcceptDate <> new$AcceptDate)or((:old.AcceptDate is not null)and(new$AcceptDate is null))) then
    BEGIN
      select
      c.AcceptDate
      into
      CapAcceptDate1$     from
      facialfincaption c
      where
      (c.id = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not ((new$AcceptDate = CapAcceptDate1$) or (CapAcceptDate1$  is null) or
    /*          (  )    */
    ((new$Progindex = 283) and (new$AcceptDate is null) and (new$Reject_CLS is not null)))) then
      RaiseException('ex_wrongacceptdate');
    END IF;
  END IF;
  /*         */
  if ((new$AcceptDate is not null) and (new$Reject_CLS is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALFINDETAIL_BU_700)
-- Create 17.09.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALFINDETAIL SET
    ID = new$ID,
    SOURCEFACIALACC_CLS = new$SOURCEFACIALACC_CLS,
    SOURCEKVR = new$SOURCEKVR,
    SOURCEKESR = new$SOURCEKESR,
    DESTFACIALACC_CLS = new$DESTFACIALACC_CLS,
    DESTKVR = new$DESTKVR,
    DESTKESR = new$DESTKESR,
    BUDGETREF = new$BUDGETREF,
    CREDIT = new$CREDIT,
    PAYSYMBOLCLS = new$PAYSYMBOLCLS,
    MEMORDERNUM = new$MEMORDERNUM,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    SOURCEKVSR = new$SOURCEKVSR,
    SOURCEKCSR = new$SOURCEKCSR,
    SOURCEKFSR = new$SOURCEKFSR,
    SOURCESUBKESR = new$SOURCESUBKESR,
    SOURCEFACT = new$SOURCEFACT,
    SOURCEMEANSTYPE = new$SOURCEMEANSTYPE,
    SOURCEFINSOURCE = new$SOURCEFINSOURCE,
    SOURCEFINTYPE = new$SOURCEFINTYPE,
    DESTKVSR = new$DESTKVSR,
    DESTKCSR = new$DESTKCSR,
    DESTKFSR = new$DESTKFSR,
    DESTSUBKESR = new$DESTSUBKESR,
    DESTFACT = new$DESTFACT,
    DESTMEANSTYPE = new$DESTMEANSTYPE,
    DESTFINSOURCE = new$DESTFINSOURCE,
    DESTFINTYPE = new$DESTFINTYPE,
    REQUESTSINDEX = new$REQUESTSINDEX,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    PROMISE = new$PROMISE,
    SOURCEDOCTYPE = new$SOURCEDOCTYPE,
    DESTDOCTYPE = new$DESTDOCTYPE,
    SOURCEPROMISE = new$SOURCEPROMISE,
    DESTPROMISE = new$DESTPROMISE,
    RECORDINDEX2 = new$RECORDINDEX2,
    SOURCEBUDGETPROMISE = new$SOURCEBUDGETPROMISE,
    DESTBUDGETPROMISE = new$DESTBUDGETPROMISE,
    SUBPROGINDEX = new$SUBPROGINDEX,
    STIMATEID = new$STIMATEID,
    RVERSION = new$RVERSION,
    SOURCEDIRECTIONCLS = new$SOURCEDIRECTIONCLS,
    DESTDIRECTIONCLS = new$DESTDIRECTIONCLS,
    SOURCEDOCBASE = new$SOURCEDOCBASE,
    DESTDOCBASE = new$DESTDOCBASE,
    SOURCEEXECDOC = new$SOURCEEXECDOC,
    DESTEXECDOC = new$DESTEXECDOC,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    SOURCEIFS = new$SOURCEIFS,
    DESTIFS = new$DESTIFS,
    CLSTYPE = new$CLSTYPE,
    UNIONNOTIFYREF = new$UNIONNOTIFYREF,
    ACCEPTDATE = new$ACCEPTDATE,
    SOURCEKD = new$SOURCEKD,
    DESTKD = new$DESTKD,
    SOURCEREGIONCLS = new$SOURCEREGIONCLS,
    DESTREGIONCLS = new$DESTREGIONCLS,
    DESTFUNDSSOURCE = new$DESTFUNDSSOURCE,
    SOURCEFUNDSSOURCE = new$SOURCEFUNDSSOURCE,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SOURCETRANSFERTCLS = new$SOURCETRANSFERTCLS,
    DESTTRANSFERTCLS = new$DESTTRANSFERTCLS,
    DESTCLSTYPE = new$DESTCLSTYPE,
    SOURCEASSIGNMENTKIND = new$SOURCEASSIGNMENTKIND,
    DESTASSIGNMENTKIND = new$DESTASSIGNMENTKIND,
    SOURCEEXECINNERNUMBER = new$SOURCEEXECINNERNUMBER,
    DESTEXECINNERNUMBER = new$DESTEXECINNERNUMBER,
    SOURCESUBSIDYCLS = new$SOURCESUBSIDYCLS,
    DESTSUBSIDYCLS = new$DESTSUBSIDYCLS,
    SOURCEFAORG_TYPE = new$SOURCEFAORG_TYPE,
    DESTFAORG_TYPE = new$DESTFAORG_TYPE,
    SOURCEBUDALLOCATIONCLS = new$SOURCEBUDALLOCATIONCLS,
    SOURCEPAYPROMISECLS = new$SOURCEPAYPROMISECLS,
    DESTBUDALLOCATIONCLS = new$DESTBUDALLOCATIONCLS,
    DESTPAYPROMISECLS = new$DESTPAYPROMISECLS,
    SOURCEINVESTOBJECT = new$SOURCEINVESTOBJECT,
    DESTINVESTOBJECT = new$DESTINVESTOBJECT,
    TRANSFERTORG_REF = new$TRANSFERTORG_REF,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    STOREDPAYMENTCONTENT = new$STOREDPAYMENTCONTENT,
    SOURCECONTRACTCOSTSCLS = new$SOURCECONTRACTCOSTSCLS,
    DESTCONTRACTCOSTSCLS = new$DESTCONTRACTCOSTSCLS,
    SOURCETARGETCLS = new$SOURCETARGETCLS,
    DESTTARGETCLS = new$DESTTARGETCLS,
    REJECT_CLS = new$REJECT_CLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CARDNUMBER = new$CARDNUMBER,
    DATEBIRTH = new$DATEBIRTH,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    CODEPURPOSE = new$CODEPURPOSE,
    LINENUMBER = new$LINENUMBER,
    AMOUNTISPDOC = new$AMOUNTISPDOC,
    SOURCEREGPROJECTRESULT = new$SOURCEREGPROJECTRESULT,
    DESTREGPROJECTRESULT = new$DESTREGPROJECTRESULT,
    SOURCEINCOMETARGETFUNDS = new$SOURCEINCOMETARGETFUNDS,
    DESTINCOMETARGETFUNDS = new$DESTINCOMETARGETFUNDS,
    SOURCEPAYTARGETFUNDS = new$SOURCEPAYTARGETFUNDS,
    DESTPAYTARGETFUNDS = new$DESTPAYTARGETFUNDS,
    SOURCEANALYTICALPARTITION = new$SOURCEANALYTICALPARTITION,
    DESTANALYTICALPARTITION = new$DESTANALYTICALPARTITION,
    NOTE = new$NOTE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_FACIALFINDETAIL_AU_100)
-- Create 14.05.2007
-- - - - - - - - - - - - -

  if (new$ClsType <> :old.ClsType) then
    update FacialFinCaption set
      ClsType = new$ClsType,
      RVersion = -1
    where
      (id = new$RecordIndex)and(ClsType <> new$ClsType);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALFINDETAIL_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (22, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=22) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- alter_ClsCorrValues_fix_unique_dates.sql
-- #########################################################
-- #########################################################

/*   ClsCorrValues -    ,          */
-- ALTER TRIGGER tr_clscorrvalues_bi_100
CREATE OR REPLACE TRIGGER TR_CLSCORRVALUES_II
  INSTEAD OF INSERT
  ON CLSCORRVALUES
  FOR EACH ROW
DECLARE
  new$ID CLSCORRVALUES.ID%TYPE := :NEW.ID;
  new$RECORDINDEX CLSCORRVALUES.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$KVSR CLSCORRVALUES.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CLSCORRVALUES.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CLSCORRVALUES.KCSR%TYPE := :NEW.KCSR;
  new$KVR CLSCORRVALUES.KVR%TYPE := :NEW.KVR;
  new$KESR CLSCORRVALUES.KESR%TYPE := :NEW.KESR;
  new$SUBKESR CLSCORRVALUES.SUBKESR%TYPE := :NEW.SUBKESR;
  new$DIRECTIONCLS CLSCORRVALUES.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$VARIANT CLSCORRVALUES.VARIANT%TYPE := :NEW.VARIANT;
  new$FACT CLSCORRVALUES.FACT%TYPE := :NEW.FACT;
  new$PAYPROMISECLS CLSCORRVALUES.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$BUDALLOCATIONCLS CLSCORRVALUES.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$CONTRACTCOSTSCLS CLSCORRVALUES.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$INVESTOBJECT CLSCORRVALUES.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$FINTYPE CLSCORRVALUES.FINTYPE%TYPE := :NEW.FINTYPE;
  new$MEANSTYPE CLSCORRVALUES.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$TARGETCLS CLSCORRVALUES.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REGIONCLS CLSCORRVALUES.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$SUBSIDYCLS CLSCORRVALUES.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$TRANSFERTCLS CLSCORRVALUES.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$PLANDOCTYPE CLSCORRVALUES.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$ASSIGNMENTSOURCE CLSCORRVALUES.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$ASSIGNMENTKIND CLSCORRVALUES.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$KD CLSCORRVALUES.KD%TYPE := :NEW.KD;
  new$ANALYTICALGROUPIFS CLSCORRVALUES.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
  new$ANALYTICALGROUPKD CLSCORRVALUES.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
  new$PROGRAMCODE CLSCORRVALUES.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$INNERFINSOURCE CLSCORRVALUES.INNERFINSOURCE%TYPE := :NEW.INNERFINSOURCE;
  new$REESTRTYPE CLSCORRVALUES.REESTRTYPE%TYPE := :NEW.REESTRTYPE;
  new$OKTMO CLSCORRVALUES.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCBASE CLSCORRVALUES.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FUNDSSOURCE CLSCORRVALUES.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$FINSOURCE CLSCORRVALUES.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$DOCTYPE CLSCORRVALUES.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$COMMDIRECTIONEXPENCECLS CLSCORRVALUES.COMMDIRECTIONEXPENCECLS%TYPE := :NEW.COMMDIRECTIONEXPENCECLS;
  new$PAYTARGETFUNDS CLSCORRVALUES.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$PAYDESTINATION CLSCORRVALUES.PAYDESTINATION%TYPE := :NEW.PAYDESTINATION;
  new$FACIALACC_CLS CLSCORRVALUES.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$REGPROJECTRESULT CLSCORRVALUES.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
  new$NATIONALPROJECT CLSCORRVALUES.NATIONALPROJECT%TYPE := :NEW.NATIONALPROJECT;
  new$PAYMENTCODETYPE CLSCORRVALUES.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$LINKRECORD CLSCORRVALUES.LINKRECORD%TYPE := :NEW.LINKRECORD;
  new$ATTACHTO CLSCORRVALUES.ATTACHTO%TYPE := :NEW.ATTACHTO;
  new$STOREDCONTENT CLSCORRVALUES.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
  new$BUDGETREF CLSCORRVALUES.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$NOTE CLSCORRVALUES.NOTE%TYPE := :NEW.NOTE;
  new$EXTID CLSCORRVALUES.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID CLSCORRVALUES.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$STARTDATE CLSCORRVALUES.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE CLSCORRVALUES.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$CREATEDATE CLSCORRVALUES.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER CLSCORRVALUES.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE CLSCORRVALUES.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER CLSCORRVALUES.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
--
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ClsCorrValues_BI_0)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_CLSCORRVALUES_BI_100)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(ID ) INTO CNT$1
  from CLSCORRVALUES
  where
  (        ((ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS) or ((ANALYTICALGROUPIFS is null) and (new$ANALYTICALGROUPIFS is null))) and
  ((ANALYTICALGROUPKD = new$ANALYTICALGROUPKD) or ((ANALYTICALGROUPKD is null) and (new$ANALYTICALGROUPKD is null))) and
  ((ASSIGNMENTKIND = new$ASSIGNMENTKIND) or ((ASSIGNMENTKIND is null) and (new$ASSIGNMENTKIND is null))) and
  ((ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE) or ((ASSIGNMENTSOURCE is null) and (new$ASSIGNMENTSOURCE is null))) and
  ((ATTACHTO = new$ATTACHTO) or ((ATTACHTO is null) and (new$ATTACHTO is null))) and
  ((BUDALLOCATIONCLS = new$BUDALLOCATIONCLS) or ((BUDALLOCATIONCLS is null) and (new$BUDALLOCATIONCLS is null))) and
  (BUDGETREF = new$BUDGETREF) and
  ((COMMDIRECTIONEXPENCECLS = new$COMMDIRECTIONEXPENCECLS) or ((COMMDIRECTIONEXPENCECLS is null) and (new$COMMDIRECTIONEXPENCECLS is null))) and
  ((PayTargetFunds = new$PayTargetFunds) or ((PayTargetFunds is null) and (new$PayTargetFunds is null))) and
  ((CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS) or ((CONTRACTCOSTSCLS is null) and (new$CONTRACTCOSTSCLS is null))) and
  ((DIRECTIONCLS = new$DIRECTIONCLS) or ((DIRECTIONCLS is null) and (new$DIRECTIONCLS is null))) and
  ((DOCBASE = new$DOCBASE) or ((DOCBASE is null) and (new$DOCBASE is null))) and
  ((DOCTYPE = new$DOCTYPE) or ((DOCTYPE is null) and (new$DOCTYPE is null))) and
  ((FACIALACC_CLS = new$FACIALACC_CLS) or ((FACIALACC_CLS is null) and (new$FACIALACC_CLS is null))) and
  ((FACT = new$FACT) or ((FACT is null) and (new$FACT is null))) and
  ((FINSOURCE = new$FINSOURCE) or ((FINSOURCE is null) and (new$FINSOURCE is null))) and
  ((FINTYPE = new$FINTYPE) or ((FINTYPE is null) and (new$FINTYPE is null))) and
  ((FUNDSSOURCE = new$FUNDSSOURCE) or ((FUNDSSOURCE is null) and (new$FUNDSSOURCE is null))) and
  ((INNERFINSOURCE = new$INNERFINSOURCE) or ((INNERFINSOURCE is null) and (new$INNERFINSOURCE is null))) and
  ((INVESTOBJECT = new$INVESTOBJECT) or ((INVESTOBJECT is null) and (new$INVESTOBJECT is null))) and
  ((KCSR = new$KCSR) or ((KCSR is null) and (new$KCSR is null))) and
  ((KD = new$KD) or ((KD is null) and (new$KD is null))) and
  ((KESR = new$KESR) or ((KESR is null) and (new$KESR is null))) and
  ((KFSR = new$KFSR) or ((KFSR is null) and (new$KFSR is null))) and
  ((KVR = new$KVR) or ((KVR is null) and (new$KVR is null))) and
  ((KVSR = new$KVSR) or ((KVSR is null) and (new$KVSR is null))) and
  ((MEANSTYPE = new$MEANSTYPE) or ((MEANSTYPE is null) and (new$MEANSTYPE is null))) and
  ((REGPROJECTRESULT = new$REGPROJECTRESULT) or ((REGPROJECTRESULT is null) and (new$REGPROJECTRESULT is null))) and
  ((NATIONALPROJECT = new$NATIONALPROJECT) or ((NATIONALPROJECT is null) and (new$NATIONALPROJECT is null))) and
  ((OKTMO = new$OKTMO) or ((OKTMO is null) and (new$OKTMO is null))) and
  ((PAYDESTINATION = new$PAYDESTINATION) or ((PAYDESTINATION is null) and (new$PAYDESTINATION is null))) and
  ((PAYPROMISECLS = new$PAYPROMISECLS) or ((PAYPROMISECLS is null) and (new$PAYPROMISECLS is null))) and
  ((PLANDOCTYPE = new$PLANDOCTYPE) or ((PLANDOCTYPE is null) and (new$PLANDOCTYPE is null))) and
  ((PROGRAMCODE = new$PROGRAMCODE) or ((PROGRAMCODE is null) and (new$PROGRAMCODE is null))) and
  ((REESTRTYPE = new$REESTRTYPE) or ((REESTRTYPE is null) and (new$REESTRTYPE is null))) and
  ((REGIONCLS = new$REGIONCLS) or ((REGIONCLS is null) and (new$REGIONCLS is null))) and
  ((SUBKESR = new$SUBKESR) or ((SUBKESR is null) and (new$SUBKESR is null))) and
  ((SUBSIDYCLS = new$SUBSIDYCLS) or ((SUBSIDYCLS is null) and (new$SUBSIDYCLS is null))) and
  ((TARGETCLS = new$TARGETCLS) or ((TARGETCLS is null) and (new$TARGETCLS is null))) and
  ((TRANSFERTCLS = new$TRANSFERTCLS) or ((TRANSFERTCLS is null) and (new$TRANSFERTCLS is null))) and
  ((VARIANT = new$VARIANT) or ((VARIANT is null) and (new$VARIANT is null))) and
  ((STARTDATE = new$STARTDATE) or ((STARTDATE is null) and (new$STARTDATE is null))) and
  ((DELETEDATE = new$DELETEDATE) or ((DELETEDATE is null) and (new$DELETEDATE is null))) and
  (RECORDINDEX = new$RECORDINDEX)
  ) AND (ROWNUM = 1)      ;
  if ((CNT$1<> 0))
  then
    RaiseException('EX_BUDSTRUCT_UNIQUE');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_ClsCorrValues_BI_500)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CLSCORRVALUES (
    ID,
    RECORDINDEX,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    SUBKESR,
    DIRECTIONCLS,
    VARIANT,
    FACT,
    PAYPROMISECLS,
    BUDALLOCATIONCLS,
    CONTRACTCOSTSCLS,
    INVESTOBJECT,
    FINTYPE,
    MEANSTYPE,
    TARGETCLS,
    REGIONCLS,
    SUBSIDYCLS,
    TRANSFERTCLS,
    PLANDOCTYPE,
    ASSIGNMENTSOURCE,
    ASSIGNMENTKIND,
    KD,
    ANALYTICALGROUPIFS,
    ANALYTICALGROUPKD,
    PROGRAMCODE,
    INNERFINSOURCE,
    REESTRTYPE,
    OKTMO,
    DOCBASE,
    FUNDSSOURCE,
    FINSOURCE,
    DOCTYPE,
    COMMDIRECTIONEXPENCECLS,
    PAYTARGETFUNDS,
    PAYDESTINATION,
    FACIALACC_CLS,
    REGPROJECTRESULT,
    NATIONALPROJECT,
    PAYMENTCODETYPE,
    LINKRECORD,
    ATTACHTO,
    STOREDCONTENT,
    BUDGETREF,
    NOTE,
    EXTID,
    EXTROOTID,
    STARTDATE,
    DELETEDATE,
    CREATEDATE,
    CREATERUSER,
    UPDATEDATE,
    UPDATERUSER
  ) VALUES (
    new$ID,
    new$RECORDINDEX,
    new$KVSR,
    new$KFSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$SUBKESR,
    new$DIRECTIONCLS,
    new$VARIANT,
    new$FACT,
    new$PAYPROMISECLS,
    new$BUDALLOCATIONCLS,
    new$CONTRACTCOSTSCLS,
    new$INVESTOBJECT,
    new$FINTYPE,
    new$MEANSTYPE,
    new$TARGETCLS,
    new$REGIONCLS,
    new$SUBSIDYCLS,
    new$TRANSFERTCLS,
    new$PLANDOCTYPE,
    new$ASSIGNMENTSOURCE,
    new$ASSIGNMENTKIND,
    new$KD,
    new$ANALYTICALGROUPIFS,
    new$ANALYTICALGROUPKD,
    new$PROGRAMCODE,
    new$INNERFINSOURCE,
    new$REESTRTYPE,
    new$OKTMO,
    new$DOCBASE,
    new$FUNDSSOURCE,
    new$FINSOURCE,
    new$DOCTYPE,
    new$COMMDIRECTIONEXPENCECLS,
    new$PAYTARGETFUNDS,
    new$PAYDESTINATION,
    new$FACIALACC_CLS,
    new$REGPROJECTRESULT,
    new$NATIONALPROJECT,
    new$PAYMENTCODETYPE,
    new$LINKRECORD,
    new$ATTACHTO,
    new$STOREDCONTENT,
    new$BUDGETREF,
    new$NOTE,
    new$EXTID,
    new$EXTROOTID,
    new$STARTDATE,
    new$DELETEDATE,
    new$CREATEDATE,
    new$CREATERUSER,
    new$UPDATEDATE,
    new$UPDATERUSER);

-- - - - - - - - - - - - -
-- AI_500 (TR_ClsCorrValues_AI_500)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 98112) and (RecordId = new$ID);

END;
/
-- ALTER TRIGGER tr_clscorrvalues_bu_100
CREATE OR REPLACE TRIGGER TR_CLSCORRVALUES_IU
  INSTEAD OF UPDATE
  ON CLSCORRVALUES
  FOR EACH ROW
DECLARE
  new$ID CLSCORRVALUES.ID%TYPE := :NEW.ID;
  new$RECORDINDEX CLSCORRVALUES.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$KVSR CLSCORRVALUES.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CLSCORRVALUES.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CLSCORRVALUES.KCSR%TYPE := :NEW.KCSR;
  new$KVR CLSCORRVALUES.KVR%TYPE := :NEW.KVR;
  new$KESR CLSCORRVALUES.KESR%TYPE := :NEW.KESR;
  new$SUBKESR CLSCORRVALUES.SUBKESR%TYPE := :NEW.SUBKESR;
  new$DIRECTIONCLS CLSCORRVALUES.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$VARIANT CLSCORRVALUES.VARIANT%TYPE := :NEW.VARIANT;
  new$FACT CLSCORRVALUES.FACT%TYPE := :NEW.FACT;
  new$PAYPROMISECLS CLSCORRVALUES.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$BUDALLOCATIONCLS CLSCORRVALUES.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$CONTRACTCOSTSCLS CLSCORRVALUES.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$INVESTOBJECT CLSCORRVALUES.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$FINTYPE CLSCORRVALUES.FINTYPE%TYPE := :NEW.FINTYPE;
  new$MEANSTYPE CLSCORRVALUES.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$TARGETCLS CLSCORRVALUES.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REGIONCLS CLSCORRVALUES.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$SUBSIDYCLS CLSCORRVALUES.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$TRANSFERTCLS CLSCORRVALUES.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$PLANDOCTYPE CLSCORRVALUES.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$ASSIGNMENTSOURCE CLSCORRVALUES.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$ASSIGNMENTKIND CLSCORRVALUES.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$KD CLSCORRVALUES.KD%TYPE := :NEW.KD;
  new$ANALYTICALGROUPIFS CLSCORRVALUES.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
  new$ANALYTICALGROUPKD CLSCORRVALUES.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
  new$PROGRAMCODE CLSCORRVALUES.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$INNERFINSOURCE CLSCORRVALUES.INNERFINSOURCE%TYPE := :NEW.INNERFINSOURCE;
  new$REESTRTYPE CLSCORRVALUES.REESTRTYPE%TYPE := :NEW.REESTRTYPE;
  new$OKTMO CLSCORRVALUES.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCBASE CLSCORRVALUES.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FUNDSSOURCE CLSCORRVALUES.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$FINSOURCE CLSCORRVALUES.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$DOCTYPE CLSCORRVALUES.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$COMMDIRECTIONEXPENCECLS CLSCORRVALUES.COMMDIRECTIONEXPENCECLS%TYPE := :NEW.COMMDIRECTIONEXPENCECLS;
  new$PAYTARGETFUNDS CLSCORRVALUES.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$PAYDESTINATION CLSCORRVALUES.PAYDESTINATION%TYPE := :NEW.PAYDESTINATION;
  new$FACIALACC_CLS CLSCORRVALUES.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$REGPROJECTRESULT CLSCORRVALUES.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
  new$NATIONALPROJECT CLSCORRVALUES.NATIONALPROJECT%TYPE := :NEW.NATIONALPROJECT;
  new$PAYMENTCODETYPE CLSCORRVALUES.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$LINKRECORD CLSCORRVALUES.LINKRECORD%TYPE := :NEW.LINKRECORD;
  new$ATTACHTO CLSCORRVALUES.ATTACHTO%TYPE := :NEW.ATTACHTO;
  new$STOREDCONTENT CLSCORRVALUES.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
  new$BUDGETREF CLSCORRVALUES.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$NOTE CLSCORRVALUES.NOTE%TYPE := :NEW.NOTE;
  new$EXTID CLSCORRVALUES.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID CLSCORRVALUES.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$STARTDATE CLSCORRVALUES.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE CLSCORRVALUES.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$CREATEDATE CLSCORRVALUES.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER CLSCORRVALUES.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE CLSCORRVALUES.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER CLSCORRVALUES.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
--
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ClsCorrValues_BU_0)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_CLSCORRVALUES_BU_100)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(ID ) INTO CNT$1
  from CLSCORRVALUES
  where
  (        ((ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS) or ((ANALYTICALGROUPIFS is null) and (new$ANALYTICALGROUPIFS is null))) and
  ((ANALYTICALGROUPKD = new$ANALYTICALGROUPKD) or ((ANALYTICALGROUPKD is null) and (new$ANALYTICALGROUPKD is null))) and
  ((ASSIGNMENTKIND = new$ASSIGNMENTKIND) or ((ASSIGNMENTKIND is null) and (new$ASSIGNMENTKIND is null))) and
  ((ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE) or ((ASSIGNMENTSOURCE is null) and (new$ASSIGNMENTSOURCE is null))) and
  ((ATTACHTO = new$ATTACHTO) or ((ATTACHTO is null) and (new$ATTACHTO is null))) and
  ((BUDALLOCATIONCLS = new$BUDALLOCATIONCLS) or ((BUDALLOCATIONCLS is null) and (new$BUDALLOCATIONCLS is null))) and
  (BUDGETREF = new$BUDGETREF) and
  ((COMMDIRECTIONEXPENCECLS = new$COMMDIRECTIONEXPENCECLS) or ((COMMDIRECTIONEXPENCECLS is null) and (new$COMMDIRECTIONEXPENCECLS is null))) and
  ((PayTargetFunds = new$PayTargetFunds) or ((PayTargetFunds is null) and (new$PayTargetFunds is null))) and
  ((CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS) or ((CONTRACTCOSTSCLS is null) and (new$CONTRACTCOSTSCLS is null))) and
  ((DIRECTIONCLS = new$DIRECTIONCLS) or ((DIRECTIONCLS is null) and (new$DIRECTIONCLS is null))) and
  ((DOCBASE = new$DOCBASE) or ((DOCBASE is null) and (new$DOCBASE is null))) and
  ((DOCTYPE = new$DOCTYPE) or ((DOCTYPE is null) and (new$DOCTYPE is null))) and
  ((FACIALACC_CLS = new$FACIALACC_CLS) or ((FACIALACC_CLS is null) and (new$FACIALACC_CLS is null))) and
  ((FACT = new$FACT) or ((FACT is null) and (new$FACT is null))) and
  ((FINSOURCE = new$FINSOURCE) or ((FINSOURCE is null) and (new$FINSOURCE is null))) and
  ((FINTYPE = new$FINTYPE) or ((FINTYPE is null) and (new$FINTYPE is null))) and
  ((FUNDSSOURCE = new$FUNDSSOURCE) or ((FUNDSSOURCE is null) and (new$FUNDSSOURCE is null))) and
  ((INNERFINSOURCE = new$INNERFINSOURCE) or ((INNERFINSOURCE is null) and (new$INNERFINSOURCE is null))) and
  ((INVESTOBJECT = new$INVESTOBJECT) or ((INVESTOBJECT is null) and (new$INVESTOBJECT is null))) and
  ((KCSR = new$KCSR) or ((KCSR is null) and (new$KCSR is null))) and
  ((KD = new$KD) or ((KD is null) and (new$KD is null))) and
  ((KESR = new$KESR) or ((KESR is null) and (new$KESR is null))) and
  ((KFSR = new$KFSR) or ((KFSR is null) and (new$KFSR is null))) and
  ((KVR = new$KVR) or ((KVR is null) and (new$KVR is null))) and
  ((KVSR = new$KVSR) or ((KVSR is null) and (new$KVSR is null))) and
  ((MEANSTYPE = new$MEANSTYPE) or ((MEANSTYPE is null) and (new$MEANSTYPE is null))) and
  ((REGPROJECTRESULT = new$REGPROJECTRESULT) or ((REGPROJECTRESULT is null) and (new$REGPROJECTRESULT is null))) and
  ((NATIONALPROJECT = new$NATIONALPROJECT) or ((NATIONALPROJECT is null) and (new$NATIONALPROJECT is null))) and
  ((OKTMO = new$OKTMO) or ((OKTMO is null) and (new$OKTMO is null))) and
  ((PAYDESTINATION = new$PAYDESTINATION) or ((PAYDESTINATION is null) and (new$PAYDESTINATION is null))) and
  ((PAYPROMISECLS = new$PAYPROMISECLS) or ((PAYPROMISECLS is null) and (new$PAYPROMISECLS is null))) and
  ((PLANDOCTYPE = new$PLANDOCTYPE) or ((PLANDOCTYPE is null) and (new$PLANDOCTYPE is null))) and
  ((PROGRAMCODE = new$PROGRAMCODE) or ((PROGRAMCODE is null) and (new$PROGRAMCODE is null))) and
  ((REESTRTYPE = new$REESTRTYPE) or ((REESTRTYPE is null) and (new$REESTRTYPE is null))) and
  ((REGIONCLS = new$REGIONCLS) or ((REGIONCLS is null) and (new$REGIONCLS is null))) and
  ((SUBKESR = new$SUBKESR) or ((SUBKESR is null) and (new$SUBKESR is null))) and
  ((SUBSIDYCLS = new$SUBSIDYCLS) or ((SUBSIDYCLS is null) and (new$SUBSIDYCLS is null))) and
  ((TARGETCLS = new$TARGETCLS) or ((TARGETCLS is null) and (new$TARGETCLS is null))) and
  ((TRANSFERTCLS = new$TRANSFERTCLS) or ((TRANSFERTCLS is null) and (new$TRANSFERTCLS is null))) and
  ((VARIANT = new$VARIANT) or ((VARIANT is null) and (new$VARIANT is null))) and
  ((STARTDATE = new$STARTDATE) or ((STARTDATE is null) and (new$STARTDATE is null))) and
  ((DELETEDATE = new$DELETEDATE) or ((DELETEDATE is null) and (new$DELETEDATE is null))) and
  (RECORDINDEX = new$RECORDINDEX) and
  (ID <> :old.ID)
  ) AND (ROWNUM = 1)      ;
  if ((CNT$1<> 0))
  then
    RaiseException('EX_BUDSTRUCT_UNIQUE');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CLSCORRVALUES SET
    ID = new$ID,
    RECORDINDEX = new$RECORDINDEX,
    KVSR = new$KVSR,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    SUBKESR = new$SUBKESR,
    DIRECTIONCLS = new$DIRECTIONCLS,
    VARIANT = new$VARIANT,
    FACT = new$FACT,
    PAYPROMISECLS = new$PAYPROMISECLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    INVESTOBJECT = new$INVESTOBJECT,
    FINTYPE = new$FINTYPE,
    MEANSTYPE = new$MEANSTYPE,
    TARGETCLS = new$TARGETCLS,
    REGIONCLS = new$REGIONCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    TRANSFERTCLS = new$TRANSFERTCLS,
    PLANDOCTYPE = new$PLANDOCTYPE,
    ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    KD = new$KD,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD,
    PROGRAMCODE = new$PROGRAMCODE,
    INNERFINSOURCE = new$INNERFINSOURCE,
    REESTRTYPE = new$REESTRTYPE,
    OKTMO = new$OKTMO,
    DOCBASE = new$DOCBASE,
    FUNDSSOURCE = new$FUNDSSOURCE,
    FINSOURCE = new$FINSOURCE,
    DOCTYPE = new$DOCTYPE,
    COMMDIRECTIONEXPENCECLS = new$COMMDIRECTIONEXPENCECLS,
    PAYTARGETFUNDS = new$PAYTARGETFUNDS,
    PAYDESTINATION = new$PAYDESTINATION,
    FACIALACC_CLS = new$FACIALACC_CLS,
    REGPROJECTRESULT = new$REGPROJECTRESULT,
    NATIONALPROJECT = new$NATIONALPROJECT,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    LINKRECORD = new$LINKRECORD,
    ATTACHTO = new$ATTACHTO,
    STOREDCONTENT = new$STOREDCONTENT,
    BUDGETREF = new$BUDGETREF,
    NOTE = new$NOTE,
    EXTID = new$EXTID,
    EXTROOTID = new$EXTROOTID,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    CREATEDATE = new$CREATEDATE,
    CREATERUSER = new$CREATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_ClsCorrValues_AU_500)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (98112, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=98112) and (RecordId=new$ID);

  END IF;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_table_INCOMES32.sql
-- #########################################################
-- #########################################################

ALTER TABLE TB_INCOMES32 ADD (
  RegProjectResult NUMBER(10),
    CHECK((RegProjectResult<=2147483647)AND(RegProjectResult>-2147483648)),
  constraint FK_INCOMES32_RegProjRes foreign key (RegProjectResult) references RegProjectResult(ID)
)
/
CREATE INDEX FK_INCOMES32_RegProjRes ON TB_INCOMES32(RegProjectResult)
/

CREATE OR REPLACE VIEW INCOMES32 (
  ID,
  DOCNUMBER,
  DOCCOUNT,
  IDATE,
  DEBIT,
  CREDIT,
  DOCTYPE,
  INN,
  ORG_REF,
  ACCOUNTINDEX,
  KD,
  SUBKD,
  REGIONCLS,
  GOSNI,
  INCACCOUNT,
  PROGINDEX,
  RECORDINDEX,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  NOTE,
  RECORDINDEX2,
  ELNUM,
  NOTEEX,
  BUHPAYMENTCLS,
  ACCOUNTREF,
  ELPACKETNUM,
  FACIALACC_CLS,
  NDS,
  MEANSTYPE,
  RECORDDATE,
  TOTALREF,
  REQUESTSINDEX,
  KVSR,
  TAXNOTE,
  DOCNUM,
  REALPAYERORG_REF,
  DOCDATE,
  DOCBASE,
  FACT,
  RVERSION,
  KFSR,
  KESR,
  KVR,
  KCSR,
  SUMCOMPLETE,
  ELDOCREF,
  REQUESTSINDEX2,
  FEDERALFUNDSREF,
  BUHOPERATIONCLS,
  IFS,
  IFS_CORR,
  CLSTYPE,
  NDSNOTE,
  DOGNUM,
  SENDERID,
  SENDERRECORDID,
  OKATO,
  ADDOKATO,
  REJECTCLS,
  FUNDSSOURCE,
  DIRECTIONCLS,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  STIMATEID,
  TRANSFERTCLS,
  SUBSIDYCLS,
  FAORGTYPE,
  OKTMO,
  UINCODE,
  FINTYPE,
  INVESTOBJECT,
  CONTRACTCOSTSCLS,
  TARGETCLS,
  REJECTCAUSE,
  STOREDCONTENT,
  INCOMETARGETFUNDS,
  PAYTARGETFUNDS,
  ANALYTICALPARTITION,
  REGPROJECTRESULT)
AS
  SELECT
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    REJECTCAUSE,
    STOREDCONTENT,
    INCOMETARGETFUNDS,
    PAYTARGETFUNDS,
    ANALYTICALPARTITION,
    REGPROJECTRESULT
  FROM TB_INCOMES32
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_ID
  INSTEAD OF DELETE
  ON INCOMES32
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_10 (TR_INCOMES32_BD10)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  delete
  from CurrencyIncomes
  where (id = :old.id);

-- - - - - - - - - - - - -
-- BD_20 (T_INCOMES32_BD_20)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  /*    */
  if (:old.DocType between 1010 and 1019) then
    delete from PayDoc32
    where
      (ProgIndex = :old.ProgIndex)
    and
     (RecordIndex = :old.id);
  end if;

-- - - - - - - - - - - - -
-- BD_500 (TR_INCOMES32_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update QuotesTitle set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- BD_600 (TR_INCOMES32_BD_600)
-- Last update 14.10.2009
-- - - - - - - - - - - - -

    --    
    if (:old.ProgIndex = 41) then
        delete
            from Incomes32
        where
           (ProgIndex=42)and
           (RecordIndex=:old.id);
    end if;

    --  (  )
    if (:old.ProgIndex = 42) then
        delete
            from Incomes32
        where
            (ProgIndex=43)and
            (RecordIndex=:old.id);
    end if;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INCOMES32
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_INCOMES32_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (161, :old.ID, SYSDATE, :old.ProgIndex, :old.DEBIT + :old.CREDIT);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_II
  INSTEAD OF INSERT
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$STOREDCONTENT INCOMES32.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
  new$INCOMETARGETFUNDS INCOMES32.INCOMETARGETFUNDS%TYPE := :NEW.INCOMETARGETFUNDS;
  new$PAYTARGETFUNDS INCOMES32.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$ANALYTICALPARTITION INCOMES32.ANALYTICALPARTITION%TYPE := :NEW.ANALYTICALPARTITION;
  new$REGPROJECTRESULT INCOMES32.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
--
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  CapDocNumber VARCHAR2(20);
  unkKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  Kd_Master NUMBER(10);
  idKD$ NUMBER(10);
  unkVKD$ VARCHAR2(20);
  val_DocCount$ NUMBER(10);
  val_DocType$ NUMBER(10);
  val_Org_Ref$ NUMBER(10);
  val_AccountIndex$ NUMBER(10);
  val_SubKD$ NUMBER(10);
  val_RegionCLS$ NUMBER(10);
  val_GosNI$ NUMBER(10);
  val_IncAccount$ NUMBER(10);
  val_BudgetRef$ NUMBER(10);
  val_MEANSTYPE$ NUMBER(10);
  val_FACIALACC_CLS$ NUMBER(10);
  val_TransfertCls$ NUMBER(10);
  CapAcceptDate$ NUMBER;
  CapReestrNumber$ VARCHAR2(20);
  CapProgIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INCOMES32_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN
    select g_shared.nextval into new$id from dual;
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN
    new$FACIALACC_CLS := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN
    new$Gosni := 0;
  END IF;
  IF (new$Fact IS NULL) THEN
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN
    new$DocBase := 0;
  END IF;
  /* 3 -    */
  IF (new$KD IS NULL) THEN
    new$KD := 0;
  END IF;
  IF (new$ProgIndex IS NULL) THEN
    new$ProgIndex := 3;
  END IF;
  IF (new$MeansType IS NULL) THEN
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN
    new$AccountIndex := 0;
  END IF;
  IF (new$DocType IS NULL) THEN
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS IS NULL) THEN
    new$IFS := 0;
  END IF;
  IF (new$IFS_CORR IS NULL) THEN
    new$Ifs_Corr := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;

  /*  ,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT qt.BudgetRef      INTO new$BudgetRef FROM QuotesTitle qt
      WHERE qt.Id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,     */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT fa.BudgetRef      INTO new$BudgetRef FROM FacialAcc_Cls fa
      WHERE fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0))
  THEN
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;

  IF (new$ProgIndex = 45)
  THEN
    IF (new$IncAccount IS NULL) THEN
      GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
    END IF;
    BEGIN

      /*     */
      SELECT qt.ProgIndex, qt.AcceptDate, qt.IncAccount, qt.ReestrNumber
      INTO CapProgIndex1$, CapAcceptDate$, new$IncAccount, CapReestrNumber$       FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*           / */
    /*  /   after insert */
    IF (CapProgIndex1$ <> 145) THEN
      new$iDate := CapAcceptDate$;
    END IF;
    IF ((CapProgIndex1$ = 145)AND (NOT ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0)OR (new$Credit<0)))) )
    THEN
      new$Idate := CapAcceptDate$;
    END IF;
    /*   -    () */
    IF ((CapProgIndex1$ = 45) AND (CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN
      /*        , *//*    */

      new$FederalFundsRef := new$ID;
      /* if-then */
    END IF;/* if-then*/
  END IF;
  BEGIN
    /*     \*/
    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*    */
  GETTARGETCLS(null, new$transfertcls, null, new$meanstype,
  new$targetcls,new$targetcls);

-- - - - - - - - - - - - -
-- BI_5 (TR_INCOMES_BI_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BI_9 (TR_INCOMES32_BI_VZ)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   IF (new$ProgIndex = 9) THEN
      /*   */
      GetIntConst (9, 1, new$IncAccount);

      BEGIN
        /*      */
        SELECT ACCEPTDATE, BUDGETREF
          INTO new$IDate, new$BudgetRef
          FROM VZ_OFFSET
         WHERE ID = new$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_INCOMES32_BI_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   BEGIN
      SELECT Inn
        INTO new$Inn
        FROM Organizations o
       WHERE (o.ID = new$Org_Ref);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

/*  .    ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT c.BudgetRef
           INTO new$budgetref
           FROM QuotesTitle c
          WHERE c.ID = NEW$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  .  ,     */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO new$budgetref
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      GetIntConst (-1, 3, new$budgetref);
   END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_INCOMES32_BI_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then
    BEGIN
      select q.BuildDate
      into
      new$DocDate        from QuotesTitle q
      where q.id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_70 (TR_INCOMES32_BI_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
               */
         new$FederalFundsRef := new$ID;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_INCOMES32_BI_100)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((not (newKD$  like unkKD$)) and
    (not (newKD$  like unkVKD$))) then
      /*   (    
            ) ,  
         ,   */

      /*       */
      if (new$Debit <> 0) then
        RaiseException('ex_UnknownRedirect');
      END IF;
      BEGIN

        /*      */
        select KD,DocCount,DocType,
        Org_Ref,AccountIndex,SubKD,RegionCLS,GosNI,
        IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,
        TransfertCls
        into
        idKD$,
        val_DocCount$,
        val_DocType$,
        val_Org_Ref$,
        val_AccountIndex$,
        val_SubKD$,
        val_RegionCLS$,
        val_GosNI$,
        val_IncAccount$,
        val_BudgetRef$,
        val_MEANSTYPE$  ,
        val_FACIALACC_CLS$,
        val_TransfertCls$         from incomes32 where id=new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      if (not idKD$ is null) then
        insert into
        /* KD=   (      )
              Debit=0
              redit=-new.credit
              ProgIndex=43
              RecordIndex=new.id
              id    Incomes32*/
        Incomes32(CreaterUser, DocNum,DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS, TransfertCls)
        Values(new$CreaterUser, new$DocNum, val_DocCount$, new$iDate, new$DOCDATE, 0, -new$Credit, val_DocType$,
        val_Org_Ref$, val_AccountIndex$, idKD$, val_SubKD$, val_RegionCLS$, val_GosNI$,
        43,new$Id, val_IncAccount$, val_BudgetRef$, new$Note,val_MEANSTYPE$,val_FACIALACC_CLS$,val_TransfertCls$);

      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_INCOMES32_BI_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       /*       ClsType */
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                /*  -  */
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INCOMES32_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update QuotesTitle set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INCOMES32 (
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    REJECTCAUSE,
    STOREDCONTENT,
    INCOMETARGETFUNDS,
    PAYTARGETFUNDS,
    ANALYTICALPARTITION,
    REGPROJECTRESULT
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$DOCCOUNT,
    new$IDATE,
    new$DEBIT,
    new$CREDIT,
    new$DOCTYPE,
    new$INN,
    new$ORG_REF,
    new$ACCOUNTINDEX,
    new$KD,
    new$SUBKD,
    new$REGIONCLS,
    new$GOSNI,
    new$INCACCOUNT,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$NOTE,
    new$RECORDINDEX2,
    new$ELNUM,
    new$NOTEEX,
    new$BUHPAYMENTCLS,
    new$ACCOUNTREF,
    new$ELPACKETNUM,
    new$FACIALACC_CLS,
    new$NDS,
    new$MEANSTYPE,
    new$RECORDDATE,
    new$TOTALREF,
    new$REQUESTSINDEX,
    new$KVSR,
    new$TAXNOTE,
    new$DOCNUM,
    new$REALPAYERORG_REF,
    new$DOCDATE,
    new$DOCBASE,
    new$FACT,
    new$RVERSION,
    new$KFSR,
    new$KESR,
    new$KVR,
    new$KCSR,
    new$SUMCOMPLETE,
    new$ELDOCREF,
    new$REQUESTSINDEX2,
    new$FEDERALFUNDSREF,
    new$BUHOPERATIONCLS,
    new$IFS,
    new$IFS_CORR,
    new$CLSTYPE,
    new$NDSNOTE,
    new$DOGNUM,
    new$SENDERID,
    new$SENDERRECORDID,
    new$OKATO,
    new$ADDOKATO,
    new$REJECTCLS,
    new$FUNDSSOURCE,
    new$DIRECTIONCLS,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$STIMATEID,
    new$TRANSFERTCLS,
    new$SUBSIDYCLS,
    new$FAORGTYPE,
    new$OKTMO,
    new$UINCODE,
    new$FINTYPE,
    new$INVESTOBJECT,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS,
    new$REJECTCAUSE,
    new$STOREDCONTENT,
    new$INCOMETARGETFUNDS,
    new$PAYTARGETFUNDS,
    new$ANALYTICALPARTITION,
    new$REGPROJECTRESULT);

-- - - - - - - - - - - - -
-- AI_20 (T_INCOMES32_AI_20)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   --     
   if (new$ProgIndex <> 42) then
     BEGIN
       SELECT ProgIndex, DocNumber, AcceptDate
        INTO CapProgIndex, CapDocNumber, CapAcceptDate
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
     EXCEPTION
       WHEN NO_DATA_FOUND THEN NULL;
     END;
   end if;

   --   - ,  
   IF ((CapProgIndex = 145) or (new$ProgIndex=42)) THEN

      If ((new$ProgIndex=42) and (new$DocType between 1010 and 1019) and
         (new$Debit>0) and (new$DOCDATE is not null))
      then
        BEGIN
          select kd into Kd_Master
    From Incomes32 inc
          where inc.id = new$RecordIndex;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;

        if (Kd_Master = new$Kd) then
          CapAcceptDate := new$DOCDATE;
          CapProgIndex  := new$ProgIndex;
          CapDocNumber  := new$DocNum;
        end if;
      end if; --       (         )

      --             
      IF ((CapAcceptDate IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit > 0) OR (new$Credit < 0))) THEN
         --    ( RealPayerOrg_Ref(PayDoc32)=new$RealPayerOrg_Ref(Incomes32))
         INSERT INTO PayDoc32
            (BudgetRef, AccountRef, PayerAttrRef, InputDate,
             Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref, FACIALACC_CLS)
         VALUES (new$BudgetRef, new$AccountRef, new$IncAccount, CapAcceptDate,
             (new$Debit - new$Credit), new$Note, new$ProgIndex, new$id, CapDocNumber, new$TaxNote,
             new$RealPayerOrg_Ref,new$FACIALACC_CLS);
      -- (new$Debit - new$Credit) --- ..      ,    ,
      --             
      END IF;

   END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INCOMES32_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 161) AND (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$STOREDCONTENT INCOMES32.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
  new$INCOMETARGETFUNDS INCOMES32.INCOMETARGETFUNDS%TYPE := :NEW.INCOMETARGETFUNDS;
  new$PAYTARGETFUNDS INCOMES32.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$ANALYTICALPARTITION INCOMES32.ANALYTICALPARTITION%TYPE := :NEW.ANALYTICALPARTITION;
  new$REGPROJECTRESULT INCOMES32.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN
    new$ProgIndex := 3;
  END IF;
  IF (new$KD IS NULL) THEN
    new$KD := 0;
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN
    new$FACIALACC_CLS := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN
    new$AccountIndex := 0;
  END IF;
  IF (new$DocType IS NULL) THEN
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*             
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN
      /*        ,
                     */
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE
      new$FederalFundsRef := NULL;
      /* if-else*/
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/


      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;



      /*           */
      IF (PayDocCount$ = 0)
      THEN
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;

        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);

        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);

          END IF;/* if-then*/
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then
    BEGIN
      select q.BuildDate
      into
      new$DocDate        from QuotesTitle q
      where q.id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  ,
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$,
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);

      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;


    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    STOREDCONTENT = new$STOREDCONTENT,
    INCOMETARGETFUNDS = new$INCOMETARGETFUNDS,
    PAYTARGETFUNDS = new$PAYTARGETFUNDS,
    ANALYTICALPARTITION = new$ANALYTICALPARTITION,
    REGPROJECTRESULT = new$REGPROJECTRESULT
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_table_UnionNotifyDetail.sql
-- #########################################################
-- #########################################################

ALTER TABLE UNIONNOTIFYDETAIL ADD (
  RegProjectResult NUMBER(10),
    CHECK((RegProjectResult<=2147483647)AND(RegProjectResult>-2147483648)),
  constraint FK_UD_RegProjRes foreign key (RegProjectResult) references RegProjectResult(ID)
)
/
CREATE INDEX FK_UD_RegProjRes ON UNIONNOTIFYDETAIL(RegProjectResult)
/
commit work 
/

-- #########################################################
-- #########################################################
-- alter_ClsCorrValues_StoredContent.sql
-- #########################################################
-- #########################################################

/*   14.10 -  ClsCorrValues.StoredContent    */
ALTER TABLE TB_ClsCorrValues DROP (StoredContent)
/

CREATE OR REPLACE VIEW ClsCorrValues (
  ID,
  RECORDINDEX,
  KVSR,
  KFSR,
  KCSR,
  KVR,
  KESR,
  SUBKESR,
  DIRECTIONCLS,
  VARIANT,
  FACT,
  PAYPROMISECLS,
  BUDALLOCATIONCLS,
  CONTRACTCOSTSCLS,
  INVESTOBJECT,
  FINTYPE,
  MEANSTYPE,
  TARGETCLS,
  REGIONCLS,
  SUBSIDYCLS,
  TRANSFERTCLS,
  PLANDOCTYPE,
  ASSIGNMENTSOURCE,
  ASSIGNMENTKIND,
  KD,
  ANALYTICALGROUPIFS,
  ANALYTICALGROUPKD,
  PROGRAMCODE,
  INNERFINSOURCE,
  REESTRTYPE,
  OKTMO,
  DOCBASE,
  FUNDSSOURCE,
  FINSOURCE,
  DOCTYPE,
  COMMDIRECTIONEXPENCECLS,
  PAYTARGETFUNDS,
  PAYDESTINATION,
  FACIALACC_CLS,
  REGPROJECTRESULT,
  NATIONALPROJECT,
  PAYMENTCODETYPE,
  LINKRECORD,
  ATTACHTO,
  BUDGETREF,
  NOTE,
  EXTID,
  EXTROOTID,
  STARTDATE,
  DELETEDATE,
  CREATEDATE,
  CREATERUSER,
  UPDATEDATE,
  UPDATERUSER)
AS
  SELECT
    ID,
    RECORDINDEX,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    SUBKESR,
    DIRECTIONCLS,
    VARIANT,
    FACT,
    PAYPROMISECLS,
    BUDALLOCATIONCLS,
    CONTRACTCOSTSCLS,
    INVESTOBJECT,
    FINTYPE,
    MEANSTYPE,
    TARGETCLS,
    REGIONCLS,
    SUBSIDYCLS,
    TRANSFERTCLS,
    PLANDOCTYPE,
    ASSIGNMENTSOURCE,
    ASSIGNMENTKIND,
    KD,
    ANALYTICALGROUPIFS,
    ANALYTICALGROUPKD,
    PROGRAMCODE,
    INNERFINSOURCE,
    REESTRTYPE,
    OKTMO,
    DOCBASE,
    FUNDSSOURCE,
    FINSOURCE,
    DOCTYPE,
    COMMDIRECTIONEXPENCECLS,
    PAYTARGETFUNDS,
    PAYDESTINATION,
    FACIALACC_CLS,
    REGPROJECTRESULT,
    NATIONALPROJECT,
    PAYMENTCODETYPE,
    LINKRECORD,
    ATTACHTO,
    BUDGETREF,
    NOTE,
    EXTID,
    EXTROOTID,
    STARTDATE,
    DELETEDATE,
    CREATEDATE,
    CREATERUSER,
    UPDATEDATE,
    UPDATERUSER
  FROM TB_ClsCorrValues
/

CREATE OR REPLACE TRIGGER TR_CLSCORRVALUES_ID
  INSTEAD OF DELETE
  ON CLSCORRVALUES
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_CLSCORRVALUES
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_ClsCorrValues_AD_500)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(98112,:old.ID,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_CLSCORRVALUES_II
  INSTEAD OF INSERT
  ON CLSCORRVALUES
  FOR EACH ROW
DECLARE
  new$ID CLSCORRVALUES.ID%TYPE := :NEW.ID;
  new$RECORDINDEX CLSCORRVALUES.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$KVSR CLSCORRVALUES.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CLSCORRVALUES.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CLSCORRVALUES.KCSR%TYPE := :NEW.KCSR;
  new$KVR CLSCORRVALUES.KVR%TYPE := :NEW.KVR;
  new$KESR CLSCORRVALUES.KESR%TYPE := :NEW.KESR;
  new$SUBKESR CLSCORRVALUES.SUBKESR%TYPE := :NEW.SUBKESR;
  new$DIRECTIONCLS CLSCORRVALUES.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$VARIANT CLSCORRVALUES.VARIANT%TYPE := :NEW.VARIANT;
  new$FACT CLSCORRVALUES.FACT%TYPE := :NEW.FACT;
  new$PAYPROMISECLS CLSCORRVALUES.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$BUDALLOCATIONCLS CLSCORRVALUES.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$CONTRACTCOSTSCLS CLSCORRVALUES.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$INVESTOBJECT CLSCORRVALUES.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$FINTYPE CLSCORRVALUES.FINTYPE%TYPE := :NEW.FINTYPE;
  new$MEANSTYPE CLSCORRVALUES.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$TARGETCLS CLSCORRVALUES.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REGIONCLS CLSCORRVALUES.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$SUBSIDYCLS CLSCORRVALUES.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$TRANSFERTCLS CLSCORRVALUES.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$PLANDOCTYPE CLSCORRVALUES.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$ASSIGNMENTSOURCE CLSCORRVALUES.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$ASSIGNMENTKIND CLSCORRVALUES.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$KD CLSCORRVALUES.KD%TYPE := :NEW.KD;
  new$ANALYTICALGROUPIFS CLSCORRVALUES.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
  new$ANALYTICALGROUPKD CLSCORRVALUES.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
  new$PROGRAMCODE CLSCORRVALUES.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$INNERFINSOURCE CLSCORRVALUES.INNERFINSOURCE%TYPE := :NEW.INNERFINSOURCE;
  new$REESTRTYPE CLSCORRVALUES.REESTRTYPE%TYPE := :NEW.REESTRTYPE;
  new$OKTMO CLSCORRVALUES.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCBASE CLSCORRVALUES.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FUNDSSOURCE CLSCORRVALUES.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$FINSOURCE CLSCORRVALUES.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$DOCTYPE CLSCORRVALUES.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$COMMDIRECTIONEXPENCECLS CLSCORRVALUES.COMMDIRECTIONEXPENCECLS%TYPE := :NEW.COMMDIRECTIONEXPENCECLS;
  new$PAYTARGETFUNDS CLSCORRVALUES.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$PAYDESTINATION CLSCORRVALUES.PAYDESTINATION%TYPE := :NEW.PAYDESTINATION;
  new$FACIALACC_CLS CLSCORRVALUES.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$REGPROJECTRESULT CLSCORRVALUES.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
  new$NATIONALPROJECT CLSCORRVALUES.NATIONALPROJECT%TYPE := :NEW.NATIONALPROJECT;
  new$PAYMENTCODETYPE CLSCORRVALUES.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$LINKRECORD CLSCORRVALUES.LINKRECORD%TYPE := :NEW.LINKRECORD;
  new$ATTACHTO CLSCORRVALUES.ATTACHTO%TYPE := :NEW.ATTACHTO;
  new$BUDGETREF CLSCORRVALUES.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$NOTE CLSCORRVALUES.NOTE%TYPE := :NEW.NOTE;
  new$EXTID CLSCORRVALUES.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID CLSCORRVALUES.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$STARTDATE CLSCORRVALUES.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE CLSCORRVALUES.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$CREATEDATE CLSCORRVALUES.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER CLSCORRVALUES.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE CLSCORRVALUES.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER CLSCORRVALUES.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
--
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ClsCorrValues_BI_0)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_CLSCORRVALUES_BI_100)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(ID ) INTO CNT$1
  from CLSCORRVALUES
  where
  (        ((ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS) or ((ANALYTICALGROUPIFS is null) and (new$ANALYTICALGROUPIFS is null))) and
  ((ANALYTICALGROUPKD = new$ANALYTICALGROUPKD) or ((ANALYTICALGROUPKD is null) and (new$ANALYTICALGROUPKD is null))) and
  ((ASSIGNMENTKIND = new$ASSIGNMENTKIND) or ((ASSIGNMENTKIND is null) and (new$ASSIGNMENTKIND is null))) and
  ((ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE) or ((ASSIGNMENTSOURCE is null) and (new$ASSIGNMENTSOURCE is null))) and
  ((ATTACHTO = new$ATTACHTO) or ((ATTACHTO is null) and (new$ATTACHTO is null))) and
  ((BUDALLOCATIONCLS = new$BUDALLOCATIONCLS) or ((BUDALLOCATIONCLS is null) and (new$BUDALLOCATIONCLS is null))) and
  (BUDGETREF = new$BUDGETREF) and
  ((COMMDIRECTIONEXPENCECLS = new$COMMDIRECTIONEXPENCECLS) or ((COMMDIRECTIONEXPENCECLS is null) and (new$COMMDIRECTIONEXPENCECLS is null))) and
  ((PayTargetFunds = new$PayTargetFunds) or ((PayTargetFunds is null) and (new$PayTargetFunds is null))) and
  ((CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS) or ((CONTRACTCOSTSCLS is null) and (new$CONTRACTCOSTSCLS is null))) and
  ((DIRECTIONCLS = new$DIRECTIONCLS) or ((DIRECTIONCLS is null) and (new$DIRECTIONCLS is null))) and
  ((DOCBASE = new$DOCBASE) or ((DOCBASE is null) and (new$DOCBASE is null))) and
  ((DOCTYPE = new$DOCTYPE) or ((DOCTYPE is null) and (new$DOCTYPE is null))) and
  ((FACIALACC_CLS = new$FACIALACC_CLS) or ((FACIALACC_CLS is null) and (new$FACIALACC_CLS is null))) and
  ((FACT = new$FACT) or ((FACT is null) and (new$FACT is null))) and
  ((FINSOURCE = new$FINSOURCE) or ((FINSOURCE is null) and (new$FINSOURCE is null))) and
  ((FINTYPE = new$FINTYPE) or ((FINTYPE is null) and (new$FINTYPE is null))) and
  ((FUNDSSOURCE = new$FUNDSSOURCE) or ((FUNDSSOURCE is null) and (new$FUNDSSOURCE is null))) and
  ((INNERFINSOURCE = new$INNERFINSOURCE) or ((INNERFINSOURCE is null) and (new$INNERFINSOURCE is null))) and
  ((INVESTOBJECT = new$INVESTOBJECT) or ((INVESTOBJECT is null) and (new$INVESTOBJECT is null))) and
  ((KCSR = new$KCSR) or ((KCSR is null) and (new$KCSR is null))) and
  ((KD = new$KD) or ((KD is null) and (new$KD is null))) and
  ((KESR = new$KESR) or ((KESR is null) and (new$KESR is null))) and
  ((KFSR = new$KFSR) or ((KFSR is null) and (new$KFSR is null))) and
  ((KVR = new$KVR) or ((KVR is null) and (new$KVR is null))) and
  ((KVSR = new$KVSR) or ((KVSR is null) and (new$KVSR is null))) and
  ((MEANSTYPE = new$MEANSTYPE) or ((MEANSTYPE is null) and (new$MEANSTYPE is null))) and
  ((REGPROJECTRESULT = new$REGPROJECTRESULT) or ((REGPROJECTRESULT is null) and (new$REGPROJECTRESULT is null))) and
  ((NATIONALPROJECT = new$NATIONALPROJECT) or ((NATIONALPROJECT is null) and (new$NATIONALPROJECT is null))) and
  ((OKTMO = new$OKTMO) or ((OKTMO is null) and (new$OKTMO is null))) and
  ((PAYDESTINATION = new$PAYDESTINATION) or ((PAYDESTINATION is null) and (new$PAYDESTINATION is null))) and
  ((PAYPROMISECLS = new$PAYPROMISECLS) or ((PAYPROMISECLS is null) and (new$PAYPROMISECLS is null))) and
  ((PLANDOCTYPE = new$PLANDOCTYPE) or ((PLANDOCTYPE is null) and (new$PLANDOCTYPE is null))) and
  ((PROGRAMCODE = new$PROGRAMCODE) or ((PROGRAMCODE is null) and (new$PROGRAMCODE is null))) and
  ((REESTRTYPE = new$REESTRTYPE) or ((REESTRTYPE is null) and (new$REESTRTYPE is null))) and
  ((REGIONCLS = new$REGIONCLS) or ((REGIONCLS is null) and (new$REGIONCLS is null))) and
  ((SUBKESR = new$SUBKESR) or ((SUBKESR is null) and (new$SUBKESR is null))) and
  ((SUBSIDYCLS = new$SUBSIDYCLS) or ((SUBSIDYCLS is null) and (new$SUBSIDYCLS is null))) and
  ((TARGETCLS = new$TARGETCLS) or ((TARGETCLS is null) and (new$TARGETCLS is null))) and
  ((TRANSFERTCLS = new$TRANSFERTCLS) or ((TRANSFERTCLS is null) and (new$TRANSFERTCLS is null))) and
  ((VARIANT = new$VARIANT) or ((VARIANT is null) and (new$VARIANT is null))) and
  ((STARTDATE = new$STARTDATE) or ((STARTDATE is null) and (new$STARTDATE is null))) and
  ((DELETEDATE = new$DELETEDATE) or ((DELETEDATE is null) and (new$DELETEDATE is null))) and
  (RECORDINDEX = new$RECORDINDEX)
  ) AND (ROWNUM = 1)      ;
  if ((CNT$1<> 0))
  then
    RaiseException('EX_BUDSTRUCT_UNIQUE');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_ClsCorrValues_BI_500)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CLSCORRVALUES (
    ID,
    RECORDINDEX,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    SUBKESR,
    DIRECTIONCLS,
    VARIANT,
    FACT,
    PAYPROMISECLS,
    BUDALLOCATIONCLS,
    CONTRACTCOSTSCLS,
    INVESTOBJECT,
    FINTYPE,
    MEANSTYPE,
    TARGETCLS,
    REGIONCLS,
    SUBSIDYCLS,
    TRANSFERTCLS,
    PLANDOCTYPE,
    ASSIGNMENTSOURCE,
    ASSIGNMENTKIND,
    KD,
    ANALYTICALGROUPIFS,
    ANALYTICALGROUPKD,
    PROGRAMCODE,
    INNERFINSOURCE,
    REESTRTYPE,
    OKTMO,
    DOCBASE,
    FUNDSSOURCE,
    FINSOURCE,
    DOCTYPE,
    COMMDIRECTIONEXPENCECLS,
    PAYTARGETFUNDS,
    PAYDESTINATION,
    FACIALACC_CLS,
    REGPROJECTRESULT,
    NATIONALPROJECT,
    PAYMENTCODETYPE,
    LINKRECORD,
    ATTACHTO,
    BUDGETREF,
    NOTE,
    EXTID,
    EXTROOTID,
    STARTDATE,
    DELETEDATE,
    CREATEDATE,
    CREATERUSER,
    UPDATEDATE,
    UPDATERUSER
  ) VALUES (
    new$ID,
    new$RECORDINDEX,
    new$KVSR,
    new$KFSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$SUBKESR,
    new$DIRECTIONCLS,
    new$VARIANT,
    new$FACT,
    new$PAYPROMISECLS,
    new$BUDALLOCATIONCLS,
    new$CONTRACTCOSTSCLS,
    new$INVESTOBJECT,
    new$FINTYPE,
    new$MEANSTYPE,
    new$TARGETCLS,
    new$REGIONCLS,
    new$SUBSIDYCLS,
    new$TRANSFERTCLS,
    new$PLANDOCTYPE,
    new$ASSIGNMENTSOURCE,
    new$ASSIGNMENTKIND,
    new$KD,
    new$ANALYTICALGROUPIFS,
    new$ANALYTICALGROUPKD,
    new$PROGRAMCODE,
    new$INNERFINSOURCE,
    new$REESTRTYPE,
    new$OKTMO,
    new$DOCBASE,
    new$FUNDSSOURCE,
    new$FINSOURCE,
    new$DOCTYPE,
    new$COMMDIRECTIONEXPENCECLS,
    new$PAYTARGETFUNDS,
    new$PAYDESTINATION,
    new$FACIALACC_CLS,
    new$REGPROJECTRESULT,
    new$NATIONALPROJECT,
    new$PAYMENTCODETYPE,
    new$LINKRECORD,
    new$ATTACHTO,
    new$BUDGETREF,
    new$NOTE,
    new$EXTID,
    new$EXTROOTID,
    new$STARTDATE,
    new$DELETEDATE,
    new$CREATEDATE,
    new$CREATERUSER,
    new$UPDATEDATE,
    new$UPDATERUSER);

-- - - - - - - - - - - - -
-- AI_500 (TR_ClsCorrValues_AI_500)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 98112) and (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_CLSCORRVALUES_IU
  INSTEAD OF UPDATE
  ON CLSCORRVALUES
  FOR EACH ROW
DECLARE
  new$ID CLSCORRVALUES.ID%TYPE := :NEW.ID;
  new$RECORDINDEX CLSCORRVALUES.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$KVSR CLSCORRVALUES.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CLSCORRVALUES.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CLSCORRVALUES.KCSR%TYPE := :NEW.KCSR;
  new$KVR CLSCORRVALUES.KVR%TYPE := :NEW.KVR;
  new$KESR CLSCORRVALUES.KESR%TYPE := :NEW.KESR;
  new$SUBKESR CLSCORRVALUES.SUBKESR%TYPE := :NEW.SUBKESR;
  new$DIRECTIONCLS CLSCORRVALUES.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$VARIANT CLSCORRVALUES.VARIANT%TYPE := :NEW.VARIANT;
  new$FACT CLSCORRVALUES.FACT%TYPE := :NEW.FACT;
  new$PAYPROMISECLS CLSCORRVALUES.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$BUDALLOCATIONCLS CLSCORRVALUES.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$CONTRACTCOSTSCLS CLSCORRVALUES.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$INVESTOBJECT CLSCORRVALUES.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$FINTYPE CLSCORRVALUES.FINTYPE%TYPE := :NEW.FINTYPE;
  new$MEANSTYPE CLSCORRVALUES.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$TARGETCLS CLSCORRVALUES.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REGIONCLS CLSCORRVALUES.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$SUBSIDYCLS CLSCORRVALUES.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$TRANSFERTCLS CLSCORRVALUES.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$PLANDOCTYPE CLSCORRVALUES.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$ASSIGNMENTSOURCE CLSCORRVALUES.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$ASSIGNMENTKIND CLSCORRVALUES.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$KD CLSCORRVALUES.KD%TYPE := :NEW.KD;
  new$ANALYTICALGROUPIFS CLSCORRVALUES.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
  new$ANALYTICALGROUPKD CLSCORRVALUES.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
  new$PROGRAMCODE CLSCORRVALUES.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$INNERFINSOURCE CLSCORRVALUES.INNERFINSOURCE%TYPE := :NEW.INNERFINSOURCE;
  new$REESTRTYPE CLSCORRVALUES.REESTRTYPE%TYPE := :NEW.REESTRTYPE;
  new$OKTMO CLSCORRVALUES.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCBASE CLSCORRVALUES.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FUNDSSOURCE CLSCORRVALUES.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$FINSOURCE CLSCORRVALUES.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$DOCTYPE CLSCORRVALUES.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$COMMDIRECTIONEXPENCECLS CLSCORRVALUES.COMMDIRECTIONEXPENCECLS%TYPE := :NEW.COMMDIRECTIONEXPENCECLS;
  new$PAYTARGETFUNDS CLSCORRVALUES.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$PAYDESTINATION CLSCORRVALUES.PAYDESTINATION%TYPE := :NEW.PAYDESTINATION;
  new$FACIALACC_CLS CLSCORRVALUES.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$REGPROJECTRESULT CLSCORRVALUES.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
  new$NATIONALPROJECT CLSCORRVALUES.NATIONALPROJECT%TYPE := :NEW.NATIONALPROJECT;
  new$PAYMENTCODETYPE CLSCORRVALUES.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$LINKRECORD CLSCORRVALUES.LINKRECORD%TYPE := :NEW.LINKRECORD;
  new$ATTACHTO CLSCORRVALUES.ATTACHTO%TYPE := :NEW.ATTACHTO;
  new$BUDGETREF CLSCORRVALUES.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$NOTE CLSCORRVALUES.NOTE%TYPE := :NEW.NOTE;
  new$EXTID CLSCORRVALUES.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID CLSCORRVALUES.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$STARTDATE CLSCORRVALUES.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE CLSCORRVALUES.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$CREATEDATE CLSCORRVALUES.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER CLSCORRVALUES.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE CLSCORRVALUES.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER CLSCORRVALUES.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
--
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ClsCorrValues_BU_0)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_CLSCORRVALUES_BU_100)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(ID ) INTO CNT$1
  from CLSCORRVALUES
  where
  (        ((ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS) or ((ANALYTICALGROUPIFS is null) and (new$ANALYTICALGROUPIFS is null))) and
  ((ANALYTICALGROUPKD = new$ANALYTICALGROUPKD) or ((ANALYTICALGROUPKD is null) and (new$ANALYTICALGROUPKD is null))) and
  ((ASSIGNMENTKIND = new$ASSIGNMENTKIND) or ((ASSIGNMENTKIND is null) and (new$ASSIGNMENTKIND is null))) and
  ((ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE) or ((ASSIGNMENTSOURCE is null) and (new$ASSIGNMENTSOURCE is null))) and
  ((ATTACHTO = new$ATTACHTO) or ((ATTACHTO is null) and (new$ATTACHTO is null))) and
  ((BUDALLOCATIONCLS = new$BUDALLOCATIONCLS) or ((BUDALLOCATIONCLS is null) and (new$BUDALLOCATIONCLS is null))) and
  (BUDGETREF = new$BUDGETREF) and
  ((COMMDIRECTIONEXPENCECLS = new$COMMDIRECTIONEXPENCECLS) or ((COMMDIRECTIONEXPENCECLS is null) and (new$COMMDIRECTIONEXPENCECLS is null))) and
  ((PayTargetFunds = new$PayTargetFunds) or ((PayTargetFunds is null) and (new$PayTargetFunds is null))) and
  ((CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS) or ((CONTRACTCOSTSCLS is null) and (new$CONTRACTCOSTSCLS is null))) and
  ((DIRECTIONCLS = new$DIRECTIONCLS) or ((DIRECTIONCLS is null) and (new$DIRECTIONCLS is null))) and
  ((DOCBASE = new$DOCBASE) or ((DOCBASE is null) and (new$DOCBASE is null))) and
  ((DOCTYPE = new$DOCTYPE) or ((DOCTYPE is null) and (new$DOCTYPE is null))) and
  ((FACIALACC_CLS = new$FACIALACC_CLS) or ((FACIALACC_CLS is null) and (new$FACIALACC_CLS is null))) and
  ((FACT = new$FACT) or ((FACT is null) and (new$FACT is null))) and
  ((FINSOURCE = new$FINSOURCE) or ((FINSOURCE is null) and (new$FINSOURCE is null))) and
  ((FINTYPE = new$FINTYPE) or ((FINTYPE is null) and (new$FINTYPE is null))) and
  ((FUNDSSOURCE = new$FUNDSSOURCE) or ((FUNDSSOURCE is null) and (new$FUNDSSOURCE is null))) and
  ((INNERFINSOURCE = new$INNERFINSOURCE) or ((INNERFINSOURCE is null) and (new$INNERFINSOURCE is null))) and
  ((INVESTOBJECT = new$INVESTOBJECT) or ((INVESTOBJECT is null) and (new$INVESTOBJECT is null))) and
  ((KCSR = new$KCSR) or ((KCSR is null) and (new$KCSR is null))) and
  ((KD = new$KD) or ((KD is null) and (new$KD is null))) and
  ((KESR = new$KESR) or ((KESR is null) and (new$KESR is null))) and
  ((KFSR = new$KFSR) or ((KFSR is null) and (new$KFSR is null))) and
  ((KVR = new$KVR) or ((KVR is null) and (new$KVR is null))) and
  ((KVSR = new$KVSR) or ((KVSR is null) and (new$KVSR is null))) and
  ((MEANSTYPE = new$MEANSTYPE) or ((MEANSTYPE is null) and (new$MEANSTYPE is null))) and
  ((REGPROJECTRESULT = new$REGPROJECTRESULT) or ((REGPROJECTRESULT is null) and (new$REGPROJECTRESULT is null))) and
  ((NATIONALPROJECT = new$NATIONALPROJECT) or ((NATIONALPROJECT is null) and (new$NATIONALPROJECT is null))) and
  ((OKTMO = new$OKTMO) or ((OKTMO is null) and (new$OKTMO is null))) and
  ((PAYDESTINATION = new$PAYDESTINATION) or ((PAYDESTINATION is null) and (new$PAYDESTINATION is null))) and
  ((PAYPROMISECLS = new$PAYPROMISECLS) or ((PAYPROMISECLS is null) and (new$PAYPROMISECLS is null))) and
  ((PLANDOCTYPE = new$PLANDOCTYPE) or ((PLANDOCTYPE is null) and (new$PLANDOCTYPE is null))) and
  ((PROGRAMCODE = new$PROGRAMCODE) or ((PROGRAMCODE is null) and (new$PROGRAMCODE is null))) and
  ((REESTRTYPE = new$REESTRTYPE) or ((REESTRTYPE is null) and (new$REESTRTYPE is null))) and
  ((REGIONCLS = new$REGIONCLS) or ((REGIONCLS is null) and (new$REGIONCLS is null))) and
  ((SUBKESR = new$SUBKESR) or ((SUBKESR is null) and (new$SUBKESR is null))) and
  ((SUBSIDYCLS = new$SUBSIDYCLS) or ((SUBSIDYCLS is null) and (new$SUBSIDYCLS is null))) and
  ((TARGETCLS = new$TARGETCLS) or ((TARGETCLS is null) and (new$TARGETCLS is null))) and
  ((TRANSFERTCLS = new$TRANSFERTCLS) or ((TRANSFERTCLS is null) and (new$TRANSFERTCLS is null))) and
  ((VARIANT = new$VARIANT) or ((VARIANT is null) and (new$VARIANT is null))) and
  ((STARTDATE = new$STARTDATE) or ((STARTDATE is null) and (new$STARTDATE is null))) and
  ((DELETEDATE = new$DELETEDATE) or ((DELETEDATE is null) and (new$DELETEDATE is null))) and
  (RECORDINDEX = new$RECORDINDEX) and
  (ID <> :old.ID)
  ) AND (ROWNUM = 1)      ;
  if ((CNT$1<> 0))
  then
    RaiseException('EX_BUDSTRUCT_UNIQUE');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CLSCORRVALUES SET
    ID = new$ID,
    RECORDINDEX = new$RECORDINDEX,
    KVSR = new$KVSR,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    SUBKESR = new$SUBKESR,
    DIRECTIONCLS = new$DIRECTIONCLS,
    VARIANT = new$VARIANT,
    FACT = new$FACT,
    PAYPROMISECLS = new$PAYPROMISECLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    INVESTOBJECT = new$INVESTOBJECT,
    FINTYPE = new$FINTYPE,
    MEANSTYPE = new$MEANSTYPE,
    TARGETCLS = new$TARGETCLS,
    REGIONCLS = new$REGIONCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    TRANSFERTCLS = new$TRANSFERTCLS,
    PLANDOCTYPE = new$PLANDOCTYPE,
    ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    KD = new$KD,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD,
    PROGRAMCODE = new$PROGRAMCODE,
    INNERFINSOURCE = new$INNERFINSOURCE,
    REESTRTYPE = new$REESTRTYPE,
    OKTMO = new$OKTMO,
    DOCBASE = new$DOCBASE,
    FUNDSSOURCE = new$FUNDSSOURCE,
    FINSOURCE = new$FINSOURCE,
    DOCTYPE = new$DOCTYPE,
    COMMDIRECTIONEXPENCECLS = new$COMMDIRECTIONEXPENCECLS,
    PAYTARGETFUNDS = new$PAYTARGETFUNDS,
    PAYDESTINATION = new$PAYDESTINATION,
    FACIALACC_CLS = new$FACIALACC_CLS,
    REGPROJECTRESULT = new$REGPROJECTRESULT,
    NATIONALPROJECT = new$NATIONALPROJECT,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    LINKRECORD = new$LINKRECORD,
    ATTACHTO = new$ATTACHTO,
    BUDGETREF = new$BUDGETREF,
    NOTE = new$NOTE,
    EXTID = new$EXTID,
    EXTROOTID = new$EXTROOTID,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    CREATEDATE = new$CREATEDATE,
    CREATERUSER = new$CREATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_ClsCorrValues_AU_500)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (98112, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=98112) and (RecordId=new$ID);

  END IF;

END;
/
commit work 
/
ALTER TABLE TB_ClsCorrValues ADD (
  StoredContent VARCHAR2(4000)
)
/

CREATE OR REPLACE VIEW ClsCorrValues (
  ID,
  RECORDINDEX,
  KVSR,
  KFSR,
  KCSR,
  KVR,
  KESR,
  SUBKESR,
  DIRECTIONCLS,
  VARIANT,
  FACT,
  PAYPROMISECLS,
  BUDALLOCATIONCLS,
  CONTRACTCOSTSCLS,
  INVESTOBJECT,
  FINTYPE,
  MEANSTYPE,
  TARGETCLS,
  REGIONCLS,
  SUBSIDYCLS,
  TRANSFERTCLS,
  PLANDOCTYPE,
  ASSIGNMENTSOURCE,
  ASSIGNMENTKIND,
  KD,
  ANALYTICALGROUPIFS,
  ANALYTICALGROUPKD,
  PROGRAMCODE,
  INNERFINSOURCE,
  REESTRTYPE,
  OKTMO,
  DOCBASE,
  FUNDSSOURCE,
  FINSOURCE,
  DOCTYPE,
  COMMDIRECTIONEXPENCECLS,
  PAYTARGETFUNDS,
  PAYDESTINATION,
  FACIALACC_CLS,
  REGPROJECTRESULT,
  NATIONALPROJECT,
  PAYMENTCODETYPE,
  LINKRECORD,
  ATTACHTO,
  BUDGETREF,
  NOTE,
  EXTID,
  EXTROOTID,
  STARTDATE,
  DELETEDATE,
  CREATEDATE,
  CREATERUSER,
  UPDATEDATE,
  UPDATERUSER,
  STOREDCONTENT)
AS
  SELECT
    ID,
    RECORDINDEX,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    SUBKESR,
    DIRECTIONCLS,
    VARIANT,
    FACT,
    PAYPROMISECLS,
    BUDALLOCATIONCLS,
    CONTRACTCOSTSCLS,
    INVESTOBJECT,
    FINTYPE,
    MEANSTYPE,
    TARGETCLS,
    REGIONCLS,
    SUBSIDYCLS,
    TRANSFERTCLS,
    PLANDOCTYPE,
    ASSIGNMENTSOURCE,
    ASSIGNMENTKIND,
    KD,
    ANALYTICALGROUPIFS,
    ANALYTICALGROUPKD,
    PROGRAMCODE,
    INNERFINSOURCE,
    REESTRTYPE,
    OKTMO,
    DOCBASE,
    FUNDSSOURCE,
    FINSOURCE,
    DOCTYPE,
    COMMDIRECTIONEXPENCECLS,
    PAYTARGETFUNDS,
    PAYDESTINATION,
    FACIALACC_CLS,
    REGPROJECTRESULT,
    NATIONALPROJECT,
    PAYMENTCODETYPE,
    LINKRECORD,
    ATTACHTO,
    BUDGETREF,
    NOTE,
    EXTID,
    EXTROOTID,
    STARTDATE,
    DELETEDATE,
    CREATEDATE,
    CREATERUSER,
    UPDATEDATE,
    UPDATERUSER,
    STOREDCONTENT
  FROM TB_ClsCorrValues
/

CREATE OR REPLACE TRIGGER TR_CLSCORRVALUES_ID
  INSTEAD OF DELETE
  ON CLSCORRVALUES
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_CLSCORRVALUES
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_ClsCorrValues_AD_500)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(98112,:old.ID,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_CLSCORRVALUES_II
  INSTEAD OF INSERT
  ON CLSCORRVALUES
  FOR EACH ROW
DECLARE
  new$ID CLSCORRVALUES.ID%TYPE := :NEW.ID;
  new$RECORDINDEX CLSCORRVALUES.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$KVSR CLSCORRVALUES.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CLSCORRVALUES.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CLSCORRVALUES.KCSR%TYPE := :NEW.KCSR;
  new$KVR CLSCORRVALUES.KVR%TYPE := :NEW.KVR;
  new$KESR CLSCORRVALUES.KESR%TYPE := :NEW.KESR;
  new$SUBKESR CLSCORRVALUES.SUBKESR%TYPE := :NEW.SUBKESR;
  new$DIRECTIONCLS CLSCORRVALUES.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$VARIANT CLSCORRVALUES.VARIANT%TYPE := :NEW.VARIANT;
  new$FACT CLSCORRVALUES.FACT%TYPE := :NEW.FACT;
  new$PAYPROMISECLS CLSCORRVALUES.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$BUDALLOCATIONCLS CLSCORRVALUES.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$CONTRACTCOSTSCLS CLSCORRVALUES.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$INVESTOBJECT CLSCORRVALUES.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$FINTYPE CLSCORRVALUES.FINTYPE%TYPE := :NEW.FINTYPE;
  new$MEANSTYPE CLSCORRVALUES.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$TARGETCLS CLSCORRVALUES.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REGIONCLS CLSCORRVALUES.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$SUBSIDYCLS CLSCORRVALUES.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$TRANSFERTCLS CLSCORRVALUES.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$PLANDOCTYPE CLSCORRVALUES.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$ASSIGNMENTSOURCE CLSCORRVALUES.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$ASSIGNMENTKIND CLSCORRVALUES.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$KD CLSCORRVALUES.KD%TYPE := :NEW.KD;
  new$ANALYTICALGROUPIFS CLSCORRVALUES.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
  new$ANALYTICALGROUPKD CLSCORRVALUES.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
  new$PROGRAMCODE CLSCORRVALUES.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$INNERFINSOURCE CLSCORRVALUES.INNERFINSOURCE%TYPE := :NEW.INNERFINSOURCE;
  new$REESTRTYPE CLSCORRVALUES.REESTRTYPE%TYPE := :NEW.REESTRTYPE;
  new$OKTMO CLSCORRVALUES.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCBASE CLSCORRVALUES.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FUNDSSOURCE CLSCORRVALUES.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$FINSOURCE CLSCORRVALUES.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$DOCTYPE CLSCORRVALUES.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$COMMDIRECTIONEXPENCECLS CLSCORRVALUES.COMMDIRECTIONEXPENCECLS%TYPE := :NEW.COMMDIRECTIONEXPENCECLS;
  new$PAYTARGETFUNDS CLSCORRVALUES.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$PAYDESTINATION CLSCORRVALUES.PAYDESTINATION%TYPE := :NEW.PAYDESTINATION;
  new$FACIALACC_CLS CLSCORRVALUES.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$REGPROJECTRESULT CLSCORRVALUES.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
  new$NATIONALPROJECT CLSCORRVALUES.NATIONALPROJECT%TYPE := :NEW.NATIONALPROJECT;
  new$PAYMENTCODETYPE CLSCORRVALUES.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$LINKRECORD CLSCORRVALUES.LINKRECORD%TYPE := :NEW.LINKRECORD;
  new$ATTACHTO CLSCORRVALUES.ATTACHTO%TYPE := :NEW.ATTACHTO;
  new$BUDGETREF CLSCORRVALUES.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$NOTE CLSCORRVALUES.NOTE%TYPE := :NEW.NOTE;
  new$EXTID CLSCORRVALUES.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID CLSCORRVALUES.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$STARTDATE CLSCORRVALUES.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE CLSCORRVALUES.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$CREATEDATE CLSCORRVALUES.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER CLSCORRVALUES.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE CLSCORRVALUES.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER CLSCORRVALUES.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$STOREDCONTENT CLSCORRVALUES.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ClsCorrValues_BI_0)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_CLSCORRVALUES_BI_100)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(ID ) INTO CNT$1
  from CLSCORRVALUES
  where
  (        ((ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS) or ((ANALYTICALGROUPIFS is null) and (new$ANALYTICALGROUPIFS is null))) and
  ((ANALYTICALGROUPKD = new$ANALYTICALGROUPKD) or ((ANALYTICALGROUPKD is null) and (new$ANALYTICALGROUPKD is null))) and
  ((ASSIGNMENTKIND = new$ASSIGNMENTKIND) or ((ASSIGNMENTKIND is null) and (new$ASSIGNMENTKIND is null))) and
  ((ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE) or ((ASSIGNMENTSOURCE is null) and (new$ASSIGNMENTSOURCE is null))) and
  ((ATTACHTO = new$ATTACHTO) or ((ATTACHTO is null) and (new$ATTACHTO is null))) and
  ((BUDALLOCATIONCLS = new$BUDALLOCATIONCLS) or ((BUDALLOCATIONCLS is null) and (new$BUDALLOCATIONCLS is null))) and
  (BUDGETREF = new$BUDGETREF) and
  ((COMMDIRECTIONEXPENCECLS = new$COMMDIRECTIONEXPENCECLS) or ((COMMDIRECTIONEXPENCECLS is null) and (new$COMMDIRECTIONEXPENCECLS is null))) and
  ((PayTargetFunds = new$PayTargetFunds) or ((PayTargetFunds is null) and (new$PayTargetFunds is null))) and
  ((CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS) or ((CONTRACTCOSTSCLS is null) and (new$CONTRACTCOSTSCLS is null))) and
  ((DIRECTIONCLS = new$DIRECTIONCLS) or ((DIRECTIONCLS is null) and (new$DIRECTIONCLS is null))) and
  ((DOCBASE = new$DOCBASE) or ((DOCBASE is null) and (new$DOCBASE is null))) and
  ((DOCTYPE = new$DOCTYPE) or ((DOCTYPE is null) and (new$DOCTYPE is null))) and
  ((FACIALACC_CLS = new$FACIALACC_CLS) or ((FACIALACC_CLS is null) and (new$FACIALACC_CLS is null))) and
  ((FACT = new$FACT) or ((FACT is null) and (new$FACT is null))) and
  ((FINSOURCE = new$FINSOURCE) or ((FINSOURCE is null) and (new$FINSOURCE is null))) and
  ((FINTYPE = new$FINTYPE) or ((FINTYPE is null) and (new$FINTYPE is null))) and
  ((FUNDSSOURCE = new$FUNDSSOURCE) or ((FUNDSSOURCE is null) and (new$FUNDSSOURCE is null))) and
  ((INNERFINSOURCE = new$INNERFINSOURCE) or ((INNERFINSOURCE is null) and (new$INNERFINSOURCE is null))) and
  ((INVESTOBJECT = new$INVESTOBJECT) or ((INVESTOBJECT is null) and (new$INVESTOBJECT is null))) and
  ((KCSR = new$KCSR) or ((KCSR is null) and (new$KCSR is null))) and
  ((KD = new$KD) or ((KD is null) and (new$KD is null))) and
  ((KESR = new$KESR) or ((KESR is null) and (new$KESR is null))) and
  ((KFSR = new$KFSR) or ((KFSR is null) and (new$KFSR is null))) and
  ((KVR = new$KVR) or ((KVR is null) and (new$KVR is null))) and
  ((KVSR = new$KVSR) or ((KVSR is null) and (new$KVSR is null))) and
  ((MEANSTYPE = new$MEANSTYPE) or ((MEANSTYPE is null) and (new$MEANSTYPE is null))) and
  ((REGPROJECTRESULT = new$REGPROJECTRESULT) or ((REGPROJECTRESULT is null) and (new$REGPROJECTRESULT is null))) and
  ((NATIONALPROJECT = new$NATIONALPROJECT) or ((NATIONALPROJECT is null) and (new$NATIONALPROJECT is null))) and
  ((OKTMO = new$OKTMO) or ((OKTMO is null) and (new$OKTMO is null))) and
  ((PAYDESTINATION = new$PAYDESTINATION) or ((PAYDESTINATION is null) and (new$PAYDESTINATION is null))) and
  ((PAYPROMISECLS = new$PAYPROMISECLS) or ((PAYPROMISECLS is null) and (new$PAYPROMISECLS is null))) and
  ((PLANDOCTYPE = new$PLANDOCTYPE) or ((PLANDOCTYPE is null) and (new$PLANDOCTYPE is null))) and
  ((PROGRAMCODE = new$PROGRAMCODE) or ((PROGRAMCODE is null) and (new$PROGRAMCODE is null))) and
  ((REESTRTYPE = new$REESTRTYPE) or ((REESTRTYPE is null) and (new$REESTRTYPE is null))) and
  ((REGIONCLS = new$REGIONCLS) or ((REGIONCLS is null) and (new$REGIONCLS is null))) and
  ((SUBKESR = new$SUBKESR) or ((SUBKESR is null) and (new$SUBKESR is null))) and
  ((SUBSIDYCLS = new$SUBSIDYCLS) or ((SUBSIDYCLS is null) and (new$SUBSIDYCLS is null))) and
  ((TARGETCLS = new$TARGETCLS) or ((TARGETCLS is null) and (new$TARGETCLS is null))) and
  ((TRANSFERTCLS = new$TRANSFERTCLS) or ((TRANSFERTCLS is null) and (new$TRANSFERTCLS is null))) and
  ((VARIANT = new$VARIANT) or ((VARIANT is null) and (new$VARIANT is null))) and
  ((STARTDATE = new$STARTDATE) or ((STARTDATE is null) and (new$STARTDATE is null))) and
  ((DELETEDATE = new$DELETEDATE) or ((DELETEDATE is null) and (new$DELETEDATE is null))) and
  (RECORDINDEX = new$RECORDINDEX)
  ) AND (ROWNUM = 1)      ;
  if ((CNT$1<> 0))
  then
    RaiseException('EX_BUDSTRUCT_UNIQUE');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_ClsCorrValues_BI_500)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CLSCORRVALUES (
    ID,
    RECORDINDEX,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    SUBKESR,
    DIRECTIONCLS,
    VARIANT,
    FACT,
    PAYPROMISECLS,
    BUDALLOCATIONCLS,
    CONTRACTCOSTSCLS,
    INVESTOBJECT,
    FINTYPE,
    MEANSTYPE,
    TARGETCLS,
    REGIONCLS,
    SUBSIDYCLS,
    TRANSFERTCLS,
    PLANDOCTYPE,
    ASSIGNMENTSOURCE,
    ASSIGNMENTKIND,
    KD,
    ANALYTICALGROUPIFS,
    ANALYTICALGROUPKD,
    PROGRAMCODE,
    INNERFINSOURCE,
    REESTRTYPE,
    OKTMO,
    DOCBASE,
    FUNDSSOURCE,
    FINSOURCE,
    DOCTYPE,
    COMMDIRECTIONEXPENCECLS,
    PAYTARGETFUNDS,
    PAYDESTINATION,
    FACIALACC_CLS,
    REGPROJECTRESULT,
    NATIONALPROJECT,
    PAYMENTCODETYPE,
    LINKRECORD,
    ATTACHTO,
    BUDGETREF,
    NOTE,
    EXTID,
    EXTROOTID,
    STARTDATE,
    DELETEDATE,
    CREATEDATE,
    CREATERUSER,
    UPDATEDATE,
    UPDATERUSER,
    STOREDCONTENT
  ) VALUES (
    new$ID,
    new$RECORDINDEX,
    new$KVSR,
    new$KFSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$SUBKESR,
    new$DIRECTIONCLS,
    new$VARIANT,
    new$FACT,
    new$PAYPROMISECLS,
    new$BUDALLOCATIONCLS,
    new$CONTRACTCOSTSCLS,
    new$INVESTOBJECT,
    new$FINTYPE,
    new$MEANSTYPE,
    new$TARGETCLS,
    new$REGIONCLS,
    new$SUBSIDYCLS,
    new$TRANSFERTCLS,
    new$PLANDOCTYPE,
    new$ASSIGNMENTSOURCE,
    new$ASSIGNMENTKIND,
    new$KD,
    new$ANALYTICALGROUPIFS,
    new$ANALYTICALGROUPKD,
    new$PROGRAMCODE,
    new$INNERFINSOURCE,
    new$REESTRTYPE,
    new$OKTMO,
    new$DOCBASE,
    new$FUNDSSOURCE,
    new$FINSOURCE,
    new$DOCTYPE,
    new$COMMDIRECTIONEXPENCECLS,
    new$PAYTARGETFUNDS,
    new$PAYDESTINATION,
    new$FACIALACC_CLS,
    new$REGPROJECTRESULT,
    new$NATIONALPROJECT,
    new$PAYMENTCODETYPE,
    new$LINKRECORD,
    new$ATTACHTO,
    new$BUDGETREF,
    new$NOTE,
    new$EXTID,
    new$EXTROOTID,
    new$STARTDATE,
    new$DELETEDATE,
    new$CREATEDATE,
    new$CREATERUSER,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$STOREDCONTENT);

-- - - - - - - - - - - - -
-- AI_500 (TR_ClsCorrValues_AI_500)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 98112) and (RecordId = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_CLSCORRVALUES_IU
  INSTEAD OF UPDATE
  ON CLSCORRVALUES
  FOR EACH ROW
DECLARE
  new$ID CLSCORRVALUES.ID%TYPE := :NEW.ID;
  new$RECORDINDEX CLSCORRVALUES.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$KVSR CLSCORRVALUES.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CLSCORRVALUES.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CLSCORRVALUES.KCSR%TYPE := :NEW.KCSR;
  new$KVR CLSCORRVALUES.KVR%TYPE := :NEW.KVR;
  new$KESR CLSCORRVALUES.KESR%TYPE := :NEW.KESR;
  new$SUBKESR CLSCORRVALUES.SUBKESR%TYPE := :NEW.SUBKESR;
  new$DIRECTIONCLS CLSCORRVALUES.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$VARIANT CLSCORRVALUES.VARIANT%TYPE := :NEW.VARIANT;
  new$FACT CLSCORRVALUES.FACT%TYPE := :NEW.FACT;
  new$PAYPROMISECLS CLSCORRVALUES.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$BUDALLOCATIONCLS CLSCORRVALUES.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$CONTRACTCOSTSCLS CLSCORRVALUES.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$INVESTOBJECT CLSCORRVALUES.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$FINTYPE CLSCORRVALUES.FINTYPE%TYPE := :NEW.FINTYPE;
  new$MEANSTYPE CLSCORRVALUES.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$TARGETCLS CLSCORRVALUES.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REGIONCLS CLSCORRVALUES.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$SUBSIDYCLS CLSCORRVALUES.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$TRANSFERTCLS CLSCORRVALUES.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$PLANDOCTYPE CLSCORRVALUES.PLANDOCTYPE%TYPE := :NEW.PLANDOCTYPE;
  new$ASSIGNMENTSOURCE CLSCORRVALUES.ASSIGNMENTSOURCE%TYPE := :NEW.ASSIGNMENTSOURCE;
  new$ASSIGNMENTKIND CLSCORRVALUES.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$KD CLSCORRVALUES.KD%TYPE := :NEW.KD;
  new$ANALYTICALGROUPIFS CLSCORRVALUES.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
  new$ANALYTICALGROUPKD CLSCORRVALUES.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
  new$PROGRAMCODE CLSCORRVALUES.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$INNERFINSOURCE CLSCORRVALUES.INNERFINSOURCE%TYPE := :NEW.INNERFINSOURCE;
  new$REESTRTYPE CLSCORRVALUES.REESTRTYPE%TYPE := :NEW.REESTRTYPE;
  new$OKTMO CLSCORRVALUES.OKTMO%TYPE := :NEW.OKTMO;
  new$DOCBASE CLSCORRVALUES.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FUNDSSOURCE CLSCORRVALUES.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$FINSOURCE CLSCORRVALUES.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$DOCTYPE CLSCORRVALUES.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$COMMDIRECTIONEXPENCECLS CLSCORRVALUES.COMMDIRECTIONEXPENCECLS%TYPE := :NEW.COMMDIRECTIONEXPENCECLS;
  new$PAYTARGETFUNDS CLSCORRVALUES.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$PAYDESTINATION CLSCORRVALUES.PAYDESTINATION%TYPE := :NEW.PAYDESTINATION;
  new$FACIALACC_CLS CLSCORRVALUES.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$REGPROJECTRESULT CLSCORRVALUES.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
  new$NATIONALPROJECT CLSCORRVALUES.NATIONALPROJECT%TYPE := :NEW.NATIONALPROJECT;
  new$PAYMENTCODETYPE CLSCORRVALUES.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$LINKRECORD CLSCORRVALUES.LINKRECORD%TYPE := :NEW.LINKRECORD;
  new$ATTACHTO CLSCORRVALUES.ATTACHTO%TYPE := :NEW.ATTACHTO;
  new$BUDGETREF CLSCORRVALUES.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$NOTE CLSCORRVALUES.NOTE%TYPE := :NEW.NOTE;
  new$EXTID CLSCORRVALUES.EXTID%TYPE := :NEW.EXTID;
  new$EXTROOTID CLSCORRVALUES.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$STARTDATE CLSCORRVALUES.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE CLSCORRVALUES.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$CREATEDATE CLSCORRVALUES.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER CLSCORRVALUES.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATEDATE CLSCORRVALUES.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER CLSCORRVALUES.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$STOREDCONTENT CLSCORRVALUES.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_ClsCorrValues_BU_0)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$BudgetRef is null) then
    new$BudgetRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_CLSCORRVALUES_BU_100)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(ID ) INTO CNT$1
  from CLSCORRVALUES
  where
  (        ((ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS) or ((ANALYTICALGROUPIFS is null) and (new$ANALYTICALGROUPIFS is null))) and
  ((ANALYTICALGROUPKD = new$ANALYTICALGROUPKD) or ((ANALYTICALGROUPKD is null) and (new$ANALYTICALGROUPKD is null))) and
  ((ASSIGNMENTKIND = new$ASSIGNMENTKIND) or ((ASSIGNMENTKIND is null) and (new$ASSIGNMENTKIND is null))) and
  ((ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE) or ((ASSIGNMENTSOURCE is null) and (new$ASSIGNMENTSOURCE is null))) and
  ((ATTACHTO = new$ATTACHTO) or ((ATTACHTO is null) and (new$ATTACHTO is null))) and
  ((BUDALLOCATIONCLS = new$BUDALLOCATIONCLS) or ((BUDALLOCATIONCLS is null) and (new$BUDALLOCATIONCLS is null))) and
  (BUDGETREF = new$BUDGETREF) and
  ((COMMDIRECTIONEXPENCECLS = new$COMMDIRECTIONEXPENCECLS) or ((COMMDIRECTIONEXPENCECLS is null) and (new$COMMDIRECTIONEXPENCECLS is null))) and
  ((PayTargetFunds = new$PayTargetFunds) or ((PayTargetFunds is null) and (new$PayTargetFunds is null))) and
  ((CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS) or ((CONTRACTCOSTSCLS is null) and (new$CONTRACTCOSTSCLS is null))) and
  ((DIRECTIONCLS = new$DIRECTIONCLS) or ((DIRECTIONCLS is null) and (new$DIRECTIONCLS is null))) and
  ((DOCBASE = new$DOCBASE) or ((DOCBASE is null) and (new$DOCBASE is null))) and
  ((DOCTYPE = new$DOCTYPE) or ((DOCTYPE is null) and (new$DOCTYPE is null))) and
  ((FACIALACC_CLS = new$FACIALACC_CLS) or ((FACIALACC_CLS is null) and (new$FACIALACC_CLS is null))) and
  ((FACT = new$FACT) or ((FACT is null) and (new$FACT is null))) and
  ((FINSOURCE = new$FINSOURCE) or ((FINSOURCE is null) and (new$FINSOURCE is null))) and
  ((FINTYPE = new$FINTYPE) or ((FINTYPE is null) and (new$FINTYPE is null))) and
  ((FUNDSSOURCE = new$FUNDSSOURCE) or ((FUNDSSOURCE is null) and (new$FUNDSSOURCE is null))) and
  ((INNERFINSOURCE = new$INNERFINSOURCE) or ((INNERFINSOURCE is null) and (new$INNERFINSOURCE is null))) and
  ((INVESTOBJECT = new$INVESTOBJECT) or ((INVESTOBJECT is null) and (new$INVESTOBJECT is null))) and
  ((KCSR = new$KCSR) or ((KCSR is null) and (new$KCSR is null))) and
  ((KD = new$KD) or ((KD is null) and (new$KD is null))) and
  ((KESR = new$KESR) or ((KESR is null) and (new$KESR is null))) and
  ((KFSR = new$KFSR) or ((KFSR is null) and (new$KFSR is null))) and
  ((KVR = new$KVR) or ((KVR is null) and (new$KVR is null))) and
  ((KVSR = new$KVSR) or ((KVSR is null) and (new$KVSR is null))) and
  ((MEANSTYPE = new$MEANSTYPE) or ((MEANSTYPE is null) and (new$MEANSTYPE is null))) and
  ((REGPROJECTRESULT = new$REGPROJECTRESULT) or ((REGPROJECTRESULT is null) and (new$REGPROJECTRESULT is null))) and
  ((NATIONALPROJECT = new$NATIONALPROJECT) or ((NATIONALPROJECT is null) and (new$NATIONALPROJECT is null))) and
  ((OKTMO = new$OKTMO) or ((OKTMO is null) and (new$OKTMO is null))) and
  ((PAYDESTINATION = new$PAYDESTINATION) or ((PAYDESTINATION is null) and (new$PAYDESTINATION is null))) and
  ((PAYPROMISECLS = new$PAYPROMISECLS) or ((PAYPROMISECLS is null) and (new$PAYPROMISECLS is null))) and
  ((PLANDOCTYPE = new$PLANDOCTYPE) or ((PLANDOCTYPE is null) and (new$PLANDOCTYPE is null))) and
  ((PROGRAMCODE = new$PROGRAMCODE) or ((PROGRAMCODE is null) and (new$PROGRAMCODE is null))) and
  ((REESTRTYPE = new$REESTRTYPE) or ((REESTRTYPE is null) and (new$REESTRTYPE is null))) and
  ((REGIONCLS = new$REGIONCLS) or ((REGIONCLS is null) and (new$REGIONCLS is null))) and
  ((SUBKESR = new$SUBKESR) or ((SUBKESR is null) and (new$SUBKESR is null))) and
  ((SUBSIDYCLS = new$SUBSIDYCLS) or ((SUBSIDYCLS is null) and (new$SUBSIDYCLS is null))) and
  ((TARGETCLS = new$TARGETCLS) or ((TARGETCLS is null) and (new$TARGETCLS is null))) and
  ((TRANSFERTCLS = new$TRANSFERTCLS) or ((TRANSFERTCLS is null) and (new$TRANSFERTCLS is null))) and
  ((VARIANT = new$VARIANT) or ((VARIANT is null) and (new$VARIANT is null))) and
  ((STARTDATE = new$STARTDATE) or ((STARTDATE is null) and (new$STARTDATE is null))) and
  ((DELETEDATE = new$DELETEDATE) or ((DELETEDATE is null) and (new$DELETEDATE is null))) and
  (RECORDINDEX = new$RECORDINDEX) and
  (ID <> :old.ID)
  ) AND (ROWNUM = 1)      ;
  if ((CNT$1<> 0))
  then
    RaiseException('EX_BUDSTRUCT_UNIQUE');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CLSCORRVALUES SET
    ID = new$ID,
    RECORDINDEX = new$RECORDINDEX,
    KVSR = new$KVSR,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    SUBKESR = new$SUBKESR,
    DIRECTIONCLS = new$DIRECTIONCLS,
    VARIANT = new$VARIANT,
    FACT = new$FACT,
    PAYPROMISECLS = new$PAYPROMISECLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    INVESTOBJECT = new$INVESTOBJECT,
    FINTYPE = new$FINTYPE,
    MEANSTYPE = new$MEANSTYPE,
    TARGETCLS = new$TARGETCLS,
    REGIONCLS = new$REGIONCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    TRANSFERTCLS = new$TRANSFERTCLS,
    PLANDOCTYPE = new$PLANDOCTYPE,
    ASSIGNMENTSOURCE = new$ASSIGNMENTSOURCE,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    KD = new$KD,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD,
    PROGRAMCODE = new$PROGRAMCODE,
    INNERFINSOURCE = new$INNERFINSOURCE,
    REESTRTYPE = new$REESTRTYPE,
    OKTMO = new$OKTMO,
    DOCBASE = new$DOCBASE,
    FUNDSSOURCE = new$FUNDSSOURCE,
    FINSOURCE = new$FINSOURCE,
    DOCTYPE = new$DOCTYPE,
    COMMDIRECTIONEXPENCECLS = new$COMMDIRECTIONEXPENCECLS,
    PAYTARGETFUNDS = new$PAYTARGETFUNDS,
    PAYDESTINATION = new$PAYDESTINATION,
    FACIALACC_CLS = new$FACIALACC_CLS,
    REGPROJECTRESULT = new$REGPROJECTRESULT,
    NATIONALPROJECT = new$NATIONALPROJECT,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    LINKRECORD = new$LINKRECORD,
    ATTACHTO = new$ATTACHTO,
    BUDGETREF = new$BUDGETREF,
    NOTE = new$NOTE,
    EXTID = new$EXTID,
    EXTROOTID = new$EXTROOTID,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    CREATEDATE = new$CREATEDATE,
    CREATERUSER = new$CREATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    STOREDCONTENT = new$STOREDCONTENT
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_ClsCorrValues_AU_500)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (98112, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=98112) and (RecordId=new$ID);

  END IF;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- alter_MeasurementCls_fix_4_Code.sql
-- #########################################################
-- #########################################################

/*   " " -   4-        */
-- ALTER TRIGGER tr_measurementcls_bi_0
CREATE OR REPLACE TRIGGER TR_MEASUREMENTCLS_BI
  BEFORE INSERT
  ON MEASUREMENTCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_measurementcls_bi_0)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  --   ,     3-
  if ((:new.Code is null) and (:new.ID is not null) and (:new.ID < 1000)) then
    FormatClsStr(:new.ID, 3,:new.Code);
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_MEASUREMENTCLS_BI_500)
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_DfAccountsBuhTable_IsForKs.sql
-- #########################################################
-- #########################################################

/* 
     - . 
    bool default 0
*/
ALTER TRIGGER TR_DFACCOUNTSBUHTABLE_BU_500 DISABLE
/
ALTER TABLE TB_DfAccountsBuhTable ADD (
  IsForKs NUMBER(5) default 0/* .  */,
    CHECK (IsForKs in (0,1))
)
/
ALTER TRIGGER TR_DFACCOUNTSBUHTABLE_BU_500 ENABLE
/

CREATE OR REPLACE VIEW DfAccountsBuhTable (
  BUDGETREF,
  ID,
  BUHACC,
  ACCMODE,
  FIXED,
  CREATEDATE,
  UPDATEDATE,
  CURRENCYCLS,
  TREASURYACCREF,
  FINORGACCREF,
  IFS,
  SINGLEID,
  ISCOMMON,
  ISFORBUDGET,
  ISFORBUSINESS,
  ISFORTEMPORARY,
  ISFORCASH,
  CREATERUSER,
  UPDATERUSER,
  REGIONCLS,
  ISFORBU_AU,
  ISDEPOSIT,
  FACIALACC_ADB,
  ISFORTEMPORARYBU_AU,
  ISFORAU,
  ISFORKS)
AS
  SELECT
    BUDGETREF,
    ID,
    BUHACC,
    ACCMODE,
    FIXED,
    CREATEDATE,
    UPDATEDATE,
    CURRENCYCLS,
    TREASURYACCREF,
    FINORGACCREF,
    IFS,
    SINGLEID,
    ISCOMMON,
    ISFORBUDGET,
    ISFORBUSINESS,
    ISFORTEMPORARY,
    ISFORCASH,
    CREATERUSER,
    UPDATERUSER,
    REGIONCLS,
    ISFORBU_AU,
    ISDEPOSIT,
    FACIALACC_ADB,
    ISFORTEMPORARYBU_AU,
    ISFORAU,
    ISFORKS
  FROM TB_DfAccountsBuhTable
/

CREATE OR REPLACE TRIGGER TR_DFACCOUNTSBUHTABLE_ID
  INSTEAD OF DELETE
  ON DFACCOUNTSBUHTABLE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_DFACCOUNTSBUHTABLE
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_DFACCOUNTSBUHTABLE_AD_500)
-- Last update 29.11.2006
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate)
  values(73,:old.SingleID,SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_DFACCOUNTSBUHTABLE_II
  INSTEAD OF INSERT
  ON DFACCOUNTSBUHTABLE
  FOR EACH ROW
DECLARE
  new$BUDGETREF DFACCOUNTSBUHTABLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ID DFACCOUNTSBUHTABLE.ID%TYPE := :NEW.ID;
  new$BUHACC DFACCOUNTSBUHTABLE.BUHACC%TYPE := :NEW.BUHACC;
  new$ACCMODE DFACCOUNTSBUHTABLE.ACCMODE%TYPE := :NEW.ACCMODE;
  new$FIXED DFACCOUNTSBUHTABLE.FIXED%TYPE := :NEW.FIXED;
  new$CREATEDATE DFACCOUNTSBUHTABLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE DFACCOUNTSBUHTABLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CURRENCYCLS DFACCOUNTSBUHTABLE.CURRENCYCLS%TYPE := :NEW.CURRENCYCLS;
  new$TREASURYACCREF DFACCOUNTSBUHTABLE.TREASURYACCREF%TYPE := :NEW.TREASURYACCREF;
  new$FINORGACCREF DFACCOUNTSBUHTABLE.FINORGACCREF%TYPE := :NEW.FINORGACCREF;
  new$IFS DFACCOUNTSBUHTABLE.IFS%TYPE := :NEW.IFS;
  new$SINGLEID DFACCOUNTSBUHTABLE.SINGLEID%TYPE := :NEW.SINGLEID;
  new$ISCOMMON DFACCOUNTSBUHTABLE.ISCOMMON%TYPE := :NEW.ISCOMMON;
  new$ISFORBUDGET DFACCOUNTSBUHTABLE.ISFORBUDGET%TYPE := :NEW.ISFORBUDGET;
  new$ISFORBUSINESS DFACCOUNTSBUHTABLE.ISFORBUSINESS%TYPE := :NEW.ISFORBUSINESS;
  new$ISFORTEMPORARY DFACCOUNTSBUHTABLE.ISFORTEMPORARY%TYPE := :NEW.ISFORTEMPORARY;
  new$ISFORCASH DFACCOUNTSBUHTABLE.ISFORCASH%TYPE := :NEW.ISFORCASH;
  new$CREATERUSER DFACCOUNTSBUHTABLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER DFACCOUNTSBUHTABLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$REGIONCLS DFACCOUNTSBUHTABLE.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ISFORBU_AU DFACCOUNTSBUHTABLE.ISFORBU_AU%TYPE := :NEW.ISFORBU_AU;
  new$ISDEPOSIT DFACCOUNTSBUHTABLE.ISDEPOSIT%TYPE := :NEW.ISDEPOSIT;
  new$FACIALACC_ADB DFACCOUNTSBUHTABLE.FACIALACC_ADB%TYPE := :NEW.FACIALACC_ADB;
  new$ISFORTEMPORARYBU_AU DFACCOUNTSBUHTABLE.ISFORTEMPORARYBU_AU%TYPE := :NEW.ISFORTEMPORARYBU_AU;
  new$ISFORAU DFACCOUNTSBUHTABLE.ISFORAU%TYPE := :NEW.ISFORAU;
  new$ISFORKS DFACCOUNTSBUHTABLE.ISFORKS%TYPE := :NEW.ISFORKS;
--
  OldValue$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  countForBU_AU$ NUMBER(10);
  countForBudget$ NUMBER(10);
  countForBusiness$ NUMBER(10);
  countForTemporary$ NUMBER(10);
  countForTemporaryBU_AU$ NUMBER(10);
  countForAU$ NUMBER(10);
  CurNum1$ NUMBER(10);
  CommonBudget1$ NUMBER(10);
  RegionCLS1$ NUMBER(10);
  checkUseAU1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_DFACCOUNTSBUHTABLE_BI_0)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$SingleID is null) then 
    select g_shared.nextval into new$SingleID from dual;
  END IF;
  if (new$CurrencyCls is null) then
    GetIntConst(19, 4,CurNum1$);
    if (CurNum1$ is null) then 
      new$CurrencyCls:= 2;
         
    else 
      new$CurrencyCls:= CurNum1$;
     
    END IF;
  END IF;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$isForBudget is null) then 
    new$isForBudget:= 0;
  END IF;
  if (new$isForBusiness is null) then 
    new$isForBusiness:= 0;
  END IF;
  if (new$isForTemporary is null) then 
    new$isForTemporary:= 0;
  END IF;
  if (new$isForBU_AU is null) then 
    new$isForBU_AU:= 0;
  END IF;
  if (new$isCommon is null) then 
    new$isCommon := 0;
  END IF;
  if (new$isDeposit is null) then 
    new$isDeposit := 0;
  END IF;
  if (new$isForCash is null) then 
    new$isForCash := 0;
  END IF;
  if (new$isForTemporaryBU_AU is null) then 
    new$isForTemporaryBU_AU := 0;
  END IF;
  if (new$isForAU is null) then 
    new$isForAU := 0;
  END IF;
  getintconst(30, 44,checkUseAU1$);
  if (checkUseAU1$ <> 1) then 
    new$isForAU := new$isForBU_AU;
  END IF;
   
  if ((new$isForBudget = 0)and(new$isForBusiness = 0)and(new$isForTemporary = 0)
  and(new$isForBU_AU = 0)and(new$isDeposit = 0)and(new$isForTemporaryBU_AU = 0)and(new$isForAU = 0)) then
    new$isForBudget := 1;
  END IF;
  if ((new$isCommon = 1)and(new$IsForBudget=1)) then
    GetIntConst(-1,3,CommonBudget1$);
    if (new$BudgetRef = CommonBudget1$) then
      SELECT COUNT(constValue ) INTO CNT$1
      from intconst where ((progindex = -1) and (constindex = 2)) AND (ROWNUM = 1);
      if ((CNT$1<> 0)) then
        Update intconst
        set Constvalue = new$ID
        where (progindex = -1) and (constindex = 2);
                
      else
        INSERT INTO INTCONST (PROGINDEX, CONSTINDEX, CONSTVALUE)
        VALUES (-1, 2, new$ID);
                
      END IF;  
    END IF;
  END IF;
  if ((new$isCommon = 1)and(new$IsForBusiness=1)) then
    GetIntConst(-1,3,CommonBudget1$);
    if (new$BudgetRef = CommonBudget1$) then
      SELECT COUNT(constValue ) INTO CNT$2
      from intconst where ((progindex = 30) and (constindex = 17)) AND (ROWNUM = 1);
      if ((CNT$2<> 0)) then
        Update intconst
        set Constvalue = new$ID
        where (progindex = 30) and (constindex = 17);
                
      else
        INSERT INTO INTCONST (PROGINDEX, CONSTINDEX, CONSTVALUE)
        VALUES (30, 17, new$ID);
                
      END IF;  
    END IF;
  END IF;
  if (new$RegionCLS is null) then
    BEGIN
      select o.RegionCls     into RegionCLS1$ from Organizations o where o.ID =
      (select oa.Org_Ref from Org_Accounts oa where oa.ID = new$ID)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not (RegionCLS1$  is null)) then
      new$RegionCLS := RegionCLS1$;
          
    else
      new$RegionCLS := 0;
      
    END IF;
  END IF;
  if (new$FacialAcc_ADB is null) then 
    new$FacialAcc_ADB := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_300 (TR_DFACCOUNTSBUHTABLE_BI_300)
-- Create 13.05.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$IFS IS NULL) THEN
      --  ,            
      SELECT MAX (IFS)
        INTO OldValue$
        FROM DFACCOUNTSBUHTABLE df
       WHERE df.ID = new$ID;

      IF ((OldValue$ IS NOT NULL) AND (OldValue$ <> 0)) THEN
         new$IFS := OldValue$;
      END IF;
   END IF;

   IF (new$CURRENCYCLS IS NULL) THEN
      SELECT MAX (CURRENCYCLS)
        INTO OldValue$
        FROM DFACCOUNTSBUHTABLE df
       WHERE df.ID = new$ID;

      IF ((OldValue$ IS NOT NULL) AND (OldValue$ <> 0)) THEN
         new$CURRENCYCLS := OldValue$;
      END IF;
   END IF;

   IF (new$TREASURYACCREF IS NULL) THEN
      SELECT MAX (TREASURYACCREF)
        INTO OldValue$
        FROM DFACCOUNTSBUHTABLE df
       WHERE df.ID = new$ID;

      IF ((OldValue$ IS NOT NULL) AND (OldValue$ <> 0)) THEN
         new$TREASURYACCREF := OldValue$;
      END IF;
   END IF;

   IF (new$FINORGACCREF IS NULL) THEN
      SELECT MAX (FINORGACCREF)
        INTO OldValue$
        FROM DFACCOUNTSBUHTABLE df
       WHERE df.ID = new$ID;

      IF ((OldValue$ IS NOT NULL) AND (OldValue$ <> 0)) THEN
         new$FINORGACCREF := OldValue$;
      END IF;
   END IF;

   UPDATE DFACCOUNTSBUHTABLE
      SET IFS = new$IFS,
          CURRENCYCLS = new$CURRENCYCLS,
          TREASURYACCREF = new$TREASURYACCREF,
          FINORGACCREF = new$FINORGACCREF
    WHERE (ID = new$id)
      AND (BUDGETREF <> new$BUDGETREF)
      AND (   (IFS <> new$IFS)
           OR (CURRENCYCLS <> new$CURRENCYCLS)
           OR (TREASURYACCREF <> new$TREASURYACCREF)
           OR (FINORGACCREF <> new$FINORGACCREF)
          );

-- - - - - - - - - - - - -
-- BI_500 (TR_DFACCOUNTSBUHTABLE_BI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_DFACCOUNTSBUHTABLE (
    BUDGETREF,
    ID,
    BUHACC,
    ACCMODE,
    FIXED,
    CREATEDATE,
    UPDATEDATE,
    CURRENCYCLS,
    TREASURYACCREF,
    FINORGACCREF,
    IFS,
    SINGLEID,
    ISCOMMON,
    ISFORBUDGET,
    ISFORBUSINESS,
    ISFORTEMPORARY,
    ISFORCASH,
    CREATERUSER,
    UPDATERUSER,
    REGIONCLS,
    ISFORBU_AU,
    ISDEPOSIT,
    FACIALACC_ADB,
    ISFORTEMPORARYBU_AU,
    ISFORAU,
    ISFORKS
  ) VALUES (
    new$BUDGETREF,
    new$ID,
    new$BUHACC,
    new$ACCMODE,
    new$FIXED,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$CURRENCYCLS,
    new$TREASURYACCREF,
    new$FINORGACCREF,
    new$IFS,
    new$SINGLEID,
    new$ISCOMMON,
    new$ISFORBUDGET,
    new$ISFORBUSINESS,
    new$ISFORTEMPORARY,
    new$ISFORCASH,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$REGIONCLS,
    new$ISFORBU_AU,
    new$ISDEPOSIT,
    new$FACIALACC_ADB,
    new$ISFORTEMPORARYBU_AU,
    new$ISFORAU,
    new$ISFORKS);

-- - - - - - - - - - - - -
-- AI_100 (TR_DFACCOUNTSBUHTABLE_AI_100)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  if (new$IsCommon=1) then
    select sum(dfbt.isForBudget),sum(dfbt.isForBusiness),sum(dfbt.isForTemporary),sum(dfbt.isForBU_AU),
    sum(dfbt.isForTemporaryBU_AU),sum(dfbt.isForAU)
    into countForBudget$, countForBusiness$, countForTemporary$, countForBU_AU$, countForTemporaryBU_AU$, countForAU$         from dfaccountsbuhtable dfbt
    LEFT JOIN Org_Accounts oa ON (dfbt.id =  oa.id)
    where (dfbt.BudgetRef = new$BudgetRef) and (dfbt.isCommon = 1) and ((oa.Closed = 0)or(oa.Closed is null))
    ;
    if ((countForBudget$  > 1)or(countForBusiness$  > 1)or(countForTemporary$  > 1)or(countForBU_AU$  > 1)
    or(countForTemporaryBU_AU$  > 1)or(countForAU$  > 1)) then
      RaiseException('EX_CHECK_common_DFACCBT');   
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_DFACCOUNTSBUHTABLE_AI_500)
-- Last update 29.11.2006
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 73) and (RecordId = new$SingleID);

END;
/

CREATE OR REPLACE TRIGGER TR_DFACCOUNTSBUHTABLE_IU
  INSTEAD OF UPDATE
  ON DFACCOUNTSBUHTABLE
  FOR EACH ROW
DECLARE
  new$BUDGETREF DFACCOUNTSBUHTABLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ID DFACCOUNTSBUHTABLE.ID%TYPE := :NEW.ID;
  new$BUHACC DFACCOUNTSBUHTABLE.BUHACC%TYPE := :NEW.BUHACC;
  new$ACCMODE DFACCOUNTSBUHTABLE.ACCMODE%TYPE := :NEW.ACCMODE;
  new$FIXED DFACCOUNTSBUHTABLE.FIXED%TYPE := :NEW.FIXED;
  new$CREATEDATE DFACCOUNTSBUHTABLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE DFACCOUNTSBUHTABLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CURRENCYCLS DFACCOUNTSBUHTABLE.CURRENCYCLS%TYPE := :NEW.CURRENCYCLS;
  new$TREASURYACCREF DFACCOUNTSBUHTABLE.TREASURYACCREF%TYPE := :NEW.TREASURYACCREF;
  new$FINORGACCREF DFACCOUNTSBUHTABLE.FINORGACCREF%TYPE := :NEW.FINORGACCREF;
  new$IFS DFACCOUNTSBUHTABLE.IFS%TYPE := :NEW.IFS;
  new$SINGLEID DFACCOUNTSBUHTABLE.SINGLEID%TYPE := :NEW.SINGLEID;
  new$ISCOMMON DFACCOUNTSBUHTABLE.ISCOMMON%TYPE := :NEW.ISCOMMON;
  new$ISFORBUDGET DFACCOUNTSBUHTABLE.ISFORBUDGET%TYPE := :NEW.ISFORBUDGET;
  new$ISFORBUSINESS DFACCOUNTSBUHTABLE.ISFORBUSINESS%TYPE := :NEW.ISFORBUSINESS;
  new$ISFORTEMPORARY DFACCOUNTSBUHTABLE.ISFORTEMPORARY%TYPE := :NEW.ISFORTEMPORARY;
  new$ISFORCASH DFACCOUNTSBUHTABLE.ISFORCASH%TYPE := :NEW.ISFORCASH;
  new$CREATERUSER DFACCOUNTSBUHTABLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER DFACCOUNTSBUHTABLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$REGIONCLS DFACCOUNTSBUHTABLE.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ISFORBU_AU DFACCOUNTSBUHTABLE.ISFORBU_AU%TYPE := :NEW.ISFORBU_AU;
  new$ISDEPOSIT DFACCOUNTSBUHTABLE.ISDEPOSIT%TYPE := :NEW.ISDEPOSIT;
  new$FACIALACC_ADB DFACCOUNTSBUHTABLE.FACIALACC_ADB%TYPE := :NEW.FACIALACC_ADB;
  new$ISFORTEMPORARYBU_AU DFACCOUNTSBUHTABLE.ISFORTEMPORARYBU_AU%TYPE := :NEW.ISFORTEMPORARYBU_AU;
  new$ISFORAU DFACCOUNTSBUHTABLE.ISFORAU%TYPE := :NEW.ISFORAU;
  new$ISFORKS DFACCOUNTSBUHTABLE.ISFORKS%TYPE := :NEW.ISFORKS;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  countForBU_AU$ NUMBER(10);
  countForBudget$ NUMBER(10);
  countForBusiness$ NUMBER(10);
  countForTemporary$ NUMBER(10);
  countForTemporaryBU_AU$ NUMBER(10);
  countForAU$ NUMBER(10);
  CurNum1$ NUMBER(10);
  CommonBudget1$ NUMBER(10);
  RegionCLS1$ NUMBER(10);
  checkUseAU1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_DFACCOUNTSBUHTABLE_BU_0)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if (new$CurrencyCls is null) then
    GetIntConst(19, 4,CurNum1$);
    if (CurNum1$ is null) then 
      new$CurrencyCls:= 2;
         
    else 
      new$CurrencyCls:= CurNum1$;
     
    END IF;
  END IF;
   
  if (new$isForBudget is null) then 
    new$isForBudget:= 0;
  END IF;
  if (new$isForBusiness is null) then 
    new$isForBusiness:= 0;
  END IF;
  if (new$isForTemporary is null) then 
    new$isForTemporary:= 0;
  END IF;
  if (new$isForBU_AU is null) then 
    new$isForBU_AU:= 0;
  END IF;
  if (new$isCommon is null) then 
    new$isCommon := 0;
  END IF;
  if (new$isDeposit is null) then 
    new$isDeposit := 0;
  END IF;
  if (new$isForCash is null) then 
    new$isForCash := 0;
  END IF;
  if (new$isForTemporaryBU_AU is null) then 
    new$isForTemporaryBU_AU := 0;
  END IF;
  if (new$isForAU is null) then 
    new$isForAU := 0;
  END IF;
  getintconst(30, 44,checkUseAU1$);
  if (checkUseAU1$ <> 1) then 
    new$isForAU := new$isForBU_AU;
  END IF;
   
  if ((new$isForBudget = 0)and(new$isForBusiness = 0)and(new$isForTemporary = 0)
  and(new$isForBU_AU = 0)and(new$isDeposit = 0)and(new$isForTemporaryBU_AU = 0)and(new$isForAU = 0))then
    new$isForBudget := 1;
  END IF;
  if (((:old.isCommon <> 1) and (new$isCommon = 1)and(new$IsForBudget=1))
  or ((new$isCommon = 1)and(:old.IsForBudget<>1)and(new$IsForBudget=1))) then
    GetIntConst(-1,3,CommonBudget1$);
    if (new$BudgetRef = CommonBudget1$) then
      SELECT COUNT(constValue ) INTO CNT$1
      from intconst where ((progindex = -1) and (constindex = 2)) AND (ROWNUM = 1);
      if ((CNT$1<> 0)) then
        Update intconst
        set Constvalue = new$ID
        where (progindex = -1) and (constindex = 2);
                
      else
        INSERT INTO INTCONST (PROGINDEX, CONSTINDEX, CONSTVALUE)
        VALUES (-1, 2, new$ID);
                
      END IF; 
    END IF;
  END IF;
  if (((:old.isCommon <> 1) and (new$isCommon = 1)and(new$isForBusiness=1))
  or ((new$isCommon = 1)and(:old.isForBusiness<>1)and(new$isForBusiness=1))) then
    GetIntConst(-1,3,CommonBudget1$);
    if (new$BudgetRef = CommonBudget1$) then
      SELECT COUNT(constValue ) INTO CNT$2
      from intconst where ((progindex = 30) and (constindex = 17)) AND (ROWNUM = 1);
      if ((CNT$2<> 0)) then
        Update intconst
        set Constvalue = new$ID
        where (progindex = 30) and (constindex = 17);
                
      else
        INSERT INTO INTCONST (PROGINDEX, CONSTINDEX, CONSTVALUE)
        VALUES (30, 17, new$ID);
                
      END IF; 
    END IF;
  END IF;
  if (new$RegionCLS is null) then
    BEGIN
      select o.RegionCls     into RegionCLS1$ from Organizations o where o.ID =
      (select oa.Org_Ref from Org_Accounts oa where oa.ID = new$ID)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not (RegionCLS1$  is null)) then
      new$RegionCLS := RegionCLS1$;
          
    else
      new$RegionCLS := 0;
      
    END IF;
  END IF;
  if (new$FacialAcc_ADB is null) then 
    new$FacialAcc_ADB := 0;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_DFACCOUNTSBUHTABLE SET
    BUDGETREF = new$BUDGETREF,
    ID = new$ID,
    BUHACC = new$BUHACC,
    ACCMODE = new$ACCMODE,
    FIXED = new$FIXED,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    CURRENCYCLS = new$CURRENCYCLS,
    TREASURYACCREF = new$TREASURYACCREF,
    FINORGACCREF = new$FINORGACCREF,
    IFS = new$IFS,
    SINGLEID = new$SINGLEID,
    ISCOMMON = new$ISCOMMON,
    ISFORBUDGET = new$ISFORBUDGET,
    ISFORBUSINESS = new$ISFORBUSINESS,
    ISFORTEMPORARY = new$ISFORTEMPORARY,
    ISFORCASH = new$ISFORCASH,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    REGIONCLS = new$REGIONCLS,
    ISFORBU_AU = new$ISFORBU_AU,
    ISDEPOSIT = new$ISDEPOSIT,
    FACIALACC_ADB = new$FACIALACC_ADB,
    ISFORTEMPORARYBU_AU = new$ISFORTEMPORARYBU_AU,
    ISFORAU = new$ISFORAU,
    ISFORKS = new$ISFORKS
  WHERE id = :old.Id and budgetref = :old.budgetref;

-- - - - - - - - - - - - -
-- AU_100 (TR_DFACCOUNTSBUHTABLE_AU_100)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  if (new$IsCommon=1) then
    select sum(dfbt.isForBudget),sum(dfbt.isForBusiness),sum(dfbt.isForTemporary),sum(dfbt.isForBU_AU),
    sum(dfbt.isForTemporaryBU_AU),sum(dfbt.isForAU)
    into countForBudget$, countForBusiness$, countForTemporary$, countForBU_AU$, countForTemporaryBU_AU$, countForAU$         from dfaccountsbuhtable dfbt
    LEFT JOIN Org_Accounts oa ON (dfbt.id =  oa.id)
    where (dfbt.BudgetRef = new$BudgetRef) and (dfbt.isCommon = 1) and ((oa.Closed = 0)or(oa.Closed is null))
    ;
    if ((countForBudget$  > 1)or(countForBusiness$  > 1)or(countForTemporary$  > 1)or(countForBU_AU$  > 1)
    or(countForTemporaryBU_AU$  > 1)or(countForAU$  > 1)) then
      RaiseException('EX_CHECK_common_DFACCBT');   
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_DFACCOUNTSBUHTABLE_AU_300)
-- Create 13.05.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  update TB_DFACCOUNTSBUHTABLE set
    IFS = new$IFS,
    CURRENCYCLS = new$CURRENCYCLS,
    TREASURYACCREF = new$TREASURYACCREF,
    FINORGACCREF = new$FINORGACCREF
  where
    (id = new$id)and(BUDGETREF <> new$BUDGETREF)and
    ((IFS <> new$IFS)or(CURRENCYCLS <> new$CURRENCYCLS)or
    (TREASURYACCREF <> new$TREASURYACCREF)or(FINORGACCREF <> new$FINORGACCREF));

-- - - - - - - - - - - - -
-- AU_500 (TR_DFACCOUNTSBUHTABLE_AU_500)
-- Create 29.11.2006
-- - - - - - - - - - - - -

  if (new$SingleId <> :old.SingleId) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (73, :Old.SingleId, SYSDATE);
    delete from DelRecIndexes where (TableID = 73) and (RecordId = new$SingleID);
  end if;

END;
/
commit work 
/
-- CREATE TRIGGER TR_DFACCOUNTSBUHTABLE_BI_0
CREATE OR REPLACE TRIGGER TR_DFACCOUNTSBUHTABLE_II
  INSTEAD OF INSERT
  ON DFACCOUNTSBUHTABLE
  FOR EACH ROW
DECLARE
  new$BUDGETREF DFACCOUNTSBUHTABLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ID DFACCOUNTSBUHTABLE.ID%TYPE := :NEW.ID;
  new$BUHACC DFACCOUNTSBUHTABLE.BUHACC%TYPE := :NEW.BUHACC;
  new$ACCMODE DFACCOUNTSBUHTABLE.ACCMODE%TYPE := :NEW.ACCMODE;
  new$FIXED DFACCOUNTSBUHTABLE.FIXED%TYPE := :NEW.FIXED;
  new$CREATEDATE DFACCOUNTSBUHTABLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE DFACCOUNTSBUHTABLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CURRENCYCLS DFACCOUNTSBUHTABLE.CURRENCYCLS%TYPE := :NEW.CURRENCYCLS;
  new$TREASURYACCREF DFACCOUNTSBUHTABLE.TREASURYACCREF%TYPE := :NEW.TREASURYACCREF;
  new$FINORGACCREF DFACCOUNTSBUHTABLE.FINORGACCREF%TYPE := :NEW.FINORGACCREF;
  new$IFS DFACCOUNTSBUHTABLE.IFS%TYPE := :NEW.IFS;
  new$SINGLEID DFACCOUNTSBUHTABLE.SINGLEID%TYPE := :NEW.SINGLEID;
  new$ISCOMMON DFACCOUNTSBUHTABLE.ISCOMMON%TYPE := :NEW.ISCOMMON;
  new$ISFORBUDGET DFACCOUNTSBUHTABLE.ISFORBUDGET%TYPE := :NEW.ISFORBUDGET;
  new$ISFORBUSINESS DFACCOUNTSBUHTABLE.ISFORBUSINESS%TYPE := :NEW.ISFORBUSINESS;
  new$ISFORTEMPORARY DFACCOUNTSBUHTABLE.ISFORTEMPORARY%TYPE := :NEW.ISFORTEMPORARY;
  new$ISFORCASH DFACCOUNTSBUHTABLE.ISFORCASH%TYPE := :NEW.ISFORCASH;
  new$CREATERUSER DFACCOUNTSBUHTABLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER DFACCOUNTSBUHTABLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$REGIONCLS DFACCOUNTSBUHTABLE.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ISFORBU_AU DFACCOUNTSBUHTABLE.ISFORBU_AU%TYPE := :NEW.ISFORBU_AU;
  new$ISDEPOSIT DFACCOUNTSBUHTABLE.ISDEPOSIT%TYPE := :NEW.ISDEPOSIT;
  new$FACIALACC_ADB DFACCOUNTSBUHTABLE.FACIALACC_ADB%TYPE := :NEW.FACIALACC_ADB;
  new$ISFORTEMPORARYBU_AU DFACCOUNTSBUHTABLE.ISFORTEMPORARYBU_AU%TYPE := :NEW.ISFORTEMPORARYBU_AU;
  new$ISFORAU DFACCOUNTSBUHTABLE.ISFORAU%TYPE := :NEW.ISFORAU;
  new$ISFORKS DFACCOUNTSBUHTABLE.ISFORKS%TYPE := :NEW.ISFORKS;
--
  OldValue$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  countForBU_AU$ NUMBER(10);
  countForBudget$ NUMBER(10);
  countForBusiness$ NUMBER(10);
  countForTemporary$ NUMBER(10);
  countForTemporaryBU_AU$ NUMBER(10);
  countForAU$ NUMBER(10);
  CurNum$ NUMBER(10);
  CommonBudget$ NUMBER(10);
  RegionCLS$ NUMBER(10);
  checkUseAU$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_DFACCOUNTSBUHTABLE_BI_0)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  if (new$SingleID is null) then 
    select g_shared.nextval into new$SingleID from dual;
  END IF;
  if (new$CurrencyCls is null) then
    GetIntConst(19, 4,CurNum$);
    if (CurNum$ is null) then 
      new$CurrencyCls:= 2;
         
    else 
      new$CurrencyCls:= CurNum$;
     
    END IF;
  END IF;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$isForBudget is null) then 
    new$isForBudget:= 0;
  END IF;
  if (new$isForBusiness is null) then 
    new$isForBusiness:= 0;
  END IF;
  if (new$isForTemporary is null) then 
    new$isForTemporary:= 0;
  END IF;
  if (new$isForBU_AU is null) then 
    new$isForBU_AU:= 0;
  END IF;
  if (new$isCommon is null) then 
    new$isCommon := 0;
  END IF;
  if (new$isDeposit is null) then 
    new$isDeposit := 0;
  END IF;
  if (new$isForCash is null) then 
    new$isForCash := 0;
  END IF;
  if (new$isForTemporaryBU_AU is null) then 
    new$isForTemporaryBU_AU := 0;
  END IF;
  if (new$isForAU is null) then 
    new$isForAU := 0;
  END IF;
  if (new$IsForKs is null) then 
    new$IsForKs := 0;
  END IF;
  getintconst(30, 44,checkUseAU$);
  if (checkUseAU$ <> 1) then 
    new$isForAU := new$isForBU_AU;
  END IF;
   
  /*    */
  if ((new$isForBudget = 0)and(new$isForBusiness = 0)and(new$isForTemporary = 0)
  and(new$isForBU_AU = 0)and(new$isDeposit = 0)and(new$isForTemporaryBU_AU = 0)and(new$isForAU = 0)and(new$IsForKs = 0)) then
    new$isForBudget := 1;
  END IF;
  if ((new$isCommon = 1)and(new$IsForBudget=1)) then
    /*       */
    GetIntConst(-1,3,CommonBudget$);
    if (new$BudgetRef = CommonBudget$) then
      SELECT COUNT(constValue ) INTO CNT$1
      from intconst where ((progindex = -1) and (constindex = 2)) AND (ROWNUM = 1);
      if ((CNT$1<> 0)) then
        Update intconst
        set Constvalue = new$ID
        where (progindex = -1) and (constindex = 2);
                
      else
        INSERT INTO INTCONST (PROGINDEX, CONSTINDEX, CONSTVALUE)
        VALUES (-1, 2, new$ID);
                
      END IF;  
    END IF;
  END IF;
  if ((new$isCommon = 1)and(new$IsForBusiness=1)) then
    /*   \    */
    GetIntConst(-1,3,CommonBudget$);
    if (new$BudgetRef = CommonBudget$) then
      SELECT COUNT(constValue ) INTO CNT$2
      from intconst where ((progindex = 30) and (constindex = 17)) AND (ROWNUM = 1);
      if ((CNT$2<> 0)) then
        Update intconst
        set Constvalue = new$ID
        where (progindex = 30) and (constindex = 17);
                
      else
        INSERT INTO INTCONST (PROGINDEX, CONSTINDEX, CONSTVALUE)
        VALUES (30, 17, new$ID);
                
      END IF;  
    END IF;
  END IF;
  if (new$RegionCLS is null) then
    BEGIN
      select o.RegionCls     into RegionCLS$ from Organizations o where o.ID =
      (select oa.Org_Ref from Org_Accounts oa where oa.ID = new$ID)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not (RegionCLS$  is null)) then
      new$RegionCLS := RegionCLS$;
          
    else
      new$RegionCLS := 0;
      
    END IF;
  END IF;
  if (new$FacialAcc_ADB is null) then 
    new$FacialAcc_ADB := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_300 (TR_DFACCOUNTSBUHTABLE_BI_300)
-- Create 13.05.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$IFS IS NULL) THEN
      --  ,            
      SELECT MAX (IFS)
        INTO OldValue$
        FROM DFACCOUNTSBUHTABLE df
       WHERE df.ID = new$ID;

      IF ((OldValue$ IS NOT NULL) AND (OldValue$ <> 0)) THEN
         new$IFS := OldValue$;
      END IF;
   END IF;

   IF (new$CURRENCYCLS IS NULL) THEN
      SELECT MAX (CURRENCYCLS)
        INTO OldValue$
        FROM DFACCOUNTSBUHTABLE df
       WHERE df.ID = new$ID;

      IF ((OldValue$ IS NOT NULL) AND (OldValue$ <> 0)) THEN
         new$CURRENCYCLS := OldValue$;
      END IF;
   END IF;

   IF (new$TREASURYACCREF IS NULL) THEN
      SELECT MAX (TREASURYACCREF)
        INTO OldValue$
        FROM DFACCOUNTSBUHTABLE df
       WHERE df.ID = new$ID;

      IF ((OldValue$ IS NOT NULL) AND (OldValue$ <> 0)) THEN
         new$TREASURYACCREF := OldValue$;
      END IF;
   END IF;

   IF (new$FINORGACCREF IS NULL) THEN
      SELECT MAX (FINORGACCREF)
        INTO OldValue$
        FROM DFACCOUNTSBUHTABLE df
       WHERE df.ID = new$ID;

      IF ((OldValue$ IS NOT NULL) AND (OldValue$ <> 0)) THEN
         new$FINORGACCREF := OldValue$;
      END IF;
   END IF;

   UPDATE DFACCOUNTSBUHTABLE
      SET IFS = new$IFS,
          CURRENCYCLS = new$CURRENCYCLS,
          TREASURYACCREF = new$TREASURYACCREF,
          FINORGACCREF = new$FINORGACCREF
    WHERE (ID = new$id)
      AND (BUDGETREF <> new$BUDGETREF)
      AND (   (IFS <> new$IFS)
           OR (CURRENCYCLS <> new$CURRENCYCLS)
           OR (TREASURYACCREF <> new$TREASURYACCREF)
           OR (FINORGACCREF <> new$FINORGACCREF)
          );

-- - - - - - - - - - - - -
-- BI_500 (TR_DFACCOUNTSBUHTABLE_BI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_DFACCOUNTSBUHTABLE (
    BUDGETREF,
    ID,
    BUHACC,
    ACCMODE,
    FIXED,
    CREATEDATE,
    UPDATEDATE,
    CURRENCYCLS,
    TREASURYACCREF,
    FINORGACCREF,
    IFS,
    SINGLEID,
    ISCOMMON,
    ISFORBUDGET,
    ISFORBUSINESS,
    ISFORTEMPORARY,
    ISFORCASH,
    CREATERUSER,
    UPDATERUSER,
    REGIONCLS,
    ISFORBU_AU,
    ISDEPOSIT,
    FACIALACC_ADB,
    ISFORTEMPORARYBU_AU,
    ISFORAU,
    ISFORKS
  ) VALUES (
    new$BUDGETREF,
    new$ID,
    new$BUHACC,
    new$ACCMODE,
    new$FIXED,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$CURRENCYCLS,
    new$TREASURYACCREF,
    new$FINORGACCREF,
    new$IFS,
    new$SINGLEID,
    new$ISCOMMON,
    new$ISFORBUDGET,
    new$ISFORBUSINESS,
    new$ISFORTEMPORARY,
    new$ISFORCASH,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$REGIONCLS,
    new$ISFORBU_AU,
    new$ISDEPOSIT,
    new$FACIALACC_ADB,
    new$ISFORTEMPORARYBU_AU,
    new$ISFORAU,
    new$ISFORKS);

-- - - - - - - - - - - - -
-- AI_100 (TR_DFACCOUNTSBUHTABLE_AI_100)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  if (new$IsCommon=1) then
    select sum(dfbt.isForBudget),sum(dfbt.isForBusiness),sum(dfbt.isForTemporary),sum(dfbt.isForBU_AU),
    sum(dfbt.isForTemporaryBU_AU),sum(dfbt.isForAU)
    into countForBudget$, countForBusiness$, countForTemporary$, countForBU_AU$, countForTemporaryBU_AU$, countForAU$         from dfaccountsbuhtable dfbt
    LEFT JOIN Org_Accounts oa ON (dfbt.id =  oa.id)
    where (dfbt.BudgetRef = new$BudgetRef) and (dfbt.isCommon = 1) and ((oa.Closed = 0)or(oa.Closed is null))
    ;
    if ((countForBudget$  > 1)or(countForBusiness$  > 1)or(countForTemporary$  > 1)or(countForBU_AU$  > 1)
    or(countForTemporaryBU_AU$  > 1)or(countForAU$  > 1)) then
      RaiseException('EX_CHECK_common_DFACCBT');   
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_DFACCOUNTSBUHTABLE_AI_500)
-- Last update 29.11.2006
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 73) and (RecordId = new$SingleID);

END;
/
-- CREATE TRIGGER TR_DFACCOUNTSBUHTABLE_BU_0
CREATE OR REPLACE TRIGGER TR_DFACCOUNTSBUHTABLE_IU
  INSTEAD OF UPDATE
  ON DFACCOUNTSBUHTABLE
  FOR EACH ROW
DECLARE
  new$BUDGETREF DFACCOUNTSBUHTABLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ID DFACCOUNTSBUHTABLE.ID%TYPE := :NEW.ID;
  new$BUHACC DFACCOUNTSBUHTABLE.BUHACC%TYPE := :NEW.BUHACC;
  new$ACCMODE DFACCOUNTSBUHTABLE.ACCMODE%TYPE := :NEW.ACCMODE;
  new$FIXED DFACCOUNTSBUHTABLE.FIXED%TYPE := :NEW.FIXED;
  new$CREATEDATE DFACCOUNTSBUHTABLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE DFACCOUNTSBUHTABLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CURRENCYCLS DFACCOUNTSBUHTABLE.CURRENCYCLS%TYPE := :NEW.CURRENCYCLS;
  new$TREASURYACCREF DFACCOUNTSBUHTABLE.TREASURYACCREF%TYPE := :NEW.TREASURYACCREF;
  new$FINORGACCREF DFACCOUNTSBUHTABLE.FINORGACCREF%TYPE := :NEW.FINORGACCREF;
  new$IFS DFACCOUNTSBUHTABLE.IFS%TYPE := :NEW.IFS;
  new$SINGLEID DFACCOUNTSBUHTABLE.SINGLEID%TYPE := :NEW.SINGLEID;
  new$ISCOMMON DFACCOUNTSBUHTABLE.ISCOMMON%TYPE := :NEW.ISCOMMON;
  new$ISFORBUDGET DFACCOUNTSBUHTABLE.ISFORBUDGET%TYPE := :NEW.ISFORBUDGET;
  new$ISFORBUSINESS DFACCOUNTSBUHTABLE.ISFORBUSINESS%TYPE := :NEW.ISFORBUSINESS;
  new$ISFORTEMPORARY DFACCOUNTSBUHTABLE.ISFORTEMPORARY%TYPE := :NEW.ISFORTEMPORARY;
  new$ISFORCASH DFACCOUNTSBUHTABLE.ISFORCASH%TYPE := :NEW.ISFORCASH;
  new$CREATERUSER DFACCOUNTSBUHTABLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER DFACCOUNTSBUHTABLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$REGIONCLS DFACCOUNTSBUHTABLE.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ISFORBU_AU DFACCOUNTSBUHTABLE.ISFORBU_AU%TYPE := :NEW.ISFORBU_AU;
  new$ISDEPOSIT DFACCOUNTSBUHTABLE.ISDEPOSIT%TYPE := :NEW.ISDEPOSIT;
  new$FACIALACC_ADB DFACCOUNTSBUHTABLE.FACIALACC_ADB%TYPE := :NEW.FACIALACC_ADB;
  new$ISFORTEMPORARYBU_AU DFACCOUNTSBUHTABLE.ISFORTEMPORARYBU_AU%TYPE := :NEW.ISFORTEMPORARYBU_AU;
  new$ISFORAU DFACCOUNTSBUHTABLE.ISFORAU%TYPE := :NEW.ISFORAU;
  new$ISFORKS DFACCOUNTSBUHTABLE.ISFORKS%TYPE := :NEW.ISFORKS;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  countForBU_AU$ NUMBER(10);
  countForBudget$ NUMBER(10);
  countForBusiness$ NUMBER(10);
  countForTemporary$ NUMBER(10);
  countForTemporaryBU_AU$ NUMBER(10);
  countForAU$ NUMBER(10);
  CurNum$ NUMBER(10);
  CommonBudget$ NUMBER(10);
  RegionCLS$ NUMBER(10);
  checkUseAU$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_DFACCOUNTSBUHTABLE_BU_0)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  if (new$CurrencyCls is null) then
    GetIntConst(19, 4,CurNum$);
    if (CurNum$ is null) then 
      new$CurrencyCls:= 2;
         
    else 
      new$CurrencyCls:= CurNum$;
     
    END IF;
  END IF;
   
  if (new$isForBudget is null) then 
    new$isForBudget:= 0;
  END IF;
  if (new$isForBusiness is null) then 
    new$isForBusiness:= 0;
  END IF;
  if (new$isForTemporary is null) then 
    new$isForTemporary:= 0;
  END IF;
  if (new$isForBU_AU is null) then 
    new$isForBU_AU:= 0;
  END IF;
  if (new$isCommon is null) then 
    new$isCommon := 0;
  END IF;
  if (new$isDeposit is null) then 
    new$isDeposit := 0;
  END IF;
  if (new$isForCash is null) then 
    new$isForCash := 0;
  END IF;
  if (new$isForTemporaryBU_AU is null) then 
    new$isForTemporaryBU_AU := 0;
  END IF;
  if (new$isForAU is null) then 
    new$isForAU := 0;
  END IF;
  if (new$IsForKs is null) then 
    new$IsForKs := 0;
  END IF;
  getintconst(30, 44,checkUseAU$);
  if (checkUseAU$ <> 1) then 
    new$isForAU := new$isForBU_AU;
  END IF;
   
  /*    */
  if ((new$isForBudget = 0)and(new$isForBusiness = 0)and(new$isForTemporary = 0)
  and(new$isForBU_AU = 0)and(new$isDeposit = 0)and(new$isForTemporaryBU_AU = 0)and(new$isForAU = 0)and(new$IsForKs = 0))then
    new$isForBudget := 1;
  END IF;
  if (((:old.isCommon <> 1) and (new$isCommon = 1)and(new$IsForBudget=1))
  or ((new$isCommon = 1)and(:old.IsForBudget<>1)and(new$IsForBudget=1))) then
    /*       */
    GetIntConst(-1,3,CommonBudget$);
    if (new$BudgetRef = CommonBudget$) then
      SELECT COUNT(constValue ) INTO CNT$1
      from intconst where ((progindex = -1) and (constindex = 2)) AND (ROWNUM = 1);
      if ((CNT$1<> 0)) then
        Update intconst
        set Constvalue = new$ID
        where (progindex = -1) and (constindex = 2);
                
      else
        INSERT INTO INTCONST (PROGINDEX, CONSTINDEX, CONSTVALUE)
        VALUES (-1, 2, new$ID);
                
      END IF; 
    END IF;
  END IF;
  if (((:old.isCommon <> 1) and (new$isCommon = 1)and(new$isForBusiness=1))
  or ((new$isCommon = 1)and(:old.isForBusiness<>1)and(new$isForBusiness=1))) then
    /*   \    */
    GetIntConst(-1,3,CommonBudget$);
    if (new$BudgetRef = CommonBudget$) then
      SELECT COUNT(constValue ) INTO CNT$2
      from intconst where ((progindex = 30) and (constindex = 17)) AND (ROWNUM = 1);
      if ((CNT$2<> 0)) then
        Update intconst
        set Constvalue = new$ID
        where (progindex = 30) and (constindex = 17);
                
      else
        INSERT INTO INTCONST (PROGINDEX, CONSTINDEX, CONSTVALUE)
        VALUES (30, 17, new$ID);
                
      END IF; 
    END IF;
  END IF;
  if (new$RegionCLS is null) then
    BEGIN
      select o.RegionCls     into RegionCLS$ from Organizations o where o.ID =
      (select oa.Org_Ref from Org_Accounts oa where oa.ID = new$ID)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not (RegionCLS$  is null)) then
      new$RegionCLS := RegionCLS$;
          
    else
      new$RegionCLS := 0;
      
    END IF;
  END IF;
  if (new$FacialAcc_ADB is null) then 
    new$FacialAcc_ADB := 0;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_DFACCOUNTSBUHTABLE SET
    BUDGETREF = new$BUDGETREF,
    ID = new$ID,
    BUHACC = new$BUHACC,
    ACCMODE = new$ACCMODE,
    FIXED = new$FIXED,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    CURRENCYCLS = new$CURRENCYCLS,
    TREASURYACCREF = new$TREASURYACCREF,
    FINORGACCREF = new$FINORGACCREF,
    IFS = new$IFS,
    SINGLEID = new$SINGLEID,
    ISCOMMON = new$ISCOMMON,
    ISFORBUDGET = new$ISFORBUDGET,
    ISFORBUSINESS = new$ISFORBUSINESS,
    ISFORTEMPORARY = new$ISFORTEMPORARY,
    ISFORCASH = new$ISFORCASH,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    REGIONCLS = new$REGIONCLS,
    ISFORBU_AU = new$ISFORBU_AU,
    ISDEPOSIT = new$ISDEPOSIT,
    FACIALACC_ADB = new$FACIALACC_ADB,
    ISFORTEMPORARYBU_AU = new$ISFORTEMPORARYBU_AU,
    ISFORAU = new$ISFORAU,
    ISFORKS = new$ISFORKS
  WHERE id = :old.Id and budgetref = :old.budgetref;

-- - - - - - - - - - - - -
-- AU_100 (TR_DFACCOUNTSBUHTABLE_AU_100)
-- Version 8.00.00.2
-- - - - - - - - - - - - -

  if (new$IsCommon=1) then
    select sum(dfbt.isForBudget),sum(dfbt.isForBusiness),sum(dfbt.isForTemporary),sum(dfbt.isForBU_AU),
    sum(dfbt.isForTemporaryBU_AU),sum(dfbt.isForAU)
    into countForBudget$, countForBusiness$, countForTemporary$, countForBU_AU$, countForTemporaryBU_AU$, countForAU$         from dfaccountsbuhtable dfbt
    LEFT JOIN Org_Accounts oa ON (dfbt.id =  oa.id)
    where (dfbt.BudgetRef = new$BudgetRef) and (dfbt.isCommon = 1) and ((oa.Closed = 0)or(oa.Closed is null))
    ;
    if ((countForBudget$  > 1)or(countForBusiness$  > 1)or(countForTemporary$  > 1)or(countForBU_AU$  > 1)
    or(countForTemporaryBU_AU$  > 1)or(countForAU$  > 1)) then
      RaiseException('EX_CHECK_common_DFACCBT');   
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_DFACCOUNTSBUHTABLE_AU_300)
-- Create 13.05.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  update TB_DFACCOUNTSBUHTABLE set
    IFS = new$IFS,
    CURRENCYCLS = new$CURRENCYCLS,
    TREASURYACCREF = new$TREASURYACCREF,
    FINORGACCREF = new$FINORGACCREF
  where
    (id = new$id)and(BUDGETREF <> new$BUDGETREF)and
    ((IFS <> new$IFS)or(CURRENCYCLS <> new$CURRENCYCLS)or
    (TREASURYACCREF <> new$TREASURYACCREF)or(FINORGACCREF <> new$FINORGACCREF));

-- - - - - - - - - - - - -
-- AU_500 (TR_DFACCOUNTSBUHTABLE_AU_500)
-- Create 29.11.2006
-- - - - - - - - - - - - -

  if (new$SingleId <> :old.SingleId) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (73, :Old.SingleId, SYSDATE);
    delete from DelRecIndexes where (TableID = 73) and (RecordId = new$SingleID);
  end if;

END;
/
-- CREATE TRIGGER TR_DFACCOUNTSBUHTABLE_AI_100
CREATE OR REPLACE TRIGGER TR_DFACCOUNTSBUHTABLE_II
  INSTEAD OF INSERT
  ON DFACCOUNTSBUHTABLE
  FOR EACH ROW
DECLARE
  new$BUDGETREF DFACCOUNTSBUHTABLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ID DFACCOUNTSBUHTABLE.ID%TYPE := :NEW.ID;
  new$BUHACC DFACCOUNTSBUHTABLE.BUHACC%TYPE := :NEW.BUHACC;
  new$ACCMODE DFACCOUNTSBUHTABLE.ACCMODE%TYPE := :NEW.ACCMODE;
  new$FIXED DFACCOUNTSBUHTABLE.FIXED%TYPE := :NEW.FIXED;
  new$CREATEDATE DFACCOUNTSBUHTABLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE DFACCOUNTSBUHTABLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CURRENCYCLS DFACCOUNTSBUHTABLE.CURRENCYCLS%TYPE := :NEW.CURRENCYCLS;
  new$TREASURYACCREF DFACCOUNTSBUHTABLE.TREASURYACCREF%TYPE := :NEW.TREASURYACCREF;
  new$FINORGACCREF DFACCOUNTSBUHTABLE.FINORGACCREF%TYPE := :NEW.FINORGACCREF;
  new$IFS DFACCOUNTSBUHTABLE.IFS%TYPE := :NEW.IFS;
  new$SINGLEID DFACCOUNTSBUHTABLE.SINGLEID%TYPE := :NEW.SINGLEID;
  new$ISCOMMON DFACCOUNTSBUHTABLE.ISCOMMON%TYPE := :NEW.ISCOMMON;
  new$ISFORBUDGET DFACCOUNTSBUHTABLE.ISFORBUDGET%TYPE := :NEW.ISFORBUDGET;
  new$ISFORBUSINESS DFACCOUNTSBUHTABLE.ISFORBUSINESS%TYPE := :NEW.ISFORBUSINESS;
  new$ISFORTEMPORARY DFACCOUNTSBUHTABLE.ISFORTEMPORARY%TYPE := :NEW.ISFORTEMPORARY;
  new$ISFORCASH DFACCOUNTSBUHTABLE.ISFORCASH%TYPE := :NEW.ISFORCASH;
  new$CREATERUSER DFACCOUNTSBUHTABLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER DFACCOUNTSBUHTABLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$REGIONCLS DFACCOUNTSBUHTABLE.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ISFORBU_AU DFACCOUNTSBUHTABLE.ISFORBU_AU%TYPE := :NEW.ISFORBU_AU;
  new$ISDEPOSIT DFACCOUNTSBUHTABLE.ISDEPOSIT%TYPE := :NEW.ISDEPOSIT;
  new$FACIALACC_ADB DFACCOUNTSBUHTABLE.FACIALACC_ADB%TYPE := :NEW.FACIALACC_ADB;
  new$ISFORTEMPORARYBU_AU DFACCOUNTSBUHTABLE.ISFORTEMPORARYBU_AU%TYPE := :NEW.ISFORTEMPORARYBU_AU;
  new$ISFORAU DFACCOUNTSBUHTABLE.ISFORAU%TYPE := :NEW.ISFORAU;
  new$ISFORKS DFACCOUNTSBUHTABLE.ISFORKS%TYPE := :NEW.ISFORKS;
--
  OldValue$ NUMBER(10);
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CurNum$ NUMBER(10);
  CommonBudget$ NUMBER(10);
  RegionCLS$ NUMBER(10);
  checkUseAU$ NUMBER(10);
  countForBudget1$ NUMBER(10);
  countForBusiness1$ NUMBER(10);
  countForTemporary1$ NUMBER(10);
  countForBU_AU1$ NUMBER(10);
  countForTemporaryBU_AU1$ NUMBER(10);
  countForAU1$ NUMBER(10);
  countForKS$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_DFACCOUNTSBUHTABLE_BI_0)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  if (new$SingleID is null) then 
    select g_shared.nextval into new$SingleID from dual;
  END IF;
  if (new$CurrencyCls is null) then
    GetIntConst(19, 4,CurNum$);
    if (CurNum$ is null) then 
      new$CurrencyCls:= 2;
         
    else 
      new$CurrencyCls:= CurNum$;
     
    END IF;
  END IF;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$isForBudget is null) then 
    new$isForBudget:= 0;
  END IF;
  if (new$isForBusiness is null) then 
    new$isForBusiness:= 0;
  END IF;
  if (new$isForTemporary is null) then 
    new$isForTemporary:= 0;
  END IF;
  if (new$isForBU_AU is null) then 
    new$isForBU_AU:= 0;
  END IF;
  if (new$isCommon is null) then 
    new$isCommon := 0;
  END IF;
  if (new$isDeposit is null) then 
    new$isDeposit := 0;
  END IF;
  if (new$isForCash is null) then 
    new$isForCash := 0;
  END IF;
  if (new$isForTemporaryBU_AU is null) then 
    new$isForTemporaryBU_AU := 0;
  END IF;
  if (new$isForAU is null) then 
    new$isForAU := 0;
  END IF;
  if (new$IsForKs is null) then 
    new$IsForKs := 0;
  END IF;
  getintconst(30, 44,checkUseAU$);
  if (checkUseAU$ <> 1) then 
    new$isForAU := new$isForBU_AU;
  END IF;
   
  /*    */
  if ((new$isForBudget = 0)and(new$isForBusiness = 0)and(new$isForTemporary = 0)
  and(new$isForBU_AU = 0)and(new$isDeposit = 0)and(new$isForTemporaryBU_AU = 0)and(new$isForAU = 0)and(new$IsForKs = 0)) then
    new$isForBudget := 1;
  END IF;
  if ((new$isCommon = 1)and(new$IsForBudget=1)) then
    /*       */
    GetIntConst(-1,3,CommonBudget$);
    if (new$BudgetRef = CommonBudget$) then
      SELECT COUNT(constValue ) INTO CNT$1
      from intconst where ((progindex = -1) and (constindex = 2)) AND (ROWNUM = 1);
      if ((CNT$1<> 0)) then
        Update intconst
        set Constvalue = new$ID
        where (progindex = -1) and (constindex = 2);
                
      else
        INSERT INTO INTCONST (PROGINDEX, CONSTINDEX, CONSTVALUE)
        VALUES (-1, 2, new$ID);
                
      END IF;  
    END IF;
  END IF;
  if ((new$isCommon = 1)and(new$IsForBusiness=1)) then
    /*   \    */
    GetIntConst(-1,3,CommonBudget$);
    if (new$BudgetRef = CommonBudget$) then
      SELECT COUNT(constValue ) INTO CNT$2
      from intconst where ((progindex = 30) and (constindex = 17)) AND (ROWNUM = 1);
      if ((CNT$2<> 0)) then
        Update intconst
        set Constvalue = new$ID
        where (progindex = 30) and (constindex = 17);
                
      else
        INSERT INTO INTCONST (PROGINDEX, CONSTINDEX, CONSTVALUE)
        VALUES (30, 17, new$ID);
                
      END IF;  
    END IF;
  END IF;
  if (new$RegionCLS is null) then
    BEGIN
      select o.RegionCls     into RegionCLS$ from Organizations o where o.ID =
      (select oa.Org_Ref from Org_Accounts oa where oa.ID = new$ID)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not (RegionCLS$  is null)) then
      new$RegionCLS := RegionCLS$;
          
    else
      new$RegionCLS := 0;
      
    END IF;
  END IF;
  if (new$FacialAcc_ADB is null) then 
    new$FacialAcc_ADB := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_300 (TR_DFACCOUNTSBUHTABLE_BI_300)
-- Create 13.05.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$IFS IS NULL) THEN
      --  ,            
      SELECT MAX (IFS)
        INTO OldValue$
        FROM DFACCOUNTSBUHTABLE df
       WHERE df.ID = new$ID;

      IF ((OldValue$ IS NOT NULL) AND (OldValue$ <> 0)) THEN
         new$IFS := OldValue$;
      END IF;
   END IF;

   IF (new$CURRENCYCLS IS NULL) THEN
      SELECT MAX (CURRENCYCLS)
        INTO OldValue$
        FROM DFACCOUNTSBUHTABLE df
       WHERE df.ID = new$ID;

      IF ((OldValue$ IS NOT NULL) AND (OldValue$ <> 0)) THEN
         new$CURRENCYCLS := OldValue$;
      END IF;
   END IF;

   IF (new$TREASURYACCREF IS NULL) THEN
      SELECT MAX (TREASURYACCREF)
        INTO OldValue$
        FROM DFACCOUNTSBUHTABLE df
       WHERE df.ID = new$ID;

      IF ((OldValue$ IS NOT NULL) AND (OldValue$ <> 0)) THEN
         new$TREASURYACCREF := OldValue$;
      END IF;
   END IF;

   IF (new$FINORGACCREF IS NULL) THEN
      SELECT MAX (FINORGACCREF)
        INTO OldValue$
        FROM DFACCOUNTSBUHTABLE df
       WHERE df.ID = new$ID;

      IF ((OldValue$ IS NOT NULL) AND (OldValue$ <> 0)) THEN
         new$FINORGACCREF := OldValue$;
      END IF;
   END IF;

   UPDATE DFACCOUNTSBUHTABLE
      SET IFS = new$IFS,
          CURRENCYCLS = new$CURRENCYCLS,
          TREASURYACCREF = new$TREASURYACCREF,
          FINORGACCREF = new$FINORGACCREF
    WHERE (ID = new$id)
      AND (BUDGETREF <> new$BUDGETREF)
      AND (   (IFS <> new$IFS)
           OR (CURRENCYCLS <> new$CURRENCYCLS)
           OR (TREASURYACCREF <> new$TREASURYACCREF)
           OR (FINORGACCREF <> new$FINORGACCREF)
          );

-- - - - - - - - - - - - -
-- BI_500 (TR_DFACCOUNTSBUHTABLE_BI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_DFACCOUNTSBUHTABLE (
    BUDGETREF,
    ID,
    BUHACC,
    ACCMODE,
    FIXED,
    CREATEDATE,
    UPDATEDATE,
    CURRENCYCLS,
    TREASURYACCREF,
    FINORGACCREF,
    IFS,
    SINGLEID,
    ISCOMMON,
    ISFORBUDGET,
    ISFORBUSINESS,
    ISFORTEMPORARY,
    ISFORCASH,
    CREATERUSER,
    UPDATERUSER,
    REGIONCLS,
    ISFORBU_AU,
    ISDEPOSIT,
    FACIALACC_ADB,
    ISFORTEMPORARYBU_AU,
    ISFORAU,
    ISFORKS
  ) VALUES (
    new$BUDGETREF,
    new$ID,
    new$BUHACC,
    new$ACCMODE,
    new$FIXED,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$CURRENCYCLS,
    new$TREASURYACCREF,
    new$FINORGACCREF,
    new$IFS,
    new$SINGLEID,
    new$ISCOMMON,
    new$ISFORBUDGET,
    new$ISFORBUSINESS,
    new$ISFORTEMPORARY,
    new$ISFORCASH,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$REGIONCLS,
    new$ISFORBU_AU,
    new$ISDEPOSIT,
    new$FACIALACC_ADB,
    new$ISFORTEMPORARYBU_AU,
    new$ISFORAU,
    new$ISFORKS);

-- - - - - - - - - - - - -
-- AI_100 (TR_DFACCOUNTSBUHTABLE_AI_100)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /* :            */
  if (new$IsCommon=1) then
    select sum(dfbt.isForBudget),sum(dfbt.isForBusiness),sum(dfbt.isForTemporary),sum(dfbt.isForBU_AU),
    sum(dfbt.isForTemporaryBU_AU),sum(dfbt.isForAU), sum(dfbt.isForKS)
    into countForBudget1$, countForBusiness1$, countForTemporary1$, countForBU_AU1$, countForTemporaryBU_AU1$, countForAU1$, countForKS$         from dfaccountsbuhtable dfbt
    LEFT JOIN Org_Accounts oa ON (dfbt.id =  oa.id)
    where (dfbt.BudgetRef = new$BudgetRef) and (dfbt.isCommon = 1) and ((oa.Closed = 0)or(oa.Closed is null))
    ;
    if ((countForBudget1$  > 1)or(countForBusiness1$  > 1)or(countForTemporary1$  > 1)or(countForBU_AU1$  > 1)
    or(countForTemporaryBU_AU1$  > 1)or(countForAU1$  > 1)or(countForKS$  > 1)) then
      RaiseException('EX_CHECK_common_DFACCBT');   
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_DFACCOUNTSBUHTABLE_AI_500)
-- Last update 29.11.2006
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 73) and (RecordId = new$SingleID);

END;
/
-- CREATE TRIGGER TR_DFACCOUNTSBUHTABLE_AU_100
CREATE OR REPLACE TRIGGER TR_DFACCOUNTSBUHTABLE_IU
  INSTEAD OF UPDATE
  ON DFACCOUNTSBUHTABLE
  FOR EACH ROW
DECLARE
  new$BUDGETREF DFACCOUNTSBUHTABLE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ID DFACCOUNTSBUHTABLE.ID%TYPE := :NEW.ID;
  new$BUHACC DFACCOUNTSBUHTABLE.BUHACC%TYPE := :NEW.BUHACC;
  new$ACCMODE DFACCOUNTSBUHTABLE.ACCMODE%TYPE := :NEW.ACCMODE;
  new$FIXED DFACCOUNTSBUHTABLE.FIXED%TYPE := :NEW.FIXED;
  new$CREATEDATE DFACCOUNTSBUHTABLE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE DFACCOUNTSBUHTABLE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CURRENCYCLS DFACCOUNTSBUHTABLE.CURRENCYCLS%TYPE := :NEW.CURRENCYCLS;
  new$TREASURYACCREF DFACCOUNTSBUHTABLE.TREASURYACCREF%TYPE := :NEW.TREASURYACCREF;
  new$FINORGACCREF DFACCOUNTSBUHTABLE.FINORGACCREF%TYPE := :NEW.FINORGACCREF;
  new$IFS DFACCOUNTSBUHTABLE.IFS%TYPE := :NEW.IFS;
  new$SINGLEID DFACCOUNTSBUHTABLE.SINGLEID%TYPE := :NEW.SINGLEID;
  new$ISCOMMON DFACCOUNTSBUHTABLE.ISCOMMON%TYPE := :NEW.ISCOMMON;
  new$ISFORBUDGET DFACCOUNTSBUHTABLE.ISFORBUDGET%TYPE := :NEW.ISFORBUDGET;
  new$ISFORBUSINESS DFACCOUNTSBUHTABLE.ISFORBUSINESS%TYPE := :NEW.ISFORBUSINESS;
  new$ISFORTEMPORARY DFACCOUNTSBUHTABLE.ISFORTEMPORARY%TYPE := :NEW.ISFORTEMPORARY;
  new$ISFORCASH DFACCOUNTSBUHTABLE.ISFORCASH%TYPE := :NEW.ISFORCASH;
  new$CREATERUSER DFACCOUNTSBUHTABLE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER DFACCOUNTSBUHTABLE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$REGIONCLS DFACCOUNTSBUHTABLE.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$ISFORBU_AU DFACCOUNTSBUHTABLE.ISFORBU_AU%TYPE := :NEW.ISFORBU_AU;
  new$ISDEPOSIT DFACCOUNTSBUHTABLE.ISDEPOSIT%TYPE := :NEW.ISDEPOSIT;
  new$FACIALACC_ADB DFACCOUNTSBUHTABLE.FACIALACC_ADB%TYPE := :NEW.FACIALACC_ADB;
  new$ISFORTEMPORARYBU_AU DFACCOUNTSBUHTABLE.ISFORTEMPORARYBU_AU%TYPE := :NEW.ISFORTEMPORARYBU_AU;
  new$ISFORAU DFACCOUNTSBUHTABLE.ISFORAU%TYPE := :NEW.ISFORAU;
  new$ISFORKS DFACCOUNTSBUHTABLE.ISFORKS%TYPE := :NEW.ISFORKS;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CurNum$ NUMBER(10);
  CommonBudget$ NUMBER(10);
  RegionCLS$ NUMBER(10);
  checkUseAU$ NUMBER(10);
  countForBudget1$ NUMBER(10);
  countForBusiness1$ NUMBER(10);
  countForTemporary1$ NUMBER(10);
  countForBU_AU1$ NUMBER(10);
  countForTemporaryBU_AU1$ NUMBER(10);
  countForAU1$ NUMBER(10);
  countForKS$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_DFACCOUNTSBUHTABLE_BU_0)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  if (new$CurrencyCls is null) then
    GetIntConst(19, 4,CurNum$);
    if (CurNum$ is null) then 
      new$CurrencyCls:= 2;
         
    else 
      new$CurrencyCls:= CurNum$;
     
    END IF;
  END IF;
   
  if (new$isForBudget is null) then 
    new$isForBudget:= 0;
  END IF;
  if (new$isForBusiness is null) then 
    new$isForBusiness:= 0;
  END IF;
  if (new$isForTemporary is null) then 
    new$isForTemporary:= 0;
  END IF;
  if (new$isForBU_AU is null) then 
    new$isForBU_AU:= 0;
  END IF;
  if (new$isCommon is null) then 
    new$isCommon := 0;
  END IF;
  if (new$isDeposit is null) then 
    new$isDeposit := 0;
  END IF;
  if (new$isForCash is null) then 
    new$isForCash := 0;
  END IF;
  if (new$isForTemporaryBU_AU is null) then 
    new$isForTemporaryBU_AU := 0;
  END IF;
  if (new$isForAU is null) then 
    new$isForAU := 0;
  END IF;
  if (new$IsForKs is null) then 
    new$IsForKs := 0;
  END IF;
  getintconst(30, 44,checkUseAU$);
  if (checkUseAU$ <> 1) then 
    new$isForAU := new$isForBU_AU;
  END IF;
   
  /*    */
  if ((new$isForBudget = 0)and(new$isForBusiness = 0)and(new$isForTemporary = 0)
  and(new$isForBU_AU = 0)and(new$isDeposit = 0)and(new$isForTemporaryBU_AU = 0)and(new$isForAU = 0)and(new$IsForKs = 0))then
    new$isForBudget := 1;
  END IF;
  if (((:old.isCommon <> 1) and (new$isCommon = 1)and(new$IsForBudget=1))
  or ((new$isCommon = 1)and(:old.IsForBudget<>1)and(new$IsForBudget=1))) then
    /*       */
    GetIntConst(-1,3,CommonBudget$);
    if (new$BudgetRef = CommonBudget$) then
      SELECT COUNT(constValue ) INTO CNT$1
      from intconst where ((progindex = -1) and (constindex = 2)) AND (ROWNUM = 1);
      if ((CNT$1<> 0)) then
        Update intconst
        set Constvalue = new$ID
        where (progindex = -1) and (constindex = 2);
                
      else
        INSERT INTO INTCONST (PROGINDEX, CONSTINDEX, CONSTVALUE)
        VALUES (-1, 2, new$ID);
                
      END IF; 
    END IF;
  END IF;
  if (((:old.isCommon <> 1) and (new$isCommon = 1)and(new$isForBusiness=1))
  or ((new$isCommon = 1)and(:old.isForBusiness<>1)and(new$isForBusiness=1))) then
    /*   \    */
    GetIntConst(-1,3,CommonBudget$);
    if (new$BudgetRef = CommonBudget$) then
      SELECT COUNT(constValue ) INTO CNT$2
      from intconst where ((progindex = 30) and (constindex = 17)) AND (ROWNUM = 1);
      if ((CNT$2<> 0)) then
        Update intconst
        set Constvalue = new$ID
        where (progindex = 30) and (constindex = 17);
                
      else
        INSERT INTO INTCONST (PROGINDEX, CONSTINDEX, CONSTVALUE)
        VALUES (30, 17, new$ID);
                
      END IF; 
    END IF;
  END IF;
  if (new$RegionCLS is null) then
    BEGIN
      select o.RegionCls     into RegionCLS$ from Organizations o where o.ID =
      (select oa.Org_Ref from Org_Accounts oa where oa.ID = new$ID)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not (RegionCLS$  is null)) then
      new$RegionCLS := RegionCLS$;
          
    else
      new$RegionCLS := 0;
      
    END IF;
  END IF;
  if (new$FacialAcc_ADB is null) then 
    new$FacialAcc_ADB := 0;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_DFACCOUNTSBUHTABLE SET
    BUDGETREF = new$BUDGETREF,
    ID = new$ID,
    BUHACC = new$BUHACC,
    ACCMODE = new$ACCMODE,
    FIXED = new$FIXED,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    CURRENCYCLS = new$CURRENCYCLS,
    TREASURYACCREF = new$TREASURYACCREF,
    FINORGACCREF = new$FINORGACCREF,
    IFS = new$IFS,
    SINGLEID = new$SINGLEID,
    ISCOMMON = new$ISCOMMON,
    ISFORBUDGET = new$ISFORBUDGET,
    ISFORBUSINESS = new$ISFORBUSINESS,
    ISFORTEMPORARY = new$ISFORTEMPORARY,
    ISFORCASH = new$ISFORCASH,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    REGIONCLS = new$REGIONCLS,
    ISFORBU_AU = new$ISFORBU_AU,
    ISDEPOSIT = new$ISDEPOSIT,
    FACIALACC_ADB = new$FACIALACC_ADB,
    ISFORTEMPORARYBU_AU = new$ISFORTEMPORARYBU_AU,
    ISFORAU = new$ISFORAU,
    ISFORKS = new$ISFORKS
  WHERE id = :old.Id and budgetref = :old.budgetref;

-- - - - - - - - - - - - -
-- AU_100 (TR_DFACCOUNTSBUHTABLE_AU_100)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /* :            */
  if (new$IsCommon=1) then
    select sum(dfbt.isForBudget),sum(dfbt.isForBusiness),sum(dfbt.isForTemporary),sum(dfbt.isForBU_AU),
    sum(dfbt.isForTemporaryBU_AU),sum(dfbt.isForAU), sum(dfbt.isForKS)
    into countForBudget1$, countForBusiness1$, countForTemporary1$, countForBU_AU1$, countForTemporaryBU_AU1$, countForAU1$, countForKS$         from dfaccountsbuhtable dfbt
    LEFT JOIN Org_Accounts oa ON (dfbt.id =  oa.id)
    where (dfbt.BudgetRef = new$BudgetRef) and (dfbt.isCommon = 1) and ((oa.Closed = 0)or(oa.Closed is null))
    ;
    if ((countForBudget1$  > 1)or(countForBusiness1$  > 1)or(countForTemporary1$  > 1)or(countForBU_AU1$  > 1)
    or(countForTemporaryBU_AU1$  > 1)or(countForAU1$  > 1)or(countForKS$  > 1)) then
      RaiseException('EX_CHECK_common_DFACCBT');   
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_300 (TR_DFACCOUNTSBUHTABLE_AU_300)
-- Create 13.05.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  update TB_DFACCOUNTSBUHTABLE set
    IFS = new$IFS,
    CURRENCYCLS = new$CURRENCYCLS,
    TREASURYACCREF = new$TREASURYACCREF,
    FINORGACCREF = new$FINORGACCREF
  where
    (id = new$id)and(BUDGETREF <> new$BUDGETREF)and
    ((IFS <> new$IFS)or(CURRENCYCLS <> new$CURRENCYCLS)or
    (TREASURYACCREF <> new$TREASURYACCREF)or(FINORGACCREF <> new$FINORGACCREF));

-- - - - - - - - - - - - -
-- AU_500 (TR_DFACCOUNTSBUHTABLE_AU_500)
-- Create 29.11.2006
-- - - - - - - - - - - - -

  if (new$SingleId <> :old.SingleId) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (73, :Old.SingleId, SYSDATE);
    delete from DelRecIndexes where (TableID = 73) and (RecordId = new$SingleID);
  end if;

END;
/

commit work 
/
ALTER TABLE TB_DfAccountsBuhTable MODIFY(IsForKs NOT NULL)
/

-- #########################################################
-- #########################################################
-- alter_KesrSubCode_Code_50.sql
-- #########################################################
-- #########################################################

/*     50  */
ALTER TABLE KESRSUBCODE DROP CONSTRAINT UQ_KESRSUBCODE_VER_KEY DROP INDEX
/
commit work
/
ALTER TABLE KesrSubCode MODIFY (Code VARCHAR2(50))
/
ALTER TABLE BUDSTRUCTRIGHTS MODIFY (SubKESR VARCHAR2(50))
/
ALTER TABLE BUDSTRUCTRIGHTS MODIFY (SubKESRUp VARCHAR2(50))
/
commit work
/
ALTER TABLE KESRSUBCODE ADD (
  CONSTRAINT UQ_KESRSUBCODE_VER_KEY UNIQUE (CODE, BUDGETREF, EXTID)
)
/
commit work
/

-- #########################################################
-- #########################################################
-- Add_AssignmentKind_UnNot.sql
-- #########################################################
-- #########################################################

/*        , 
*/
ALTER TABLE UnionNotifyDetail ADD (
  AssignmentKind NUMBER(10),
    CHECK((AssignmentKind<=2147483647)AND(AssignmentKind>-2147483648)),
  constraint FK_UnionNotDetail_AssignKind foreign key (AssignmentKind) references AssignmentKind (ID)
)
/
CREATE INDEX FK_UnionNotDetail_AssignKind ON UnionNotifyDetail(AssignmentKind)
/
-- CREATE TRIGGER TR_UNIONNOTIFYDETAIL_BI
CREATE OR REPLACE TRIGGER TR_UNIONNOTIFYDETAIL_BI
  BEFORE INSERT
  ON UNIONNOTIFYDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_UNIONNOTIFYDETAIL_BI)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  IF (:new.ID IS NULL) THEN
    select g_shared.nextval into :new.ID from dual;
  END IF;
  if (:new.kesr is null) then
    :new.kesr := 0;
  END IF;
  if (:new.kvsr is null) then
    :new.kvsr := 0;
  END IF;
  if (:new.kcsr is null) then
    :new.kcsr := 0;
  END IF;
  if (:new.kfsr is null) then
    :new.kfsr := 0;
  END IF;
  if (:new.kvr is null) then
    :new.kvr := 0;
  END IF;
  if (:new.ifs is null) then
    :new.ifs := 0;
  END IF;
  if (:new.ActivityKind is null) then
    :new.ActivityKind := 0;
  END IF;
  if (:new.Fact is null) then
    :new.Fact := 0;
  END IF;
  if (:new.MeansType is null) then
    :new.MeansType := 0;
  END IF;
  if (:new.DirectionCLS is null) then
    :new.DirectionCLS := 0;
  END IF;
  if (:new.RegionCLS is null) then
    :new.RegionCLS := 0;
  END IF;
  if (:new.SubKESR is null) then
    :new.SubKESR := 0;
  END IF;
  if (:new.FinType is null) then
    :new.FinType := 0;
  END IF;
  if (:new.AssignmentKind is null) then
    :new.AssignmentKind := 0;
  END IF;
  if (:new.summalimit is null) then
    :new.summalimit := 0;
  END IF;
  if (:new.summaassignment is null) then
    :new.summaassignment := 0;
  END IF;
  if (:new.summafin is null) then
    :new.summafin := 0;
  END IF;
  if (:new.SummaLimitYear is null) then
    :new.SummaLimitYear := 0;
  END IF;
  if (:new.SummaAssignmentYear is null) then
    :new.SummaAssignmentYear := 0;
  END IF;
  if (:new.SummaFinYear is null) then
    :new.SummaFinYear := 0;
  END IF;
  if (:new.SummaYear1 is null) then
    :new.SummaYear1 := 0;
  END IF;
  if (:new.SummaYear2 is null) then
    :new.SummaYear2 := 0;
  END IF;
  if (:new.SummaYear3 is null) then
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0;
  END IF;
  if (:new.BA_LBO_Flag is null) then
    :new.BA_LBO_Flag := 0;
  END IF;
  if (:new.BuhOperationCLS is null) then
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;
  if (:new.ClsType is null) then
    BEGIN
      select
      c.ClsType
      into :new.ClsType     from
      UnionNotifyCaption c
      where
      (c.id = :new.RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_UNIONNOTIFYDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is null) then
    if (:new.IFS <> 0) then
      :new.ClsType := 1;
          
    else
      :new.ClsType := 0;
      
    END IF;
  END IF;
  if ((:new.ClsType = 0)and(:new.IFS <> 0)) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if ((:new.ClsType = 1)and((:new.KVSR <> 0)or(:new.KCSR <> 0)or(:new.KVR <> 0)or
  (:new.KFSR <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_UNIONNOTIFYDETAIL_BI_500)
-- Create 15.02.2006
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;
  :NEW.CreaterUser := USER;
  :NEW.UpdaterUser := USER;

END;
/
-- CREATE TRIGGER TR_UNIONNOTIFYDETAIL_BU
CREATE OR REPLACE TRIGGER TR_UNIONNOTIFYDETAIL_BU
  BEFORE UPDATE
  ON UNIONNOTIFYDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_UNIONNOTIFYDETAIL_BU)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  if (:new.kesr is null) then
    :new.kesr := 0;
  END IF;
  if (:new.kvsr is null) then
    :new.kvsr := 0;
  END IF;
  if (:new.kcsr is null) then
    :new.kcsr := 0;
  END IF;
  if (:new.kfsr is null) then
    :new.kfsr := 0;
  END IF;
  if (:new.kvr is null) then
    :new.kvr := 0;
  END IF;
  if (:new.ifs is null) then
    :new.ifs := 0;
  END IF;
  if (:new.ActivityKind is null) then
    :new.ActivityKind := 0;
  END IF;
  if (:new.Fact is null) then
    :new.Fact := 0;
  END IF;
  if (:new.MeansType is null) then
    :new.MeansType := 0;
  END IF;
  if (:new.DirectionCLS is null) then
    :new.DirectionCLS := 0;
  END IF;
  if (:new.RegionCLS is null) then
    :new.RegionCLS := 0;
  END IF;
  if (:new.SubKESR is null) then
    :new.SubKESR := 0;
  END IF;
  if (:new.FinType is null) then
    :new.FinType := 0;
  END IF;
  if (:new.AssignmentKind is null) then
    :new.AssignmentKind := 0;
  END IF;
  if (:new.summalimit is null) then
    :new.summalimit := 0;
  END IF;
  if (:new.summaassignment is null) then
    :new.summaassignment := 0;
  END IF;
  if (:new.summafin is null) then
    :new.summafin := 0;
  END IF;
  if (:new.SummaLimitYear is null) then
    :new.SummaLimitYear := 0;
  END IF;
  if (:new.SummaAssignmentYear is null) then
    :new.SummaAssignmentYear := 0;
  END IF;
  if (:new.SummaFinYear is null) then
    :new.SummaFinYear := 0;
  END IF;
  if (:new.SummaYear1 is null) then
    :new.SummaYear1 := 0;
  END IF;
  if (:new.SummaYear2 is null) then
    :new.SummaYear2 := 0;
  END IF;
  if (:new.SummaYear3 is null) then
    :new.SummaYear3 := 0;
  END IF;
  IF (:new.SummaYear4 IS NULL) THEN  
    :new.SummaYear4 := 0;
  END IF;
  IF (:new.SummaOtherYears IS NULL) THEN  
    :new.SummaOtherYears := 0;
  END IF;
  if (:new.BA_LBO_Flag is null) then
    :new.BA_LBO_Flag := 0;
  END IF;
  if (:new.BuhOperationCLS is null) then
    GetIntConst(60, 15,:new.BuhOperationCLS);
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_UNIONNOTIFYDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if (:new.ClsType is null) then
    if (:new.IFS <> 0) then
      :new.ClsType := 1;
          
    else
      :new.ClsType := 0;
      
    END IF;
  END IF;
  if ((:new.ClsType = 0)and(:new.IFS <> 0)) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  if ((:new.ClsType = 1)and((:new.KVSR <> 0)or(:new.KCSR <> 0)or(:new.KVR <> 0)or
  (:new.KFSR <> 0))) then
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_UNIONNOTIFYDETAIL_BU_700)
-- Create 15.02.2006
-- - - - - - - - - - - - -

  if (:New.RVersion is null) then
    :New.RVersion := 1;
  elsif ((:New.RVersion = -1) and (:Old.RVersion <> -1)) then
    :New.RVersion := :Old.RVersion;
  else
    :New.RVersion := :Old.RVersion + 1;
  end if;

END;
/
ALTER TRIGGER TR_UNIONNOTIFYDETAIL_BU_500 DISABLE
/
update UnionNotifyDetail set
  AssignmentKind = 0
/
ALTER TRIGGER TR_UNIONNOTIFYDETAIL_BU_500 ENABLE
/

commit work 
/
ALTER TABLE UnionNotifyDetail MODIFY(AssignmentKind NOT NULL)
/

-- #########################################################
-- #########################################################
-- alter_SubsidyCls_CurrentYear.sql
-- #########################################################
-- #########################################################

/*     -    ,       .
      ,    */
-- ALTER TRIGGER tr_subsidycls_bi
CREATE OR REPLACE TRIGGER TR_SUBSIDYCLS_BI
  BEFORE INSERT
  ON SUBSIDYCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_SubsidyCLS_BI)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.SubsidyKind is null) then 
    :new.SubsidyKind := 0;
  END IF;
  if (:new.BelongingKind is null) then
    :new.BelongingKind := 0;
  END IF;
  if (:new.SubsidyYear is null) then
    if (:new.StartDate is not null) then
      :new.SubsidyYear := Extract(Year from :new.StartDate);
          
    else
      GetIntConst(-1, 73,:new.SubsidyYear);
      
    END IF;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.DocumentCLS is Null) then
    :new.DocumentCLS := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_SubsidyCLS_BI_500)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER tr_subsidycls_bu
CREATE OR REPLACE TRIGGER TR_SUBSIDYCLS_BU
  BEFORE UPDATE
  ON SUBSIDYCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_SubsidyCLS_BU)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.SubsidyKind is null) then 
    :new.SubsidyKind := 0;
  END IF;
  if (:new.BelongingKind is null) then
    :new.BelongingKind := 0;
  END IF;
  if (:new.SubsidyYear is null) then
    if (:new.StartDate is not null) then
      :new.SubsidyYear := Extract(Year from :new.StartDate);
          
    else
      GetIntConst(-1, 73,:new.SubsidyYear);
      
    END IF;
  END IF;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_AT_BU10_Triggers.sql
-- #########################################################
-- #########################################################

/*       ,      .      
*/
-- CREATE TRIGGER TR_AGREEMENTS_BU_10
CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
  new$EXECUTERSTOREDPROPS AGREEMENTS.EXECUTERSTOREDPROPS%TYPE := :NEW.EXECUTERSTOREDPROPS;
  new$AUTOSANCTION AGREEMENTS.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
  new$PURCHASECODE AGREEMENTS.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$DOCUMENTNUMBER AGREEMENTS.DOCUMENTNUMBER%TYPE := :NEW.DOCUMENTNUMBER;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$TENDERREF AGREEMENTS.TENDERREF%TYPE := :NEW.TENDERREF;
  new$TENDERINNERNUMBER AGREEMENTS.TENDERINNERNUMBER%TYPE := :NEW.TENDERINNERNUMBER;
  new$STOREDCONTENT AGREEMENTS.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$TREASURYSUPPORTID AGREEMENTS.TREASURYSUPPORTID%TYPE := :NEW.TREASURYSUPPORTID;
  new$ISKS AGREEMENTS.ISKS%TYPE := :NEW.ISKS;
  new$ROOTDOC AGREEMENTS.ROOTDOC%TYPE := :NEW.ROOTDOC;
--
  CNT$1 NUMBER(10);
  CountAcc$ NUMBER(10);
  DetCount1$ NUMBER(10);
  previousAccept1$ NUMBER(10);
  previousAcceptDate1$ NUMBER(10);
  previousLastAdjustment$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*   14.0*/
  /*    -*/
  if (new$CardAdvancePercent is null) then
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then
    new$client_ref := 0;
  END IF;
  if (new$IsKs is null) then
    new$isks := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount1$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount1$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /*   */
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  /*    .  */

  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*     30.  id */

  new$TenderInnerNumber := null;
  if (new$TenderRef is not null) then
    BEGIN
      select InnerNumber
      into new$TenderInnerNumber     from TenderCaption
      where id = new$TenderRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*   14.20*/
  /* ,      ,   */
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber) or
  (new$AgreementType <> :old.AgreementType)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*   */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$Accepted = 1) then
    BEGIN
      /*             */
      select Accepted, AcceptDate, LastAdjustment
      into previousAccept1$, previousAcceptDate1$, previousLastAdjustment$       from Agreements
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept1$ = 0 or (previousAcceptDate1$ is null) or (previousLastAdjustment$ = 0))) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
      
  END IF;
  /*  ,     LastAccepted*/
  if ((:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1)) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if ((:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1)) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_AGR_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_AGR_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
          
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;

  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID is not null) and (:old.rnClientID is null or new$rnClientID <> :old.rnClientID)) or
  ((new$rnYear is not null) and (:old.rnYear is null or new$rnYear <> :old.rnYear)) or
  ((new$rnNumber is not null) and (:old.rnNumber is null or new$rnNumber <> :old.rnNumber))) then
    RaiseException('ex_UsedOldFieldRNUM');
  END IF;

-- - - - - - - - - - - - -
-- BU_600 (agreements_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER,
    EXECUTERSTOREDPROPS = new$EXECUTERSTOREDPROPS,
    AUTOSANCTION = new$AUTOSANCTION,
    PURCHASECODE = new$PURCHASECODE,
    DOCUMENTNUMBER = new$DOCUMENTNUMBER,
    REJECTCAUSE = new$REJECTCAUSE,
    TENDERREF = new$TENDERREF,
    TENDERINNERNUMBER = new$TENDERINNERNUMBER,
    STOREDCONTENT = new$STOREDCONTENT,
    PURPORTDOC = new$PURPORTDOC,
    TREASURYSUPPORTID = new$TREASURYSUPPORTID,
    ISKS = new$ISKS,
    ROOTDOC = new$ROOTDOC
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*      */
  /*     ,       */
  /*        */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update Agreements set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*              */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and ((:old.LastAdjustment = 1) or (new$LastAdjustment = 1))) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/
-- CREATE TRIGGER TR_PAYMENTSCHEDULE_BU_10
CREATE OR REPLACE TRIGGER TR_PAYMENTSCHEDULE_IU
  INSTEAD OF UPDATE
  ON PAYMENTSCHEDULE
  FOR EACH ROW
DECLARE
  new$ID PAYMENTSCHEDULE.ID%TYPE := :NEW.ID;
  new$ANUMBER PAYMENTSCHEDULE.ANUMBER%TYPE := :NEW.ANUMBER;
  new$PARENTNUMBER PAYMENTSCHEDULE.PARENTNUMBER%TYPE := :NEW.PARENTNUMBER;
  new$KFSR PAYMENTSCHEDULE.KFSR%TYPE := :NEW.KFSR;
  new$KESR PAYMENTSCHEDULE.KESR%TYPE := :NEW.KESR;
  new$KVSR PAYMENTSCHEDULE.KVSR%TYPE := :NEW.KVSR;
  new$KCSR PAYMENTSCHEDULE.KCSR%TYPE := :NEW.KCSR;
  new$KVR PAYMENTSCHEDULE.KVR%TYPE := :NEW.KVR;
  new$MONTH01 PAYMENTSCHEDULE.MONTH01%TYPE := :NEW.MONTH01;
  new$MONTH02 PAYMENTSCHEDULE.MONTH02%TYPE := :NEW.MONTH02;
  new$MONTH03 PAYMENTSCHEDULE.MONTH03%TYPE := :NEW.MONTH03;
  new$MONTH04 PAYMENTSCHEDULE.MONTH04%TYPE := :NEW.MONTH04;
  new$MONTH05 PAYMENTSCHEDULE.MONTH05%TYPE := :NEW.MONTH05;
  new$MONTH06 PAYMENTSCHEDULE.MONTH06%TYPE := :NEW.MONTH06;
  new$MONTH07 PAYMENTSCHEDULE.MONTH07%TYPE := :NEW.MONTH07;
  new$MONTH08 PAYMENTSCHEDULE.MONTH08%TYPE := :NEW.MONTH08;
  new$MONTH09 PAYMENTSCHEDULE.MONTH09%TYPE := :NEW.MONTH09;
  new$MONTH10 PAYMENTSCHEDULE.MONTH10%TYPE := :NEW.MONTH10;
  new$MONTH11 PAYMENTSCHEDULE.MONTH11%TYPE := :NEW.MONTH11;
  new$MONTH12 PAYMENTSCHEDULE.MONTH12%TYPE := :NEW.MONTH12;
  new$SUMMA PAYMENTSCHEDULE.SUMMA%TYPE := :NEW.SUMMA;
  new$REGION PAYMENTSCHEDULE.REGION%TYPE := :NEW.REGION;
  new$SUBKESR PAYMENTSCHEDULE.SUBKESR%TYPE := :NEW.SUBKESR;
  new$MEANSTYPE PAYMENTSCHEDULE.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FINSOURCE PAYMENTSCHEDULE.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE PAYMENTSCHEDULE.FINTYPE%TYPE := :NEW.FINTYPE;
  new$FACT PAYMENTSCHEDULE.FACT%TYPE := :NEW.FACT;
  new$FACIALACC_CLS PAYMENTSCHEDULE.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$CREATERUSER PAYMENTSCHEDULE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE PAYMENTSCHEDULE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE PAYMENTSCHEDULE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER PAYMENTSCHEDULE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF PAYMENTSCHEDULE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$ACCEPTDATE PAYMENTSCHEDULE.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$LASTADJUSTMENT PAYMENTSCHEDULE.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$ACCEPTED PAYMENTSCHEDULE.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED PAYMENTSCHEDULE.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$PROMISETYPE PAYMENTSCHEDULE.PROMISETYPE%TYPE := :NEW.PROMISETYPE;
  new$ADJUSTMENTREF PAYMENTSCHEDULE.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$SUMMAPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAPREVIOUSYEAR%TYPE := :NEW.SUMMAPREVIOUSYEAR;
  new$SUMMAFINPREVIOUSYEAR PAYMENTSCHEDULE.SUMMAFINPREVIOUSYEAR%TYPE := :NEW.SUMMAFINPREVIOUSYEAR;
  new$QUARTER1 PAYMENTSCHEDULE.QUARTER1%TYPE := :NEW.QUARTER1;
  new$QUARTER2 PAYMENTSCHEDULE.QUARTER2%TYPE := :NEW.QUARTER2;
  new$QUARTER3 PAYMENTSCHEDULE.QUARTER3%TYPE := :NEW.QUARTER3;
  new$QUARTER4 PAYMENTSCHEDULE.QUARTER4%TYPE := :NEW.QUARTER4;
  new$RECORDINDEX PAYMENTSCHEDULE.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$CRYPTOSTATUS PAYMENTSCHEDULE.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID PAYMENTSCHEDULE.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID PAYMENTSCHEDULE.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DIRECTIONCLS PAYMENTSCHEDULE.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$RVERSION PAYMENTSCHEDULE.RVERSION%TYPE := :NEW.RVERSION;
  new$BUHOPERATIONCLS PAYMENTSCHEDULE.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$MONTH01DELTA PAYMENTSCHEDULE.MONTH01DELTA%TYPE := :NEW.MONTH01DELTA;
  new$MONTH02DELTA PAYMENTSCHEDULE.MONTH02DELTA%TYPE := :NEW.MONTH02DELTA;
  new$MONTH03DELTA PAYMENTSCHEDULE.MONTH03DELTA%TYPE := :NEW.MONTH03DELTA;
  new$MONTH04DELTA PAYMENTSCHEDULE.MONTH04DELTA%TYPE := :NEW.MONTH04DELTA;
  new$MONTH05DELTA PAYMENTSCHEDULE.MONTH05DELTA%TYPE := :NEW.MONTH05DELTA;
  new$MONTH06DELTA PAYMENTSCHEDULE.MONTH06DELTA%TYPE := :NEW.MONTH06DELTA;
  new$MONTH07DELTA PAYMENTSCHEDULE.MONTH07DELTA%TYPE := :NEW.MONTH07DELTA;
  new$MONTH08DELTA PAYMENTSCHEDULE.MONTH08DELTA%TYPE := :NEW.MONTH08DELTA;
  new$MONTH09DELTA PAYMENTSCHEDULE.MONTH09DELTA%TYPE := :NEW.MONTH09DELTA;
  new$MONTH10DELTA PAYMENTSCHEDULE.MONTH10DELTA%TYPE := :NEW.MONTH10DELTA;
  new$MONTH11DELTA PAYMENTSCHEDULE.MONTH11DELTA%TYPE := :NEW.MONTH11DELTA;
  new$MONTH12DELTA PAYMENTSCHEDULE.MONTH12DELTA%TYPE := :NEW.MONTH12DELTA;
  new$QUARTER1DELTA PAYMENTSCHEDULE.QUARTER1DELTA%TYPE := :NEW.QUARTER1DELTA;
  new$QUARTER2DELTA PAYMENTSCHEDULE.QUARTER2DELTA%TYPE := :NEW.QUARTER2DELTA;
  new$QUARTER3DELTA PAYMENTSCHEDULE.QUARTER3DELTA%TYPE := :NEW.QUARTER3DELTA;
  new$QUARTER4DELTA PAYMENTSCHEDULE.QUARTER4DELTA%TYPE := :NEW.QUARTER4DELTA;
  new$SUMMADELTA PAYMENTSCHEDULE.SUMMADELTA%TYPE := :NEW.SUMMADELTA;
  new$NOTE PAYMENTSCHEDULE.NOTE%TYPE := :NEW.NOTE;
  new$FINYEAR PAYMENTSCHEDULE.FINYEAR%TYPE := :NEW.FINYEAR;
  new$SUMMAYEAR2 PAYMENTSCHEDULE.SUMMAYEAR2%TYPE := :NEW.SUMMAYEAR2;
  new$SUMMAYEAR3 PAYMENTSCHEDULE.SUMMAYEAR3%TYPE := :NEW.SUMMAYEAR3;
  new$SUMMAYEAR2DELTA PAYMENTSCHEDULE.SUMMAYEAR2DELTA%TYPE := :NEW.SUMMAYEAR2DELTA;
  new$SUMMAYEAR3DELTA PAYMENTSCHEDULE.SUMMAYEAR3DELTA%TYPE := :NEW.SUMMAYEAR3DELTA;
  new$ASSIGNMENTKIND PAYMENTSCHEDULE.ASSIGNMENTKIND%TYPE := :NEW.ASSIGNMENTKIND;
  new$TRANSFERTCLS PAYMENTSCHEDULE.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SENDERIDKEY PAYMENTSCHEDULE.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY PAYMENTSCHEDULE.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$EXECUTIONREF PAYMENTSCHEDULE.EXECUTIONREF%TYPE := :NEW.EXECUTIONREF;
  new$INNERPROMISENUM PAYMENTSCHEDULE.INNERPROMISENUM%TYPE := :NEW.INNERPROMISENUM;
  new$ADJUSTMENTNUMBER PAYMENTSCHEDULE.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$PROMISENUMBER PAYMENTSCHEDULE.PROMISENUMBER%TYPE := :NEW.PROMISENUMBER;
  new$SUBSIDYCLS PAYMENTSCHEDULE.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$AGREEMENTREF PAYMENTSCHEDULE.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$BUDALLOCATIONCLS PAYMENTSCHEDULE.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS PAYMENTSCHEDULE.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$PROGINDEX PAYMENTSCHEDULE.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$INVESTOBJECT PAYMENTSCHEDULE.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$SUMMAYEAR4 PAYMENTSCHEDULE.SUMMAYEAR4%TYPE := :NEW.SUMMAYEAR4;
  new$SUMMAOTHERYEARS PAYMENTSCHEDULE.SUMMAOTHERYEARS%TYPE := :NEW.SUMMAOTHERYEARS;
  new$SUMMAYEAR4DELTA PAYMENTSCHEDULE.SUMMAYEAR4DELTA%TYPE := :NEW.SUMMAYEAR4DELTA;
  new$SUMMAOTHERYEARSDELTA PAYMENTSCHEDULE.SUMMAOTHERYEARSDELTA%TYPE := :NEW.SUMMAOTHERYEARSDELTA;
  new$CONTRACTCOSTSCLS PAYMENTSCHEDULE.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS PAYMENTSCHEDULE.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$OLDNUMBER PAYMENTSCHEDULE.OLDNUMBER%TYPE := :NEW.OLDNUMBER;
  new$PAYMENTCODETYPE PAYMENTSCHEDULE.PAYMENTCODETYPE%TYPE := :NEW.PAYMENTCODETYPE;
  new$REGPROJECTRESULT PAYMENTSCHEDULE.REGPROJECTRESULT%TYPE := :NEW.REGPROJECTRESULT;
  new$PAYTARGETFUNDS PAYMENTSCHEDULE.PAYTARGETFUNDS%TYPE := :NEW.PAYTARGETFUNDS;
  new$ANALYTICALPARTITION PAYMENTSCHEDULE.ANALYTICALPARTITION%TYPE := :NEW.ANALYTICALPARTITION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  M011$ NUMBER;
  M021$ NUMBER;
  M031$ NUMBER;
  M041$ NUMBER;
  M051$ NUMBER;
  M061$ NUMBER;
  M071$ NUMBER;
  M081$ NUMBER;
  M091$ NUMBER;
  M101$ NUMBER;
  M111$ NUMBER;
  M121$ NUMBER;
  Q11$ NUMBER;
  Q21$ NUMBER;
  Q31$ NUMBER;
  Q41$ NUMBER;
  S5$ NUMBER;
  S21$ NUMBER;
  S31$ NUMBER;
  S41$ NUMBER;
  SOther1$ NUMBER;
  previousAccept1$ NUMBER(10);
  previousAcceptDate1$ NUMBER(10);
  previousLastAdjustment$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_PAYMENTSCHEDULE_BU)
-- Version 14.00.00.2
-- - - - - - - - - - - - -

  /*   2.4*/
  /*    -*/
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  if (new$PromiseType is null) then
    new$PromiseType := 0;
  END IF;
  if (new$KFSR is null) then
    new$KFSR := 0;
  END IF;
  if (new$KVSR is null) then
    new$KVSR := 0;
  END IF;
  if (new$KCSR is null) then
    new$KCSR := 0;
  END IF;
  if (new$KVR is null) then
    new$KVR := 0;
  END IF;
  if (new$SubKESR is null) then
    new$SubKESR := 0;
  END IF;
  if (new$AssignmentKind is null) then
    new$AssignmentKind := 0;
  END IF;

  if (new$DirectionCls is null) then
    new$DirectionCls := 0;
  END IF;

  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Region is null) then
    new$Region := 0;
  END IF;
  if (new$MeansType is null) then
    new$MeansType := 0;
  END IF;
  if (new$FinSource is null) then
    new$FinSource := 0;
  END IF;
  if (new$FinType is null) then
    new$FinType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$BuhOperationCLS is null) then
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  if (new$Month01 is null) then
    new$Month01 := 0;
  END IF;
  if (new$Month02 is null) then
    new$Month02 := 0;
  END IF;
  if (new$Month03 is null) then
    new$Month03 := 0;
  END IF;
  if (new$Month04 is null) then
    new$Month04 := 0;
  END IF;
  if (new$Month05 is null) then
    new$Month05 := 0;
  END IF;
  if (new$Month06 is null) then
    new$Month06 := 0;
  END IF;
  if (new$Month07 is null) then
    new$Month07 := 0;
  END IF;
  if (new$Month08 is null) then
    new$Month08 := 0;
  END IF;
  if (new$Month09 is null) then
    new$Month09 := 0;
  END IF;
  if (new$Month10 is null) then
    new$Month10 := 0;
  END IF;
  if (new$Month11 is null) then
    new$Month11 := 0;
  END IF;
  if (new$Month12 is null) then
    new$Month12 := 0;
  END IF;
  if (new$Quarter1 is null) then
    new$Quarter1 := 0;
  END IF;
  if (new$Quarter2 is null) then
    new$Quarter2 := 0;
  END IF;
  if (new$Quarter3 is null) then
    new$Quarter3 := 0;
  END IF;
  if (new$Quarter4 is null) then
    new$Quarter4 := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$Month01Delta is null) then
    new$Month01Delta := 0;
  END IF;
  if (new$Month02Delta is null) then
    new$Month02Delta := 0;
  END IF;
  if (new$Month03Delta is null) then
    new$Month03Delta := 0;
  END IF;
  if (new$Month04Delta is null) then
    new$Month04Delta := 0;
  END IF;
  if (new$Month05Delta is null) then
    new$Month05Delta := 0;
  END IF;
  if (new$Month06Delta is null) then
    new$Month06Delta := 0;
  END IF;
  if (new$Month07Delta is null) then
    new$Month07Delta := 0;
  END IF;
  if (new$Month08Delta is null) then
    new$Month08Delta := 0;
  END IF;
  if (new$Month09Delta is null) then
    new$Month09Delta := 0;
  END IF;
  if (new$Month10Delta is null) then
    new$Month10Delta := 0;
  END IF;
  if (new$Month11Delta is null) then
    new$Month11Delta := 0;
  END IF;
  if (new$Month12Delta is null) then
    new$Month12Delta := 0;
  END IF;
  if (new$Quarter1Delta is null) then
    new$Quarter1Delta := 0;
  END IF;
  if (new$Quarter2Delta is null) then
    new$Quarter2Delta := 0;
  END IF;
  if (new$Quarter3Delta is null) then
    new$Quarter3Delta := 0;
  END IF;
  if (new$Quarter4Delta is null) then
    new$Quarter4Delta := 0;
  END IF;
  if (new$SummaDelta is null) then
    new$SummaDelta := 0;
  END IF;
  if (new$SummaPreviousYear is null) then
    new$SummaPreviousYear := 0;
  END IF;
  if (new$SummaFinPreviousYear is null) then
    new$SummaFinPreviousYear := 0;
  END IF;

  if (new$SummaYear2 is null) then
    new$SummaYear2 := 0;
  END IF;
  if (new$SummaYear3 is null) then
    new$SummaYear3 := 0;
  END IF;
  if (new$SummaYear4 is null) then
    new$SummaYear4 := 0;
  END IF;
  if (new$SummaOtherYears is null) then
    new$SummaOtherYears := 0;
  END IF;

  if (new$SummaYear2Delta is null) then
    new$SummaYear2Delta := 0;
  END IF;
  if (new$SummaYear3Delta is null) then
    new$SummaYear3Delta := 0;
  END IF;
  if (new$SummaYear4Delta is null) then
    new$SummaYear4Delta := 0;
  END IF;
  if (new$SummaOtherYearsDelta is null) then
    new$SummaOtherYearsDelta := 0;
  END IF;

  /*   ,        */
  if (new$ProgIndex = 304 and new$RecordIndex is not null and (:old.RecordIndex is null or :old.RecordIndex <> new$RecordIndex)) then
    SELECT COUNT(*) INTO CNT$1
    from AgreementSteps s where (s.Id = new$RecordIndex and s.RecordIndex = new$AgreementRef) AND (ROWNUM = 1);
    if (not (CNT$1<> 0)) then
      RaiseException('Ex_WrongStep');
    END IF;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      RaiseException('Ex_CantModufyBudget');
    END IF;
  END IF;
  if ((:old.ANumber is null) and (new$ANumber is not Null)) then
    SELECT COUNT(                    id
    ) INTO CNT$2
    from
    PaymentSchedule ps
    where
    (                    (ps.ANumber = new$ANumber)
    and
    (ps.BudgetRef = new$BudgetRef)) AND (ROWNUM = 1);
    if ((CNT$2<> 0)) then
      RaiseException('ex_Promise_NumUQ');
    END IF;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);
  /*   */
  GetDocumentKESR(:old.SubKESR, new$SubKESR, new$KESR, new$BudgetRef,new$KESR);

-- - - - - - - - - - - - -
-- BU_1 (TR_PAYMENTSCHEDULE_BU_1)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*   1.0*/    
  new$Quarter1 := new$Month01 + new$Month02 + new$Month03;
  new$Quarter2 := new$Month04 + new$Month05 + new$Month06;
  new$Quarter3 := new$Month07 + new$Month08 + new$Month09;
  new$Quarter4 := new$Month10 + new$Month11 + new$Month12;
  if (new$ProgIndex not in (317,318)) then
    new$Summa := new$Quarter1 + new$Quarter2 + new$Quarter3 + new$Quarter4;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_PAYMENTSCHEDULE_BU_10)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*   14.20*/
  /* ,      ,   */
  if ((new$ANumber <> :old.ANumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$InnerPromiseNum <> :old.InnerPromiseNum) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*   */
  if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and 
  ((new$Accepted = 1) or (new$AcceptDate is null))) then
    BEGIN
      /*             */
      select Accepted, AcceptDate, LastAdjustment
      into previousAccept1$, previousAcceptDate1$, previousLastAdjustment$       from Paymentschedule
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept1$ = 0 or (previousAcceptDate1$ is null) or (previousLastAdjustment$ = 0))) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
        
  END IF;
  /*   ,     LastAccepted*/
  if ((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
              
    else
      RaiseException('EX_BP_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*   ,     LastAdjustment*/
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_BP_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
              
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_PAYMENTSCHEDULE_BU_100)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*           */
  if (new$AdjustmentNumber > 0) then
    BEGIN
      select
      Month01, Month02, Month03, Month04, Month05, Month06,
      Month07, Month08, Month09, Month10, Month11, Month12,
      Quarter1, Quarter2, Quarter3, Quarter4, Summa,
      SummaYear2, SummaYear3, SummaYear4, SummaOtherYears
      into
      M011$, M021$, M031$, M041$, M051$, M061$, M071$, M081$, M091$, M101$, M111$, M121$,
      Q11$, Q21$, Q31$, Q41$, S5$, S21$, S31$, S41$, SOther1$         from
      PaymentSchedule
      where
      ID = new$AdjustmentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;

    new$Month01Delta := new$Month01 - M011$;
    new$Month02Delta := new$Month02 - M021$;
    new$Month03Delta := new$Month03 - M031$;
    new$Month04Delta := new$Month04 - M041$;
    new$Month05Delta := new$Month05 - M051$;
    new$Month06Delta := new$Month06 - M061$;
    new$Month07Delta := new$Month07 - M071$;
    new$Month08Delta := new$Month08 - M081$;
    new$Month09Delta := new$Month09 - M091$;
    new$Month10Delta := new$Month10 - M101$;
    new$Month11Delta := new$Month11 - M111$;
    new$Month12Delta := new$Month12 - M121$;
    new$Quarter1Delta := new$Quarter1 - Q11$;
    new$Quarter2Delta := new$Quarter2 - Q21$;
    new$Quarter3Delta := new$Quarter3 - Q31$;
    new$Quarter4Delta := new$Quarter4 - Q41$;
    new$SummaDelta := new$Summa - S5$;
    new$SummaYear2Delta := new$SummaYear2 - S21$;
    new$SummaYear3Delta := new$SummaYear3 - S31$;
    new$SummaYear4Delta := new$SummaYear4 - S41$;
    new$SummaOtherYearsDelta := new$SummaOtherYears - SOther1$;

  else /*        */
    new$Month01Delta := new$Month01;
    new$Month02Delta := new$Month02;
    new$Month03Delta := new$Month03;
    new$Month04Delta := new$Month04;
    new$Month05Delta := new$Month05;
    new$Month06Delta := new$Month06;
    new$Month07Delta := new$Month07;
    new$Month08Delta := new$Month08;
    new$Month09Delta := new$Month09;
    new$Month10Delta := new$Month10;
    new$Month11Delta := new$Month11;
    new$Month12Delta := new$Month12;
    new$Quarter1Delta := new$Quarter1;
    new$Quarter2Delta := new$Quarter2;
    new$Quarter3Delta := new$Quarter3;
    new$Quarter4Delta := new$Quarter4;
    new$SummaDelta := new$Summa;
    new$SummaYear2Delta := new$SummaYear2;
    new$SummaYear3Delta := new$SummaYear3;
    new$SummaYear4Delta := new$SummaYear4;
    new$SummaOtherYearsDelta := new$SummaOtherYears;

  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_PAYMENTSCHEDULE_BU_200)
-- Version 14.00.00.1
-- - - - - - - - - - - - -

  /*    */
  if (new$Accepted = 0 and new$AcceptDate is not null and :old.Accepted = 1) then
    /*   ,     
         *    ,      */
    FOR REC$1 IN (      select ffc.Reject_Cls  AS DocumentRejectCls from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum
    )
    LOOP
      if (REC$1.DocumentRejectCls is null) then
        RaiseException('Ex_BP_CannotReject');
      END IF;
    END LOOP;
    /* ,         */
    FOR REC$1 IN (      SELECT Count(ps_in.ID)  AS AdjCount FROM PaymentSchedule ps_in
    WHERE (ps_in.InnerPromiseNum = new$InnerPromiseNum)and(ps_in.AdjustmentNumber > new$AdjustmentNumber)
    and (ps_in.Accepted<>0)
    )
    LOOP
      if (REC$1.AdjCount > 0) then
        RaiseException('EX_BP_AdjustmentedCANNOTREJECT');
      END IF;
    END LOOP;
  END IF;
  /*   .       */
  if (new$Accepted = 1 and new$AcceptDate is null and :old.Accepted = 1 and :old.AcceptDate is not null) then
    SELECT COUNT(ffc.id ) INTO CNT$1
    from FacialFinDetail ffd
    left join FacialFinCaption ffc on (ffc.ID = ffd.RecordIndex)
    where ((SourcePromise = new$ANumber and SourceBudgetPromise = new$InnerPromiseNum
    or DestPromise = new$ANumber and DestBudgetPromise = new$InnerPromiseNum)
    and ffc.acceptdate is not null and ffc.Reject_cls is null) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_BP_NOTACCEPTED');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (tr_PaymentSchedule_BU_400)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$AgreementRef <> :old.AgreementRef or new$ExecutionRef <> :old.ExecutionRef) then
    RaiseException('EX_CANTCHANGECAPTIONREF');
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_PAYMENTSCHEDULE_BU_700)
-- Create 14.10.2004
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$RVersion is null) then
    new$RVersion := 1;
  elsif ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
    new$RVersion := :Old.RVersion;
  else
    new$RVersion := :Old.RVersion + 1;
  end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_PAYMENTSCHEDULE SET
    ID = new$ID,
    ANUMBER = new$ANUMBER,
    PARENTNUMBER = new$PARENTNUMBER,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    MONTH01 = new$MONTH01,
    MONTH02 = new$MONTH02,
    MONTH03 = new$MONTH03,
    MONTH04 = new$MONTH04,
    MONTH05 = new$MONTH05,
    MONTH06 = new$MONTH06,
    MONTH07 = new$MONTH07,
    MONTH08 = new$MONTH08,
    MONTH09 = new$MONTH09,
    MONTH10 = new$MONTH10,
    MONTH11 = new$MONTH11,
    MONTH12 = new$MONTH12,
    SUMMA = new$SUMMA,
    REGION = new$REGION,
    SUBKESR = new$SUBKESR,
    MEANSTYPE = new$MEANSTYPE,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    FACT = new$FACT,
    FACIALACC_CLS = new$FACIALACC_CLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    ACCEPTDATE = new$ACCEPTDATE,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    PROMISETYPE = new$PROMISETYPE,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    SUMMAPREVIOUSYEAR = new$SUMMAPREVIOUSYEAR,
    SUMMAFINPREVIOUSYEAR = new$SUMMAFINPREVIOUSYEAR,
    QUARTER1 = new$QUARTER1,
    QUARTER2 = new$QUARTER2,
    QUARTER3 = new$QUARTER3,
    QUARTER4 = new$QUARTER4,
    RECORDINDEX = new$RECORDINDEX,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DIRECTIONCLS = new$DIRECTIONCLS,
    RVERSION = new$RVERSION,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    MONTH01DELTA = new$MONTH01DELTA,
    MONTH02DELTA = new$MONTH02DELTA,
    MONTH03DELTA = new$MONTH03DELTA,
    MONTH04DELTA = new$MONTH04DELTA,
    MONTH05DELTA = new$MONTH05DELTA,
    MONTH06DELTA = new$MONTH06DELTA,
    MONTH07DELTA = new$MONTH07DELTA,
    MONTH08DELTA = new$MONTH08DELTA,
    MONTH09DELTA = new$MONTH09DELTA,
    MONTH10DELTA = new$MONTH10DELTA,
    MONTH11DELTA = new$MONTH11DELTA,
    MONTH12DELTA = new$MONTH12DELTA,
    QUARTER1DELTA = new$QUARTER1DELTA,
    QUARTER2DELTA = new$QUARTER2DELTA,
    QUARTER3DELTA = new$QUARTER3DELTA,
    QUARTER4DELTA = new$QUARTER4DELTA,
    SUMMADELTA = new$SUMMADELTA,
    NOTE = new$NOTE,
    FINYEAR = new$FINYEAR,
    SUMMAYEAR2 = new$SUMMAYEAR2,
    SUMMAYEAR3 = new$SUMMAYEAR3,
    SUMMAYEAR2DELTA = new$SUMMAYEAR2DELTA,
    SUMMAYEAR3DELTA = new$SUMMAYEAR3DELTA,
    ASSIGNMENTKIND = new$ASSIGNMENTKIND,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    EXECUTIONREF = new$EXECUTIONREF,
    INNERPROMISENUM = new$INNERPROMISENUM,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    PROMISENUMBER = new$PROMISENUMBER,
    SUBSIDYCLS = new$SUBSIDYCLS,
    AGREEMENTREF = new$AGREEMENTREF,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    PROGINDEX = new$PROGINDEX,
    INVESTOBJECT = new$INVESTOBJECT,
    SUMMAYEAR4 = new$SUMMAYEAR4,
    SUMMAOTHERYEARS = new$SUMMAOTHERYEARS,
    SUMMAYEAR4DELTA = new$SUMMAYEAR4DELTA,
    SUMMAOTHERYEARSDELTA = new$SUMMAOTHERYEARSDELTA,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    OLDNUMBER = new$OLDNUMBER,
    PAYMENTCODETYPE = new$PAYMENTCODETYPE,
    REGPROJECTRESULT = new$REGPROJECTRESULT,
    PAYTARGETFUNDS = new$PAYTARGETFUNDS,
    ANALYTICALPARTITION = new$ANALYTICALPARTITION
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_10 (TR_PAYMENTSCHEDULE_AU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*      */
  /*        */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update PaymentSchedule set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*              */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and ((:old.LastAdjustment = 1) or (new$LastAdjustment = 1))) then
    update PaymentSchedule set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment    */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update PaymentSchedule set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_PAYMENTSCHEDULE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (113, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=113) and (RecordId=new$ID);
  end if;

END;
/
-- CREATE TRIGGER TR_EXECDOCCAPTION_BU_10
CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_IU
  INSTEAD OF UPDATE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$INFONUMBER EXECUTIONDOCUMENTSCAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$NOTIFYDATE EXECUTIONDOCUMENTSCAPTION.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$MONEYPROMISENUMBER EXECUTIONDOCUMENTSCAPTION.MONEYPROMISENUMBER%TYPE := :NEW.MONEYPROMISENUMBER;
  new$PURPORTDOC EXECUTIONDOCUMENTSCAPTION.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$STOREDCONTENT EXECUTIONDOCUMENTSCAPTION.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
  new$PAYDATE EXECUTIONDOCUMENTSCAPTION.PAYDATE%TYPE := :NEW.PAYDATE;
  new$AUTOSANCTION EXECUTIONDOCUMENTSCAPTION.AUTOSANCTION%TYPE := :NEW.AUTOSANCTION;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CntAgr$ NUMBER(10);
  CntStep$ NUMBER(10);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  CountExecDoc$ NUMBER(10);
  previousAccept1$ NUMBER(10);
  previousAcceptDate1$ NUMBER(10);
  previousLastAdjustment$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_EXECDOCCAPTION_BU)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      SELECT COUNT(                   Id
      ) INTO CNT$1
      from ExecutionDocumentsDetail
      where
      (                   RecordIndex = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$1<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      SELECT COUNT(                   Id
      ) INTO CNT$2
      from PaymentSchedule
      where
      (                   ExecutionRef = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$2<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /* c,           */
  /* ,    */
  if (new$InnerNumber <> :old.InnerNumber or
  new$AdjustmentRef <> :old.AdjustmentRef or
  new$AdjustmentNumber <> :old.AdjustmentNumber) then
    RaiseException('EX_Agr_ChangeInnerNums');
  END IF;
  /*      id */
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_EXECDOCCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_EXECDOCCAPTION_BU_10)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*   14.20*/
  /*   */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$Accepted = 1) then
    BEGIN
      /*             */
      select Accepted, AcceptDate, LastAdjustment
      into previousAccept1$, previousAcceptDate1$, previousLastAdjustment$       from ExecutionDocumentsCaption
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept1$ = 0 or (previousAcceptDate1$ is null) or (previousLastAdjustment$ = 0))) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
      
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
          
    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;
      
  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
          
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_40 (tr_execdoccaption_bu_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if ((:old.AcceptDate is not null) and (new$AcceptDate is null)) then
    select count(ID) into CntAgr$ from Agreements where (CloseDoc = :old.ID) ;
    select count(ID) into CntStep$ from AgreementSteps where (CloseDoc = :old.ID) ;
    if ((CntAgr$ > 0) or (CntStep$ > 0)) then
      RaiseException('ex_CannotUpdateCloseDoc');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_execdoccaption_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_EXECDOCCAPTION_BU_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_EXECDOCCAPTION_BU_210)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  /*   */
  if (new$rejectcls is not null and new$accepted = 0) then
    /*         */
    select
    count(ffd.id)
    into CountExecDoc$     from
    facialfindetail ffd
    left join facialfincaption ffc on ffc.id = ffd.recordindex
    where
    (ffc.acceptdate is not null and (ffd.sourceexecdoc = new$id or ffd.destexecdoc = new$id))
    ;
    /*       */
    if (CountExecDoc$ <> 0) then
      RaiseException('ex_exedoc_useinfacialfindetail');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_EDCAPTION_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_EXECUTIONDOCUMENTSCAPTION SET
    ID = new$ID,
    DOCTYPE = new$DOCTYPE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    SUMMA = new$SUMMA,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    STEPNUMBER = new$STEPNUMBER,
    FACIALACC_CLS = new$FACIALACC_CLS,
    RECIPIENT_REF = new$RECIPIENT_REF,
    REGISTRATIONTYPE = new$REGISTRATIONTYPE,
    REESTRNUMBER = new$REESTRNUMBER,
    AGREEMENTINNERNUMBER = new$AGREEMENTINNERNUMBER,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXECDOCFINSUMMA = new$EXECDOCFINSUMMA,
    FACT = new$FACT,
    DOCNUMBER = new$DOCNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    AGREEMENTREF = new$AGREEMENTREF,
    NOTE = new$NOTE,
    SUPPLIERSTOREDPROPS = new$SUPPLIERSTOREDPROPS,
    SUPPLIER_REF = new$SUPPLIER_REF,
    SUPPLIERACC_REF = new$SUPPLIERACC_REF,
    REJECTCAUSE = new$REJECTCAUSE,
    INFONUMBER = new$INFONUMBER,
    NOTIFYDATE = new$NOTIFYDATE,
    MONEYPROMISENUMBER = new$MONEYPROMISENUMBER,
    PURPORTDOC = new$PURPORTDOC,
    STOREDCONTENT = new$STOREDCONTENT,
    PAYDATE = new$PAYDATE,
    AUTOSANCTION = new$AUTOSANCTION
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_0 (TR_ExecDocCaption_AU)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*       */
  /*     ,       */
  /*        */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*              */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and ((:old.LastAdjustment = 1) or (new$LastAdjustment = 1))) then
    update ExecutionDocuMENTSCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_EXECDOCCAPTION_AU_30)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where ExecutionRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_EXECDOCCAPTION_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (114, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=114) and (RecordId=new$ID);
  end if;

END;
/
-- CREATE TRIGGER TR_TENDERCAPTION_BU_10
CREATE OR REPLACE TRIGGER TR_TENDERCAPTION_IU
  INSTEAD OF UPDATE
  ON TENDERCAPTION
  FOR EACH ROW
DECLARE
  new$ID TENDERCAPTION.ID%TYPE := :NEW.ID;
  new$BUDGETREF TENDERCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FACIALACCCLS TENDERCAPTION.FACIALACCCLS%TYPE := :NEW.FACIALACCCLS;
  new$MULTIPURPOSE TENDERCAPTION.MULTIPURPOSE%TYPE := :NEW.MULTIPURPOSE;
  new$DOCUMENTDATE TENDERCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE TENDERCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$PERIOD TENDERCAPTION.PERIOD%TYPE := :NEW.PERIOD;
  new$ACCEPTSUMMA TENDERCAPTION.ACCEPTSUMMA%TYPE := :NEW.ACCEPTSUMMA;
  new$SALETYPE TENDERCAPTION.SALETYPE%TYPE := :NEW.SALETYPE;
  new$REJECTCLS TENDERCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS TENDERCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID TENDERCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID TENDERCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF TENDERCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$CREATERUSER TENDERCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TENDERCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE TENDERCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER TENDERCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$LASTADJUSTMENT TENDERCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED TENDERCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$ADJUSTMENTREF TENDERCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ACCEPTED TENDERCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$EXPORTDATE TENDERCAPTION.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$YEARACCEPTSUMMA TENDERCAPTION.YEARACCEPTSUMMA%TYPE := :NEW.YEARACCEPTSUMMA;
  new$TENDEROPTION TENDERCAPTION.TENDEROPTION%TYPE := :NEW.TENDEROPTION;
  new$TENDERTARGET TENDERCAPTION.TENDERTARGET%TYPE := :NEW.TENDERTARGET;
  new$RVERSION TENDERCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$ALLOWANCE TENDERCAPTION.ALLOWANCE%TYPE := :NEW.ALLOWANCE;
  new$REFINEMENTCAUSE TENDERCAPTION.REFINEMENTCAUSE%TYPE := :NEW.REFINEMENTCAUSE;
  new$PREFERENCE TENDERCAPTION.PREFERENCE%TYPE := :NEW.PREFERENCE;
  new$PREFERENCESIZE TENDERCAPTION.PREFERENCESIZE%TYPE := :NEW.PREFERENCESIZE;
  new$SECURITY TENDERCAPTION.SECURITY%TYPE := :NEW.SECURITY;
  new$UNKNOWNAMOUNT TENDERCAPTION.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PERIODYEAR TENDERCAPTION.PERIODYEAR%TYPE := :NEW.PERIODYEAR;
  new$SUPPORTUNDERTAKER TENDERCAPTION.SUPPORTUNDERTAKER%TYPE := :NEW.SUPPORTUNDERTAKER;
  new$AYEAR TENDERCAPTION.AYEAR%TYPE := :NEW.AYEAR;
  new$REWORKCAUSE TENDERCAPTION.REWORKCAUSE%TYPE := :NEW.REWORKCAUSE;
  new$NOTE TENDERCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$REALID TENDERCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER TENDERCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTNUMBER TENDERCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$SENDERIDKEY TENDERCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY TENDERCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$PROTOCOLREASON TENDERCAPTION.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$PROGINDEX TENDERCAPTION.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$DOCNUMBER TENDERCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SECURITYTSIZE TENDERCAPTION.SECURITYTSIZE%TYPE := :NEW.SECURITYTSIZE;
  new$SECURITYASIZE TENDERCAPTION.SECURITYASIZE%TYPE := :NEW.SECURITYASIZE;
  new$AVANSSIZE TENDERCAPTION.AVANSSIZE%TYPE := :NEW.AVANSSIZE;
  new$PREFERENCECRIPPLE TENDERCAPTION.PREFERENCECRIPPLE%TYPE := :NEW.PREFERENCECRIPPLE;
  new$PREFERENCERUSPRODUCT TENDERCAPTION.PREFERENCERUSPRODUCT%TYPE := :NEW.PREFERENCERUSPRODUCT;
  new$PREFERENCEPRISON TENDERCAPTION.PREFERENCEPRISON%TYPE := :NEW.PREFERENCEPRISON;
  new$AGREEMENTEXECUTIONDATE TENDERCAPTION.AGREEMENTEXECUTIONDATE%TYPE := :NEW.AGREEMENTEXECUTIONDATE;
  new$PURCHASECODE TENDERCAPTION.PURCHASECODE%TYPE := :NEW.PURCHASECODE;
  new$PURCHASESOCIALNKO TENDERCAPTION.PURCHASESOCIALNKO%TYPE := :NEW.PURCHASESOCIALNKO;
  new$AVERSION TENDERCAPTION.AVERSION%TYPE := :NEW.AVERSION;
  new$PARENTREF TENDERCAPTION.PARENTREF%TYPE := :NEW.PARENTREF;
  new$REJECTCAUSE TENDERCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$PARENTINNERNUMBER TENDERCAPTION.PARENTINNERNUMBER%TYPE := :NEW.PARENTINNERNUMBER;
--
  DetCount1$ NUMBER(10);
  ParentProgIndex1$ NUMBER(10);
  AdjParentRef1$ NUMBER(10);
  AdjParentInnerNumber1$ NUMBER(10);
  previousAccept1$ NUMBER(10);
  previousAcceptDate1$ NUMBER(10);
  previousLastAdjustment$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TENDERCAPTION_BU_0)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  /*   13.0*/
  if (new$FacialAccCls is null) then
    new$FacialAccCls := 0;
  END IF;
  /*         ( ) */
  if (new$ProgIndex = 230 and new$Multipurpose is null) then
    new$Multipurpose := 0;
  END IF;
  if (new$AcceptSumma is null) then
    new$AcceptSumma := 0;
  END IF;
  if (new$YearAcceptSumma is null) then
    new$YearAcceptSumma := 0;
  END IF;
  if (new$Allowance is null) then
    new$Allowance := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if (not((new$BudgetRef is null) and (:old.BudgetRef is null))) then
      select count(ID)         into DetCount1$ from TENDERSOURCEORG where RecordIndex = :old.ID
      ;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERCONTACTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERSUPDOCUMENT where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERSUPPLEMENTS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TENDERYARDSTICKS where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      else
        select count(ID)         into DetCount1$ from TenderLot where RecordIndex = :old.ID
        ;
      END IF;
      if (DetCount1$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  if (new$SaleType is null) then
    new$SaleType := 0;
  END IF;
  if (new$TenderOption is null) then
    new$TenderOption := 0;
  END IF;
  if (new$RefinementCause is Null) then
    new$RefinementCause := 0;
  END IF;
  if (new$Preference is Null) then
    new$Preference := 0;
  END IF;
  if (new$UnknownAmount is null) then
    new$UnknownAmount := 0;
  END IF;
  if (new$SupportUndertaker is null) then
    new$SupportUndertaker := 0;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_TENDERCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_TENDERCAPTION_BU_10)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*   14.20*/
  if ((new$InnerNumber <> :old.InnerNumber) or
  (new$AdjustmentRef <> :old.AdjustmentRef) or
  (new$AdjustmentNumber <> :old.AdjustmentNumber)) then
    RaiseException('EX_AGR_ChangeInnerNums');
  END IF;
      
  /*  */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$Accepted = 1) then
    BEGIN
      /*             */
      select Accepted, AcceptDate, LastAdjustment
      into previousAccept1$, previousAcceptDate1$, previousLastAdjustment$       from TenderCaption
      where id=new$Adjustmentref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (new$Adjustmentref is not null and (previousAccept1$ = 0 or (previousAcceptDate1$ is null) or (previousLastAdjustment$ = 0))) then
      RaiseException('EX_RollbackCancel');
    END IF;
    new$LastAdjustment := 1;
      
  END IF;
  /*  ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;
            
    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 0 and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (new$LastAdjustment = 1) then
      new$LastAccepted := 1;
            
    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;
            
    else
      RaiseException('EX_Ten_ChangeStateAdjust');
    END IF;
  END IF;
  /*   ,     LastAdjustment*/
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment <> 1) then
      RaiseException('EX_Ten_ChangeStateAdjust');
    else
      new$LastAdjustment := 0;
      new$LastAccepted := 0;
            
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_TENDERCAPTION_BU_30)
-- Version 13.00.00.1
-- - - - - - - - - - - - -

  new$ParentInnerNumber := null;
  if (new$ParentRef is not null) then
    BEGIN
      select InnerNumber
      into new$ParentInnerNumber     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /* :  /    / */
  if (new$ParentRef is not null
  /*  ,   */
  and  (:old.ParentRef is null
  or (:old.ParentRef is not null and :old.ParentRef <> new$ParentRef)))
  then
    /* :     ParentRef  */
    if (new$LastAdjustment = 0) then
      RaiseException('EX_ChangeAdjTenderParentRef');
    END IF;
    BEGIN
      select ProgIndex
      into ParentProgIndex1$     from TenderCaption
      where ID=new$ParentRef
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /* :  /    / */
    if  ((new$ProgIndex=243 and ParentProgIndex1$ <> 242)
    or (new$ProgIndex=241 and ParentProgIndex1$ <> 240))
    then
      RaiseException('EX_IncorrectTenderParentRef');
    END IF;
    /* :       /     ( ,    ) */
    if (new$AdjustmentRef is not null) then
      BEGIN
        select ParentRef
        into AdjParentRef1$       from TenderCaption
        where ID=new$AdjustmentRef
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (AdjParentRef1$ is not null) then
        BEGIN
          select InnerNumber
          into AdjParentInnerNumber1$         from TenderCaption
          where ID=AdjParentRef1$

          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        if (AdjParentInnerNumber1$ <> new$ParentInnerNumber) then
          RaiseException('EX_IncorrectAdjTenderParentRef');
        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TENDERCAPTION_BU_200)
-- Create 03.12.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   /*        */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_600 (tendercaption_realid_bu_600)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_TENDERCAPTION_BU_700)
-- Create 14.10.2004
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TENDERCAPTION SET
    ID = new$ID,
    BUDGETREF = new$BUDGETREF,
    FACIALACCCLS = new$FACIALACCCLS,
    MULTIPURPOSE = new$MULTIPURPOSE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    PERIOD = new$PERIOD,
    ACCEPTSUMMA = new$ACCEPTSUMMA,
    SALETYPE = new$SALETYPE,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ACCEPTED = new$ACCEPTED,
    EXPORTDATE = new$EXPORTDATE,
    YEARACCEPTSUMMA = new$YEARACCEPTSUMMA,
    TENDEROPTION = new$TENDEROPTION,
    TENDERTARGET = new$TENDERTARGET,
    RVERSION = new$RVERSION,
    ALLOWANCE = new$ALLOWANCE,
    REFINEMENTCAUSE = new$REFINEMENTCAUSE,
    PREFERENCE = new$PREFERENCE,
    PREFERENCESIZE = new$PREFERENCESIZE,
    SECURITY = new$SECURITY,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PERIODYEAR = new$PERIODYEAR,
    SUPPORTUNDERTAKER = new$SUPPORTUNDERTAKER,
    AYEAR = new$AYEAR,
    REWORKCAUSE = new$REWORKCAUSE,
    NOTE = new$NOTE,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    PROTOCOLREASON = new$PROTOCOLREASON,
    PROGINDEX = new$PROGINDEX,
    DOCNUMBER = new$DOCNUMBER,
    SECURITYTSIZE = new$SECURITYTSIZE,
    SECURITYASIZE = new$SECURITYASIZE,
    AVANSSIZE = new$AVANSSIZE,
    PREFERENCECRIPPLE = new$PREFERENCECRIPPLE,
    PREFERENCERUSPRODUCT = new$PREFERENCERUSPRODUCT,
    PREFERENCEPRISON = new$PREFERENCEPRISON,
    AGREEMENTEXECUTIONDATE = new$AGREEMENTEXECUTIONDATE,
    PURCHASECODE = new$PURCHASECODE,
    PURCHASESOCIALNKO = new$PURCHASESOCIALNKO,
    AVERSION = new$AVERSION,
    PARENTREF = new$PARENTREF,
    REJECTCAUSE = new$REJECTCAUSE,
    PARENTINNERNUMBER = new$PARENTINNERNUMBER
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_TENDERCAPTION_AU_10)
-- Version 13.10.00.1
-- - - - - - - - - - - - -

  /*   13.10*/
  /*      */
  /*     ,       */
  /*        */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update TenderCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*              */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and ((:old.LastAdjustment = 1) or (new$LastAdjustment = 1))) then
    update TenderCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

  /*       LastAdjustment    */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update TenderCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_TENDERCAPTION_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   2.0*/
  /*       ,      */
  if (:old.FacialAccCls <> new$FacialAccCls) then
    update TenderProduct set
    RVersion = -1,
    FacialAccCls = new$FacialAccCls
    where
    (RecordIndex = new$ID) and (ProgIndex = 230);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (tr_TenderCaption_au_30)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) /*      */
  and ((new$ProgIndex = 240) /* */ or (new$ProgIndex = 242) /* */))
  then
    if ((new$Accepted <> :old.Accepted)
    or (new$AcceptDate is not null and :old.AcceptDate is null)
    or (new$AcceptDate is null and :old.AcceptDate is not null)
    or (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))
    then
      update TenderCaption set
      RejectCls = new$RejectCls,
      AcceptDate = new$AcceptDate
      where ParentRef=new$ID;
      /*          */
      if (:old.Accepted=1 and new$Accepted=0) then
        update TenderCaption set
        RejectCause = '   : ' || new$RejectCause
        where ParentRef=new$ID;
      END IF;
      /*             */
      if (:old.Accepted=0 and new$Accepted=1) then
        update TenderCaption set
        RejectCls = null,
        RejectCause = null
        where ParentRef=new$ID;

      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_TENDERCAPTION_AU_500)
-- Create 28.04.2005
-- Last update 25.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
           VALUES (139, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 139) AND (RecordId = new$ID);
   END IF;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- alter_KD_allow_delete_NSI.sql
-- #########################################################
-- #########################################################

/*    ,     .     */
-- ALTER TRIGGER tr_kd_bd_0
CREATE OR REPLACE TRIGGER TR_KD_ID
  INSTEAD OF DELETE
  ON KD
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_KD_BD_0)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*    ,      */
  if (:old.kvsr = 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where
    (                       (kd1.KDValue = :old.KDValue) and
    (kd1.BudgetRef = :old.BudgetRef) and
    (kd1.Id <> :old.ID)
    ) AND (ROWNUM = 1)
    ;
    /*   ,      ,      */
    if (not (CNT$1<> 0))
    then
      SELECT COUNT(*) INTO CNT$2
      from kd kd1
      where ((kd1.kvsr <> 0) and
      ((kd1.descriptioncode-:old.descriptioncode>-1) and (kd1.descriptioncode-:old.descriptioncode<1)) and
      (kd1.programcode = :old.programcode) and
      (kd1.AnalyticalGroupKD = :old.AnalyticalGroupKD) and
      (kd1.BudgetRef = :old.BudgetRef)
      ) AND (ROWNUM = 1)       ;
      if ((CNT$2<> 0)) 
      then
        RaiseException('EX_CANTDELBASECODE');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_KD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_KD_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(80, :old.ID, sysdate);

END;
/
-- ALTER TRIGGER tr_innerfinsource_bd_0
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_ID
  INSTEAD OF DELETE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_INNERFINSOURCE_BD_0)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  /*    ,      */
  if (:old.kvsr = 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where
    (                       (ifs1.FinSourceValue = :old.FinSourceValue) and
    (ifs1.BudgetRef = :old.BudgetRef) and
    (ifs1.Id <> :old.ID)
    ) AND (ROWNUM = 1)
    ;
    /*   ,      ,      */
    if (not (CNT$1<> 0))
    then
      SELECT COUNT(*) INTO CNT$2
      from InnerFinSource ifs1
      where ((ifs1.kvsr <> 0) and
      ((ifs1.descriptioncode-:old.descriptioncode>-1) and (ifs1.descriptioncode-:old.descriptioncode<1)) and
      (ifs1.AnalyticalGroupIFS = :old.AnalyticalGroupIFS) and
      (ifs1.BudgetRef = :old.BudgetRef)
      ) AND (ROWNUM = 1)       ;
      if ((CNT$2<> 0)) 
      then
        RaiseException('EX_CANTDELBASECODE');
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INNERFINSOURCE
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AD_500 (TR_INNERFINSOURCE_AD_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate) values(145,:old.ID,SYSDATE);

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- alter_table_commdirectionexpencecls.sql
-- #########################################################
-- #########################################################

/* 1. добавление поля Бюджет в справочник Направление расходования
   2. доработка тригера заполнения поля Бюджет при вставке новой записи
*/
ALTER TABLE commdirectionexpencecls DROP CONSTRAINT UQ_CDECLS_CODE DROP INDEX
/
ALTER TABLE commdirectionexpencecls ADD (
  BudgetRef NUMBER(10),
    CHECK((BudgetRef<=2147483647)AND(BudgetRef>-2147483648)),
  constraint FK_CDECLS_BUDGETREF foreign key (BudgetRef) references TB_budgets_s (id),
  constraint UQ_CDECLS_CODE UNIQUE (CODE,EXTID,BudgetRef)
)
/
CREATE INDEX FK_CDECLS_BUDGETREF ON commdirectionexpencecls(BudgetRef)
/
ALTER TRIGGER TR_CDECLS_BU_500 DISABLE
/
update commdirectionexpencecls
set BudgetRef = 0
/
ALTER TRIGGER TR_CDECLS_BU_500 ENABLE
/
-- CREATE TRIGGER TR_CDECLS_BI_0
CREATE OR REPLACE TRIGGER TR_COMMDIRECTIONEXPENCECLS_BI
  BEFORE INSERT
  ON COMMDIRECTIONEXPENCECLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_CDECLS_BI_0)
-- Version 14.20.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then 
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.OWNERLEVEL is null) then 
    :new.OWNERLEVEL := 0;
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_CDECLS_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
commit work
/
ALTER TABLE commdirectionexpencecls MODIFY(BudgetRef NOT NULL)
/

-- #########################################################
-- #########################################################
-- UpdDocFields_14.20.00_Ora.sql
-- #########################################################
-- #########################################################


--  : 141000 - 142000.     05.01.2022 13:06:24.
CREATE OR REPLACE PROCEDURE ImportDocType (
   ID_               NUMBER,
   PROGINDEX_        NUMBER,
   NAME_             VARCHAR2,
   USESTATE_         NUMBER,
   DBTABLE_          VARCHAR2,
   NEEDEDS_          NUMBER,
   LOCKMASK_         NUMBER,
   DEFAULTACTIONMACROSNAME_ VARCHAR2,
   DOCUMENTKIND_     NUMBER,
   SHORTNAME_         VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentTypes
    WHERE (ID = ID_);

  IF (IDExists$ = 0) THEN
     INSERT INTO DocumentTypes
                 (ID, PROGINDEX, NAME, USESTATE, DBTABLE, NEEDEDS, LOCKMASK, DEFAULTACTIONMACROSNAME, DOCUMENTKIND, SHORTNAME)
          VALUES (ID_, PROGINDEX_, NAME_, USESTATE_, DBTABLE_, NEEDEDS_, LOCKMASK_, DEFAULTACTIONMACROSNAME_, DOCUMENTKIND_, SHORTNAME_);
  else
      Update documenttypes set
        Name=Name_,
		    DBTABLE=DBTABLE_,
        LockMask=LockMask_,
        DEFAULTACTIONMACROSNAME=DEFAULTACTIONMACROSNAME_,
        DOCUMENTKIND=DOCUMENTKIND_,
        SHORTNAME=SHORTNAME_,
	      PROGINDEX=PROGINDEX_
      where (id=ID_)
        and (
          (Name<>Name_) or
          (length(Name)<>length(Name_)) or 
          ((LockMask is null) and (LockMask_ is not null)) or
          ((LockMask is not null) and (LockMask_ is null)) or
          ((LockMask is not null) and (LockMask_ is not null) and (LockMask <> LockMask_)) or
          (DEFAULTACTIONMACROSNAME is null) or
          (DOCUMENTKIND<>DOCUMENTKIND_) or 
          (SHORTNAME is null) or 
          (SHORTNAME<>SHORTNAME_) or
          (PROGINDEX <> PROGINDEX_) or 
          ((DBTABLE is null) and (DBTABLE_ is not null)) or
          ((DBTABLE is not null) and (DBTABLE_ is null)) or
          ((DBTABLE is not null) and (DBTABLE_ is not null) and (DBTABLE <> DBTABLE_))
        );
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE UPDATEINTERFACES (
  CLS_   NUMBER,
  NOTE_  VARCHAR2,
  GUID_  VARCHAR2,
  PARAM_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT (ID)
   INTO IDEXISTS$
   FROM INTERFACES
  WHERE (GUID=GUID_);
  
  IF (IDExists$ = 0)  THEN
    INSERT INTO INTERFACES
      (CLS,NOTE,GUID,PARAM)
    VALUES
      (CLS_,NOTE_,GUID_,PARAM_);
  ELSE
    IF ((PARAM_ ='')OR(PARAM_ IS NULL)) THEN 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    ELSE 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND (PARAM=PARAM_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    END IF;
  END IF;
END;
/

--   
CALL ImportDocType(300, 0, '  ', 0, '', 0,0,'',30000,'') ;

CALL ImportDocType(302, 63, '  \', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(303, 65, ' ()', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(304, 64, '  ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(325, 283, '   ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(325, '   ', '{594D6AF0-9A00-4380-B4FE-9C18C45B2B70}', '') ;

CALL ImportDocType(903, 45, '  ', 0, 'QuotesTitle', 0,-1,'',10100,'_') ;

CALL ImportDocType(905, 0, '  ', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(906, 41, '  ()', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(907, 0, '  ()', 0, ' ', 0,-1,'',10200,'_') ;

CALL ImportDocType(1825, 0, '    ', 0, 'PayDocExchange ', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1825, '    ', '{698B68B7-A731-4FCF-A36D-19A77365DF41}', '') ;

CALL ImportDocType(2504, 314, ' ', 0, 'Agreements', 0,-65537,'',10100,'') ;

DROP PROCEDURE ImportDocType
/

DROP PROCEDURE UPDATEINTERFACES
/



CREATE OR REPLACE PROCEDURE SELECTIONS_IMPORT(
  ID_ NUMBER,
  KIND_ NUMBER,
  NAME_ VARCHAR2,
  NOTE_ VARCHAR2,
  READONLY_ NUMBER,
  USEINDOC_ NUMBER,
  TABLENAME_ VARCHAR2,
  ALIAS_ VARCHAR2,
  TABLECODE_ NUMBER,
  NEEDGROUPONDB_ NUMBER,
  NEEDDISTINCT_ NUMBER,
  MASTER_ NUMBER,
  DISCRIMVALUE_ VARCHAR2,
  AVAILABLEINDEREF_ NUMBER,
  CACHETYPE_ NUMBER,
  FULLORMODINSREFRTIME_ NUMBER,
  DELETEREFRTIME_ NUMBER,
  FINDTIMEREFRESH_ NUMBER,
  ANNOTATION_ VARCHAR2,
  DEREFNAME_ VARCHAR2,
  GroupID_ NUMBER,
  IsLogged_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONS SET
      KIND = KIND_,
      NAME = NAME_,
      NOTE = NOTE_,
      READONLY = READONLY_,
      USEINDOC = USEINDOC_,
      TABLENAME = TABLENAME_,
      ALIAS = ALIAS_,
      TABLECODE = TABLECODE_,    
      NEEDGROUPONDB = NEEDGROUPONDB_,
      NEEDDISTINCT = NEEDDISTINCT_,
      MASTER = MASTER_,
      DISCRIMVALUE = DISCRIMVALUE_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,         
      CACHETYPE = CACHETYPE_,   
      FULLORMODINSREFRTIME = FULLORMODINSREFRTIME_,   
      DELETEREFRTIME = DELETEREFRTIME_,   
      FINDTIMEREFRESH = FINDTIMEREFRESH_,   
      ANNOTATION = ANNOTATION_,   
      DEREFNAME = DEREFNAME_,     
      GroupID = GroupID_, 
      IsLogged = IsLogged_  
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONS
      (ID, KIND, NAME, NOTE, READONLY, USEINDOC, TABLENAME, ALIAS, TABLECODE, NEEDGROUPONDB, NEEDDISTINCT, MASTER, DISCRIMVALUE,
      AVAILABLEINDEREF, CACHETYPE, FULLORMODINSREFRTIME, DELETEREFRTIME, FINDTIMEREFRESH, ANNOTATION, DEREFNAME, GroupID, IsLogged)
    VALUES
      (ID_, KIND_, NAME_, NOTE_, READONLY_, USEINDOC_, TABLENAME_, ALIAS_, TABLECODE_, NEEDGROUPONDB_, NEEDDISTINCT_, MASTER_, DISCRIMVALUE_,
      AVAILABLEINDEREF_, CACHETYPE_, FULLORMODINSREFRTIME_, DELETEREFRTIME_, FINDTIMEREFRESH_, ANNOTATION_, DEREFNAME_, GroupID_, IsLogged_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  ALIAS_ VARCHAR2,
  JOINORDER_ NUMBER,
  JOINTYPE_ NUMBER,
  RELATIONTYPE_ NUMBER,
  JOINCONDITION_ VARCHAR2,
  DONTUSETABLELIMITS_ NUMBER,
  LIMITNAMESLIST_ VARCHAR2,
  QueryGroup_ NUMBER  
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONSDETAIL
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONSDETAIL SET
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      ALIAS = ALIAS_,
      JOINORDER = JOINORDER_,
      JOINTYPE = JOINTYPE_,
      RELATIONTYPE = RELATIONTYPE_,
      JOINCONDITION = JOINCONDITION_,
      DONTUSETABLELIMITS = DONTUSETABLELIMITS_,
      LIMITNAMESLIST = LIMITNAMESLIST_,
      QueryGroup = QueryGroup_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONSDETAIL
      (ID, SELECTIONREF, TABLEREF, ALIAS, JOINORDER, JOINTYPE, RELATIONTYPE, JOINCONDITION, DONTUSETABLELIMITS, LIMITNAMESLIST, QueryGroup)
    VALUES
      (ID_, SELECTIONREF_, TABLEREF_, ALIAS_, JOINORDER_, JOINTYPE_, RELATIONTYPE_, JOINCONDITION_, DONTUSETABLELIMITS_, LIMITNAMESLIST_, QueryGroup_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_IMPORT(
  ID_ NUMBER,
  FIELDKIND_ NUMBER,
  DESCRIPTIONLEVEL_ NUMBER,
  ANCESTORREF_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  FIELDNAME_ VARCHAR2,
  DATATYPE_ NUMBER,
  SUBDATATYPE_ NUMBER,
  FIELDSIZE_ NUMBER,
  DISPLAYLABEL_ VARCHAR2,
  NOTE_ VARCHAR2,
  DEFAULTWIDTH_ NUMBER,
  EDITMASK_ VARCHAR2,
  DISPLAYFORMAT_ VARCHAR2,
  EDITFORMAT_ VARCHAR2,
  CANTEDIT_ NUMBER,
  NOVISUALIZE_ NUMBER,
  ENUMSREF_ NUMBER,
  REQUIRED_ NUMBER,
  FOREIGNKEY_ NUMBER,
  ONDELACTION_ NUMBER,
  PRIMARYKEY_ NUMBER,
  ISRVERSION_ NUMBER,
  LIMITPARAMNAMES_ VARCHAR2,
  FOLLOWORDER_ NUMBER,
  SORTDIRECTION_ NUMBER,
  SORTORDER_ NUMBER,
  AGRFUNCTION_ NUMBER,
  FLAGFIELDNAME_ NUMBER,
  FLAGDISPLAYLABEL_ NUMBER,
  FLAGNOTE_ NUMBER,
  FLAGDEFAULTWIDTH_ NUMBER,
  FLAGCANTEDIT_ NUMBER,
  FLAGNOVISUALIZE_ NUMBER,
  FLAGREQUIRED_ NUMBER,
  FLAGLIMITPARAMNAMES_ NUMBER,
  FLAGAGRFUNCTION_ NUMBER,
  ISTIMESTAMPFIELD_ NUMBER,
  ISBUDGET_ NUMBER,
  AVAILABLEINDEREF_ NUMBER,
  ANNOTATION_ VARCHAR2,
  ALIAS_ VARCHAR2,
  DEREFNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM FIELDSINFO
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE FIELDSINFO SET
      FIELDKIND = FIELDKIND_,
      DESCRIPTIONLEVEL = DESCRIPTIONLEVEL_,
      ANCESTORREF = ANCESTORREF_,
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      FIELDNAME = FIELDNAME_,
      DATATYPE = DATATYPE_,
      SUBDATATYPE = SUBDATATYPE_,
      FIELDSIZE = FIELDSIZE_,
      DISPLAYLABEL = DISPLAYLABEL_,
      NOTE = NOTE_,
      DEFAULTWIDTH = DEFAULTWIDTH_,
      EDITMASK = EDITMASK_,
      DISPLAYFORMAT = DISPLAYFORMAT_,
      EDITFORMAT = EDITFORMAT_,
      CANTEDIT = CANTEDIT_,
      NOVISUALIZE = NOVISUALIZE_,
      ENUMSREF = ENUMSREF_,
      REQUIRED = REQUIRED_,
      FOREIGNKEY = FOREIGNKEY_,
      ONDELACTION = ONDELACTION_,
      PRIMARYKEY = PRIMARYKEY_,
      ISRVERSION = ISRVERSION_,
      LIMITPARAMNAMES = LIMITPARAMNAMES_,
      FOLLOWORDER = FOLLOWORDER_,
      SORTDIRECTION = SORTDIRECTION_,
      SORTORDER = SORTORDER_,
      AGRFUNCTION = AGRFUNCTION_,
      FLAGFIELDNAME = FLAGFIELDNAME_,
      FLAGDISPLAYLABEL = FLAGDISPLAYLABEL_,
      FLAGNOTE = FLAGNOTE_,
      FLAGDEFAULTWIDTH = FLAGDEFAULTWIDTH_,
      FLAGCANTEDIT = FLAGCANTEDIT_,
      FLAGNOVISUALIZE = FLAGNOVISUALIZE_,
      FLAGREQUIRED = FLAGREQUIRED_,
      FLAGLIMITPARAMNAMES = FLAGLIMITPARAMNAMES_,
      FLAGAGRFUNCTION = FLAGAGRFUNCTION_,
      ISTIMESTAMPFIELD = ISTIMESTAMPFIELD_,
      ISBUDGET = ISBUDGET_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,
      ANNOTATION = ANNOTATION_,
      ALIAS = ALIAS_,
      DEREFNAME = DEREFNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO FIELDSINFO
      (ID, FIELDKIND, DESCRIPTIONLEVEL, ANCESTORREF, SELECTIONREF, TABLEREF, FIELDNAME, DATATYPE, SUBDATATYPE,
       FIELDSIZE, DISPLAYLABEL, NOTE, DEFAULTWIDTH, EDITMASK, DISPLAYFORMAT, EDITFORMAT, CANTEDIT, NOVISUALIZE,
       ENUMSREF, REQUIRED, FOREIGNKEY, ONDELACTION, PRIMARYKEY, ISRVERSION, LIMITPARAMNAMES,
       FOLLOWORDER, SORTDIRECTION, SORTORDER, AGRFUNCTION, FLAGFIELDNAME, FLAGDISPLAYLABEL, FLAGNOTE,
       FLAGDEFAULTWIDTH, FLAGCANTEDIT, FLAGNOVISUALIZE, FLAGREQUIRED, FLAGLIMITPARAMNAMES, FLAGAGRFUNCTION,
       ISTIMESTAMPFIELD, ISBUDGET, AVAILABLEINDEREF, ANNOTATION, ALIAS, DEREFNAME)
    VALUES
      (ID_, FIELDKIND_, DESCRIPTIONLEVEL_, ANCESTORREF_, SELECTIONREF_, TABLEREF_, FIELDNAME_, DATATYPE_, SUBDATATYPE_,
       FIELDSIZE_, DISPLAYLABEL_, NOTE_, DEFAULTWIDTH_, EDITMASK_, DISPLAYFORMAT_, EDITFORMAT_, CANTEDIT_, NOVISUALIZE_,
       ENUMSREF_, REQUIRED_, FOREIGNKEY_, ONDELACTION_, PRIMARYKEY_, ISRVERSION_, LIMITPARAMNAMES_,
       FOLLOWORDER_, SORTDIRECTION_, SORTORDER_, AGRFUNCTION_, FLAGFIELDNAME_, FLAGDISPLAYLABEL_, FLAGNOTE_,
       FLAGDEFAULTWIDTH_, FLAGCANTEDIT_, FLAGNOVISUALIZE_, FLAGREQUIRED_, FLAGLIMITPARAMNAMES_, FLAGAGRFUNCTION_,
       ISTIMESTAMPFIELD_, ISBUDGET_, AVAILABLEINDEREF_, ANNOTATION_, ALIAS_, DEREFNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  EVENTCODE_ NUMBER,
  SCRIPTNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONEVENTS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONEVENTS SET
      SELECTIONREF = SELECTIONREF_,
      EVENTCODE = EVENTCODE_,
      SCRIPTNAME = SCRIPTNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONEVENTS
      (ID, SELECTIONREF, EVENTCODE, SCRIPTNAME)
    VALUES
      (ID_, SELECTIONREF_, EVENTCODE_, SCRIPTNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_DELETE(
  ID_ NUMBER
) IS
BEGIN
  UPDATE DOCUMENTFIELDS SET
    FIELDINFOREF = NULL
  WHERE FIELDINFOREF = ID_;
  DELETE FROM FIELDSINFO FI
  WHERE FI.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONSDETAIL SLD
  WHERE SLD.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONEVENTS SE
  WHERE SE.ID = ID_;
END;
/

-- 
-- DFACCOUNTSBUHTABLE
CALL FIELDSINFO_IMPORT(47938, 0, 1, null, 17265, null, 'ISFORKS', 3, 0, 0, '  ( )', '', 11, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- INVESTOBJECT
CALL FIELDSINFO_IMPORT(38206, 0, 1, null, 38203, null, 'SUBCODE', 1, 0, 50, '   .', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

--  
DROP PROCEDURE SELECTIONS_IMPORT
/

DROP PROCEDURE SELECTIONSDETAIL_IMPORT
/

DROP PROCEDURE FIELDSINFO_IMPORT
/

DROP PROCEDURE SELECTIONEVENTS_IMPORT
/

DROP PROCEDURE FIELDSINFO_DELETE
/

DROP PROCEDURE SELECTIONSDETAIL_DELETE
/

DROP PROCEDURE SELECTIONS_DELETE
/

DROP PROCEDURE SELECTIONEVENTS_DELETE
/

CREATE OR REPLACE PROCEDURE ImportDocCLS (
   ID_                 NUMBER,
   DOCTYPE_            NUMBER,
   DOCTYPENOTE_        VARCHAR2,
   TABLENAME_          VARCHAR2,
   TABLENAMEURM_       VARCHAR2,
   PRIMARYKEYNAME_     VARCHAR2,
   PRIMARYKEYNAMEURM_  VARCHAR2,
   LINKFIELDNAME_      VARCHAR2,
   LINKFIELDNAMEURM_   VARCHAR2,
   CLSTYPE_            NUMBER,
   SELECTIONREFBUDGET_ NUMBER,
   SELECTIONREFURM_    NUMBER,
   PROGINDEX_          NUMBER
) IS IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
   INTO IDExists$
   FROM DOCUMENTCLS
   WHERE (ID = ID_);

   IF (IDExists$ = 0) THEN
   INSERT INTO DOCUMENTCLS
   (ID, DOCTYPE, DOCTYPENOTE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM, LINKFIELDNAME, LINKFIELDNAMEURM, CLSTYPE, 
     SELECTIONREFBUDGET, SELECTIONREFURM, PROGINDEX)
   VALUES (ID_, DOCTYPE_, DOCTYPENOTE_, TABLENAME_, TABLENAMEURM_, PRIMARYKEYNAME_, PRIMARYKEYNAMEURM_, LINKFIELDNAME_, LINKFIELDNAMEURM_, CLSTYPE_, 
     SELECTIONREFBUDGET_, SELECTIONREFURM_, PROGINDEX_);
   ELSE
   UPDATE DOCUMENTCLS 
   SET
     DOCTYPENOTE = DOCTYPENOTE_,
     TABLENAME = TABLENAME_,
     TABLENAMEURM = TABLENAMEURM_,
     PRIMARYKEYNAME = PRIMARYKEYNAME_,
     PRIMARYKEYNAMEURM = PRIMARYKEYNAMEURM_,
     LINKFIELDNAME = LINKFIELDNAME_,
     LINKFIELDNAMEURM = LINKFIELDNAMEURM_,
     CLSTYPE = CLSTYPE_,
     SELECTIONREFBUDGET = SELECTIONREFBUDGET_,
     SELECTIONREFURM = SELECTIONREFURM_,
     PROGINDEX = PROGINDEX_
   WHERE  
    (ID = ID_)
    AND NOT (
            (
                    ((DOCTYPENOTE IS NOT NULL AND DOCTYPENOTE_ IS NOT NULL) AND
                       (UPPER (DOCTYPENOTE) = UPPER (DOCTYPENOTE_))
                    )
                    OR (DOCTYPENOTE IS NULL AND DOCTYPENOTE_ IS NULL)
                )    
        AND (UPPER (TABLENAME) = UPPER (TABLENAME_))    
        AND (
                    ((TABLENAMEURM IS NOT NULL AND TABLENAMEURM_ IS NOT NULL) AND
                       (UPPER (TABLENAMEURM) = UPPER (TABLENAMEURM_))
                    )
                    OR (TABLENAMEURM IS NULL AND TABLENAMEURM_ IS NULL)
                )    
        AND (UPPER (PRIMARYKEYNAME) = UPPER (PRIMARYKEYNAME_))
        AND (
                    ((PRIMARYKEYNAMEURM IS NOT NULL AND PRIMARYKEYNAMEURM_ IS NOT NULL) AND
                       (UPPER (PRIMARYKEYNAMEURM) = UPPER (PRIMARYKEYNAMEURM_))
                    )
                    OR (PRIMARYKEYNAMEURM IS NULL AND PRIMARYKEYNAMEURM_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAME IS NOT NULL AND LINKFIELDNAME_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAME) = UPPER (LINKFIELDNAME_))
                    )
                    OR (LINKFIELDNAME IS NULL AND LINKFIELDNAME_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAMEURM IS NOT NULL AND LINKFIELDNAMEURM_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAMEURM) = UPPER (LINKFIELDNAMEURM_))
                    )
                    OR (LINKFIELDNAMEURM IS NULL AND LINKFIELDNAMEURM_ IS NULL)
                )    
        AND (
                    ((CLSTYPE IS NOT NULL AND CLSTYPE_ IS NOT NULL) AND
                       (UPPER (CLSTYPE) = UPPER (CLSTYPE_))
                    )
                    OR (CLSTYPE IS NULL AND CLSTYPE_ IS NULL)
                ) 
        AND (
                    ((PROGINDEX IS NOT NULL AND PROGINDEX_ IS NOT NULL) AND
                       (PROGINDEX = PROGINDEX_)
                    )
                    OR (PROGINDEX IS NULL AND PROGINDEX_ IS NULL)
                )   
            );
   
   END IF;
END;
/

--   
CALL ImportDocCLS(10100, 101, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10101, 101, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10102, 101, ' ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10103, 101, ' ', 'DEBT', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10104, 101, ' %  ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10105, 101, ' ', 'INCOMES32', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20100, 201, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(20101, 201, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(30100, 301, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30101, 301, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30200, 302, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30201, 302, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30300, 303, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30301, 303, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30400, 304, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30401, 304, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30500, 305, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30501, 305, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30600, 306, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30601, 306, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30700, 307, '', 'FACIALFINREESTR', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(31100, 311, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31101, 311, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31200, 312, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31201, 312, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31400, 314, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31401, 314, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31500, 315, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(31501, 315, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(992500, 9925, '', 'Cards', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992501, 9925, ' ', 'CARDSDETAIL_FACC', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(490300, 4903, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 527) ;

CALL ImportDocCLS(32200, 322, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32201, 322, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32300, 323, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32301, 323, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32400, 324, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(32401, 324, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(420300, 4203, '', 'DEBT', ' ', 'ID', ' ', '', '', 0, null, null, 220) ;

CALL ImportDocCLS(40100, 401, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 130) ;

CALL ImportDocCLS(40101, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 131) ;

CALL ImportDocCLS(40102, 401, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 137) ;

CALL ImportDocCLS(40103, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 132) ;

CALL ImportDocCLS(40104, 401, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 134) ;

CALL ImportDocCLS(40105, 401, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 138) ;

CALL ImportDocCLS(40106, 401, ' %', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 133) ;

CALL ImportDocCLS(40107, 401, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40108, 401, '. ', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40109, 401, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 340) ;

CALL ImportDocCLS(40110, 401, '.', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 341) ;

CALL ImportDocCLS(40111, 401, '', 'LOANCREDITCONTRACTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 342) ;

CALL ImportDocCLS(50100, 501, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 120) ;

CALL ImportDocCLS(50101, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 121) ;

CALL ImportDocCLS(50102, 501, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 127) ;

CALL ImportDocCLS(50103, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 122) ;

CALL ImportDocCLS(50104, 501, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 124) ;

CALL ImportDocCLS(50105, 501, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 128) ;

CALL ImportDocCLS(50106, 501, ' %', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 123) ;

CALL ImportDocCLS(50107, 501, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(50108, 501, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 321) ;

CALL ImportDocCLS(70100, 701, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70101, 701, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70200, 702, '', 'PAYDOC32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70201, 702, '', 'PAYDOC32', ' ', 'ID', ' ', 'PARENTINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70300, 703, '', 'FINDOCDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, 36) ;

CALL ImportDocCLS(80100, 801, '', 'LIMITNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80101, 801, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 57) ;

CALL ImportDocCLS(80200, 802, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80300, 803, '', 'REQUESTFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80301, 803, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80400, 804, '', 'LIMITFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90100, 901, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 145) ;

CALL ImportDocCLS(90101, 901, '', 'INCOMES32', ' ', 'ID', ' ', 'RecordIndex', ' ', 0, null, null, 0) ;

CALL ImportDocCLS(90300, 903, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90301, 903, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90500, 905, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 44) ;

CALL ImportDocCLS(90600, 906, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 41) ;

CALL ImportDocCLS(90601, 906, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 42) ;

CALL ImportDocCLS(120100, 1201, '', 'BUH_JOURNAL', ' ', 'ID', ' ', '', ' ', 0, null, null, 309) ;

CALL ImportDocCLS(150100, 1501, '', 'ORGOPERAT', ' ', 'ID', ' ', '', ' ', 0, null, null, 35) ;

CALL ImportDocCLS(160100, 1601, '', 'PROMISE_CAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(160101, 1601, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', 'TITLE_REF', ' ', 0, null, null, 345) ;

CALL ImportDocCLS(160200, 1602, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(170100, 1701, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 222) ;

CALL ImportDocCLS(170200, 1702, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 221) ;

CALL ImportDocCLS(170201, 1702, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(190100, 1901, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(190101, 1901, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(220100, 2201, '', 'BUDNOTIFY', 'BUDNOTIFY', 'ID', ' ', '', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(220101, 2201, '', 'BUDGETDATA', 'BUDGETDATA', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(280100, 2801, '', 'ACCSOPERTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(280101, 2801, '', 'PAYDOC32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 16) ;

CALL ImportDocCLS(280200, 2802, '', 'DFACCOUNTOPERATION', ' ', 'ID', ' ', '', ' ', 0, null, null, 50) ;

CALL ImportDocCLS(440100, 4401, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(440101, 4401, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(0, 0, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991304, 9913, ' ', 'STATICLINKS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(440300, 4403, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(440301, 4403, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(989500, 9895, ' ', 'OKTMO', 'OKTMO', 'id', 'id', '', '', 95, null, null, null) ;

CALL ImportDocCLS(500000, 5000, '', 'ALLOWANCECAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 112) ;

CALL ImportDocCLS(500001, 5000, '', 'ALLOWANCEDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 112) ;

CALL ImportDocCLS(990300, 9903, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990301, 9903, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990302, 9903, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990500, 9905, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90200, 902, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 38) ;

CALL ImportDocCLS(20701, 207, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(90700, 907, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181200, 1812, '', 'ED_CorrectionCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181000, 1810, '', 'ED_OUTPAYDOC', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20700, 207, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(181001, 1810, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992700, 9927, '', 'REMOTECLIENT', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550100, 5501, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(20801, 208, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(30701, 307, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', 'REESTR_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21100, 211, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 275) ;

CALL ImportDocCLS(490100, 4901, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 525) ;

CALL ImportDocCLS(992701, 9927, '  ', 'REMOTEREADRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(550101, 5501, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(490301, 4903, '', 'ARCHIVEOPLOG', ' ', 'ID', ' ', 'DATAPACKETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(390100, 3901, '', 'DELOIN', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21101, 211, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(992300, 9923, '', 'SIGNSCHEMECAPTION', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181201, 1812, '', 'ED_CorrectionDetail', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(550200, 5502, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(20800, 208, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(550201, 5502, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(90000, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992301, 9923, '', 'SIGNSCHEMEDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991600, 9916, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992200, 9922, '', 'ARCHIVEDOCTYPE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(90001, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(390101, 3901, '', 'DELOEXEC', ' ', 'ID', ' ', 'DOCID', ' ', 0, null, null, null) ;

CALL ImportDocCLS(180700, 1807, '', 'PayDocExchange', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(420100, 4201, '', 'FINDOCDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, 25) ;

CALL ImportDocCLS(21102, 211, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(420200, 4202, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 19) ;

CALL ImportDocCLS(991700, 9917, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991200, 9912, '', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181600, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30800, 308, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250100, 2501, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 305) ;

CALL ImportDocCLS(21200, 212, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 276) ;

CALL ImportDocCLS(250101, 2501, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(30801, 308, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250200, 2502, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 304) ;

CALL ImportDocCLS(250201, 2502, ' ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(988900, 9889, ' ', 'SubsidyCls', ' ', 'id', ' ', '', '', 89, null, null, null) ;

CALL ImportDocCLS(250202, 2502, '  ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 304) ;

CALL ImportDocCLS(988700, 9887, ' ', 'VariantCls', ' ', 'ID', ' ', '', '', 87, null, null, null) ;

CALL ImportDocCLS(520100, 5201, '', 'WritExecutionCaption', 'WritExecutionCaption', 'id', 'id', '', '', 0, null, null, 555) ;

CALL ImportDocCLS(990800, 9908, '', 'DocumentTypes', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(250300, 2503, '', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21201, 212, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(250301, 2503, '', 'EXECUTIONDOCUMENTSDETAIL', 'EXECUTIONDOCUMENTSDETAIL', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(180500, 1805, '', 'BANKEXCH_MERDOC', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20201, 202, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20301, 203, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20401, 204, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20501, 205, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20601, 206, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190201, 1902, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190301, 1903, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(20000, 200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190601, 1906, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(20200, 202, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20300, 203, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20400, 204, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20500, 205, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20600, 206, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190200, 1902, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190300, 1903, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(180501, 1805, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(190600, 1906, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(988400, 9884, ' ', 'TransfertCLS', ' ', 'ID', ' ', '', '', 84, null, null, null) ;

CALL ImportDocCLS(988800, 9888, ' ', 'OKP', ' ', 'ID', ' ', '', '', 88, null, null, null) ;

CALL ImportDocCLS(989900, 9899, ' ', 'DBUsers', ' ', 'ID', ' ', '', '', 201, null, null, null) ;

CALL ImportDocCLS(990801, 9908, ' ', 'DOCUMENTFIELDS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(361000, 3610, '', 'UTYPEDFORMSCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 550) ;

CALL ImportDocCLS(987200, 9872, ' ', 'BalanceCls', ' ', 'ID', ' ', '', '', 72, null, null, null) ;

CALL ImportDocCLS(984600, 9846, ' ', 'BUHPAYMENTCLS', ' ', 'ID', ' ', '', '', 46, null, null, null) ;

CALL ImportDocCLS(981800, 9818, ' ', 'CURRENCYCLS', ' ', 'ID', ' ', '', '', 18, null, null, null) ;

CALL ImportDocCLS(988500, 9885, ' ', 'AssignmentKind', ' ', 'ID', ' ', '', '', 85, null, null, null) ;

CALL ImportDocCLS(983500, 9835, ' ', 'BUDGETTYPE', ' ', 'ID', ' ', '', '', 35, null, null, null) ;

CALL ImportDocCLS(985800, 9858, ' ', 'DEBTTYPE', ' ', 'ID', ' ', '', '', 58, null, null, null) ;

CALL ImportDocCLS(988600, 9886, ' ', 'AssignmentSource', ' ', 'ID', ' ', ' ', ' ', 86, null, null, null) ;

CALL ImportDocCLS(988300, 9883, ' ', 'Org_Type', ' ', 'ID', ' ', '', '', 83, null, null, null) ;

CALL ImportDocCLS(986400, 9864, ' ', 'PlanDocType', ' ', 'ID', ' ', '', '', 64, null, null, null) ;

CALL ImportDocCLS(985700, 9857, ' ', 'LOANTYPE', ' ', 'ID', ' ', '', '', 57, null, null, null) ;

CALL ImportDocCLS(984300, 9843, ' ', 'PAYTYPECLS', ' ', 'ID', ' ', '', '', 43, null, null, null) ;

CALL ImportDocCLS(982300, 9823, ' ', 'GOSNI', ' ', 'ID', ' ', '', '', 23, null, null, null) ;

CALL ImportDocCLS(982200, 9822, ' ', 'GroupInf_CLS', ' ', 'ID', ' ', '', '', 22, null, null, null) ;

CALL ImportDocCLS(982900, 9829, ' ', 'DocBase', ' ', 'ID', ' ', '', '', 29, null, null, null) ;

CALL ImportDocCLS(981100, 9811, ' ', 'DocTypes', ' ', 'ID', ' ', '', '', 11, null, null, null) ;

CALL ImportDocCLS(986000, 9860, ' ', 'MEASUREMENTCLS', ' ', 'ID', ' ', '', '', 60, null, null, null) ;

CALL ImportDocCLS(988000, 9880, ' ', 'FundsSource', ' ', 'ID', ' ', '', '', 80, null, null, null) ;

CALL ImportDocCLS(985200, 9852, ' ', 'InnerFinSource', ' ', 'ID', ' ', '', '', 52, null, null, null) ;

CALL ImportDocCLS(981300, 9813, ' ', 'NOTIFYTYPES', ' ', 'ID', ' ', '', '', 13, null, null, null) ;

CALL ImportDocCLS(984500, 9845, ' ', 'PAYSYMBOLCLS', ' ', 'ID', ' ', '', '', 45, null, null, null) ;

CALL ImportDocCLS(980400, 9804, ' ', 'KVR', ' ', 'ID', ' ', '', '', 4, null, null, null) ;

CALL ImportDocCLS(980300, 9803, ' ', 'KVSR', ' ', 'ID', ' ', '', '', 3, null, null, null) ;

CALL ImportDocCLS(980900, 9809, ' ', 'KD', ' ', 'ID', ' ', '', '', 9, null, null, null) ;

CALL ImportDocCLS(984700, 9847, ' ', 'TYPEOPERATIONCLS', ' ', 'ID', ' ', '', '', 47, null, null, null) ;

CALL ImportDocCLS(986800, 9868, ' ', 'KESR', ' ', 'ID', ' ', '', '', 68, null, null, null) ;

CALL ImportDocCLS(987900, 9879, ' ', 'TargetCls', ' ', 'ID', ' ', '', '', 79, null, null, null) ;

CALL ImportDocCLS(985100, 9851, ' ', 'Error', ' ', 'ID', ' ', '', '', 51, null, null, null) ;

CALL ImportDocCLS(982100, 9821, ' ', 'ACC_CLS', ' ', 'ID', ' ', '', '', 21, null, null, null) ;

CALL ImportDocCLS(981400, 9814, ' ', 'KSHK', ' ', 'ID', ' ', '', '', 14, null, null, null) ;

CALL ImportDocCLS(980200, 9802, ' ', 'kfsr', ' ', 'ID', ' ', '', '', 2, null, null, null) ;

CALL ImportDocCLS(980500, 9805, ' ', 'KCSR', ' ', 'ID', ' ', '', '', 5, null, null, null) ;

CALL ImportDocCLS(984100, 9841, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', '', '', 41, null, null, null) ;

CALL ImportDocCLS(981500, 9815, ' ', 'VALUECLS', ' ', 'ID', ' ', '', '', 15, null, null, null) ;

CALL ImportDocCLS(982800, 9828, ' ', 'FACT', ' ', 'ID', ' ', '', '', 28, null, null, null) ;

CALL ImportDocCLS(984800, 9848, ' ', 'PAYDESTINATIONCLS', ' ', 'ID', ' ', '', '', 48, null, null, null) ;

CALL ImportDocCLS(986900, 9869, ' ', 'DirectionCLS', ' ', 'ID', ' ', '', '', 69, null, null, null) ;

CALL ImportDocCLS(986200, 9862, ' ', 'OKATO', ' ', 'ID', ' ', '', '', 62, null, null, null) ;

CALL ImportDocCLS(988200, 9882, ' ', 'OKOPF', ' ', 'ID', ' ', '', '', 82, null, null, null) ;

CALL ImportDocCLS(988100, 9881, ' ', 'OKFS', ' ', 'ID', ' ', '', '', 81, null, null, null) ;

CALL ImportDocCLS(981600, 9816, ' ', 'MeansCLS', ' ', 'ID', ' ', '', '', 16, null, null, null) ;

CALL ImportDocCLS(985900, 9859, ' ', 'DepartmentCLS', ' ', 'ID', ' ', '', '', 59, null, null, null) ;

CALL ImportDocCLS(986500, 9865, ' ', 'BuhAccPlan', ' ', 'ID', ' ', '', '', 65, null, null, null) ;

CALL ImportDocCLS(986100, 9861, ' ', 'TenderObjects', ' ', 'ID', ' ', '', '', 61, null, null, null) ;

CALL ImportDocCLS(985000, 9850, ' ', 'RejectCLS', ' ', 'ID', ' ', '', '', 50, null, null, null) ;

CALL ImportDocCLS(987000, 9870, ' ', 'ProgramCode', ' ', 'ID', ' ', '', '', 70, null, null, null) ;

CALL ImportDocCLS(981200, 9812, ' ', 'RegionCLS', ' ', 'ID', ' ', '', '', 12, null, null, null) ;

CALL ImportDocCLS(982600, 9826, ' ', 'BUDGETACCOUNTS', ' ', 'ID', ' ', '', '', 26, null, null, null) ;

CALL ImportDocCLS(981700, 9817, ' ', 'REFCLS', ' ', 'ID', ' ', '', '', 17, null, null, null) ;

CALL ImportDocCLS(981000, 9810, ' ', 'SubKD', ' ', 'ID', ' ', '', '', 10, null, null, null) ;

CALL ImportDocCLS(980600, 9806, ' ', 'SUBKCSR', ' ', 'ID', ' ', '', '', 6, null, null, null) ;

CALL ImportDocCLS(980800, 9808, ' ', 'KESRSubCode', ' ', 'ID', ' ', '', '', 8, null, null, null) ;

CALL ImportDocCLS(986300, 9863, ' ', 'COLLATERALTYPE', ' ', 'ID', ' ', '', '', 63, null, null, null) ;

CALL ImportDocCLS(982000, 9820, ' ', 'ORG_CLS', ' ', 'ID', ' ', '', '', 20, null, null, null) ;

CALL ImportDocCLS(983400, 9834, ' ', 'ReportType', ' ', 'ID', ' ', '', '', 34, null, null, null) ;

CALL ImportDocCLS(985300, 9853, ' ', 'REESTRTYPE', ' ', 'ID', ' ', '', '', 53, null, null, null) ;

CALL ImportDocCLS(984900, 9849, ' ', 'MEANSTYPE', ' ', 'ID', ' ', '', '', 49, null, null, null) ;

CALL ImportDocCLS(982700, 9827, ' ', 'FinType', ' ', 'ID', ' ', '', '', 27, null, null, null) ;

CALL ImportDocCLS(984400, 9844, ' ', 'Org_AccDefaults', ' ', 'ID', ' ', '', '', 44, null, null, null) ;

CALL ImportDocCLS(960100, 9601, ' ', 'ORGANIZATIONS', ' ', 'ID', ' ', '', '', 1000, null, null, null) ;

CALL ImportDocCLS(960200, 9602, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', '', '', 1001, null, null, null) ;

CALL ImportDocCLS(960400, 9604, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', '', 1003, null, null, null) ;

CALL ImportDocCLS(960300, 9603, ' ', 'BANKS', ' ', 'ID', ' ', '', '', 1002, null, null, null) ;

CALL ImportDocCLS(987100, 9871, ' ', 'BuhOperationCls', ' ', 'Id', ' ', '', '', 71, null, null, null) ;

CALL ImportDocCLS(987800, 9878, ' ', 'budgets_s', ' ', 'id', ' ', '', '', 78, null, null, null) ;

CALL ImportDocCLS(991400, 9914, '', 'DATAPACKETTYPES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991401, 9914, '', 'DATAPACKETCONTENT', ' ', 'ID', ' ', 'DATAPACKETTYPE', '', 0, null, null, null) ;

CALL ImportDocCLS(991500, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991501, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', 'ID', '', 0, null, null, null) ;

CALL ImportDocCLS(20001, 200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(30000, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30001, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190000, 1900, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190001, 1900, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(220000, 2200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(220001, 2200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991300, 9913, '', 'INTERFACES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991301, 9913, '', 'Permissions', ' ', 'ID', ' ', 'INTERFACEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(991302, 9913, '', 'LinkType', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991303, 9913, ' ', ' ', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(490200, 4902, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 526) ;

CALL ImportDocCLS(250400, 2504, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', '', 0, null, null, 314) ;

CALL ImportDocCLS(300100, 3001, '', 'TenderCaption', ' ', 'ID', ' ', '', '', 0, null, null, 230) ;

CALL ImportDocCLS(250401, 2504, '  ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(250402, 2504, '   ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 304) ;

CALL ImportDocCLS(250403, 2504, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(300600, 3006, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 241) ;

CALL ImportDocCLS(250102, 2501, '  . ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(70202, 702, '', 'PAYDOCEXCHANGE', ' ', 'ID', ' ', 'PAYDOCREF', '', 0, null, null, null) ;

CALL ImportDocCLS(170101, 1701, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20900, 209, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 274) ;

CALL ImportDocCLS(300601, 3006, '  ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 241) ;

CALL ImportDocCLS(300602, 3006, '   ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300300, 3003, '', 'TenderResultCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(300101, 3001, ' ', 'TenderProduct', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 230) ;

CALL ImportDocCLS(300102, 3001, ' ', 'TenderLot', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300103, 3001, '   ', 'TENDERSOURCEORG', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300104, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300105, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300106, 3001, ' ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300107, 3001, '   ', 'TENDERSUPPLEMENTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300108, 3001, ',  ', 'TENDERSUPDOCUMENT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(370100, 3701, '', 'TenderObjects', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(520101, 5201, '', 'WritExecutionDetail', 'WritExecutionDetail', 'id', 'id', 'RecordIndex', '', 0, null, null, 556) ;

CALL ImportDocCLS(20901, 209, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(21000, 210, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 252) ;

CALL ImportDocCLS(21001, 210, ', ', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 252) ;

CALL ImportDocCLS(21002, 210, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 253) ;

CALL ImportDocCLS(991800, 9918, '', 'USERGENERATOR', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991801, 9918, '', 'USERGENERATORFIELDS', ' ', 'ID', ' ', 'GENREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992702, 9927, '   ', 'REMOTEINPUTRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(21202, 212, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(990802, 9908, ' ', 'STATE_DOCSTATES', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990803, 9908, '', 'STATE_JUMPS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990804, 9908, '', 'STATE_ACTIONS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992703, 9927, '   ', 'REMOTECLIENTACCOUNT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992000, 9920, '', 'BUHOPERATIONCLS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992001, 9920, '', 'BUHACCCORR', ' ', 'ID', ' ', 'BUHOPERATIONCLS', '', 0, null, null, null) ;

CALL ImportDocCLS(992100, 9921, '', 'BUDGETS_S', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992101, 9921, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992102, 9921, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(989000, 9890, ' ', 'BudAllocationCls', ' ', 'id', ' ', '', '', 90, null, null, null) ;

CALL ImportDocCLS(989100, 9891, ' ', 'PayPromiseCls', ' ', 'id', ' ', '', '', 91, null, null, null) ;

CALL ImportDocCLS(550300, 5503, '', 'ReplacementClsCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550301, 5503, '   ', 'ReplacementClsDetail', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(550302, 5503, ' ', 'ReplacementClsDetailInfo', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(250302, 2503, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'EXECUTIONREF', '', 0, null, null, 308) ;

CALL ImportDocCLS(181400, 1814, '', 'BANKEXCH_LS_KB', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(180900, 1809, '', 'BANKEXCH_SUBSTITUTION', 'BANKEXCH_SUBSTITUTION', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181500, 1815, '', 'BANKEXCH_KO_SALDO', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992900, 9929, '', 'BudStruct', 'BudStruct', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992201, 9922, '', 'ARCHIVEDOCPARAMS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(992400, 9924, '', 'SIGNS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(480101, 4801, '', 'GeneralDocsDetail', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992502, 9925, '', 'CARDSDETAIL_KESR', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(250203, 2502, ' ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 304) ;

CALL ImportDocCLS(250404, 2504, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', '', 0, null, null, 318) ;

CALL ImportDocCLS(520102, 5201, '2', 'WritExecutionNotify', 'WritExecutionNotify', 'id', 'id', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(989200, 9892, ' ', 'ArchiveDocType', ' ', 'id', ' ', '', '', 92, null, null, null) ;

CALL ImportDocCLS(480100, 4801, '', 'GeneralDocuments', ' ', 'ID', ' ', '', '', 0, null, null, 528) ;

CALL ImportDocCLS(992600, 9926, '', 'WritNotifyCls', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992601, 9926, '', 'WRITNOTIFYCLSDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992602, 9926, ' ', 'WritNotifyClsPart', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(31600, 316, '', 'ManagerBid', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20902, 209, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(992704, 9927, '  + /', 'DUALRIGHTS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992705, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992706, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(990400, 9904, '', 'CONTACTPERSONS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181601, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992707, 9927, '', 'SIGNCERTIFICATE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992708, 9927, '  ', 'SIGNDOCUMENTSGROUP', ' ', 'ID', ' ', 'CLIENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(510100, 5101, '', 'StoredAttributesCaption', 'StoredAttributesCaption', 'id', 'id', '', '', 0, null, null, null) ;

CALL ImportDocCLS(510101, 5101, '', 'StoredAttributesDetail', 'StoredAttributesDetail', 'id', 'id', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(250405, 2504, ' ', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', 'AGREEMENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(993000, 9930, '', 'AUTOSANCTIONDATA', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(301000, 3010, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 242) ;

CALL ImportDocCLS(970200, 9702, ' ', 'AnalyticalGroupIFS', 'AnalyticalGroupIFS', 'ID', 'ID', '', '', 102, null, null, null) ;

CALL ImportDocCLS(970100, 9701, ' ', 'AnalyticalGroupKD', 'AnalyticalGroupKD', 'ID', 'ID', '', '', 101, null, null, null) ;

CALL ImportDocCLS(181800, 1818, '', 'OOS_CONTRACT', 'OOS_CONTRACT', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(301100, 3011, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 243) ;

CALL ImportDocCLS(301101, 3011, ' ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 243) ;

CALL ImportDocCLS(300500, 3005, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 240) ;

CALL ImportDocCLS(181801, 1818, '', 'OOS_CONTRACT_FINANCES', 'OOS_CONTRACT_FINANCES', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(181802, 1818, '', 'OOS_CONTRACT_PRODUCTS', 'OOS_CONTRACT_PRODUCTS', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(181803, 1818, '', 'OOS_CONTRACTPROCEDURE', 'OOS_CONTRACTPROCEDURE', 'ID', 'ID', 'RegNum', 'RegNum', 0, null, null, null) ;

CALL ImportDocCLS(989700, 9897, ' ', 'ContractCostsCls', 'ContractCostsCls', 'id', 'id', '', '', 97, null, null, null) ;

CALL ImportDocCLS(960101, 9601, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(989800, 9898, ' ', 'PURCHASETYPE ', 'PURCHASETYPE ', 'id', 'id', '', '', 98, null, null, null) ;

CALL ImportDocCLS(21300, 213, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 277) ;

CALL ImportDocCLS(21301, 213, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 277) ;

CALL ImportDocCLS(21400, 214, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 278) ;

CALL ImportDocCLS(21401, 214, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 278) ;

CALL ImportDocCLS(993200, 9932, '', 'BudStrLink', 'BudStrLink', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(993201, 9932, '', 'BudStrLink', 'BudStrLink', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(21500, 215, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 279) ;

CALL ImportDocCLS(21501, 215, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 279) ;

CALL ImportDocCLS(250204, 2502, ' ', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', 'AGREEMENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(181900, 1819, '', 'OOS_CONTRACT', 'OOS_CONTRACT', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181901, 1819, '', 'OOS_CONTRACT_FINANCES', 'OOS_CONTRACT_FINANCES', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(182000, 1820, '', 'OOS_CONTRACT', 'OOS_CONTRACT', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(182001, 1820, '', 'OOS_CONTRACT_FINANCES', 'OOS_CONTRACT_FINANCES', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(181804, 1818, '', 'OOS_ATTACHMENTS', 'OOS_ATTACHMENTS', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(250406, 2504, '', 'Suppliers', 'Suppliers', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(540200, 5402, '', 'EPBSExportLogCaption', 'EPBSExportLogCaption', 'id', 'id', '', '', 0, null, null, null) ;

CALL ImportDocCLS(540201, 5402, '', 'EPBSExportLogDetail', 'EPBSExportLogDetail', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(970900, 9709, ' ', 'TargetCls', ' ', 'ID', ' ', '', '', 109, null, null, null) ;

CALL ImportDocCLS(985400, 9854, ' ', 'InvestObject', ' ', 'ID', ' ', '', '', 54, null, null, null) ;

CALL ImportDocCLS(182100, 1821, '', 'PayDocExchange', 'PayDocExchange', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(470100, 4701, '', 'SignCertificate', 'SignCertificate', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(971000, 9710, ' ', 'NATIONALPROJECT', 'NATIONALPROJECT', 'ID', 'ID', '', '', 110, null, null, null) ;

CALL ImportDocCLS(21600, 216, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 280) ;

CALL ImportDocCLS(21601, 216, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 280) ;

CALL ImportDocCLS(21700, 217, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 281) ;

CALL ImportDocCLS(21701, 217, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 281) ;

CALL ImportDocCLS(21702, 217, '2', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 281) ;

CALL ImportDocCLS(993300, 9933, '', 'ClsCorr', 'ClsCorr', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(993301, 9933, '', 'ClsCorrColumns', 'ClsCorrColumns', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(993400, 9934, '', 'ClsCorr', 'ClsCorr', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(993401, 9934, '', 'ClsCorrValues', 'ClsCorrValues', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(971100, 9711, ' ', 'RegProjectResult', 'RegProjectResult', 'ID', 'ID', '', '', 111, null, null, null) ;

CALL ImportDocCLS(21800, 218, '', 'BudNotify', 'BudNotify', 'ID', 'ID', '', '', 0, null, null, 282) ;

CALL ImportDocCLS(21801, 218, '', 'BudgetData', 'BudgetData', 'ID', 'ID', 'RecordIndex', '', 0, null, null, 282) ;

CALL ImportDocCLS(32500, 325, '', 'FACIALFINCAPTION', 'FACIALFINCAPTION', 'ID', 'ID', '', '', 0, null, null, 283) ;

CALL ImportDocCLS(32501, 325, '', 'FACIALFINDETAIL', 'FACIALFINDETAIL', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, 283) ;

CALL ImportDocCLS(182400, 1824, '', 'PayDocExchange ', 'PayDocExchange ', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(182401, 1824, '', 'ED_OUT_FACIALACC', 'ED_OUT_FACIALACC', 'ID', 'ID', 'ELDOCREF', '', 0, null, null, null) ;

CALL ImportDocCLS(182500, 1825, '', 'PayDocExchange', 'PayDocExchange', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(971300, 9713, ' ', 'PayTargetFunds', 'PayTargetFunds', 'ID', 'ID', '', '', 113, null, null, null) ;

CALL ImportDocCLS(971200, 9712, ' ', 'IncomeTargetFunds', 'IncomeTargetFunds', 'ID', 'ID', '', '', 112, null, null, null) ;

CALL ImportDocCLS(971400, 9714, ' ', 'AnalyticalPartition', 'AnalyticalPartition', 'ID', 'ID', '', '', 114, null, null, null) ;

CALL ImportDocCLS(971600, 9716, ' ', 'PaymentCodeType', 'PaymentCodeType', 'ID', 'ID', '', '', 116, null, null, null) ;

DROP PROCEDURE ImportDocCLS
/

COMMIT WORK
/


CREATE OR REPLACE PROCEDURE ImportField (
   ID_                NUMBER,
   NAME_              VARCHAR2,
   ITFFIELDNAME_      VARCHAR2,
   NOTE_              VARCHAR2,
   TEMPLATEFIELD_     VARCHAR2,
   ISBUDGET_          NUMBER,
   DOCTYPEREF_        NUMBER,
   DETAILNUMBER_      NUMBER,
   ONLYREAD_          NUMBER,
   ReportFieldName_   VARCHAR2,
   KIND_	      NUMBER,
   FIELDINFOREF_      NUMBER,
   CONTAINERREF_      NUMBER, 
   ATTRFIELDKIND_     NUMBER,
   ATTRIBUTENAME_     VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentFields
    WHERE (ID = ID_);

   IF (IDExists$ <> 0) THEN
      UPDATE DocumentFields
         SET NAME = NAME_,
             ITFFIELDNAME = ITFFIELDNAME_,
             NOTE = NOTE_,
             TEMPLATEFIELD = TEMPLATEFIELD_,
             ISBUDGET = ISBUDGET_,
             DOCTYPEREF = DOCTYPEREF_,
             DETAILNUMBER = DETAILNUMBER_,
             ONLYREAD = ONLYREAD_,
             ReportFieldName = ReportFieldName_,
			       FIELDINFOREF = FIELDINFOREF_, 
             CONTAINERREF = CONTAINERREF_, 
             ATTRFIELDKIND = ATTRFIELDKIND_,
             ATTRIBUTENAME = ATTRIBUTENAME_
       WHERE (ID = ID_)
         AND NOT (
                      (
                          (
                           (NAME IS NOT NULL AND NAME_ IS NOT NULL) AND
                           (UPPER (NAME) = UPPER (NAME_))
                          )
                       OR (NAME IS NULL AND NAME_ IS NULL)
                      )

                  AND (
                          (
                           (ITFFIELDNAME_ IS NOT NULL AND ITFFIELDNAME IS NOT NULL) AND
                           (UPPER (ITFFIELDNAME_) = UPPER (ITFFIELDNAME))
                          )
                       OR (ITFFIELDNAME_ IS NULL AND ITFFIELDNAME IS NULL)
                      )
                      
                  AND (
                          (
                           (NOTE IS NOT NULL AND NOTE_ IS NOT NULL) AND
                           (UPPER (NOTE) = UPPER (NOTE_))
                          )
                       OR (NOTE IS NULL AND NOTE_ IS NULL)
                      )
                  AND (UPPER (TEMPLATEFIELD) = UPPER (TEMPLATEFIELD_))
                  AND (
                          (
                           (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                           (ISBUDGET = ISBUDGET_)
                          )
                       OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                      )
                  AND (
                          (
                           (FIELDINFOREF IS NOT NULL AND FIELDINFOREF_ IS NOT NULL) AND
                           (FIELDINFOREF = FIELDINFOREF_)
                          )
                       OR (FIELDINFOREF IS NULL AND FIELDINFOREF_ IS NULL)
                      )
                  AND (
                          (
                           (CONTAINERREF IS NOT NULL AND CONTAINERREF_ IS NOT NULL) AND
                           (CONTAINERREF = CONTAINERREF_)
                          )
                       OR (CONTAINERREF IS NULL AND CONTAINERREF_ IS NULL)
                      )   
                  AND (
                          (
                           (ATTRFIELDKIND IS NOT NULL AND ATTRFIELDKIND_ IS NOT NULL) AND
                           (ATTRFIELDKIND = ATTRFIELDKIND_)
                          )
                       OR (ATTRFIELDKIND IS NULL AND ATTRFIELDKIND_ IS NULL)
                      )
                  AND (
                          (
                           (ATTRIBUTENAME_ IS NOT NULL AND ATTRIBUTENAME IS NOT NULL) AND
                           (UPPER (ATTRIBUTENAME_) = UPPER (ATTRIBUTENAME))
                          )
                       OR (ATTRIBUTENAME_ IS NULL AND ATTRIBUTENAME IS NULL)
                      )
                  AND (DOCTYPEREF = DOCTYPEREF_)
                  AND (DETAILNUMBER = DETAILNUMBER_)
                  AND (ONLYREAD = ONLYREAD_)
                  AND (
                          (
                           (ReportFieldName IS NOT NULL AND ReportFieldName_ IS NOT NULL) AND
                           (UPPER (ReportFieldName) = UPPER (ReportFieldName_))
                          )
                       OR (ReportFieldName IS NULL AND ReportFieldName_ IS NULL)
                      )
                 );
   ELSE
      INSERT INTO DocumentFields
                  (ID, NAME, ITFFIELDNAME, NOTE, TEMPLATEFIELD,
                   ISBUDGET, DOCTYPEREF, DETAILNUMBER, ONLYREAD, ReportFieldName, FIELDINFOREF, CONTAINERREF, ATTRFIELDKIND, ATTRIBUTENAME
                  )
           VALUES (ID_, NAME_, ITFFIELDNAME_, NOTE_, TEMPLATEFIELD_,
                   ISBUDGET_, DOCTYPEREF_, DETAILNUMBER_, ONLYREAD_, ReportFieldName_, FIELDINFOREF_, CONTAINERREF_, ATTRFIELDKIND_, ATTRIBUTENAME_
                  );
   END IF;

   FOR tab_rec IN (
                   SELECT ID
                     FROM DocumentFields
                    WHERE (ID <> ID_)
                      AND (DOCTYPEREF = DOCTYPEREF_)
                      AND (
                              (
                               (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                               (ISBUDGET = ISBUDGET_)
                              )
                           OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                          )
                      AND (DETAILNUMBER = DETAILNUMBER_)
              AND ( /*      ,       ,       */
                            (
                             ((ITFFIELDNAME_ IS NULL)or(ITFFIELDNAME_=' '))
                 and not((TEMPLATEFIELD_ IS NULL)or(TEMPLATEFIELD_=' '))
                 and(TEMPLATEFIELD is NOT null) and (UPPER(TEMPLATEFIELD)=UPPER(TEMPLATEFIELD_))
                            )
                    or (
                        not ((ITFFIELDNAME_ IS NULL) or (ITFFIELDNAME_=' '))
                                and (ITFFIELDNAME IS NOT NULL) and (UPPER(ITFFIELDNAME)=UPPER(ITFFIELDNAME_)))
                            )
                       )
   LOOP
      UPDATE State_OpenFields
         SET DOCFIELDREF = ID_
       WHERE (DOCFIELDREF = tab_rec.ID);

      UPDATE DOCLOCKFIELDS
         SET FIELDREF = ID_
       WHERE (FIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET PARENTFIELDREF = ID_
      WHERE (PARENTFIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET CHILDFIELDREF = ID_
      WHERE (CHILDFIELDREF = tab_rec.ID);

      DELETE FROM DocumentFields
            WHERE (ID = tab_rec.ID);
   END LOOP;
END;
/

CREATE OR REPLACE PROCEDURE DeleteFields (ID$ NUMBER) IS
BEGIN
  DELETE FROM State_OpenFields
  WHERE (docfieldref = ID$);
  DELETE FROM DOCLOCKFIELDS
  WHERE (fieldref = ID$);

  DELETE FROM STATE_JUMPCONTROL
  WHERE STATICLINKREF IN(SELECT ID FROM staticlinks
                           WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$));
  DELETE FROM staticlinks
  WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$);
  
  DELETE FROM DOCUMENTTEMPLATEFIELDS
  WHERE (FIELDS=ID$);

  DELETE FROM STOREDATTRIBUTESDETAIL
  WHERE (ATTRIBUTEFIELD = ID$) or (CONTAINERFIELD = ID$);  

  DELETE FROM DocumentFields
  WHERE (id = ID$);
END;
/

CREATE OR REPLACE PROCEDURE INSERTCONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER,
  NOTE_          VARCHAR2,
  VARCHARVALUE_  VARCHAR2,
  DOUBLEVALUE_   NUMBER,
  INTVALUE_      INTEGER,
  EDITDOCCODE_   INTEGER
) IS
  IDEXISTS$ NUMBER;
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM IntConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO INTCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,INTVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE INTCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 8) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM VarcharConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO VARCHARCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,VARCHARVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE VARCHARCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 5) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM RealConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO REALCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,DOUBLEVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE REALCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;   
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DELETECONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER
) IS
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    UPDATE IntConst
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
  IF (CONSTTYPE_ = 8) THEN
    UPDATE VARCHARCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_); 
  END IF;
  IF (CONSTTYPE_ = 5) THEN
    UPDATE REALCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
END;
/

--       
ALTER TRIGGER TR_INTCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 DISABLE
/

--     
--    (), +(2)
CALL ImportField(20111214, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20111215, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 201, 1, 1, '', 0, null, 0, 0, '') ;

--  (), +(2)
CALL ImportField(20211159, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 202, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20211160, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 202, 1, 1, '', 0, null, 0, 0, '') ;

--   (), +(2)
CALL ImportField(20311167, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 203, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20311168, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 203, 1, 1, '', 0, null, 0, 0, '') ;

--  , , +(2)
CALL ImportField(20411159, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 204, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20411160, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 204, 1, 1, '', 0, null, 0, 0, '') ;

-- , +(2)
CALL ImportField(20511146, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 205, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20511147, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 205, 1, 1, '', 0, null, 0, 0, '') ;

--    (), +(2)
CALL ImportField(20611207, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 206, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20611208, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 206, 1, 1, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(20711230, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 207, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20711231, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 207, 1, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(20811231, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 208, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20811232, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 208, 1, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(20911168, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 209, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20911169, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 209, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20912170, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 209, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20912171, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 209, 2, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(21011090, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 210, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21011091, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 210, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21012092, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 210, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21012093, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 210, 2, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(21111089, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 211, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21111090, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 211, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21112091, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 211, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21112092, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 211, 2, 1, '', 0, null, 0, 0, '') ;

--   , , +(2)
CALL ImportField(21211075, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 212, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21211076, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 212, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(21212079, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 212, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21212080, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 212, 2, 1, '', 0, null, 0, 0, '') ;

--   14 /, +(2)
CALL ImportField(21511053, '  ()', 'KVSR', '  ()', 'DestKVSRKey', 2, 215, 1, 1, '', 0, 17412, 0, 0, '') ;

CALL ImportField(21511054, ' ', 'KVSRCode', ' ', 'DestKVSR', 2, 215, 1, 0, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(21811134, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 218, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21811135, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 218, 1, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(30111226, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 301, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30111227, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 301, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30111228, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 301, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30111229, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 301, 1, 1, '', 0, null, 0, 0, '') ;

--   \, (0)
CALL ImportField(30201125, ' ', 'SourceFundsSource', ' ', 'SourceFundsSource', 0, 302, 1, 0, '', 0, null, 0, 0, '') ;

--   \, +(2)
CALL ImportField(30211238, '   ', 'SourceRegProjectResultCode', '   ', 'SourceRegProjectResultCode', 2, 302, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30211239, '   ', 'DestRegProjectResultCode', '   ', 'DestRegProjectResultCode', 2, 302, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30211240, '   ()', 'SourceRegProjectResult', '   ()', 'SourceRegProjectResult', 2, 302, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(30211241, '   ()', 'DestRegProjectResult', '   ()', 'DestRegProjectResult', 2, 302, 1, 1, '', 0, null, 0, 0, '') ;

--  (), +(2)
CALL ImportField(30311125, '   ', 'DestRegProjectResultCode', '   ', 'DestRegProjectResultCode', 2, 303, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30311126, '   ()', 'DestRegProjectResult', '   ()', 'DestRegProjectResult', 2, 303, 1, 1, ',', 0, null, 0, 0, '') ;

--   , (0)
CALL ImportField(30401041, '  .', 'SourceBudgetPromiseAgrReestrNum', '  .', 'SourceBudgetPromiseAgrReestrNum', 0, 304, 1, 1, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(30411181, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 304, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30411182, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 304, 1, 1, ',', 0, null, 0, 0, '') ;

--   \, +(2)
CALL ImportField(30511194, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 305, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30511195, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 305, 1, 1, ',', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(30611212, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 306, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30611213, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 306, 1, 1, ',', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(30811269, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 308, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30811270, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 308, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(30811271, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 308, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30811272, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 308, 1, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(31111124, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 311, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(31111125, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 311, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(31111126, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 311, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(31111127, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 311, 1, 1, '', 0, null, 0, 0, '') ;

--     , +(2)
CALL ImportField(31211188, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 312, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(31211189, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 312, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(31211190, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 312, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(31211191, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 312, 1, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(31411183, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 314, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(31411184, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 314, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(31411185, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 314, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(31411186, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 314, 1, 1, '', 0, null, 0, 0, '') ;

--      , +(2)
CALL ImportField(31511111, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 315, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(31511112, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 315, 1, 1, ',', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(32211107, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 322, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(32211108, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResult', 2, 322, 1, 1, ',', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(32311225, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 323, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(32311226, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 323, 1, 1, ',', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(32411270, '  ', 'DestRegProjectResultCode', '  ', 'DestRegProjectResultCode', 2, 324, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(32411271, '  ()', 'DestRegProjectResult', '  ', 'DestRegProjectResult', 2, 324, 1, 1, ',', 0, null, 0, 0, '') ;

--    , (0)
CALL ImportField(32500028, '. ()', 'DESTFACIALACC_CLS', '. ()', 'DESTFACIALACCCLS', 0, 325, 0, 0, ',DestFacialACCCLS', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(32510027, '. ()', 'DESTFACIALACC_CLS', '. ()', 'DESTFACIALACCCLS', 1, 325, 0, 0, ',DestFacialACCCLS', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(32510147, ' ', 'CRYPTOSTATUS', ' ', 'CRYPTOSTATUS', 2, 325, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(32511138, '  ', 'SourceRegProjectResultCode', '  ', 'SourceRegProjectResultCode', 2, 325, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(32511139, '  ()', 'SourceRegProjectResult', '  ', 'SourceRegProjectResultKey', 2, 325, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(32511140, '   ', 'ACCEPTDATE', '   ', 'ACCEPTDATE_DET', 2, 325, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(32511148, ' ', 'SourceRegionCLS', ' ', 'SourceRegionCls', 2, 325, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(32511149, '.   ', 'SourceBudgetPromise', '     ', 'SOURCEBUDGETPROMISE', 2, 325, 1, 1, ',', 0, 18908, 0, 0, '') ;

--   , +(2)
CALL ImportField(90311190, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 903, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(90311191, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 903, 1, 1, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(90510061, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 905, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(90510062, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 905, 0, 1, '', 0, null, 0, 0, '') ;

--   (), +(2)
CALL ImportField(90610117, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 906, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(90610119, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 906, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(90611118, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode_DET', 2, 906, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(90611120, '  ()', 'RegProjectResult', '  ', 'RegProjectResult_DET', 2, 906, 1, 1, '', 0, null, 0, 0, '') ;

--   (), +(2)
CALL ImportField(90710069, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 907, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(90710070, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 907, 0, 1, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(182410035, 'LastLog_FAUPDATEDATE', 'LastLog_FAUPDATEDATE', 'LastLog_FAUPDATEDATE', ' ', 1, 1824, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(182410036, '', 'StatusCalc', ' ,   "" ', ' ', 1, 1824, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182411028, '', 'Procnote', '', ' ', 1, 1824, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(182411036, '', 'Status', ' ', ' ', 1, 1824, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(182411037, ' ', 'NOTE', ' ', ' ', 1, 1824, 1, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(250212096, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 2502, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250212097, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 2502, 2, 1, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(250310090, ' ', 'RealID', ' ', 'RealID', 2, 2503, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250312088, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 2503, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250312089, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 2503, 2, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(250412053, '', 'InvestObject', '', 'InvestObject', 2, 2504, 2, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(250412054, '', 'InvestObjectCode', '', 'InvestObjectCode', 2, 2504, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250412168, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 2504, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250412169, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 2504, 2, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(300111154, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 3001, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300111155, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 3001, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300111156, '   ', 'PayTargetFundsCode', '   ', 'PayTargetFunds', 2, 3001, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300111157, '   ()', 'PayTargetFunds', '   ', ' ', 2, 3001, 1, 1, '', 0, null, 0, 0, '') ;

--     223-, +(2)
CALL ImportField(300611094, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 3006, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300611095, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 3006, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(300611096, '   ', 'PayTargetFundsCode', '   ', 'PayTargetFunds', 2, 3006, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(300611097, '   ()', 'PayTargetFunds', '   ', ' ', 2, 3006, 1, 1, '', 0, null, 0, 0, '') ;

--  - , +(2)
CALL ImportField(301111034, '', 'DirectionClsCode', '', 'DirectionCls', 2, 3011, 1, 0, '', 0, 36861, 0, 0, '') ;

CALL ImportField(301111037, ' . ', 'FinTypeCode', '', 'FinType', 2, 3011, 1, 0, ',', 0, 36853, 0, 0, '') ;

CALL ImportField(301111039, ' ', 'SubsidyClsCode', '', 'SubsidyClsCode', 2, 3011, 1, 0, '', 0, 26641, 0, 0, '') ;

CALL ImportField(301111041, ' .  ()', 'FinType', '', 'FinTypeKey', 2, 3011, 1, 1, ',', 0, 21114, 0, 0, '') ;

CALL ImportField(301111042, ' ()', 'DirectionCls', '', 'DirectionClsKey', 2, 3011, 1, 1, '', 0, 21104, 0, 0, '') ;

CALL ImportField(301111049, '', 'ContractCostsCls', '', 'ContractCostsCls', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111050, '', 'ContractCostsClsCode', '', 'ContractCostsClsCode', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111064, '  ()', 'BudAllocationCls', '', 'BudAllocationCls', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301111084, '   ', 'PayTargetFundsCode', '   ', 'PayTargetFundsCode', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111085, '   ()', 'PayTargetFunds', '   ', 'PayTargetFunds', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(301111086, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 3011, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(301111087, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 3011, 1, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(440111081, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 4401, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(440111082, '   ()', 'RegProjectResult', '   ()', 'RegProjectResult', 2, 4401, 1, 1, '', 0, null, 0, 0, '') ;

--  ,, +(2)
CALL ImportField(440311073, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 4403, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(440311074, '   ()', 'RegProjectResult', '   ()', 'RegProjectResult', 2, 4403, 1, 1, '', 0, null, 0, 0, '') ;

--  / , +(2)
CALL ImportField(520111089, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 5201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(520111090, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 5201, 1, 1, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(550110172, ' ', 'ErrorNote', ' ', 'ErrorNote', 1, 5501, 0, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(550111194, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 5501, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550111195, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 5501, 1, 1, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(550210157, ' ', 'ErrorNote', ' ', 'ErrorNote', 1, 5502, 0, 1, '', 0, null, 0, 0, '') ;

--    , +(2)
CALL ImportField(550211208, '  ', 'RegProjectResultCode', '  ', 'RegProjectResultCode', 2, 5502, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550211209, '  ()', 'RegProjectResult', '  ', 'RegProjectResult', 2, 5502, 1, 1, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(550311085, '  ', 'RegProjectResultCode', '  ', 'RegProjectResult', 1, 5503, 1, 0, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(984110053, ' ', 'DateChange', '', ' ', 1, 9841, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(984110054, '  /', 'PrevCls', '', ' ', 1, 9841, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(984110055, ' .  ', 'ChangeDocNumber', '', ' ', 1, 9841, 0, 0, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(984110056, '.', 'IsKS', '', ' ', 2, 9841, 0, 0, '', 0, null, 0, 0, '') ;

-- , +(2)
CALL ImportField(985410010, '   .', 'SubCode', '', ' ', 2, 9854, 0, 0, '', 0, 38206, 0, 0, '') ;

--  , (1)
CALL ImportField(991210025, '. ', 'IsForKS', '. ', ' ', 1, 9912, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(991210026, ' ', 'isForAU', ' ', ' ', 1, 9912, 0, 0, '', 0, null, 0, 0, '') ;

--     , (1)
CALL ImportField(992910040, '', 'InvestObject', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0, '') ;

--   , (1)
CALL ImportField(993411092, '.   ()', 'StoredContent', '.   ()', ' ', 1, 9934, 1, 0, '', 0, null, 0, 2, '') ;

--       
ALTER TRIGGER TR_INTCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 ENABLE
/

DROP PROCEDURE ImportField
/

/*      */
ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 DISABLE
/

Update TB_DocumentFields df
set documentcls=doctyperef*100+detailnumber
where (detailnumber<100)and(documentcls is null)
 and(exists(select dc.id from documentcls dc where id=df.doctyperef*100+df.detailnumber))
/

ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 ENABLE
/

DROP PROCEDURE DeleteFields
/

DROP PROCEDURE InsertConst
/

DROP PROCEDURE DELETECONST
/




CREATE OR REPLACE PROCEDURE DOCLOCK_IMPORT(
  NAME_              VARCHAR2,
  LOCKMASK_          NUMBER,
  DOCREF_            NUMBER,
  DETAILNUM_         NUMBER,
  RUNPOS_            NUMBER,
  LOCKACTION_        NUMBER,
  USERIGHTS_        NUMBER,
  FORMULA_           VARCHAR2,
  FORDELETE_         NUMBER,
  ISSYSTEM_          NUMBER,
  NOTE_              VARCHAR2,
  FORINSERT_         NUMBER,
  VALIDATEMESSAGE_ VARCHAR2,
  VALIDATELEVEL_   NUMBER,
  VALIDATEFILTER_  VARCHAR2,
  ISBUDGET_ NUMBER,
  DEFAULTVALUE_ VARCHAR2)
IS
  DOCLOCKID$ Number(10);
BEGIN
   BEGIN
     SELECT ID
     INTO DOCLOCKID$
     FROM DOCLOCK
     WHERE (DOCREF = DOCREF_) AND(DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DOCLOCKID$ := NULL;  
   END;
   
   IF (DOCLOCKID$ is not null) THEN
     IF (ISSYSTEM_ = 3) THEN
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_,
         USERIGHTS = USERIGHTS_,
         DEFAULTVALUE = DEFAULTVALUE_
       WHERE ID = DOCLOCKID$;  
     ELSE
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_,
         DEFAULTVALUE = DEFAULTVALUE_
       WHERE ID = DOCLOCKID$;    
     END IF;  
   ELSE
     INSERT INTO DOCLOCK
       (ISBUDGET,NAME,LOCKMASK,DOCREF,DETAILNUM,RUNPOS,LOCKACTION,USERIGHTS,FORMULA,FORDELETE,ISSYSTEM,NOTE,FORINSERT,VALIDATEMESSAGE,VALIDATELEVEL,VALIDATEFILTER,DEFAULTVALUE)
     VALUES
       (ISBUDGET_,NAME_,LOCKMASK_,DOCREF_,DETAILNUM_,RUNPOS_,LOCKACTION_,USERIGHTS_,FORMULA_,FORDELETE_,ISSYSTEM_,NOTE_,FORINSERT_,VALIDATEMESSAGE_,VALIDATELEVEL_,VALIDATEFILTER_,DEFAULTVALUE_);
   END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_INSERTFIELD(
  NAME_      VARCHAR2,
  DOCREF_    NUMBER,
  DETAILNUM_ NUMBER,
  FIELDREF_  NUMBER,
  ISBUDGET_ NUMBER)
IS
  NID$ NUMBER(10);
  cnt$ number(10);
BEGIN
  BEGIN
    SELECT ID
    INTO NID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      NID$ := NULL;  
  END;

  IF (NID$ is not null) THEN
    CNT$ := 0;
    SELECT count(ID)
    into cnt$
    FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    
    IF (cnt$ = 0) THEN
      INSERT INTO DOCLOCKFIELDS
        (DOCLOCKREF,FIELDREF,ISSYSTEM)
      VALUES
        (NID$,FIELDREF_,1);
    ELSE
      UPDATE DOCLOCKFIELDS SET
        ISSYSTEM = 1
      WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    END IF;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCK_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCK
    WHERE ID = DOCLOCKID$;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, CANCHANGEFIELDS_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION  
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;  

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = DOCLOCKID$) AND ((ISSYSTEM = 1) OR ((ISSYSTEM = 0) AND (CANCHANGEFIELDS_ = 0) ));
  END IF;
END;
/

-- 
CALL DOCLOCK_DELETE('  ',325, 0, 2) ;

CALL DOCLOCK_DELETE('  ""',1824, -1, 1) ;

CALL DOCLOCK_DELETE('  ""',1824, -1, 1) ;

CALL DOCLOCK_DELETE('  ',1824, -1, 1) ;

CALL DOCLOCK_DELETE('  ""',1824, 0, 1) ;

CALL DOCLOCK_DELETE('  ',1824, 0, 1) ;

CALL DOCLOCK_DELETE('     ',9903, 0, 1) ;

CALL DOCLOCK_IMPORT('     ,',0,200,1,0,11,0,' ( in (213, 214, 215))  ([20011012] <> 1)',0,1,'          "",   -   ""',0,'       ""          ""  ',null,'((.[20011012]=2)  ([988410016] = 0)) 

((.[20011012]=0)  ([988410016] = 1))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     ,', 200, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',200,1,20011011,1) ;

CALL DOCLOCK_IMPORT('    / ,',0,200,1,0,11,0,' ((=204)(=212)  (=218))',0,3,'  \,  ,       ',0,'    / , ,  / , , / , /         ',null,'([984110041]=0)([984110045]=0)([984110046]=0)([984110056]=0)',1,'') ;

CALL DOCLOCKFIELDS_DELETE('    / ,', 200, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    / ,',200,1,20011008,1) ;

CALL DOCLOCK_IMPORT('     ',0,200,1,0,11,0,'([20011012] = 2)   ( in (213, 214, 215))   ( ("_._",[20011008]))  ( ("_._",[20011008]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[20011017] = 0)  ([970910023] = .[20011026]) 

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[20011026], 4)))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 200, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',200,1,20011043,1) ;

CALL DOCLOCK_IMPORT('     ,',0,200,1,0,11,0,'([20001012] <> 1)',0,1,'          "",   -   ""',0,'       ""          ""  ',null,'((.[20001012]=2)  ([988410016] = 0)) 

((.[20001012]=0)  ([988410016] = 1))',0,'') ;

CALL DOCLOCKFIELDS_DELETE('     ,', 200, 1, 0, 0) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',200,1,20001011,0) ;

CALL DOCLOCK_IMPORT('    / ,',0,200,1,0,11,0,' ((=204)(=212)  (=218))',0,3,'  \,  ,       ',0,'    / , ,  / , , /       ',null,'([984110041]=0)([984110045]=0)([984110046]=0)([984110056]=0)',0,'') ;

CALL DOCLOCKFIELDS_DELETE('    / ,', 200, 1, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    / ,',200,1,20001008,0) ;

CALL DOCLOCK_IMPORT('     ',0,200,1,0,11,0,'([20001012] = 2)   ( in (213, 214, 215))   ( ("_._",[20001008]))  ( ("_._",[20001008]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[20011017] = 0)  ([970910023] = .[20011026]) 

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[20011026], 4)))',0,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 200, 1, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',200,1,20001043,0) ;

CALL DOCLOCK_IMPORT('   ',0,203,0,0,11,0,'',0,1,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1,'') ;

CALL DOCLOCKFIELDS_DELETE('   ', 203, 0, 0, 1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',203,0,20310039,1) ;

CALL DOCLOCK_IMPORT('   ',0,203,0,0,11,0,'',0,1,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',0,'') ;

CALL DOCLOCKFIELDS_DELETE('   ', 203, 0, 0, 0) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',203,0,20300124,0) ;

CALL DOCLOCK_IMPORT('   ',0,203,1,0,11,0,'',0,1,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',1,'') ;

CALL DOCLOCKFIELDS_DELETE('   ', 203, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('   ',203,1,20311038,1) ;

CALL DOCLOCK_IMPORT('   ',0,203,1,0,11,0,'',0,1,'   ',0,'  .          ',null,'([960110035] > 10099  [960110035] < 10400)([960110035] = 30200)',0,'') ;

CALL DOCLOCKFIELDS_DELETE('   ', 203, 1, 0, 0) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('   ',203,1,20301139,0) ;

CALL DOCLOCK_IMPORT('      ',0,210,2,0,11,0,'[21000005] = 0',0,1,'      ',0,'     ',null,'([970910066] is null) ? 
((((.[21002021] = "")  ([970910017] = "000"))  
  ((.[21002021] <> "")  (.[21002021], [970910017], "9.9.9")))  
(((.[21002017] = "")  ([970910015] = "0000"))  
  ((.[21002017] <> "")  (.[21002017], [970910015], "99.99"))) 
(((.[21002014] = "")  ([970910013] = "0000000000"))  
  ((.[21002014] <> "")  (.[21002014], [970910013], ">aa.a.aa.aaaaa")))     
(((.[21002019] = "")  ([970910016] = "000"))  
  ((.[21002019] <> "")  (.[21002019], [970910016], ">a.a.a")))) :
/*      */
((([970910049] = 0)  (.[21002020] = 0)  (.[21002021] = [970910050])) 
(([970910046] = 0)  (.[21002017] = 0)  (.[21002017] = [970910046])) 
(([970910047] = 0)  (.[21002018] = 0)  (.[21002019] = [970910048])) 
(([970910042] = 0)  (.[21002013] = 0)  (.[21002014] = [970910043])) 
(([970910044] = 0)  (.[21002015] = 0)  (.[21002071] = [970910045])) 
(([970910065] = 0)  (.[21002022] = 0)  (.[21002022] = [970910065])) 
(([970910056] = "")  (.[21002075] = "")  (.[21002076] = [970910056])) 
(([970910060] = 0)  (.[21002009] = 0)  (.[21002059] = [970910061])) 
(([970910051] = 0)  (.[21002043] = 0)  (.[21002072] = [970910052])) 
(([970910064] = 0)  (.[21002041] = 0)  (.[21002041] = [970910064])) 
(([970910040] = 0)  (.[21002010] = 0)  (.[21002078] = [970910041])) 
(([970910038] = 0)  (.[21002006] = 0)  (.[21002080] = [970910039]))   
(([970910054] = "")  (.[21002055] = "")  (.[21002057] = [970910054])) 
(([970910033] = 0)  (.[21002001] = 0)  (.[21002001] = [970910033])) 
(([970910035] = "")  (.[21002082] = "")  (.[21002084] = [970910035])) 
(([970910059] = "")  (.[21002086] = "")  (.[21002088] = [970910059]))  
(([970910037] = "")  (.[21002068] = "")  (.[21002069] = [970910037])))',0,'') ;

CALL DOCLOCKFIELDS_DELETE('      ', 210, 2, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',210,2,21002062,0) ;

CALL DOCLOCK_IMPORT('      ',0,210,2,0,11,0,'[21010005] = 0',0,1,'      ',0,'     ',null,'([970910066] is null) ? 
((((.[21012021] = "")  ([970910017] = "000"))  
  ((.[21012021] <> "")  (.[21012021], [970910017], "9.9.9")))  
(((.[21012017] = "")  ([970910015] = "0000"))  
  ((.[21012017] <> "")  (.[21012017], [970910015], "99.99"))) 
(((.[21012014] = "")  ([970910013] = "0000000000"))  
  ((.[21012014] <> "")  (.[21012014], [970910013], ">aa.a.aa.aaaaa")))     
(((.[21012019] = "")  ([970910016] = "000"))  
  ((.[21012019] <> "")  (.[21012019], [970910016], ">a.a.a")))) :
/*      */
((([970910049] = 0)  (.[21012020] = 0)  (.[21012021] = [970910050])) 
(([970910046] = 0)  (.[21012017] = 0)  (.[21012017] = [970910046])) 
(([970910047] = 0)  (.[21012018] = 0)  (.[21012019] = [970910048])) 
(([970910042] = 0)  (.[21012013] = 0)  (.[21012014] = [970910043])) 
(([970910044] = 0)  (.[21012015] = 0)  (.[21012071] = [970910045])) 
(([970910065] = 0)  (.[21012022] = 0)  (.[21012022] = [970910065])) 
(([970910056] = "")  (.[21012065] = "")  (.[21012064] = [970910056])) 
(([970910060] = 0)  (.[21012058] = 0)  (.[21012009] = [970910061])) 
(([970910051] = 0)  (.[21012043] = 0)  (.[21012072] = [970910052])) 
(([970910064] = 0)  (.[21012041] = 0)  (.[21012041] = [970910064])) 
(([970910040] = 0)  (.[21012060] = 0)  (.[21012010] = [970910041])) 
(([970910038] = 0)  (.[21012059] = 0)  (.[21012006] = [970910039]))   
(([970910054] = "")  (.[21012053] = "")  (.[21012052] = [970910054])) 
(([970910033] = 0)  (.[21012001] = 0)  (.[21012001] = [970910033])) 
(([970910035] = "")  (.[21012054] = "")  (.[21012055] = [970910035])) 
(([970910059] = "")  (.[21012056] = "")  (.[21012057] = [970910059]))  
(([970910037] = "")  (.[21012063] = "")  (.[21012062] = [970910037])))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('      ', 210, 2, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('      ',210,2,21012066,1) ;

CALL DOCLOCK_IMPORT('     ',0,300,0,0,11,0,'(("/.",[30010021]) = 0) (("/.",[30010021])=0) (("/.",[30010021]) = 0)',0,1,'            ,   /c   ", "  " , "  ""',0,'     , ,   ,             ',null,'(([984110042] = 1)  ([984110044] = 1)  ([984110043] = 1)  ([984110056] = 1)) 
( ([984110044] = 0)  ([984110042] = 0)  ([984110041] = 0)  
    ([984110045] = 0)  ([984110046] = 0)  ([984110043] = 0) )',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 300, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',300,0,30010008,1) ;

CALL DOCLOCK_IMPORT('     (2)',0,300,0,0,11,0,'(<>323)  (("/._",[30010021]) = 0)    ((("/.",[30010021]) <> 0)  (30,44,3) = 1)   (("/._",[30010021]) = 0)  (("/._",[30010021]) = 0)  (("/.",[30010021]) = 0)',0,1,'          () ,   , ,  /c  /c   ',0,'         ", ", " , ", "", " " ',null,'(([984110041] = 1)  ([984110045] = 1)  ([984110046]=1)  ([984110056] = 1) ) 
( ([984110044] = 0)  ([984110042] = 0)  ([984110043] = 0))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     (2)', 300, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     (2)',300,0,30010008,1) ;

CALL DOCLOCK_IMPORT('  ',0,300,0,0,9,0,'(1) ? (ABS([30010015] - ([30011016])) < 0.005) : (ABS([30010015]- (".FACIALFINDETAIL[CREDIT,RecordIndex].{SUM(CREDIT)}", ("RecordIndex=" + [30010022]))) < 0.005)',0,3,'       ',0,'C    ',0,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('  ', 300, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',300,0,30010001,1) ;

CALL DOCLOCK_IMPORT('     (3)',0,300,0,0,11,0,'(("/._",[30000021]) = 1)   (("/.",[30000021]) = 0)   (("/._",[30000021]) = 0)  (("/.",[30000021]) = 0)  (("/.",[30000021])=0)  (("/.",[30000021]) = 0)',0,1,'         /,   /c,      (),    ,   ',0,'         (),     ',null,'((".",[984110031]) between 011000 and 011199) 
((".",[984110031]) between 010100 and 010199)',0,'') ;

CALL DOCLOCKFIELDS_DELETE('     (3)', 300, 0, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     (3)',300,0,30000008,0) ;

CALL DOCLOCK_IMPORT('     (2)',0,300,0,0,11,0,'(<>323)  (("/._",[30000021]) = 0)   ((("/.",[30000021]) <> 0)  (30,44,3) = 1)   (("/._",[30000021]) = 0)  (("/._",[30000021]) = 0)  (("/.",[30000021]) = 0)',0,1,'          () ,   , ,  /c  /c   ',0,'         ", "  " , " ',null,'(([984110041] = 1)  ([984110045] = 1)  ([984110046]=1)  ([984110056] = 1)) 
( ([984110044] = 0)  ([984110042] = 0)  ([984110043] = 0) )',0,'') ;

CALL DOCLOCKFIELDS_DELETE('     (2)', 300, 0, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     (2)',300,0,30000008,0) ;

CALL DOCLOCK_IMPORT('     ',0,300,0,0,11,0,'(("/.",[30000021]) = 0)  (("/.",[30000021])=0)  (("/.",[30000021]) = 0)',0,1,'            ,   /c   ", "  " , "  ""',0,'     , ,          ',null,'(([984110042] = 1)  ([984110044] = 1)  ([984110043] = 1)  ([984110056] = 1)) 
( ([984110044] = 0)  ([984110042] = 0)  ([984110041] = 0)  
    ([984110045] = 0)  ([984110046] = 0)  ([984110043] = 0) )',0,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 300, 0, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',300,0,30000008,0) ;

CALL DOCLOCK_IMPORT('     (3)',0,300,0,0,11,0,'(("/._",[30010021]) = 1)   (("/.",[30010021]) = 0)   (("/._",[30010021]) = 0)  (("/.",[30010021]) = 0)  (("/.",[30010021])=0)  (("/.",[30010021]) = 0)',0,1,'         /,   /c,      (),    ,   ',0,'         (),     ,      ',null,'((".",[984110031]) between 011000 and 011199) 
((".",[984110031]) between 010100 and 010199)',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     (3)', 300, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     (3)',300,0,30010008,1) ;

CALL DOCLOCK_IMPORT('     ',0,300,1,0,11,0,'([30001019] = 2)  ( ("/._",[30000021]))  ( ("/._",[30000021]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[30001025] = 0)  (.[30001034] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[30001034], 4)))',0,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 300, 1, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',300,1,30001047,0) ;

CALL DOCLOCK_IMPORT('     ',0,300,1,0,11,0,'([30011019] = 2)  ( ("/._", [30010021]))  ( ("/._", [30010021]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[30011025] = 0)  (.[30011034] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[30011034], 4)))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 300, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',300,1,30011047,1) ;

CALL DOCLOCK_IMPORT('   .   ',0,301,1,0,11,0,'([30101081] = 2)  ( ("/._", [30100024]))  ( ("/._", [30100024]))',0,3,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[30101162] = 0)  (.[30101165] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[30101165], 4)))',0,'') ;

CALL DOCLOCKFIELDS_DELETE('   .   ', 301, 1, 0, 0) ;

--  "  -"
CALL DOCLOCKFIELDS_INSERTFIELD('   .   ',301,1,30101207,0) ;

CALL DOCLOCK_IMPORT('   .   ',0,301,1,0,11,0,'([30111051] = 2)  ( ("/._", [30110028]))  ( ("/._", [30110028]))',0,3,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[30111122] = 0)  (.[30111130] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[30111130], 4)))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('   .   ', 301, 1, 0, 1) ;

--  "  -"
CALL DOCLOCKFIELDS_INSERTFIELD('   .   ',301,1,30111193,1) ;

CALL DOCLOCK_IMPORT('   .   ',0,308,1,0,11,0,'([30801172] = 2)  ( ("/._", [30800053]))  ( ("/._", [30800053]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[30801209] = 0)  (.[30801210] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[30801210], 4)))',0,'') ;

CALL DOCLOCKFIELDS_DELETE('   .   ', 308, 1, 0, 0) ;

--  "  -"
CALL DOCLOCKFIELDS_INSERTFIELD('   .   ',308,1,30801248,0) ;

CALL DOCLOCK_IMPORT('   .   ',0,308,1,0,11,0,'([30811003] = 2)  ( ("/._", [30810018]))  ( ("/._", [30810018]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[30811019] = 0)  (.[30811093] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[30811093], 4)))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('   .   ', 308, 1, 0, 1) ;

--  "  -"
CALL DOCLOCKFIELDS_INSERTFIELD('   .   ',308,1,30811120,1) ;

CALL DOCLOCK_IMPORT(' ',1048576,325,-1,0,6,0,'',1,1,'  .       .',2,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE(' ', 325, -1, 0, 1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',325,-1,32510123,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',325,-1,32510122,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',325,-1,32510016,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',325,-1,32510008,1) ;

CALL DOCLOCK_IMPORT(' ,   ',1073741824,325,-1,0,8,0,'',1,1,'   ,      ',1,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE(' ,   ', 325, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('  ',1048576,325,-1,0,7,0,'',1,3,'   .   ,   .           .',2,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('  ', 325, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('  ',2,325,-1,0,8,2,'',1,1,'     ,   .       .',2,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('  ', 325, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('  ',64,325,-1,0,4,2,'',1,1,'         .       .',1,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('  ', 325, -1, 0, 1) ;

CALL DOCLOCK_IMPORT('    ',1074855941,325,-1,0,4,2,'',0,2,'      ,  ,    .         .',0,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('    ', 325, -1, 1, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',325,-1,32511088,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',325,-1,32511086,1) ;

--  " . "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',325,-1,32511084,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',325,-1,32511082,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',325,-1,32511074,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',325,-1,32511072,1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD('    ',325,-1,32511068,1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',325,-1,32511036,1) ;

CALL DOCLOCK_IMPORT(' ,   ',1074790404,325,-1,0,4,2,'',0,2,'     ,   .       . ,     .',0,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE(' ,   ', 325, -1, 1, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32511102,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32511088,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32511086,1) ;

--  " . "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32511084,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32511082,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32511074,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32511072,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32511070,1) ;

--  "()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32511068,1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32511036,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32510024,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32510016,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ,   ',325,-1,32510012,1) ;

CALL DOCLOCK_IMPORT(' ',1048580,325,0,0,4,2,'',0,1,'  .       .',0,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE(' ', 325, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',325,0,32510008,1) ;

CALL DOCLOCK_IMPORT(' ',1048580,325,0,0,4,2,'',0,1,'  .       ',0,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE(' ', 325, 0, 0, 1) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD(' ',325,0,32510123,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD(' ',325,0,32510122,1) ;

CALL DOCLOCK_IMPORT('  ',1048576,325,0,0,4,0,'',0,1,'     ,   .   ()     ',0,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('  ', 325, 0, 0, 1) ;

CALL DOCLOCK_IMPORT('     ',0,900,1,0,11,0,'([90001001] = 2)  ( ("/._", [90000001]))  ( ("/._", [90000001]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[90001004] = 0)  (.[90001005] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[90001005], 4)))',0,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 900, 1, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',900,1,90001010,0) ;

CALL DOCLOCK_IMPORT('     ',0,900,1,0,11,0,'([90011001] = 2)  ( ("/._", [90010001]))  ( ("/._", [90010001]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[90011004] = 0)  (.[90011005] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[90011005], 4)))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 900, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',900,1,90011010,1) ;

CALL DOCLOCK_IMPORT('  ""',32768,1824,0,0,3,4,'',0,1,'         ',0,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('  ""', 1824, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('  ""',1824,0,182410036,1) ;

CALL DOCLOCK_IMPORT('  ',2,1824,0,0,4,2,'',1,1,'     ,   .       .',2,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('  ', 1824, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('  ',1824,0,182410036,1) ;

CALL DOCLOCK_IMPORT('     ',0,2201,1,0,11,0,'( ("_._", [220111019]))  ( ("_._", [220111019]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[220111046] = 0)  (.[220111012] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[220111012], 4)))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 2201, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',2201,1,220111084,1) ;

CALL DOCLOCK_IMPORT('     ',0,2201,1,0,11,0,'( ("_._", [220100011]))  ( ("_._", [220100011]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[220101057] = 0)  (.[220101200] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[220101200], 4)))',0,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 2201, 1, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',2201,1,220101210,0) ;

CALL DOCLOCK_IMPORT('     ,',0,3006,1,0,11,0,'("_._",[300611012])   ("_._",[300611012])   ("_.",[300611012])',0,3,',        =- \,  =. ',0,'         ',null,'([988910008] = ("_.",.[300611012])
 (((".",[988910008]) between 10100  10199)
 ((".",[988910008]) between 11000  11099)))
   
(( ("_._",.[300611012])
 ([988910010] = 0))

(("_._",.[300611012])
 ([988910010] <> 0)))',2,'') ;

CALL DOCLOCKFIELDS_DELETE('     ,', 3006, 1, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',3006,1,300611080,2) ;

CALL DOCLOCK_IMPORT('   ',0,3006,1,0,11,0,'("_.",[300611012])   ("_.",[300611012])',0,1,' (   , , )          .     \   .   \      .',0,'         ',null,'(("_...",.[300611012]) between 10000  10499)

(((".",[988910008]) between 10100  10199)

([988910008] = ("_.",.[300611012]))
 ((("_.",.[300611012])<>0)
      (("_.",.[300611012])=0)
     ((".",[988910008])= ("_.",.[300611012])))
)',2,'') ;

CALL DOCLOCKFIELDS_DELETE('   ', 3006, 1, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',3006,1,300611080,2) ;

CALL DOCLOCK_IMPORT('     ,',0,3011,1,0,11,0,'("_._",[301111006])   ("_._",[301111006])   ("_.",[301111006])',0,3,',        =- \,  =. ',0,'         ',null,'([988910008] = ("_.",.[301111006])
 (((".",[988910008]) between 10100  10199)
 ((".",[988910008]) between 11000  11099)))
   
(( ("_._",.[301111006])
 ([988910010] = 0))

(("_._",.[301111006])
 ([988910010] <> 0)))',2,'') ;

CALL DOCLOCKFIELDS_DELETE('     ,', 3011, 1, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,',3011,1,301111066,2) ;

CALL DOCLOCK_IMPORT('   ',0,3011,1,0,11,0,'("_.",[301111006])   ("_.",[301111006])',0,1,' (   , , )          .     \   .   \      .',0,'         ',null,'(("_...",.[301111006]) between 10000  10499)

(((".",[988910008]) between 10100  10199)

([988910008] = ("_.",.[301111006]))
 ((("_.",.[301111006])<>0)
      (("_.",.[301111006])=0)
     ((".",[988910008])= ("_.",.[301111006])))
)',2,'') ;

CALL DOCLOCKFIELDS_DELETE('   ', 3011, 1, 0, 2) ;

--  "  ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',3011,1,301111066,2) ;

CALL DOCLOCK_IMPORT('     ',0,5201,1,0,11,0,'([520101070] = 2)   ( ("_._", [520101005]))  ( ("_._",[520101005]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[520101068]= 0)  ([970910023] = .[520101069])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[520101069], 4)))',0,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 5201, 1, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5201,1,520101081,0) ;

CALL DOCLOCK_IMPORT('     ',0,5201,1,0,11,0,'([520111071] = 2)   ( ("_._", [520111005]))  ( ("_._",[520111005]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[520111064] = 0)  ([970910023] = .[520111070])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[520111070], 4)))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 5201, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5201,1,520111081,1) ;

CALL DOCLOCK_IMPORT('     ',0,5501,1,0,11,0,'([550101066] = 2)  ( ("/._", [550100162]))  ( ("/._", [550100162]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[550101090] = 0)  (.[550101162] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[550101162], 4)))',0,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 5501, 1, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5501,1,550101182,0) ;

CALL DOCLOCK_IMPORT('     ',0,5501,1,0,11,0,'([550111066] = 2)  ( ("/._", [550110164]))  ( ("/._", [550110164]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[550111090] = 0)  (.[550111156] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[550111156], 4)))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 5501, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5501,1,550111172,1) ;

CALL DOCLOCK_IMPORT('     ',0,5502,1,0,11,0,'([550201066] = 2)  ( ("/._", [550200145]))  ( ("/._", [550200145]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[550201090] = 0)  (.[550201150] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[550201150], 4)))',0,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 5502, 1, 0, 0) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5502,1,550201195,0) ;

CALL DOCLOCK_IMPORT('     ',0,5502,1,0,11,0,'([550211066] = 2)  ( ("/._", [550210148]))  ( ("/._", [550210148]))',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[550211090] = 0)  (.[550211135] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[550211135], 4)))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 5502, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5502,1,550211160,1) ;

CALL DOCLOCK_IMPORT('     ',0,5503,1,0,11,0,'[550311008] = 2',0,1,'       ',0,'     ',null,'([970910023] = "00000000000000000000")  (.[550311022] = 0)  (.[550311072] = [970910023])

((copy([970910023], 1, 3) = 000)  
      (copy([970910023], 4) = copy(.[550311072], 4)))',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     ', 5503, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5503,1,550311067,1) ;

CALL DOCLOCK_IMPORT('    /',0,9841,0,0,10,1,'[984110012] is not null',0,1,'      /',0,' " "   ',0,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('    /', 9841, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    /',9841,0,984110012,1) ;

CALL DOCLOCK_IMPORT('   /',0,9841,0,0,10,1,'(([984110011] is null)  ([984110011] >= [984110012]))  (([984110053] is null)  ([984110053] >= [984110012]))',0,1,'             /',0,'    ',0,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('   /', 9841, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   /',9841,0,984110012,1) ;

CALL DOCLOCK_IMPORT('    ',0,9841,0,0,10,1,'([984110054] is null) = ([984110053] is null)',0,1,'      /     ,   ',0,'  " "  "  /"  ',0,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('    ', 9841, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9841,0,984110053,1) ;

CALL DOCLOCK_IMPORT('   ',32768,9841,0,0,3,1,'',0,1,'      * /',0,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('   ', 9841, 0, 0, 1) ;

--  " .  "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',9841,0,984110055,1) ;

--  " .  "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',9841,0,984110030,1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('   ',9841,0,984110005,1) ;

CALL DOCLOCK_IMPORT('   /',0,9903,2,0,10,1,'(([990312050] is null)  ([990312050] >= [990312049]))  (([990312095] is null)  ([990312095] >= [990312049]))',0,1,'             /',0,'    ',0,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('   /', 9903, 2, 0, 1) ;

--  " (  )"
CALL DOCLOCKFIELDS_INSERTFIELD('   /',9903,2,990312049,1) ;

CALL DOCLOCK_IMPORT('     /',0,9903,2,0,10,1,'([990312100] is null) = ([990312095] is null)',0,1,'      /     ,   ',0,'  " "  "  /"  ',0,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('     /', 9903, 2, 0, 1) ;

--  " (  )"
CALL DOCLOCKFIELDS_INSERTFIELD('     /',9903,2,990312095,1) ;

CALL DOCLOCK_IMPORT('    /',0,9903,2,0,10,1,'[990312049] is not null',0,1,'      /',0,' " "   ',0,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('    /', 9903, 2, 0, 1) ;

--  " (  )"
CALL DOCLOCKFIELDS_INSERTFIELD('    /',9903,2,990312049,1) ;

CALL DOCLOCK_IMPORT('   ',32768,9903,2,0,3,1,'',0,1,'      * /',0,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('   ', 9903, 2, 0, 1) ;

--  " .  .(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',9903,2,990312094,1) ;

--  " .  .(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',9903,2,990312082,1) ;

--  " .  .(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',9903,2,990312081,1) ;

CALL DOCLOCK_IMPORT('   .',32768,9912,-1,0,3,0,'0 <> [991210025]',0,3,' .     ',0,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('   .', 9912, -1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   .',9912,-1,991210026,1) ;

--  "  \( )"
CALL DOCLOCKFIELDS_INSERTFIELD('   .',9912,-1,991210019,1) ;

--  " \( )"
CALL DOCLOCKFIELDS_INSERTFIELD('   .',9912,-1,991210017,1) ;

--  " ( )"
CALL DOCLOCKFIELDS_INSERTFIELD('   .',9912,-1,991210008,1) ;

--  " \"
CALL DOCLOCKFIELDS_INSERTFIELD('   .',9912,-1,991210007,1) ;

--  "( )"
CALL DOCLOCKFIELDS_INSERTFIELD('   .',9912,-1,991210006,1) ;

CALL DOCLOCK_IMPORT('   .',32768,9912,-1,0,3,0,'0 <> [991210006]+[991210017]+[991210008]+[991210019]+[991210007]+[991210026]',0,3,' .     ',0,'',null,'',1,'') ;

CALL DOCLOCKFIELDS_DELETE('   .', 9912, -1, 0, 1) ;

--  ". "
CALL DOCLOCKFIELDS_INSERTFIELD('   .',9912,-1,991210025,1) ;

DROP PROCEDURE DOCLOCK_IMPORT      
/

DROP PROCEDURE DocLockFields_InsertField
/

DROP PROCEDURE DOCLOCK_DELETE
/

DROP PROCEDURE DOCLOCKFIELDS_DELETE
/

CREATE OR REPLACE PROCEDURE LINKTYPE_DELETE(
  NAME_         VARCHAR2,
  TEMPLATECLS_  NUMBER,
  PARENTDOCCLS_ NUMBER,
  CHILDDOCCLS_  NUMBER) IS
BEGIN
  FOR tab_rec in (SELECT id FROM LINKTYPE LT
  WHERE (((NAME_ <> '') or (NAME_ is not null)) and (LT.NAME = NAME_)) or 
    (((NAME_ = '') or (NAME_ is null)) and (LT.TEMPLATECLS = TEMPLATECLS_ AND LT.PARENTDOCCLS = PARENTDOCCLS_ AND LT.CHILDDOCCLS = CHILDDOCCLS_)))    
  LOOP
    UPDATE STATE_JUMPCONTROL SET
      REFERENCEREF = NULL
    WHERE REFERENCEREF = tab_rec.id;
    DELETE FROM REPLACEMENTCLSDETAIL WHERE LINKID IN (SELECT ID FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id);
    DELETE FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id;
    DELETE FROM LINKTYPE LT
      WHERE LT.ID = tab_rec.id;
  END LOOP;     
END;
/

CREATE OR REPLACE PROCEDURE LINKTYPE_IMPORT(
   ID_                    NUMBER,
   NAME_                  VARCHAR2,
   TEMPLATECLS_           NUMBER,
   PARENTDOCCLS_          NUMBER,
   CHILDDOCCLS_           NUMBER,
   LINKCOMMENT_           VARCHAR2,
   BLOCKPARENT_           NUMBER,
   BLOCKCHILD_            NUMBER,
   CANDELBLOCKPARENT_     NUMBER,
   CANDELBLOCKCHILD_      NUMBER,
   PARENTPICTURETYPE_     NUMBER,
   PARENTPICTURENAME_     VARCHAR2,
   CHILDPICTURETYPE_      NUMBER,
   CHILDPICTURENAME_      VARCHAR2,
   PICTURECOLLECTIONNAME_ VARCHAR2,
   URMUSE_                NUMBER,
   DELMACROSNAME_         VARCHAR2,
   NEEDDELCHILD_          NUMBER,
   LINKKIND_              NUMBER
) IS
   CNT$ NUMBER(10);
BEGIN
   /*          ,     */
   /*  ,   , ,  ,     */
   IF (
   ((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0))or(Name_ is not null))   
   THEN
     FOR tab_rec in(SELECT id FROM LINKTYPE LT WHERE 
		 (id<>ID_)	
         and(((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0)and(LT.TEMPLATECLS = TEMPLATECLS_)
         and (LT.PARENTDOCCLS = PARENTDOCCLS_) and (LT.CHILDDOCCLS = CHILDDOCCLS_))
         or((Name_ is not null)and(lt.Name=Name_))))
     LOOP
        /*             */    
        DELETE FROM LINKRECORDS WHERE LINKTYPEREF = -10;  
        DELETE FROM TB_LINKTYPE WHERE ID = -10;
        DELETE FROM DOCUMENTCLS WHERE ID = -10;
        DELETE FROM DOCUMENTTYPES WHERE ID = -10;
        INSERT INTO DOCUMENTTYPES(ID, PROGINDEX) VALUES(-10, -10);
        INSERT INTO DOCUMENTCLS(ID, DOCTYPE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM)
           VALUES(-10, -10, ' ', ' ', ' ', ' ');
        INSERT INTO LINKTYPE(ID, PARENTDOCCLS, CHILDDOCCLS, NAME) VALUES(-10, -10, -10, ' ');
        UPDATE STATE_JUMPCONTROL SET
           REFERENCEREF = -10
        WHERE
           REFERENCEREF = tab_rec.id;
        UPDATE LINKRECORDS SET
           LINKTYPEREF = -10
        WHERE
           LINKTYPEREF = tab_rec.id;
        DELETE FROM TB_LINKTYPE WHERE ID = tab_rec.Id;
     END LOOP;
   end if;
   /*      */ 
   SELECT count(*) into CNT$
      FROM LINKTYPE LT WHERE LT.ID = ID_;
   IF (CNT$ = 0)    
   THEN
      INSERT INTO LINKTYPE
       (ID,NAME,TEMPLATECLS,PARENTDOCCLS, CHILDDOCCLS, LINKCOMMENT, BLOCKPARENT,BLOCKCHILD,CANDELBLOCKPARENT,
        CANDELBLOCKCHILD, PARENTPICTURETYPE,PARENTPICTURENAME,CHILDPICTURETYPE,CHILDPICTURENAME,
        PICTURECOLLECTIONNAME,URMUSE,DELMACROSNAME,NEEDDELCHILD,LINKKIND)
      VALUES
       (ID_,NAME_,TEMPLATECLS_, PARENTDOCCLS_, CHILDDOCCLS_, LINKCOMMENT_, BLOCKPARENT_,BLOCKCHILD_,CANDELBLOCKPARENT_,
        CANDELBLOCKCHILD_, PARENTPICTURETYPE_,PARENTPICTURENAME_,CHILDPICTURETYPE_,CHILDPICTURENAME_,
        PICTURECOLLECTIONNAME_,URMUSE_,DELMACROSNAME_,NEEDDELCHILD_,LINKKIND_);
   ELSE
      UPDATE LINKTYPE SET
         NAME = NAME_,
         TEMPLATECLS = TEMPLATECLS_,
         PARENTDOCCLS = PARENTDOCCLS_,
         CHILDDOCCLS = CHILDDOCCLS_,
         LINKCOMMENT = LINKCOMMENT_,
         BLOCKPARENT = BLOCKPARENT_,
         BLOCKCHILD = BLOCKCHILD_,
         CANDELBLOCKPARENT = CANDELBLOCKPARENT_,
         CANDELBLOCKCHILD = CANDELBLOCKCHILD_,
         PARENTPICTURETYPE = PARENTPICTURETYPE_,
         PARENTPICTURENAME = PARENTPICTURENAME_,
         CHILDPICTURETYPE = CHILDPICTURETYPE_,
         CHILDPICTURENAME = CHILDPICTURENAME_,
         PICTURECOLLECTIONNAME = PICTURECOLLECTIONNAME_,
         URMUSE = URMUSE_,
         DELMACROSNAME = DELMACROSNAME_,
         NEEDDELCHILD = NEEDDELCHILD_,
         LINKKIND = LINKKIND_
      WHERE ID = ID_;
   END IF;      
   
   /*      ,      */
   UPDATE STATE_JUMPCONTROL SET
     REFERENCEREF = ID_
   WHERE
     REFERENCEREF = -10;
   UPDATE LINKRECORDS SET
      LINKTYPEREF = ID_
   WHERE
      LINKTYPEREF = -10;
   /*   */  
   DELETE FROM TB_LINKTYPE WHERE ID = -10;
   DELETE FROM DOCUMENTCLS WHERE ID = -10;
   DELETE FROM DOCUMENTTYPES WHERE ID = -10;
END;
/

--  
CALL LINKTYPE_IMPORT(30304500,'-> ',null,32400,32300,'       ',1,0,0,0,1,'',1,'','1616',0,'',1,0) ;

CALL LINKTYPE_IMPORT(30304600,'-> ',null,32401,32301,'       ',1,0,0,0,1,'',1,'','1616',0,'',1,0) ;

CALL LINKTYPE_IMPORT(24902400,'142',null,21500,490200,'   14 /   ',0,0,0,0,2,'',1,'','1616',1,'',0,1) ;

CALL LINKTYPE_IMPORT(24902500,'142',null,21400,490200,'   14 /   ',0,0,0,0,2,'',1,'','1616',1,'',0,1) ;

DROP PROCEDURE LINKTYPE_DELETE
/

DROP PROCEDURE LINKTYPE_IMPORT
/

CREATE OR REPLACE PROCEDURE STATICLINK_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATICLINKS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE STATICLINK_IMPORT(
  ID_             NUMBER,
  NAME_           VARCHAR2,
  PARENTFIELDREF_ NUMBER,
  CHILDFIELDREF_  NUMBER,
  LINKKIND_      NUMBER,
  ParentDelAction_ NUMBER
) IS
  FINDID$ NUMBER;
  FINDNEWID$ NUMBER;
  IDExists$ NUMBER;
BEGIN
  /*     ID,    CHILDFIELDREF,PARENTFIELDREF. 
   ,     ,    ID.       ID  , 
   (  )     id ,      */
  BEGIN
    SELECT
      SL.ID
    INTO FINDID$
    FROM 
      STATICLINKS SL
    WHERE (SL.CHILDFIELDREF = CHILDFIELDREF_) AND (SL.PARENTFIELDREF = PARENTFIELDREF_) AND (SL.ID <> ID_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      FINDID$ := NULL;
  END;
  
  IF (FINDID$ IS NOT NULL) THEN
  /*   ID         */

    SELECT COUNT (ID)
      INTO IDExists$
      FROM STATE_JUMPCONTROL
    WHERE (STATICLINKREF = FINDID$);

    IF (IDExists$ > 0) THEN

      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM 
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
 
      IF (FINDNEWID$ IS NULL) THEN
        INSERT INTO STATICLINKS
         (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
        VALUES
          (ID_,NAME_,CHILDFIELDREF_,PARENTFIELDREF_,1,ParentDelAction_);
      END IF;        
      UPDATE STATE_JUMPCONTROL
        SET STATICLINKREF = ID_
      WHERE (STATICLINKREF = FINDID$);

      DELETE FROM STATICLINKS  
      WHERE ID=FINDID$;
    ELSE   
      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
      IF (FINDNEWID$ IS NULL) THEN
        UPDATE STATICLINKS
        SET ID=ID_
        WHERE ID=FINDID$;
      ELSE
        DELETE FROM STATICLINKS
        WHERE ID=FINDID$;
      END IF;
    END IF;
      
  END IF; /*  id  */
  
  /*       ( ), 
   ,            CHILDFIELDREF.
   ,        1( )*/
  IF (LINKKIND_=0) THEN
    UPDATE STATICLINKS
    SET LINKKIND=1  
    WHERE (CHILDFIELDREF = CHILDFIELDREF_) AND (ID <> ID_) AND (LINKKIND=0);
  END IF;    
  
  /*        id.  ,   .  ,   */
  BEGIN
    SELECT SL.ID
      INTO FINDID$
      FROM
        STATICLINKS SL
      WHERE
        (SL.ID = ID_);
  EXCEPTION
      WHEN NO_DATA_FOUND THEN
        FINDID$ := NULL;
  END;
  IF (FINDID$ IS NOT NULL) THEN
    UPDATE STATICLINKS SET
      NAME           = NAME_,
      PARENTFIELDREF = PARENTFIELDREF_,
      CHILDFIELDREF  = CHILDFIELDREF_,
      LINKKIND       = LINKKIND_,
      ParentDelAction = ParentDelAction_
      WHERE ID = ID_;
  ELSE
    INSERT INTO STATICLINKS
     (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
    VALUES
      (ID_,NAME_,PARENTFIELDREF_,CHILDFIELDREF_,LINKKIND_,ParentDelAction_);
  END IF;      

END;
/

--  
CALL STATICLINK_IMPORT(970203200,'_.1.REGPROJECTRESULT()->.ID',971110002,20111215,0,0) ;

CALL STATICLINK_IMPORT(970203300,'_.1.REGPROJECTRESULT()->.ID',971110002,20211160,0,0) ;

CALL STATICLINK_IMPORT(970203400,'_.1.REGPROJECTRESULT()->.ID',971110002,20311168,0,0) ;

CALL STATICLINK_IMPORT(970203500,'_.1.REGPROJECTRESULT()->.ID',971110002,20411160,0,0) ;

CALL STATICLINK_IMPORT(970203600,'.1.REGPROJECTRESULT()->.ID',971110002,20511147,0,0) ;

CALL STATICLINK_IMPORT(970203700,'__.1.REGPROJECTRESULT()->.ID',971110002,20611208,0,0) ;

CALL STATICLINK_IMPORT(970203800,'_.1.REGPROJECTRESULT()->.ID',971110002,20711231,0,0) ;

CALL STATICLINK_IMPORT(970203900,'__.1.REGPROJECTRESULT()->.ID',971110002,20811232,0,0) ;

CALL STATICLINK_IMPORT(970204000,'_.1.REGPROJECTRESULT()->.ID',971110002,20911169,0,0) ;

CALL STATICLINK_IMPORT(970204100,'.1.REGPROJECTRESULT()->.ID',971110002,21011091,0,0) ;

CALL STATICLINK_IMPORT(970204200,'_.1.REGPROJECTRESULT()->.ID',971110002,21111090,0,0) ;

CALL STATICLINK_IMPORT(970204300,'_.1.REGPROJECTRESULT()->.ID',971110002,21211076,0,0) ;

CALL STATICLINK_IMPORT(970302300,'.1.SOURCEREGPROJECTRESULT()->.ID',971110002,30111227,0,0) ;

CALL STATICLINK_IMPORT(970302400,'.1.DESTREGPROJECTRESULT()->.ID',971110002,30111229,0,0) ;

CALL STATICLINK_IMPORT(970302900,'.1.DESTPAYTARGETFUNDS()->.ID',971110002,30511193,0,0) ;

CALL STATICLINK_IMPORT(970304000,'.1.SOURCEPAYTARGETFUNDS()->.ID',971110002,32211106,0,0) ;

CALL STATICLINK_IMPORT(970303500,'_.1.SOURCEPAYTARGETFUNDS(,)->.ID',971110002,31211185,0,0) ;

CALL STATICLINK_IMPORT(970303600,'_.1.DESTPAYTARGETFUNDS()->.ID',971110002,31211187,0,0) ;

CALL STATICLINK_IMPORT(970303700,'_.1.SOURCEPAYTARGETFUNDS(,)->.ID',971110002,31411180,0,0) ;

CALL STATICLINK_IMPORT(970303800,'_.1.DESTPAYTARGETFUNDS()->.ID',971110002,31411182,0,0) ;

CALL STATICLINK_IMPORT(970303900,'_.1.DESTPAYTARGETFUNDS()->.ID',971110002,31511110,0,0) ;

CALL STATICLINK_IMPORT(970302600,'.1.DESTREGPROJECTRESULTCODE()->.ID',971110002,30211239,0,0) ;

CALL STATICLINK_IMPORT(970302500,'.1.SOURCEREGPROJECTRESULT()->.ID',971110002,30211240,0,0) ;

CALL STATICLINK_IMPORT(970302700,'.1.DESTREGPROJECTRESULT()->.ID',971110002,30311126,0,0) ;

CALL STATICLINK_IMPORT(970302800,'.1.SOURCEREGPROJECTRESULT()->.ID',971110002,30411182,0,0) ;

CALL STATICLINK_IMPORT(970303000,'.1.DESTREGPROJECTRESULT()->.ID',971110002,30611213,0,0) ;

CALL STATICLINK_IMPORT(970303200,'.1.SOURCEREGPROJECTRESULT()->.ID',971110002,30811270,0,0) ;

CALL STATICLINK_IMPORT(970303100,'.1.DESTREGPROJECTRESULT()->.ID',971110002,30811272,0,0) ;

CALL STATICLINK_IMPORT(970303400,'_.1.SOURCEREGPROJECTRESULT()->.ID',971110002,31111125,0,0) ;

CALL STATICLINK_IMPORT(970303300,'_.1.DESTREGPROJECTRESULT()->.ID',971110002,31111127,0,0) ;

CALL STATICLINK_IMPORT(970304100,'.1.DESTREGPROJECTRESULT()->.ID',971110002,32311226,0,0) ;

CALL STATICLINK_IMPORT(970304200,'.1.DESTREGPROJECTRESULT()->.ID',971110002,32411271,0,0) ;

CALL STATICLINK_IMPORT(975500500,'_.1.REGPROJECTRESULT()->.ID',971110002,550111195,0,0) ;

CALL STATICLINK_IMPORT(975500600,'_.1.REGPROJECTRESULT()->.ID',971110002,550211209,0,0) ;

CALL STATICLINK_IMPORT(972500500,'.2.REGPROJECTRESULT()->.ID',971110002,250212097,0,0) ;

CALL STATICLINK_IMPORT(972500600,'.2.REGPROJECTRESULT()->.ID',971110002,250312089,0,0) ;

CALL STATICLINK_IMPORT(972500700,'.2.REGPROJECTRESULT()->.ID',971110002,250412169,0,0) ;

CALL STATICLINK_IMPORT(974400300,'.1.REGPROJECTRESULT()->.ID',971110002,440111082,0,0) ;

CALL STATICLINK_IMPORT(974400400,'.1.REGPROJECTRESULT()->.ID',971110002,440311074,0,0) ;

CALL STATICLINK_IMPORT(999905800,'.INVESTOBJECT->.ID',985410045,992910040,0,0) ;

DROP PROCEDURE STATICLINK_DELETE
/

DROP PROCEDURE STATICLINK_IMPORT
/

CREATE OR REPLACE PROCEDURE FILTERS_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATE_JUMPCONTROL
  WHERE STATE_JUMPCONTROL.FILTERCODE = ID_;
  UPDATE STATE_ACTIONJUMPS SAJ
  SET SAJ.FILTERCODE = NULL, SAJ.OPTIONS = NULL
  WHERE SAJ.FILTERCODE = ID_;
  DELETE FROM State_Filter SF
  WHERE SF.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORT(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValue_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValue,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValue_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValue = FilterValue_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORTURM(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValueURM_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValueURM,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValueURM_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValueURM = FilterValueURM_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

-- 
DROP PROCEDURE FILTERS_DELETE
/

DROP PROCEDURE FILTERS_IMPORT
/

DROP PROCEDURE FILTERS_IMPORTURM
/

CREATE OR REPLACE PROCEDURE STATUSICONS_IMPORT(
  ID_ NUMBER,
  NOTE_ VARCHAR2,
  DOCREF_ NUMBER,
  DETAILNUM_ NUMBER,
  ICONNAME_ VARCHAR2,
  ISSYSTEM_ NUMBER,
  ICONPOS_ NUMBER,
  RUNPOS_ NUMBER,
  RESERVEPOS_ NUMBER,
  ICONHINT_ VARCHAR2,
  ICONKIND_ NUMBER,
  LOCKMASK_ NUMBER,
  FORMULA_ VARCHAR2,
  ISBUDGET_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM STATUSICONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE STATUSICONS SET
      NOTE = NOTE_,
      DOCREF = DOCREF_,
      DETAILNUM = DETAILNUM_,
      ICONNAME = ICONNAME_,
      ISSYSTEM = ISSYSTEM_,
      ICONPOS = ICONPOS_,
      RUNPOS = RUNPOS_,
      RESERVEPOS = RESERVEPOS_,
      ICONHINT = ICONHINT_,
      ICONKIND = ICONKIND_,
      LOCKMASK = LOCKMASK_,
      ISBUDGET = ISBUDGET_,
      FORMULA = FORMULA_
    WHERE ID = ID_;
  ELSE
    INSERT INTO STATUSICONS
      (ISBUDGET, ID, NOTE, DOCREF, DETAILNUM, ICONNAME, ISSYSTEM, ICONPOS, RUNPOS, RESERVEPOS, ICONHINT, ICONKIND, LOCKMASK, FORMULA)
    VALUES
      (ISBUDGET_, ID_, NOTE_, DOCREF_, DETAILNUM_, ICONNAME_, ISSYSTEM_, ICONPOS_, RUNPOS_, RESERVEPOS_, ICONHINT_, ICONKIND_, LOCKMASK_, FORMULA_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE STATUSICONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM STATUSICONS SI
  WHERE SI.ID = ID_;
END;
/

--  
CALL STATUSICONS_IMPORT(47879,'',325,0,'',1,5,5,1,' ',0,0,'[32510051] = 11',1) ;

CALL STATUSICONS_IMPORT(47805,'',1824,0,'',1,1,1,0,'  ',0,0,'([182410023] = 21)  ([182410023] = 19)  ([182410023] = 24)  ([182410023] = 17)',1) ;

CALL STATUSICONS_IMPORT(47806,'',1824,0,'',1,1,1,0,'  /    ',0,0,'(([182410023] = 22) (([182410008])))  ((([182410023] = 22 )  ([182410023] = 23))  ([182410005]))  (([182410023] = 23)  ([182410008]>[182410035]))',1) ;

CALL STATUSICONS_IMPORT(47808,'',1824,0,'',1,1,1,0,'',0,0,'[182410023] = 3',1) ;

CALL STATUSICONS_IMPORT(47809,'',1824,0,'',1,1,1,0,' ',0,0,'[182410023] = 7',1) ;

CALL STATUSICONS_IMPORT(47880,'',1824,0,'',1,1,1,0,'  ',0,0,'[182410023] = 10',1) ;

CALL STATUSICONS_IMPORT(47804,'',1824,0,'',1,1,2,0,' ',0,0,'([182410023] = 22)  ([182410023] = 23)  ([182410023] = 25)  ([182410023] = 15)',1) ;

CALL STATUSICONS_IMPORT(47810,'',1824,1,'',1,1,1,0,' ',0,0,'[182411014] = 0',1) ;

CALL STATUSICONS_IMPORT(47881,'',1824,1,'',1,1,1,0,'  ',0,0,'(([182411036] = 21)  ([182411036] = 19 )  ([182411036] = 24 )  ([182411036] = 17))  ( ([182411014]))',1) ;

CALL STATUSICONS_IMPORT(47882,'',1824,1,'',1,1,1,0,'  ',0,0,'[182411036] = 10',1) ;

CALL STATUSICONS_IMPORT(47811,'',1824,1,'',1,1,2,0,' ',0,0,'[182411014] = 1',1) ;

CALL STATUSICONS_IMPORT(47812,'',1824,1,'',1,2,1,0,'',0,0,'[182411036] = 3',1) ;

CALL STATUSICONS_IMPORT(47822,' ,   ',5501,0,'',1,1,1,0,'[550110172]',0,0,'([550110172] is not null) and ([550110172] <> '''')',1) ;

CALL STATUSICONS_IMPORT(47819,' ,   ',5502,0,'',1,1,1,0,'[550210157]',0,0,'([550210157] is not null) and ([550210157] <> '''')',1) ;

DROP PROCEDURE STATUSICONS_IMPORT
/

DROP PROCEDURE STATUSICONS_DELETE
/


CREATE OR REPLACE PROCEDURE ENUMS_IMPORT(NAME_ VARCHAR2,FACIALACCCLS_ NUMBER) IS
  IDEXISTS$ NUMBER;
BEGIN
  SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMS WHERE NAME = NAME_;
  IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMS E1
      WHERE (E1.NAME = NAME_) AND (E1.ID > (SELECT MIN(E2.ID) FROM ENUMS E2 WHERE E2.NAME = NAME_));
  END IF;
  IF (IDEXISTS$ > 0) THEN
    UPDATE ENUMS SET
      FACIALACCCLS = FACIALACCCLS_,
      ISSYSTEM = 1
    WHERE NAME = NAME_;
  ELSE
    INSERT INTO ENUMS
      (NAME,FACIALACCCLS,ISSYSTEM)    
    VALUES
      (NAME_,FACIALACCCLS_,1);
  END IF;    
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_IMPORT(ENUMNAME_ VARCHAR2,NAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
  IDEXISTS$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      IDENUM$ := NULL;
  END;  
  IF (IDENUM$ IS NOT NULL) THEN
    SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMVALUES WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMVALUES EV1
      WHERE (EV1.ENUMREF = IDENUM$) AND (EV1.VAL = VAL_) AND
        (EV1.ID > (SELECT MIN(EV2.ID) FROM ENUMVALUES EV2 WHERE EV2.ENUMREF = IDENUM$ AND EV2.VAL = VAL_));
    END IF;
    IF (IDEXISTS$ > 0) THEN
      UPDATE ENUMVALUES SET
        NAME = NAME_
      WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    ELSE
      INSERT INTO ENUMVALUES
        (VAL,NAME,ENUMREF)  
      VALUES
        (VAL_,NAME_,IDENUM$);
    END IF;    
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE ENUMS_DELETE(NAME_ VARCHAR2) IS
BEGIN
  DELETE FROM ENUMS WHERE NAME = NAME_;
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_DELETE(ENUMNAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       IDENUM$ := NULL;  
  END;
  IF (IDENUM$ IS NOT NULL) THEN
    DELETE FROM ENUMVALUES WHERE (VAL = VAL_) AND (ENUMREF = IDENUM$);
  END IF;  
END;
/

-- 
CALL ENUMVALUES_DELETE('',9) ;

CALL ENUMVALUES_DELETE('',10) ;

CALL ENUMVALUES_DELETE('',11) ;

CALL ENUMVALUES_DELETE('',12) ;

CALL ENUMVALUES_DELETE('',18) ;

CALL ENUMVALUES_DELETE('',21) ;

CALL ENUMVALUES_DELETE('',22) ;

CALL ENUMVALUES_DELETE('',25) ;

CALL ENUMVALUES_DELETE('',26) ;

CALL ENUMVALUES_DELETE('',2) ;

CALL ENUMVALUES_DELETE('',3) ;

CALL ENUMVALUES_DELETE('',7) ;

CALL ENUMVALUES_DELETE('',8) ;

CALL ENUMVALUES_DELETE('',9) ;

CALL ENUMVALUES_DELETE('',16) ;

CALL ENUMVALUES_DELETE('',28) ;

CALL ENUMVALUES_DELETE('',9) ;

CALL ENUMVALUES_DELETE('',10) ;

CALL ENUMVALUES_IMPORT('',' ',1) ;

CALL ENUMVALUES_IMPORT('','',2) ;

CALL ENUMVALUES_IMPORT('','  ',3) ;

CALL ENUMVALUES_IMPORT('',' ',4) ;

CALL ENUMVALUES_IMPORT('','  ',5) ;

CALL ENUMVALUES_IMPORT('','    ',6) ;

CALL ENUMVALUES_IMPORT('','',7) ;

CALL ENUMVALUES_IMPORT('','13= ( ,     ,   ) - , , ,   , ,   ,   () ',13) ;

CALL ENUMVALUES_IMPORT('','30= ,         (  ,   )',30) ;

CALL ENUMVALUES_IMPORT('','=    ,  () ,    ',1) ;

CALL ENUMVALUES_IMPORT('','=  () ,    -               ,     ',20) ;

CALL ENUMVALUES_IMPORT('','     ',8) ;

CALL ENUMS_IMPORT('',null) ;

CALL ENUMVALUES_IMPORT('',' ',0) ;

CALL ENUMVALUES_IMPORT('',' ',1) ;

CALL ENUMVALUES_IMPORT('',' ',2) ;

CALL ENUMVALUES_IMPORT('','   ',3) ;

CALL ENUMVALUES_IMPORT('','   ',4) ;

CALL ENUMVALUES_IMPORT('','   ',5) ;

CALL ENUMVALUES_IMPORT('',' ',6) ;

CALL ENUMVALUES_IMPORT('',' ',7) ;

CALL ENUMVALUES_IMPORT('','',8) ;

CALL ENUMVALUES_IMPORT('','  ',9) ;

CALL ENUMVALUES_IMPORT('','',10) ;

CALL ENUMS_IMPORT('',null) ;

CALL ENUMVALUES_IMPORT('',' ',0) ;

CALL ENUMVALUES_IMPORT('','',10) ;

CALL ENUMVALUES_IMPORT('',' ',21) ;

CALL ENUMVALUES_IMPORT('','',22) ;

CALL ENUMVALUES_IMPORT('',' ',19) ;

CALL ENUMVALUES_IMPORT('','',23) ;

CALL ENUMVALUES_IMPORT('',' ',24) ;

CALL ENUMVALUES_IMPORT('','',25) ;

CALL ENUMVALUES_IMPORT('','',3) ;

CALL ENUMVALUES_IMPORT('',' ',7) ;

CALL ENUMVALUES_IMPORT('',' ',17) ;

CALL ENUMVALUES_IMPORT('','',15) ;

DROP PROCEDURE ENUMS_IMPORT
/

DROP PROCEDURE ENUMVALUES_IMPORT
/

DROP PROCEDURE ENUMS_DELETE
/

DROP PROCEDURE ENUMVALUES_DELETE
/

--      
INSERT INTO DFUCHANGELOG (VersionID, BEGINUPDATECODE, ENDUPDATECODE, LASTUPDATEDFU, ISBUDGET, INCLUDEDEL, INCLUDEBLOCKS, INCLUDEDOCS, SCRIPTCREATOR, SCRIPTCREATEDATE, NOTE) VALUES (3797, 141000, 142000, TO_DATE('05.01.2022 13:6:24', 'DD.MM.YYYY HH24:MI:SS'), 2, 1, ',    ,  , ,  , ,  , , ', '00.00, 01.01, 02.00, 02.01, 02.02, 02.03, 02.04, 02.05, 02.06, 02.07, 02.08, 02.09, 02.10, 02.11, 02.12, 02.13, 02.14, 02.15, 02.16, 02.17, 02.18, 03.00, 03.01, 03.02, 03.03, 03.04, 03.05, 03.06, 03.07, 03.08, 03.11, 03.12, 03.14, 03.15, 03.16, 03.22, 03.23, 03.24, 03.25, 04.01, 05.01, 07.01, 07.02, 07.03, 08.01, 08.02, 08.03, 08.04, 09.00, 09.01, 09.02, 09.03, 09.05, 09.06, 09.07, 12.01, 15.01, 16.01, 16.02, 17.01, 17.02, 18.05, 18.07, 18.09, 18.10, 18.12, 18.13, 18.14, 18.15, 18.16, 18.18, 18.19, 18.20, 18.21, 18.24, 18.25, 19.00, 19.01, 19.02, 19.03, 19.06, 22.00, 22.01, 25.01, 25.02, 25.03, 25.04, 28.01, 28.02, 30.01, 30.02, 30.03, 30.04, 30.05, 30.06, 30.10, 30.11, 36.10, 37.01, 39.01, 42.01, 42.02, 42.03, 44.01, 44.03, 47.01, 48.01, 49.01, 49.02, 49.03, 50.00, 51.01, 52.01, 53.01, 53.02, 53.03, 53.04, 53.05, 53.06, 54.01, 54.02, 55.01, 55.02, 55.03, 56.01, 96.01, 96.02, 96.03, 96.04, 97.01, 97.02, 97.09, 97.10, 97.11, 97.12, 97.13, 97.14, 97.16, 98.02, 98.03, 98.04, 98.05, 98.06, 98.08, 98.09, 98.10, 98.11, 98.12, 98.13, 98.14, 98.15, 98.16, 98.17, 98.18, 98.20, 98.21, 98.22, 98.23, 98.26, 98.27, 98.28, 98.29, 98.34, 98.35, 98.41, 98.42, 98.43, 98.44, 98.45, 98.46, 98.47, 98.48, 98.49, 98.50, 98.51, 98.52, 98.53, 98.54, 98.57, 98.58, 98.59, 98.60, 98.61, 98.62, 98.63, 98.64, 98.65, 98.67, 98.68, 98.69, 98.70, 98.71, 98.72, 98.78, 98.79, 98.80, 98.81, 98.82, 98.83, 98.84, 98.85, 98.86, 98.87, 98.88, 98.89, 98.90, 98.91, 98.92, 98.94, 98.95, 98.97, 98.98, 98.99, 99.03, 99.04, 99.05, 99.08, 99.12, 99.13, 99.14, 99.15, 99.16, 99.17, 99.18, 99.19, 99.20, 99.21, 99.22, 99.23, 99.24, 99.25, 99.26, 99.27, 99.28, 99.29, 99.30, 99.31, 99.32, 99.33, 99.34', 'ALEXEEV/alexeev', TO_DATE('05.01.2022 13:9:27', 'DD.MM.YYYY HH24:MI:SS'), '') ;

COMMIT WORK
/




-- #########################################################
-- #########################################################
-- DBVersion.sql
-- #########################################################
-- #########################################################

INSERT INTO DataBaseVersion(VERSION, Major, Minor, AComment)
  VALUES ('14.20.00', 1420, 00, ' 14.20.00')
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Index_Fix.sql
-- #########################################################
-- #########################################################

--      INDX
DECLARE
  CURSOR C$ IS
    select INDEX_NAME from DBA_INDEXES
    where OWNER = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      and TABLESPACE_NAME <> 'INDX'
      and INDEX_TYPE LIKE '%NORMAL%';
  CNT$ NUMBER(10);    
BEGIN
  BEGIN
    select count(*) into CNT$ from V$TABLESPACE
    where name = 'INDX';
  EXCEPTION
    WHEN OTHERS THEN
      CNT$ := 1;
  END;
  IF CNT$ = 1 THEN
    FOR R$ IN C$ LOOP
      EXECUTE IMMEDIATE 'ALTER INDEX ' || R$.INDEX_NAME || ' REBUILD TABLESPACE INDX';
    END LOOP;
  END IF;
END;
/

-- #########################################################
-- #########################################################
-- compile_scr.sql
-- #########################################################
-- #########################################################

--      , 
--  -  
--  DBMS_UTILITY.COMPILE_SCHEMA(user, TRUE);

DECLARE
  CURSOR C$ IS
    SELECT 'ALTER ' || object_type || ' ' || owner || '.' || object_name || ' COMPILE' AS str,
      object_type, object_name
    FROM SYS.ALL_OBJECTS
    WHERE owner = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      AND object_type IN ('VIEW', 'PROCEDURE', 'TRIGGER')
      AND status = 'INVALID'
      AND object_name not like 'BIN$%'
    ORDER BY DECODE(object_type, 'VIEW', 1, 'PROCEDURE', 2, 'TRIGGER', 3), object_name;
  S VARCHAR2(100);
BEGIN
  FOR R$ IN C$ LOOP
    BEGIN
      S := R$.object_type || ' ' || R$.object_name;
      EXECUTE IMMEDIATE R$.str;
    EXCEPTION
      WHEN OTHERS THEN 
        --DBMS_OUTPUT.PUT_LINE(S);
        RAISE_APPLICATION_ERROR(-20000, '    ' || S);
    END;
  END LOOP;
END;
/

-- #########################################################
-- #########################################################
-- dbms_stats_scr.sql
-- #########################################################
-- #########################################################

ALTER SESSION SET NLS_NUMERIC_CHARACTERS='.,'
/

BEGIN
  DBMS_STATS.GATHER_SCHEMA_STATS(
    SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA'),
    DBMS_STATS.AUTO_SAMPLE_SIZE,
    false,
    'FOR ALL COLUMNS SIZE AUTO',
    cascade=>TRUE
  );
END;
/

exit
